package App::BPOMUtils::Table;

use 5.010001;
use strict;
use utf8;
use warnings;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-11-10'; # DATE
our $DIST = 'App-BPOMUtils'; # DIST
our $VERSION = '0.014'; # VERSION

# BEGIN FRAGMENT id=meta-idn_bpom_jenis_pangan varname=meta_idn_bpom_jenis_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_jenis_pangan/meta.yaml
# src-revision: 7d9fb0684b5983e6d55c16bead9f904f783798e3 (Thu Oct 27 17:19:46 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_jenis_pangan = {
  "fields" => {
    code => {
      filterable_regex => "Yes",
      pos => 0,
      schema => ["str*", { match => "^[0-9]+\$" }],
      sortable => "Yes",
      summary => "code",
    },
    summary => {
      filterable_regex => "Yes",
      pos => 1,
      schema => ["str*"],
      sortable => "Yes",
      summary => "Summary",
      unique => "No",
    },
  },
  "pk" => "code",
  "summary" => "Food types in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Jenis pangan di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_jenis_pangan

# BEGIN FRAGMENT id=data-idn_bpom_jenis_pangan varname=data_idn_bpom_jenis_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_jenis_pangan/data.csv
# src-revision: 7d9fb0684b5983e6d55c16bead9f904f783798e3 (Thu Oct 27 17:19:46 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_jenis_pangan = [
  ["001", "Susu Pasteurisasi"],
  ["002", "Susu UHT"],
  ["003", "Susu Steril"],
  ["004", "Susu Skim"],
  ["005", "Susu Lemak Nabati"],
  ["006", "Buttermilk"],
  ["007", "Dadih"],
  ["008", "Minuman Susu"],
  ["009", "Minuman dengan/ mengandung Susu"],
  ["010", "Minuman Susu Fermentasi"],
  ["011", "Minuman Yoghurt"],
  ["012", "Lassi"],
  ["013", "Susu Diasamkan"],
  ["014", "Susu Fermentasi"],
  ["015", "Yogurt"],
  ["016", "Susu yang Digumpalkan dengan Enzim Renin"],
  ["017", "Susu Evaporasi"],
  ["018", "Susu Kental Manis"],
  ["019", "Susu Skim Kental Manis"],
  ["020", "Krim Kental Manis"],
  ["021", "Krimer Kental Manis"],
  ["022", "Khoa"],
  ["023", "Krimer Minuman (Bukan Susu)"],
  ["024", "Krim"],
  ["025", "Whipped Cream"],
  ["026", "Krim yang digumpalkan"],
  ["027", "Krim Nabati (Krim Analog)"],
  ["028", "Susu Bubuk Berlemak (Full Cream)"],
  ["029", "Susu Skim Bubuk"],
  ["030", "Krim Bubuk"],
  ["031", "Susu dan Krim Bubuk Analog"],
  ["032", "Susu Bubuk Lemak/Minyak Nabati"],
  ["033", "Buttermilk Bubuk"],
  ["034", "Keju Analog"],
  ["035", "Keju Tanpa Pemeraman"],
  ["035", "Keju tanpa Pemeraman (Keju Mentah)"],
  ["036", "Keju Peram"],
  ["037", "Kulit Keju Peram"],
  ["038", "Keju Bubuk"],
  ["039", "Keju Whey"],
  ["040", "Keju Olahan"],
  ["041", "Es Krim"],
  ["042", "Es Susu / Es Mengandung Susu"],
  ["043", "Makanan Pencuci Mulut Berbahan Dasar Susu"],
  ["044", "Puding (Berbahan dasar susu atau bahan lainnya)"],
  ["045", "Whey"],
  ["046", "Whey Bubuk"],
  ["047", "Kolostrum"],
  ["048", "Bahan untuk Es Krim / Bahan untuk Es Susu"],
  ["049", "Bahan untuk Puding (Bubuk)"],
  ["050", "Susu Bubuk"],
  ["078", "Ghee"],
  ["079", "Virgin Oil"],
  ["080", "Cold Pressed Oils"],
  ["081", "Minyak Goreng (Frying Oil atau frying fat)"],
  ["082", "Minyak Masak atau Minyak Sayur (Cooking Oil)"],
  ["083", "Minyak Salad"],
  ["084", "Minyak serbuk"],
  ["085", "Vanaspati atau Minyak Samin (Vegetable Ghee)"],
  ["086", "Lemak Reroti (Shortening)"],
  ["087", "Pengganti Minyak mentega (Butter Oil Substitute)"],
  [
    "088",
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO)",
  ],
  [
    "089",
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein)",
  ],
  [
    "090",
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm stearin)",
  ],
  [
    "091",
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil)",
  ],
  [
    "092",
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/Refined Bleached Deodorized Groundnut Oil)",
  ],
  ["093", "Minyak Jagung (Refined Bleached Deodorized Corn Oil)"],
  [
    "094",
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Limbang Oil)",
  ],
  [
    "095",
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil)",
  ],
  ["096", "Minyak Wijen (Sesame Oil)"],
  [
    "097",
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil)",
  ],
  ["098", "Minyak Safflower"],
  ["099", "Minyak Biji Bunga Matahari"],
  [
    100,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached Deodorized Rice Brand Oil)",
  ],
  [
    101,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil)",
  ],
  [
    102,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil)",
  ],
  [
    103,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil)",
  ],
  [104, "Lemak Hewani"],
  [105, "Minyak Ikan"],
  [106, "Mentega"],
  [107, "Margarin"],
  [
    108,
    "Campuran Margarin dan Mentega (Blends of Butter and Margarine)",
  ],
  [109, "Emulsi yang Mengandung Lemak Kurang Dari 80%"],
  [110, "Emulsi lemak dan makanan pencuci mulut berbasis lemak"],
  [111, "Es krim non dairy"],
  [112, "Minyak Nabati Lainnya"],
  [142, "Es selain es krim dan es susu"],
  [
    143,
    "Sediaan Cair atau Serbuk yang akan Dikonsumsi dalam Keadaan Beku",
  ],
  [174, "Manisan Buah"],
  [174, "Manisan Gula"],
  [175, "Buah Kering"],
  [176, "Asinan Buah"],
  [177, "Buah dalam ...... (medianya) kemasan"],
  [178, "Jem (Selai), Jeli dan Marmalad"],
  [179, "Sambal buah"],
  [180, "Bubur Buah, Puree Buah, Pasta Buah"],
  [181, "Saus Buah/Topping buah"],
  [181, "Saus Buah/Topping Buah"],
  [182, "Hasil olah kelapa"],
  [183, "Konsentrat Asam Jawa/Tamarin"],
  [184, "Buah Bubuk"],
  [185, "Makanan Pencuci Mulut"],
  [186, "Cincau"],
  [187, "Acar buah/ Produk Fermentasi Buah"],
  [188, "Lempok Buah"],
  [189, "Geplak"],
  [190, "Sayur beku"],
  [191, "Sayur Kering"],
  [192, "Rumput laut Kering"],
  [193, "Biji-Bjian / Kacang-Kacangan Kering"],
  [194, "Emping"],
  [195, "Sayur bubuk"],
  [196, "Sayur/ Jamur/Buah dalam Media Minyak"],
  [197, "Sayur Asin"],
  [198, "Acar Sayur / Produk Fermentasi Sayur"],
  [199, "Sayur dan Kacang dalam Kemasan"],
  [200, "Pasta sayur, bubur sayur, puree sayur, saus sayur"],
  [201, "Pasta Biji-bijian"],
  [202, "Produk sayur lain"],
  [202, "Produk Sayur Lain"],
  [203, "Olahan Buah Lainnya"],
  [233, "Kakao Bubuk"],
  [234, "Kakao Nib"],
  [235, "Massa Kakao dan Cairan Kental (Liquor) Cokelat"],
  [236, "Keik Kakao (Cococa Press Cake)"],
  [237, "Minuman Kakao/Cokelat"],
  [238, "Cokelat Instan"],
  [239, "Pasta coklat"],
  [240, "Cokelat"],
  [241, "Permen Cokelat/Permen Isi Cokelat"],
  [242, "Lemak kakao (Cocoa Butter)"],
  [243, "Produk Cokelat Analog/ Pengganti Cokelat"],
  [244, "Kembang Gula/permen Keras"],
  [245, "Kembang Gula/Permen Lunak"],
  [246, "Nougat, Marzipan"],
  [247, "Kembang Gula/Permen Karet"],
  [248, "Dekorasi, Topping (Non-Buah) dan Saus Manis"],
  [249, "Kakao Bubuk Lainnya"],
  [279, "Beras Diperkaya"],
  [281, "Tepung Beras (Beras, Beras Ketan)"],
  [282, "Tepung Jagung"],
  [283, "Tepung Kacang-Kacangan"],
  [284, "Tepung Kedelai"],
  [285, "Tepung Gandum / Pati Gandum"],
  [286, "Tepung Jewawut (Pearl Millet Flour)"],
  [287, "Tepung sorgum"],
  [288, "Tepung Terigu"],
  [289, "Tepung Gluten Terigu (Wheat Gluten Powder)"],
  [290, "Tepung Kulit Ari (Fine Bran)"],
  [291, "Tepung / Pati"],
  [293, "Dekstrin"],
  [294, "Tepung Gaplek"],
  [295, "Tepung Aren"],
  [296, "Pati Garut"],
  [297, "Pati Jagung atau Maizena"],
  [298, "Pati Sagu"],
  [299, "Tepung Hunkwee/Pati Kacang hijau"],
  [300, "Tapioka / Pati Singkong/Gari"],
  [301, "Pati Termodifikasi"],
  [304, "Nasi Jagung"],
  [305, "Sereal Siap Saji Termasuk Sereal Sarapan"],
  [306, "Tiwul"],
  [307, "Degermed Maize (Corn) Grits"],
  [308, "Mi Basah"],
  [309, "Kulit Pangsit"],
  [310, "Kuetiauw"],
  [311, "Pasta"],
  [312, "Sohun"],
  [313, "Bihun"],
  [314, "Mi Kering"],
  [315, "Mi instan"],
  [316, "Nasi Instan"],
  [
    317,
    "Makanan Pencuci Mulut Berbasis Serealia dan Pati (Misalnya Puding Nasi, Puding Tapioka)",
  ],
  [318, "Tepung Bumbu"],
  [319, "Kue berbahan dasar beras"],
  [320, "Minuman/Sari Kedelai"],
  [321, "Kembang Tahu"],
  [321, "KembangTahu"],
  [322, "Tahu"],
  [323, "Produk Kedelai Fermentasi"],
  [325, "Bubur Instan (Rasa Ayam, dll)"],
  [
    326,
    "Biji-Bijian dan Kacang-Kacangan (Utuh, Patahan, atau Serpihan)",
  ],
  [327, "Kerupuk Mentah"],
  [328, "Produk Protein Kedelai Lainnya"],
  [329, "Olahan dari Tepung/Pati"],
  [354, "Roti"],
  [355, "Krekers"],
  [356, "Biskuit"],
  [357, "Tepung Roti"],
  [358, "Roti Kukus"],
  [359, "Premiks untuk Bakeri /Untuk Stufing"],
  [360, "Keik (Cake)"],
  [361, "Wafer"],
  [362, "Kukis"],
  [363, "Kue (Contoh: bika ambon, cucur, cakue, dll)"],
  [
    395,
    "Daging Sapi Olahan / Daging Kerbau Olahan/Daging Rusa Olahan",
  ],
  [396, "Daging Babi Olahan"],
  [397, "Daging Ayam Olahan"],
  [
    398,
    "Produk Daging Campuran Olahan (terdiri dari 2 macam atau lebih)",
  ],
  [399, "Daging lain olahan"],
  [400, "Daging Analog"],
  [402, "Daging Kambing atau Daging Olahan"],
  [402, "Daging Kambing atau Domba Olahan"],
  [402, "Daging Kambing atau Domnba Olahan"],
  [432, "Ikan Olahan"],
  [435, "Udang Olahan"],
  [436, "Rajungan/Kepiting Olahan"],
  [437, "Produk olahan ikan lain"],
  [438, "Telur Ikan Olahan"],
  [439, "Ikan dalam kaleng"],
  [441, "Produk Ikan Olahan Lain dalam Kaleng"],
  [474, "Produk Telur Olahan"],
  [475, "Tepung telur"],
  [476, "Telur awetan"],
  [477, "Makanan Pencuci Mulut Berbahan Dasar Telur"],
  [478, "Ikan dan Olahan Analog"],
  [508, "Dekstrosa"],
  [509, "Fruktosa"],
  [510, "Tepung Gula atau Gula Halus"],
  [511, "Gula Merah"],
  [512, "Sirup Glukosa"],
  [513, "Glukosa"],
  [514, "Gula Kristal Putih atau Gula Pasir"],
  [515, "Laktosa"],
  [516, "Sirup Fruktosa (High Fructose Syrup/HFS)"],
  [517, "Tetes Tebu atau Molases"],
  [518, "Gula Invert"],
  [520, "Sirup lain"],
  [521, "Madu"],
  [522, "Sediaan Pemanis (Table Top)"],
  [524, "Gula Batu"],
  [553, "Garam"],
  [555, "Pengganti Garam"],
  [556, "Bumbu dan kondimen"],
  [556, "Bumbu dan Kondimen"],
  [557, "Cuka"],
  [558, "Arak masak (Angciu)"],
  [559, "Sup"],
  [560, "Sari Pati Ayam"],
  [561, "Kaldu"],
  [562, "Mayonais/Salad Dressing"],
  [563, "Sambal"],
  [564, "Saus Bumbu"],
  [565, "Saus Tomat"],
  [566, "Kecap selain kedelai"],
  [567, "Bubuk Untuk Saus dan Gravies"],
  [568, "Produk Oles Untuk Salad"],
  [569, "Ragi"],
  [570, "Pasta kedelai fermentasi"],
  [571, "Saus kedelai"],
  [572, "Kecap (Berbasis kedelai)"],
  [573, "Produk protein"],
  [574, "Mustard"],
  [596, "Ragi"],
  [604, "Formula bayi"],
  [605, "Formula Lanjutan"],
  [606, "Formula Pertumbuhan"],
  [610, "Makanan Diet Diabetes"],
  [
    613,
    "Makanan formula sebagai makanan diet kontrol berat badan",
  ],
  [615, "Pangan Ibu Hamil dan Pangan Ibu Menyusui"],
  [651, "Air mineral alami"],
  [652, "Air Minum dalam Kemasan (AMDK)"],
  [653, "Air Bermineral"],
  [654, "Air Soda"],
  [655, "Air minum Beroksigen"],
  [657, "Sari Buah"],
  [658, "Sari Sayur"],
  [659, "Sari buah dan sari sayuran"],
  [660, "Konsentrat Sari Buah"],
  [661, "Konsentrat Sari Sayur"],
  [662, "Konsentrat Sari Buah dan Sari Sayuran"],
  [663, "Nektar Buah/Sayur"],
  [664, "Konsentrat Nektar Buah/Sayur"],
  [665, "Minuman Berperisa Berkarbonat"],
  [666, "Minuman Berperisa tidak Berkarbonat"],
  [667, "Minuman Elektrolit Berkarbonat"],
  [668, "Minuman Elektrolit Tidak Berkarbonat"],
  [669, "Minuman Serbuk Berkarbonat"],
  [670, "Minuman Serbuk Tidak Berkarbonat"],
  [671, "Minuman Sari Buah"],
  [672, "Sirup Berperisa"],
  [673, "Sirup buah"],
  [674, "Sirup coklat, sirup karamel, sirup kopi"],
  [675, "Squash"],
  [
    677,
    "Minuman Botanikal/ Minuman lain-lain (asam jawa, nira, dll)",
  ],
  [678, "Minuman Nata De Coco / Jeli"],
  [679, "Teh Fermentasi"],
  [680, "Teh Olong atau Teh semi Fermentasi"],
  [681, "Teh tanpa Fermentasi"],
  [682, "Teh wangi"],
  [683, "Minuman Teh"],
  [684, "Teh instan"],
  [685, "Konsentrat teh"],
  [686, "Biji kopi"],
  [687, "Kopi"],
  [688, "Minuman Kopi (Siap Minum)"],
  [689, "Konsentrat kopi"],
  [690, "Minuman Botanikal"],
  [691, "Minuman sari kacang hijau"],
  [702, "Minuman Tradisional"],
  [703, "Minuman Konsentrat"],
  [704, "Sirup Teh"],
  [705, "Minuman Biji-Bijian dan Sereal"],
  [728, "Keripik"],
  [729, "Makanan ringan simulasi"],
  [730, "Makanan ringan lain"],
  [731, "Pilus"],
  [732, "Berondong"],
  [733, "Marning"],
  [734, "Jipang"],
  [735, "Kerupuk"],
  [736, "Rengginang / Ekivalen / Batiah"],
  [737, "Makanan ringan Ekstrudat"],
  [738, "Makanan ringan kacang"],
  [739, "Kemplang"],
  [740, "Getas"],
  [758, "Pangan Siap Saji (Terkemas)"],
  [758, "Pangan Siap Saji Terkemas"],
  [759, "Sup Sayuran"],
  [760, "Sup Jamur"],
  [761, "Pangsit Isi (Sayuran, Daging, dll)"],
  [762, "Jajanan Pasar"],
  [763, "Kebab/Roti Isi Daging/Tortilla Isi Daging"],
  [764, "Pasta Instan"],
  [765, "Kombinasi Pangan Olahan"],
  [766, "Olahan Gluten"],
  [767, "Kolak"],
  [789, "Bahan Tambahan Pangan"],
];
# END FRAGMENT id=data-idn_bpom_jenis_pangan

# BEGIN FRAGMENT id=meta-idn_bpom_kategori_pangan varname=meta_idn_bpom_kategori_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_kategori_pangan/meta.yaml
# src-revision: 7d9fb0684b5983e6d55c16bead9f904f783798e3 (Thu Oct 27 17:19:46 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_kategori_pangan = {
  "fields" => {
    code    => {
                 filterable_regex => "Yes",
                 pos => 0,
                 schema => ["str*", { match => "^[0-9ABC]+\$" }],
                 sortable => "Yes",
                 summary => "Code",
                 unique => "Yes",
               },
    name    => {
                 filterable_regex => "Yes",
                 pos => 1,
                 schema => "str*",
                 sortable => "Yes",
                 summary => "Name",
                 unique => "Yes",
               },
    status  => {
                 filterable_regex => "Yes",
                 pos => 3,
                 schema => ["str*"],
                 sortable => "Yes",
                 summary => "Status",
                 unique => "No",
               },
    summary => {
                 filterable_regex => "Yes",
                 pos => 2,
                 schema => ["str*"],
                 sortable => "Yes",
                 summary => "Summary",
                 unique => "No",
               },
  },
  "pk" => "code",
  "summary" => "Food categories in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Kategori pangan di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_kategori_pangan

# BEGIN FRAGMENT id=data-idn_bpom_kategori_pangan varname=data_idn_bpom_kategori_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_kategori_pangan/data.csv
# src-revision: 7d9fb0684b5983e6d55c16bead9f904f783798e3 (Thu Oct 27 17:19:46 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_kategori_pangan = [
  [
    "0101010102",
    "Susu Segar",
    "Susu segar adalah cairan dari ambing sapi, kerbau, kuda, kambing, domba, dan hewan ternak penghasil susu lainnya yang sehat yang diperoleh dengan cara pemerahan yang benar, yang kandungan alaminya tidak dikurangi atau ditambah sesuatu apapun, belum mendapat perlakuan apapun kecuali pendinginan.<br> Karakteristik dasar Susu Sapi Segar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 7,8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%<br> Karakteristik dasar Susu Kuda Segar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 1,3%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2%",
    "Aktif",
  ],
  [
    "0101010103",
    "Susu Pasteurisasi",
    "Susu pasteurisasi adalah produk susu cair yang diperoleh dari susu segar atau susu rekonstitusi atau susu rekombinasi yang dipanaskan dengan tujuan untuk membunuh semua mikroba pathogen.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 7,8%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010104",
    "Susu UHT (Ultra High Temperature)",
    "Susu UHT adalah produk susu cair yang diperoleh dari susu segar atau susu rekonstitusi atau susu rekombinasi yang disterilkan pada suhu tidak kurang dari 135\xC2\xB0C dengan F0 tidak kurang dari 3 menit dan dikemas segera dalam kemasan yang steril secara aseptis.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 7,8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010105",
    "Susu Steril",
    "Susu steril adalah produk susu cair yang diperoleh dari susu segar atau susu rekonstitusi atau susu rekombinasi yang dipanaskan pada suhu tidak kurang dari 1000C selama waktu yang cukup untuk mencapai keadaan steril komersial (dengan F0 tidak kurang dari 3 menit) dan dikemas secara kedap (hermetis).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 7,8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010106",
    "Susu Skim",
    "Susu skim adalah produk susu cair yang sebagian besar lemaknya telah dihilangkan, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak lebih dari 0,5%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010107",
    "Susu Skim Sebagian (Pasteurisasi)",
    "Susu skim sebagian adalah produk susu cair yang sebagian lemaknya telah dihilangkan, dan dipasteurisasi.<br> Karakteristik dasar:<br> - Kadar lemak susu 0,5% sampai kurang dari 3%<br> - Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010110",
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk)",
    "Susu lemak nabati / susu minyak nabati (filled milk) adalah produk susu cair yang diperoleh dengan cara menggantikan sebagian atau seluruh lemak susu dengan minyak atau lemak nabati, atau campurannya dalam jumlah yang setara. Produk ini mempunyai komposisi umum, penampakan, dan penggunaan yang mirip dengan susu segar.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak tidak kurang dari 3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 7,8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010113",
    "Susu UHT (Ultra High Temperature) Berperisa",
    "&nbsp;",
    "Tidak Aktif",
  ],
  ["0101010114", "Susu Kuda", "&nbsp;", "Tidak Aktif"],
  [
    "0101010115",
    "Susu Skim Sebagian (Steril atau UHT)",
    "Susu skim sebagian adalah produk susu cair yang sebagian lemaknya telah dihilangkan, dan disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> - Kadar lemak susu 0,5% sampai kurang dari 3%<br> - Kadar protein tidak kurang dari 2,8%",
    "Tidak Aktif",
  ],
  [
    "0101010201",
    "Buttermilk (Plain)",
    "Buttermilk (plain) adalah produk susu yang diperoleh dari proses penggumpalan krim yang telah dipisahkan dari susu segar atau susu yang telah dipanaskan, dengan atau tanpa penambahan bakteri asam laktat pada susu segar atau susu yang telah dipanaskan. Produk ini dapat dipasteurisasi atau disterilisasi.",
    "Tidak Aktif",
  ],
  [
    "0101010202",
    "Dadih",
    "Dadih adalah produk susu yang diperoleh dari proses fermentasi spontan bakteri asam laktat pada susu kerbau.",
    "Tidak Aktif",
  ],
  [
    "010101A0",
    "Susu Lemak Penuh (Full Cream) Plain (Cair)",
    "Susu Lemak Penuh (Full Cream) adalah produk susu cair yang diperoleh dari susu segar yang tidak dikurangi lemaknya, dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature). Nama jenis produk ini dapat diikuti dengan prosesnya, contohnya susu lemak penuh (full cream) pasteurisasi, susu pasteurisasi.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 7,8%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%",
    "Aktif",
  ],
  [
    "010101A1",
    "Susu Skim Plain (Cair)",
    "Susu skim adalah produk susu cair yang sebagian besar lemaknya telah dihilangkan, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak lebih dari 0,5%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "010101A2",
    "Susu Skim Sebagian Plain (Cair)",
    "Susu skim sebagian adalah produk susu cair yang sebagian lemaknya telah dihilangkan, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 0,6% sampai kurang dari 2,9%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%",
    "Aktif",
  ],
  [
    "01010201",
    "Minuman Susu Berperisa",
    "Minuman susu berperisa adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi yang diberi perisa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi serta dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    "01010202",
    "Minuman Mengandung Susu (Cair) (Plain)",
    "Minuman mengandung susu adalah minuman yang dibuat dengan menggunakan susu segar, susu rekonstitusi atau susu rekombinasi, dapat ditambahkan bahan pangan lain dan disterilisasi atau dipasteurisasi.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 0,3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 0,78%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 0,27%",
    "Aktif",
  ],
  [
    "01010203",
    "Minuman Susu Fermentasi (Plain)",
    "Minuman susu fermentasi adalah minuman berbahan dasar susu fermentasi, dapat ditambahkan bahan pangan lain dengan atau tanpa proses pemanasan. Penamaan jenis produk berdasarkan bahan dasar yang digunakan, misalnya minuman yogurt, minuman kefir, minuman kumys.<br> Karakteristik Dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 2,6%;<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 0,92%",
    "Aktif",
  ],
  [
    "01010204",
    "Minuman Yogurt (Plain dan Berperisa)",
    "Minuman yogurt adalah minuman berbahan dasar yogurt dengan atau tanpa penambahan perisa atau rasa, dapat ditambahkan gula, bahan pangan lain dengan atau tanpa proses pemanasan, serta dikemas secara kedap (hermetis).<br> Karakteristik Dasar:<br> Total padatan susu bukan lemak tidak kurang dari 3%",
    "Tidak Aktif",
  ],
  [
    "01010205",
    "Lassi (Plain)",
    "Lassi adalah minuman yang diperoleh dari susu yang difermentasi dengan bakteri asam laktat sampai terbentuk curd (gumpalan protein susu) kemudian dikocok.",
    "Aktif",
  ],
  [
    "01010206",
    "Minuman Mengandung Susu Steril",
    "Minuman mengandung susu (steril)<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 0,3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 1,2%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 1%",
    "Tidak Aktif",
  ],
  [
    "01010207",
    "Minuman Susu Steril (Plain)",
    "Minuman Susu Steril (Plain) adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi, dapat ditambahkan bahan pangan lain dan disterilisasi<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 1,2% sampai kurang dari 2%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4,4%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 1%.",
    "Aktif",
  ],
  [
    "01010208",
    "Minuman Susu Pasteurisasi (Plain)",
    "Minuman Susu Pasteurisasi (Plain) adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi, dapat ditambahkan bahan pangan lain dan dipasteurisasi.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 1,2% sampai kurang dari 2%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4,4%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 1%.",
    "Aktif",
  ],
  [
    "01010209",
    "Minuman Susu Evaporasi (Plain dan Berperisa)",
    "Minuman Susu Evaporasi (Plain dan Berperisa) adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan atau tanpa tambahan perisa atau rasa, dapat ditambahkan gula, bahan pangan lain dan dievaporasi serta dikemas secara kedap (hermetis).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 1,2% sampai kurang dari 2%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 4,4%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 1%",
    "Tidak Aktif",
  ],
  [
    "01010210",
    "Minuman Mengandung Susu (Serbuk)",
    "Minuman mengandung susu bentuk serbuk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 0,3%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 1,2%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 1%",
    "Tidak Aktif",
  ],
  [
    "01010211",
    "Susu (Rasa) Steril / UHT",
    "Susu (rasa) steril / UHT adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan penambahan bahan/ekstrak alami yang menimbulkan rasa, dengan atau tanpa penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi pada suhu tidak kurang dari 135\xC2\xB0C dengan F0 tidak kurang dari 3 menit dan dikemas segera dalam kemasan yang steril secara aseptis. Contoh susu cokelat. susu stroberi.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Kadar bahan/ekstrak alami tidak kurang dari 0.5%",
    "Tidak Aktif",
  ],
  [
    "01010212",
    "Susu (Rasa) Pasteurisasi",
    "Susu (rasa) pasteurisasi adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan penambahan bahan/ekstrak alami yang menimbulkan rasa, dengan atau tanpa penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan dipasteurisasi serta dikemas secara kedap (hermetis). Contoh susu cokelat, susu stroberi.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Kadar bahan/ekstrak alami tidak kurang dari 0.5%",
    "Tidak Aktif",
  ],
  [
    "01010213",
    "Susu Berperisa / Susu Rasa Steril atau UHT",
    "Susu berperisa / susu rasa steril atau UHT adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi pada suhu tidak kurang dari 100\xC2\xB0C selama waktu yang cukup untuk mencapai keadaan steril komersial (dengan F0 tidak kurang dari 3 menit) dan dikemas secara kedap (hermetis). Contoh susu rasa cokelat/susu berperisa cokelat, susu rasa stroberi/susu berperisa stroberi.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2%",
    "Tidak Aktif",
  ],
  [
    "01010214",
    "Susu Berperisa / Susu Rasa Pasteurisasi",
    "Susu berperisa / susu rasa pasteurisasi adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan dipasteurisasi serta dikemas secara kedap (hermetis). Contoh susu rasa cokelat/susu berperisa cokelat, susu rasa stroberi/susu berperisa stroberi.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 2%<br> \xE2\x{20AC}\xA2 Total padatan susu bukan lemak tidak kurang dari 8%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2%",
    "Tidak Aktif",
  ],
  [
    "01010215",
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk",
    "Susu Lemak Penuh Rekombinasi (Recombined Full Cream Milk) adalah produk susu yang tidak dikurangi lemaknya yang dihasilkan dari penggabungan lemak susu dan padatan susu bukan-lemak dengan atau tanpa penambahan air untuk mendapatkan komposisi susu yang sesuai, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 7,8%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010216",
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk",
    "Susu Lemak Penuh Rekonstitusi (Reconstituted Full Cream Milk) adalah produk susu yang tidak dikurangi lemaknya yang dihasilkan dari penambahan air pada susu bubuk kering atau produk susu evaporasi untuk mengembalikan rasio air terhadap padatan yang sesuai, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 7,8%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010217",
    "Susu Skim Rekonstitusi Plain (Cair)",
    "Susu skim rekonstitusi adalah produk susu cair hasil penambahan air pada susu bubuk skim atau susu skim evaporasi, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak lebih dari 0,5%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010218",
    "Susu Skim Sebagian Rekonstitusi Plain (Cair)",
    "Susu skim sebagian rekonstitusi adalah produk susu cair hasil penambahan air pada susu bubuk skim sebagian atau susu skim sebagian evaporasi untuk mendapatkan komposisi susu skim sebagian yang sesuai, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 0,6% sampai kurang dari 2,9%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010219",
    "Susu Skim Sebagian Rekombinasi Plain (Cair)",
    "Susu skim sebagian rekombinasi adalah produk susu cair yang dihasilkan dari penggabungan lemak susu dan padatan susu bukan-lemak dengan atau tanpa penambahan air untuk mendapatkan komposisi susu skim sebagian yang sesuai, dan dipasteurisasi atau disterilisasi atau diproses secara UHT (Ultra High Temperature).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu 0,6% sampai kurang dari 2,9%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010220",
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk)",
    "Susu lemak nabati/susu minyak nabati (filled milk) adalah produk susu cair yang diperoleh dengan cara menggantikan sebagian atau seluruh lemak susu dengan minyak atau lemak nabati, atau campurannya dalam jumlah yang setara. Produk ini mempunyai komposisi umum, penampakan, dan penggunaan yang mirip dengan susu segar.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 3%;<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 7,8%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 2,7%.",
    "Aktif",
  ],
  [
    "01010301",
    "Buttermilk cair",
    "Buttermilk cair adalah cairan yang hampir bebas lemak susu yang diperoleh dari proses pembuatan mentega (yaitu mengocok susu dan krim fermentasi atau tidak difermentasi). Buttermilk cair juga diproduksi dengan fermentasi susu skim cair, baik dengan pengasaman spontan melalui aktivitas bakteri asam laktat atau bakteri pembentuk aroma, atau dengan inokulasi susu yang dipanaskan dengan kultur bakteri murni (buttermilk terfermentasi).<br> Buttermilk cair dapat dipasteurisasi atau disterilisasi.",
    "Aktif",
  ],
  [
    "01010401",
    "Susu (Rasa) Lemak Penuh (Full Cream Milk)",
    "Susu (rasa) Lemak Penuh (Full Cream Milk) adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi yang tidak dikurangi lemaknya, dengan penambahan bahan/ekstrak alami yang menimbulkan rasa, dengan atau tanpa penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi. Contoh susu cokelat, susu stroberi.",
    "Aktif",
  ],
  [
    "01010402",
    "Susu Berperisa/Susu Rasa",
    "Susu berperisa/susu rasa adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan penambahan perisa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi. Contoh susu rasa cokelat/susu berperisa cokelat, susu rasa stroberi/susu berperisa stroberi.",
    "Aktif",
  ],
  [
    "01010403",
    "Minuman Susu Berperisa/Rasa",
    "Minuman susu adalah minuman berbahan dasar susu segar, susu rekonstitusi atau susu rekombinasi dengan bahan tambahan pangan perisa atau rasa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi.",
    "Aktif",
  ],
  [
    "01010404",
    "Minuman Mengandung Susu Berperisa/Rasa",
    "Minuman mengandung susu adalah minuman yang dibuat dengan menggunakan susu segar, susu rekonstitusi atau susu rekombinasi dengan bahan tambahan pangan perisa atau rasa, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi.<br>",
    "Aktif",
  ],
  [
    "01010405",
    "Minuman Susu Fermentasi Berperisa/Rasa",
    "Minuman susu fermentasi adalah minuman berbahan dasar susu fermentasi dengan penambahan perisa atau rasa, dapat ditambahkan gula, bahan pangan lain dengan atau tanpa proses pemanasan. Penamaan jenis produk berdasarkan bahan dasar yang digunakan, misalnya minuman yogurt, minuman kefir, minuman kumys.<br>",
    "Aktif",
  ],
  [
    "01010406",
    "Lassi (Rasa/Berperisa)",
    "Lassi adalah minuman yang diperoleh dari susu yang difermentasi dengan bakteri asam laktat sampai terbentuk curd (gumpalan protein susu) kemudian dikocok dan dicampur dengan gula dan/atau pemanis.",
    "Aktif",
  ],
  [
    "01010407",
    "Minuman Berbasis Whey (Berperisa/Rasa)",
    "Minuman berbasis whey adalah minuman berbahan dasar whey, dapat ditambahkan gula, bahan pangan lain dan disterilisasi atau dipasteurisasi. Contoh minuman berbasis whey rasa cokelat.",
    "Aktif",
  ],
  [
    "01010408",
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll)",
    "Susu bubuk (rasa) adalah susu bubuk yang ditambah dengan bahan pangan berupa bubuk kakao, ekstrak stroberi, ekstrak vanilla dan atau bahan lain yang sesuai, dapat ditambah gula dan atau perisa. Nama jenis produk ini susu bubuk cokelat, susu bubuk stroberi, susu bubuk vanilla, susu bubuk madu, dan lain-lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 26%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar gula dihitung sebagai sakarosa tidak lebih dari 55%<br> <br>",
    "Aktif",
  ],
  [
    "01010409",
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll)",
    "Susu bubuk skim (rasa) adalah susu bubuk skim yang ditambah dengan bahan pangan berupa bubuk kakao, ekstrak stroberi, ekstrak vanilla dan atau bahan lain yang sesuai, dapat ditambah gula dan atau perisa. Nama jenis produk ini susu bubuk skim cokelat, susu bubuk skim stroberi, susu bubuk skim vanilla, susu bubuk skim madu, dan lain-lain.",
    "Aktif",
  ],
  [
    "01010410",
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll)",
    "Susu bubuk skim sebagian (rasa) adalah susu bubuk skim sebagian yang ditambah dengan bahan pangan berupa bubuk kakao, ekstrak stroberi, ekstrak vanilla dan atau bahan lain yang sesuai, dapat<br> ditambah gula dan atau perisa. Nama jenis produk ini susu bubuk skim sebagian cokelat, susu bubuk skim sebagian stroberi, susu bubuk skim sebagian vanilla, susu bubuk skim sebagian madu, dan<br> lain-lain.<br>",
    "Aktif",
  ],
  [
    "01010411",
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll)",
    "Susu bubuk rasa/berperisa adalah susu bubuk yang ditambah dengan bahan tambahan pangan perisa atau rasa, dan dapat ditambah gula. Nama jenis produk ini susu bubuk rasa cokelat, susu bubuk rasa stroberi, susu bubuk rasa vanilla, susu bubuk rasa madu, dan lain-lain.<br>",
    "Aktif",
  ],
  [
    "01010412",
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll)",
    "Susu bubuk skim rasa/berperisa adalah susu bubuk skim yang ditambah dengan bahan tambahan pangan perisa atau rasa, dan dapat ditambah gula. Nama jenis produk ini susu bubuk skim rasa cokelat, susu bubuk skim rasa stroberi, susu bubuk skim rasa vanilla, susu bubuk skim rasa madu, dan lain-lain.<br>",
    "Aktif",
  ],
  [
    "01010413",
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll)",
    "Susu bubuk skim sebagian rasa/berperisa adalah susu bubuk skim sebagian yang ditambah dengan bahan tambahan pangan perisa atau rasa, dan dapat ditambah gula. Nama jenis produk ini susu bubuk skim sebagian rasa cokelat, susu bubuk skim sebagian rasa stroberi, susu bubuk skim sebagian rasa vanilla, susu bubuk skim sebagian rasa madu, dan lain-lain.<br>",
    "Aktif",
  ],
  [
    "01010414",
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa",
    "Campuran susu dan krim bubuk berperisa atau (dengan) rasa adalah produk susu berbentuk bubuk, dibuat dari susu bubuk dengan penambahan gula dan perisa dalam bentuk kakao bubuk atau kopi bubuk dan lain-lain",
    "Aktif",
  ],
  [
    "01010415",
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa)",
    "Minuman mengandung susu bubuk berperisa atau dengan (rasa) adalah minuman yang dibuat dengan menggunakan susu, susu rekonstitusi atau susu rekombinasi dengan tambahan perisa atau rasa, dapat ditambahkan gula.<br>",
    "Aktif",
  ],
  [
    "0102010103",
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Susu diasamkan adalah produk susu yang diperoleh dari susu segar atau susu pasteurisasi atau susu rekonstitusi atau susu rekombinasi yang diasamkan, dengan atau tanpa penambahan mikroba, vitamin dan bahan pangan lain. Jenis asam yang dapat digunakan sesuai dengan ketentuan.<br> Karakteristik dasar:<br> Total padatan susu bukan-lemak tidak kurang dari 6.6 %",
    "Aktif",
  ],
  [
    "0102010104",
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Susu asidofilus adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus acidophilus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.5 %",
    "Aktif",
  ],
  [
    "0102010105",
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Yogurt adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus bulgaricus dan Streptococcus thermophilus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2.3 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.5 %<br>",
    "Aktif",
  ],
  [
    "0102010106",
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Yogurt kultur lain adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Streptococcus thermophilus dan spesies Lactobacillus, dapat ditambahkan bakteri lain yang sesuai. Penamaan produk mengikuti ketentuan Standar Codex untuk Susu Fermentasi.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2.3 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.5 %",
    "Aktif",
  ],
  [
    "0102010107",
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Kefir adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan kultur starter yang dibuat dari biji kefir, Lactobacillus kefiri, spesies dari genus Leuconostoc, Lactococcus dan Acetobacter yang tumbuh saling sinergi. Biji kefir mengandung khamir yang mampu memfermentasi laktosa (Kluyveromyces marxianus) dan khamir yang tidak mampu memfermentasi laktosa (Saccharomyces unisporus, Saccharomyces cerevisiae dan Saccharomyces exiguus), dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2.3 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.6 %",
    "Aktif",
  ],
  [
    "0102010108",
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Kumys adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri Lactobacillus delbrueckii subsp. bulgaricus dan Kluyveromyces marxianus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2.3 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.7 %<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 0.5 %",
    "Aktif",
  ],
  [
    "0102010109",
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi)",
    "Susu fermentasi atau susu berkultur (cultured milk) adalah produk susu yang dihasilkan dari fermentasi susu segar dengan atau tanpa pasteurisasi, susu rekonstitusi atau susu rekombinasi yang diperoleh dari fermentasi dengan bakteri asam laktat yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6.6 %<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2.3 %<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.5 %",
    "Aktif",
  ],
  [
    "0102010203",
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Susu diasamkan adalah produk susu yang diperoleh dari susu segar atau susu pasteurisasi atau susu rekonstitusi atau susu rekombinasi yang diasamkan, dengan atau tanpa penambahan mikroba, vitamin dan bahan pangan lain. Jenis asam yang dapat digunakan sesuai dengan ketentuan.<br> Karakteristik dasar:<br> Total padatan susu bukan-lemak tidak kurang dari 6.6 %",
    "Aktif",
  ],
  [
    "0102010204",
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Susu asidofilus adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus acidophilus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%<br>",
    "Aktif",
  ],
  [
    "0102010205",
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Yogurt adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus bulgaricus dan Streptococcus thermophilus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2,3%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%<br>",
    "Aktif",
  ],
  [
    "0102010206",
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Yogurt kultur lain adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Streptococcus thermophilus dan spesies Lactobacillus, dapat ditambahkan bakteri lain yang sesuai. Penamaan produk mengikuti ketentuan Standar Codex untuk Susu Fermentasi.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2,3%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%<br>",
    "Aktif",
  ],
  [
    "0102010207",
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Kefir adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan kultur starter yang dibuat dari biji kefir, Lactobacillus kefiri, spesies dari genus Leuconostoc, Lactococcus dan Acetobacter yang tumbuh saling sinergi. Biji kefir mengandung khamir yang mampu memfermentasi laktosa (Kluyveromyces marxianus) dan khamir yang tidak mampu memfermentasi laktosa (Saccharomyces unisporus, Saccharomyces cerevisiae dan Saccharomyces exiguus), dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2,3%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,6%<br>",
    "Aktif",
  ],
  [
    "0102010208",
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Kumys adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri Lactobacillus delbrueckii subsp. bulgaricus dan Kluyveromyces marxianus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2,3%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,7%<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 0,5%<br>",
    "Aktif",
  ],
  [
    "0102010209",
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi)",
    "Susu fermentasi atau susu berkultur (cultured milk) adalah produk susu yang dihasilkan dari fermentasi susu segar dengan atau tanpa pasteurisasi, susu rekonstitusi atau susu rekombinasi yang diperoleh dari fermentasi dengan bakteri asam laktat yang sesuai.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 6,6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 2,3%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%<br>",
    "Aktif",
  ],
  [
    "010201A0",
    "Susu Diasamkan",
    "Susu diasamkan adalah produk susu yang diperoleh dari susu segar atau susu pasteurisasi atau susu rekonstitusi atau susu rekombinasi yang diasamkan, dengan atau tanpa penambahan mikroba, vitamin dan bahan pangan lainnya. Jenis asam yang dapat digunakan sesuai dengan ketentuan.<br> Karakteristik dasar:<br> Total padatan susu bukan lemak tidak kurang dari 7,8%",
    "Tidak Aktif",
  ],
  [
    "010201A3",
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk)",
    "Susu fermentasi atau susu berkultur (cultured milk) adalah produk susu yang dihasilkan dari fermentasi susu segar dengan atau tanpa pasteurisasi, susu rekonstitusi atau susu rekombinasi yang diperoleh dari fermentasi dengan bakteri asam laktat yang sesuai.<br> Karakteristik dasar:<br> - Total padatan susu bukan-lemak tidak kurang dari 7,8%<br> - Kadar asam laktat tidak kurang dari 0,5%",
    "Tidak Aktif",
  ],
  [
    "010201A4",
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak",
    "Susu fermentasi rendah lemak atau susu berkultur (cultured milk) rendah lemak adalah produk susu fermentasi atau susu berkultur yang sebagian lemaknya telah dihilangkan.",
    "Tidak Aktif",
  ],
  [
    "010201A5",
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak",
    "Susu fermentasi tanpa lemak atau susu berkultur (cultured milk) tanpa lemak adalah produk susu fermentasi atau susu berkultur yang sebagian besar lemaknya telah dihilangkan.",
    "Tidak Aktif",
  ],
  [
    "010201A6",
    "Yogurt",
    "Yogurt adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus bulgaricus dan Streptococcus thermophilus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> - Total padatan susu bukan-lemak tidak kurang dari 7,8%<br> - Kadar asam laktat tidak kurang dari 0,5%",
    "Tidak Aktif",
  ],
  [
    "010201A9",
    "Kefir",
    "Kefir adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan kultur starter yang dibuat dari biji kefir, Lactobacillus kefiri, spesies dari genus Leuconostoc, Lactococcus dan Acetobacter yang tumbuh saling sinergi. Biji kefir mengandung khamir yang mampu memfermentasi laktosa (Kluyveromyces marxianus) dan khamir yang tidak mampu memfermentasi laktosa (Saccharomyces unisporus, Saccharomyces cerevisiae dan Saccharomyces exiguus), dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> - Total padatan susu bukan-lemak tidak kurang dari 7,8%;<br> - Kadar asam laktat tidak kurang dari 0,6%",
    "Tidak Aktif",
  ],
  [
    "010201B0",
    "Kumys",
    "Kumys adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri Lactobacillus delbrueckii subsp. bulgaricus dan Kluyveromyces marxianus, dapat ditambahkan bakteri lain yang sesuai.<br> Karakteristik dasar:<br> - Total padatan susu bukan-lemak tidak kurang dari 7,8%<br> - Kadar asam laktat tidak kurang dari 0,7%<br> - Kadar etanol tidak kurang dari 0,5%",
    "Tidak Aktif",
  ],
  [
    "010201B1",
    "Yogurt Plain Bubuk",
    "produk susu bentuk bubuk yang diperoleh dari fermentasi susu<br> dengan menggunakan bakteri asam laktat Lactobacillus bulgaricus<br> dan Streptococcus thermophilus, dapat ditambahkan bakteri lain<br> yang sesuai.<br>",
    "Aktif",
  ],
  [
    "010201B3",
    "Yogurt kultur lain (alternate culture yoghurt)",
    "Yogurt kultur lain adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Streptococcus thermophilus dan spesies Lactobacillus, dapat ditambahkan bakteri lain yang sesuai. Penamaan produk mengikuti ketentuan Standar Codex untuk Susu Fermentasi.<br> Karakteristik dasar:<br> - Total padatan susu bukan-lemak tidak kurang dari 7,8%<br> - Kadar asam laktat tidak kurang dari 0,5%",
    "Tidak Aktif",
  ],
  [
    "010202",
    "Susu yang Digumpalkan dengan Enzim Renin (Plain)",
    "Susu yang digumpalkan dengan enzim renin (plain) adalah produk susu yang dihasilkan melalui kerja enzim renin.<br> Karakteristik dasar:<br> Total padatan susu bukan lemak tidak kurang dari 7,8%",
    "Aktif",
  ],
  [
    "0102A0",
    "Dadih",
    "Dadih adalah produk susu yang diperoleh dari proses fermentasi spontan bakteri asam laktat pada susu kerbau.",
    "Aktif",
  ],
  [
    "01030101",
    "Susu Evaporasi",
    "Susu evaporasi adalah produk susu cair yang diperoleh dengan cara menghilangkan sebagian air dari susu segar atau susu rekonstitusi atau susu rekombinasi, dengan menggunakan proses evaporasi hingga diperoleh tingkat kepekatan tertentu. Produk dikemas secara kedap (hermetis) dan diproses dengan pemanasan setelah penutupan pengemas.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 7,5%<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 25%",
    "Aktif",
  ],
  [
    "01030102",
    "Susu Skim Evaporasi",
    "Susu skim evaporasi adalah produk susu cair yang diperoleh dengan cara menghilangkan sebagian air dari susu skim atau susu skim hasil rekonstitusi, dengan menggunakan proses evaporasi sehingga diperoleh tingkat kepekatan tertentu. Produk dikemas secara kedap (hermetis).<br> Karakteristik dasar:<br> -Kadar lemak susu tidak lebih dari 1%<br> -Total padatan tidak kurang dari 20%",
    "Aktif",
  ],
  [
    "01030103",
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi",
    "Susu lemak nabati evaporasi / susu minyak nabati evaporasi adalah produk susu berbentuk cair yang diperoleh dengan cara menghilangkan sebagian air dari susu segar, susu rekombinasi, atau susu rekonstitusi yang lemaknya sebagian atau seluruhnya diganti dengan lemak nabati hingga diperoleh tingkat kepekatan tertentu. Produk dikemas secara kedap (hermetis). Susu lemak nabati evaporasi / susu minyak nabati evaporasi memiliki karakter dasar Kadar lemak tidak kurang dari 6% dan Total padatan tidak kurang dari 23,5%.",
    "Tidak Aktif",
  ],
  [
    "01030104",
    "Susu Kental Manis",
    "Susu kental manis adalah produk susu berbentuk cairan kental yang diperoleh dengan menghilangkan sebagian air dari campuran susu dan gula hingga mencapai tingkat kepekatan tertentu; atau merupakan hasil rekonstitusi susu bubuk dengan penambahan gula, dengan atau tanpa penambahan bahan lain. Gula yang ditambahkan harus dapat mencegah kerusakan produk. Produk dipasteurisasi dan dikemas secara kedap (hermetis). Susu kental manis memiliki karakteristik dasar Kadar lemak susu tidak kurang dari 8% dan Kadar protein tidak kurang dari 6,5% (untuk plain).",
    "Aktif",
  ],
  [
    "01030105",
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati",
    "Susu kental manis lemak nabati / susu kental manis minyak nabati adalah produk susu berbentuk cairan kental yang diperoleh dari susu segar, susu rekombinasi, atau susu rekonstitusi yang lemaknya sebagian atau seluruhnya diganti dengan lemak nabati, dengan penambahan gula hingga mencapai kepekatan tertentu dengan atau tanpa penambahan bahan lain. Gula yang ditambahkan harus dapat mencegah kerusakan produk. Produk dipasteurisasi dan dikemas secara kedap (hermetis).<br> <br> Karakteristik dasar:<br> Kadar lemak tidak kurang dari 8%",
    "Tidak Aktif",
  ],
  [
    "01030106",
    "Susu Skim Kental Manis",
    "Susu skim kental manis adalah produk susu yang berbentuk cairan kental, yang diperoleh dengan menghilangkan sebagian air dari susu skim yang telah ditambahkan gula hingga mencapai kepekatan tertentu; atau merupakan hasil rekonstitusi susu skim bubuk dengan penambahan gula, dengan atau tanpa penambahan bahan lain. Gula yang ditambahkan harus dapat mencegah kerusakan produk. Produk dipasteurisasi dan dikemas secara kedap (hermetis). Susu skim kental manis memiliki karakteristik dasar kadar lemak susu tidak lebih dari 1%.",
    "Aktif",
  ],
  [
    "01030107",
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati",
    "Susu kental manis diperkaya lemak nabati / susu kental manis diperkaya minyak nabati adalah produk susu yang berbentuk cairan kental, yang diperoleh dari susu yang telah ditambahkan gula dan lemak nabati atau minyak nabati yang kemudian sebagian air dihilangkan hingga mencapai kepekatan tertentu; atau merupakan hasil rekonstitusi susu bubuk dengan penambahan gula dan lemak nabati / minyak nabati, dengan atau tanpa penambahan bahan lain. Gula yang ditambahkan harus dapat mencegah pembusukan. Produk dikemas secara kedap (hermetis) dan dipasteurisasi.<br>",
    "Tidak Aktif",
  ],
  [
    "01030108",
    "Krim Kental Manis",
    "Krim kental manis adalah produk susu yang berbentuk cairan<br> kental yang diperoleh dengan merekonstitusi krim dengan<br> penambahan gula hingga mencapai kepekatan tertentu. Gula yang<br> ditambahkan harus dapat mencegah kerusakan produk. Produk<br> dipasteurisasi dan dikemas secara kedap (hermetis).<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 45%<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 65%",
    "Aktif",
  ],
  [
    "01030109",
    "Krimer Kental Manis",
    "Krimer kental manis adalah produk susu yang berbentuk cairan kental, yang diperoleh dari susu yang telah ditambahkan gula dan lemak nabati yang kemudian sebagian air dihilangkan hingga mencapai kepekatan tertentu, atau merupakan hasil rekonstitusi susu bubuk dengan penambahan gula dan lemak nabati/minyak nabati dan bahan lain. Gula yang ditambahkan harus dapat mencegah kerusakan produk. Produk dipasteurisasi dan dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    "01030110",
    "Khoa",
    "Khoa adalah produk susu yang diperoleh dari susu sapi atau kerbau yang dikentalkan dengan proses perebusan.",
    "Aktif",
  ],
  [
    "01030111",
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril)",
    "Susu lemak nabati evaporasi / susu minyak nabati evaporasi (steril) adalah produk susu berbentuk cair yang diperoleh dengan cara menghilangkan sebagian air dari susu segar, susu rekombinasi, atau susu rekonstitusi yang lemaknya sebagian atau seluruhnya diganti dengan lemak nabati hingga diperoleh tingkat kepekatan tertentu. Produk dikemas secara kedap (hermetis). Susu lemak nabati evaporasi / susu minyak nabati evaporasi memiliki karakteristik dasar Kadar lemak tidak kurang dari 6% dan Total padatan tidak kurang dari 23,5%.",
    "Tidak Aktif",
  ],
  [
    "01030112",
    "Susu Skim Sebagian Evaporasi",
    "Susu skim sebagian evaporasi adalah produk susu cair yang diperoleh dengan cara menghilangkan sebagian air dari susu skim sebagian atau susu skim sebagian hasil rekonstitusi, dengan menggunakan proses evaporasi atau proses lain sehingga diperoleh tingkat kepekatan tertentu.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu lebih dari 1% dan kurang dari 7,5%<br> \xE2\x{20AC}\xA2 Total padatan susu tidak kurang dari 20%<br> \xE2\x{20AC}\xA2 Kadar protein antara 4% sampai 6%<br>",
    "Aktif",
  ],
  [
    "01030201",
    "Krimer Minuman",
    "Krimer minuman adalah produk pengganti susu atau krim yang merupakan produk emulsi lemak dalam air, yang dibuat dari minyak nabati yang dihidrogenasi. Produk dapat berupa cairan atau bubuk dan digunakan untuk minuman seperti kopi dan teh.<br> Karakteristik dasar:<br> Produk cair: mengandung lemak tidak kurang dari 3,25% dan<br> total padatan tidak lebih dari 8,25%<br> Produk bubuk: mengandung lemak tidak kurang dari 26% dan<br> kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "01030202",
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi",
    "Susu lemak nabati evaporasi / susu minyak nabati evaporasi adalah produk susu berbentuk cair yang diperoleh dengan cara menghilangkan sebagian air dari susu segar, susu rekombinasi, atau susu rekonstitusi yang lemaknya sebagian atau seluruhnya diganti dengan lemak nabati hingga diperoleh tingkat kepekatan tertentu.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak tidak kurang dari 6%<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 23,5%<br>",
    "Aktif",
  ],
  [
    "01030203",
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati",
    "Susu kental manis lemak nabati / susu kental manis minyak nabati adalah produk susu berbentuk cairan kental yang diperoleh dari susu segar, susu rekombinasi, atau susu rekonstitusi yang lemaknya sebagian atau seluruhnya diganti dengan lemak nabati, dengan penambahan gula hingga mencapai kepekatan tertentu dengan atau tanpa penambahan bahan lain. Gula yang<br> ditambahkan harus dapat mencegah kerusakan produk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 8%;<br> \xE2\x{20AC}\xA2 Kadar protein total tidak kurang dari 2%.",
    "Aktif",
  ],
  [
    "01030204",
    "Krimer Kental Manis",
    "Krimer kental manis adalah produk susu yang berbentuk cairan kental, yang diperoleh dari susu yang telah ditambahkan gula dan lemak nabati yang kemudian sebagian air dihilangkan hingga mencapai kepekatan tertentu, atau merupakan hasil rekonstitusi susu bubuk dengan penambahan gula dan lemak nabati/minyak nabati dan bahan lain. Gula yang ditambahkan harus dapat mencegah kerusakan produk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 8%;<br> \xE2\x{20AC}\xA2 Kadar protein total tidak kurang dari 1%.",
    "Aktif",
  ],
  [
    "01040101",
    "Krim Pasteurisasi (Plain)",
    "Krim pasteurisasi (plain) adalah krim yang telah mengalami proses pemanasan untuk membunuh cemaran mikroba patogen.<br> Karakteristik dasar:<br> Kadar lemak susu tidak kurang dari 10%",
    "Aktif",
  ],
  [
    "01040102",
    "Half and Half",
    "Half and half adalah produk susu yang terdiri dari campuran susu dan tidak kurang dari 10,5% krim, dengan kadar lemak susu tidak kurang dari 18%. Produk ini dipasteurisasi atau ultra pasteurisasi dan dapat dihomogenisasi, dengan atau tanpa penambahan gula",
    "Aktif",
  ],
  [
    "01040103",
    "Half and Half (Steril Komersial / Tetrapak)",
    "Half and half adalah produk susu yang terdiri dari campuran susu dan tidak kurang dari 10,5% krim, dengan kadar lemak susu tidak kurang dari 18%. Produk ini diproses dengan sterilisasi komersial.",
    "Tidak Aktif",
  ],
  [
    "01040201",
    "Whipped Cream",
    "Whipped Cream adalah produk krim, krim rekonstitusi dan / atau krim kombinasi yang disertai udara atau gas inert tanpa mempengaruhi lemak dalam emulsi susu skim",
    "Aktif",
  ],
  [
    "01040202",
    "Krim Rendah Lemak",
    "Krim rendah lemak adalah krim yang berisi lemak susu 18% hingga 34%. Produk ini dipasteurisasi atau ultra pasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "01040204",
    "Krim Sterilisasi",
    "Krim sterilisasi adalah krim yang telah mengalami proses sterilisasi untuk membunuh cemaran mikroba patogen.",
    "Aktif",
  ],
  [
    "01040205",
    "Whipping Cream",
    "Whipping cream adalah produk krim, krim rekonstitusi dan/atau krim kombinasi yang khusus digunakan untuk tujuan whipping.<br> Karakteristik dasar:<br> Kadar lemak susu tidak kurang dari 10%.",
    "Aktif",
  ],
  [
    "01040301",
    "Krim Asam",
    "Krim asam adalah produk susu yang diperoleh dari proses pengasaman krim yang telah dipasteurisasi, dengan menggunakan bakteri asam laktat dan dikentalkan dengan enzim.",
    "Aktif",
  ],
  [
    "01040302",
    "Krim yang Diasamkan",
    "Krim yang diasamkan adalah produk susu yang diperoleh dari proses pengasaman krim yang telah dipasteurisasi, dengan menggunakan asam yang sesuai, dengan atau tanpa penggunaan bakteri asam laktat.",
    "Aktif",
  ],
  [
    "01040303",
    "Krim yang Digumpalkan dengan Enzim",
    "Krim yang digumpalkan dengan enzim adalah krim yang digumpalkan dengan enzim rennet.",
    "Aktif",
  ],
  [
    "01040401",
    "Krim Nabati",
    "Krim nabati adalah produk pengganti krim yang merupakan emulsi lemak nabati dalam air.",
    "Aktif",
  ],
  ["01040402", "Krim Nabati Bubuk", "", "Aktif"],
  [
    "0104AA",
    "Krim",
    "Krim adalah produk susu kaya lemak susu yang diperoleh dengan proses pemisahan yang memisahkan lemak susu dari komponen susu lainnya.",
    "Aktif",
  ],
  [
    "0104AA01",
    "Krim UHT",
    "produk susu kaya lemak susu yang diperoleh dengan proses pemisahan yang memisahkan lemak susu dari komponen susu lainnya.",
    "Tidak Aktif",
  ],
  [
    "01050101",
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain)",
    "Susu bubuk lemak penuh (full cream) adalah produk susu berbentuk bubuk yang tidak dikurangi lemaknya, yang diperoleh dari susu cair; atau susu hasil pencampuran susu cair dengan susu kental atau krim bubuk; atau susu hasil pencampuran susu cair dengan susu kental atau susu bubuk, yang telah dipasteurisasi dan melalui proses pengeringan. Nama jenis untuk produk ini susu bubuk full cream.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 26%;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang 32% dari padatan susu bukanlemak.",
    "Aktif",
  ],
  [
    "01050102",
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain)",
    "Susu bubuk lemak penuh (full cream) instan adalah susu bubuk yang tidak dikurangi lemaknya, yang mengalami proses instanisasi. Nama jenis untuk produk ini susu bubuk full cream instan.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 26%;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang 32% dari padatan susu bukan lemak.",
    "Aktif",
  ],
  [
    "01050103",
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak",
    "Susu bubuk rendah lemak dan susu bubuk kurang lemak adalah produk susu berbentuk bubuk yang diperoleh dengan proses pengeringan susu yang sebelumnya telah dipisahkan sebagian lemak susunya dengan alat pemisah krim (cream separator) atau susu hasil pencampuran susu cair dengan susu kental atau krim bubuk; atau susu hasil pencampuran susu cair dengan susu kental atau susu bubuk.<br>",
    "Tidak Aktif",
  ],
  [
    "01050104",
    "Susu Bubuk Skim",
    "Susu bubuk skim adalah produk susu berbentuk bubuk yang diperoleh dengan proses pengeringan susu skim pasteurisasi.",
    "Aktif",
  ],
  [
    "01050105",
    "Krim Bubuk",
    "Krim bubuk adalah susu berbentuk bubuk yang diperoleh dengan menghilangkan sebagian air dari susu krim dengan pengering semprot.",
    "Aktif",
  ],
  ["01050106", "Susu Bubuk", "Susu Bubuk", "Tidak Aktif"],
  ["01050107", "Susu Bubuk untuk Kue", "-", "Tidak Aktif"],
  ["01050108", "Susu Bubuk Berperisa", "", "Tidak Aktif"],
  [
    "01050109",
    "Susu Bubuk Skim Sebagian",
    "Susu bubuk skim sebagian adalah produk susu berbentuk bubuk yang diperoleh dengan proses pengeringan susu yang sebelumnya telah dipisahkan sebagian lemak susunya dengan alat pemisah krim (cream separator) atau susu hasil pencampuran susu cair dengan susu kental atau susu skim bubuk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu lebih dari 1,5% dan kurang dari 26%<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang 32% dari padatan susu bukan lemak",
    "Aktif",
  ],
  [
    "01050110",
    "Campuran Susu dan Krim Bubuk (Plain)",
    "Campuran susu dan krim bubuk (plain2) adalah produk susu berbentuk bubuk yang diperoleh dengan proses pengeringan susu<br> yang telah dipasteurisasi; atau susu hasil pencampuran susu cair dengan susu kental atau krim bubuk; atau susu hasil pencampuran susu cair dengan susu kental atau susu bubuk; atau rekombinasi susu bubuk dan krim bubuk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 26%;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    "01050111",
    "Bubuk Buttermilk",
    "Bubuk buttermilk adalah produk susu yang diperoleh dari krim yang telah dipisahkan lemaknya, kemudian dikeringkan.",
    "Aktif",
  ],
  [
    "01050112",
    "Minuman Mengandung Susu Bubuk (Plain)",
    "Minuman mengandung susu bubuk (plain) adalah minuman yang dibuat dengan menggunakan susu, susu rekonstitusi atau susu rekombinasi, dapat ditambahkan gula.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 2,6%;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%;<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang 3,2% dari padatan susu bukan lemak.",
    "Aktif",
  ],
  [
    "01050201",
    "Campuran Susu dan Krim Bubuk (Plain)",
    "Campuran susu dan krim bubuk (plain) adalah produk susu berbentuk bubuk yang diperoleh dengan proses pengeringan susu yang telah dipasteurisasi; atau susu hasil pencampuran susu cair dengan susu kental atau krim bubuk; atau susu hasil pencampuran susu cair dengan susu kental atau susu bubuk; atau rekombinasi susu bubuk dan krim bubuk.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu tidak kurang dari 26%<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%",
    "Tidak Aktif",
  ],
  [
    "01050202",
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa",
    "Campuran susu dan krim bubuk berperisa atau (dengan) rasa adalah produk susu berbentuk bubuk, dibuat dari susu bubuk dengan penambahan gula dan perisa dalam bentuk kakao bubuk atau kopi bubuk dan lain-lain.<br>",
    "Tidak Aktif",
  ],
  [
    "01050203",
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati",
    "Susu bubuk lemak nabati / susu bubuk minyak nabati adalah produk susu berbentuk bubuk yang sebagian lemaknya telah dihilangkan dan digantikan dengan minyak nabati/lemak nabati dalam jumlah yang setara.",
    "Aktif",
  ],
  ["01050204", "Bubuk Buttermilk", "", "Tidak Aktif"],
  [
    "01050205",
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll)",
    "Susu bubuk yang ditambah dengan bahan pangan berupa bubuk kakao, ekstrak stroberi, ekstrak vanilla dan atau bahan lain yang sesuai, dapat ditambah gula dan atau perisa. Nama jenis produk ini susu bubuk cokelat, susu bubuk stroberi, susu bubuk vanilla, susu bubuk madu, dan lain-lain.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar gula dihitung sebagai sakarosa tidak lebih dari 55%",
    "Tidak Aktif",
  ],
  [
    "01050206",
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll)",
    "Susu bubuk yang ditambah dengan bahan tambahan pangan perisa, dan dapat ditambah gula. Nama jenis produk ini susu bubuk rasa cokelat, susu bubuk rasa stroberi, susu bubuk rasa vanilla, susu bubuk rasa madu, dan lain-lain.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar gula dihitung sebagai sakarosa tidak lebih dari 55%",
    "Tidak Aktif",
  ],
  [
    "01060101",
    "Keju Cottage (Cottage Cheese)",
    "Keju cottage (cottage cheese) adalah keju lunak tanpa pemeraman yang dibuat dari susu segar atau susu segar yang dihilangkan lemaknya atau susu rekombinasi.<br> <br> Karakteristik dasar:<br> Padatan susu bukan lemak tidak kurang dari 18%",
    "Aktif",
  ],
  [
    "01060102",
    "Keju Krim (Cream Cheese)",
    "Keju krim (cream cheese) adalah keju lunak tanpa pemeraman yang dibuat dari krim atau susu yang ditambah dengan krim dengan penambahan kultur bakteri asam laktat dan enzim penggumpal (rennet, atau enzim penggumpal lainnya).<br> <br> Karakteristik dasar:<br> - Lemak susu dari total padatan tidak kurang dari 25%<br> - Kadar air terhadap bahan tanpa lemak tidak kurang dari 67%<br> - Total padatan tidak kurang dari 22%",
    "Aktif",
  ],
  [
    "01060103",
    "Keju Mozzarella",
    "Keju mozzarella adalah keju lunak yang dibuat dengan starter Lactobacillus bulgaricus dan Steptococcus thermophilus atau bakteri asam laktat lainnya yang sesuai.<br> <br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 20% (dengan kelembaban tinggi), tidak kurang dari 18% (dengan kelembaban rendah)",
    "Aktif",
  ],
  [
    "01060104",
    "Keju Bocconcini",
    "Keju Bocconcini adalah keju lunak, segar, yang tidak mudah putus (stretch curd), plastis, dengan rasa sedikit ringan dan aroma segar",
    "Aktif",
  ],
  [
    "01060105",
    "Keju Tanpa Pemeraman (Keju Mentah)",
    "&nbsp;",
    "Aktif",
  ],
  [
    "01060106",
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese)",
    "Keju cottage yang ditambah krim (creamed cottage cheese) adalah keju lunak tanpa pemeraman yang dibuat dari susu segar atau susu segar yang dihilangkan lemaknya atau susu rekombinasi dan ditambahkan krim.",
    "Aktif",
  ],
  [
    "0106020101",
    "Keju Biru (Blue cheese)",
    "Keju biru (blue cheese) adalah keju keras yang dibuat dengan starter<br> Lactobacillus lactis subsp. lactis biovar diacetylactis dan cremoris,<br> diperam dengan Penicillium roqueforti tidak kurang dari 60 hari,<br> ditandai dengan adanya kapang hijau kebiruan di seluruh bagian<br> keju.",
    "Aktif",
  ],
  [
    "0106020102",
    "Keju Bata (Brick Cheese)",
    "Keju bata (brick cheese) adalah keju keras yang diperoleh dari susu dan ingredien lainnya, jika dibuat dari susu segar maka pemeraman dilakukanpada suhu tidak kurang dari 35\\xB0C dan waktu tidak kurang dari 60 hari. Keju bata dapat juga diproses pada suhu da",
    "Aktif",
  ],
  [
    "0106020103",
    "Keju Gouda",
    "Keju gouda adalah keju khas Belanda, yang dibuat dengan starter bakteri asam laktat yang sesuai, tergolong keju agak keras (semi hard) dengan kulit keras dan dilapis lilin atau bahan lainnya.",
    "Aktif",
  ],
  [
    "0106020104",
    "Keju Havarti",
    "Keju havarti adalah keju khas Denmark yang tergolong keju agak keras (semi hard), dengan atau tanpa kulit hasil pengentalan bakteri asam laktat, rennet atau penggumpal lainnya dan difermentasi dengan bakteri asam laktat dan kapang dengan penambahan garam.",
    "Aktif",
  ],
  [
    "0106020105",
    "Keju Brie",
    "Keju brie adalah keju yang dihasilkan dengan starter Lactobacillus lactis subsp. lactis dan cremoris, dan diperam dengan Penicillium caseicolum atau kapang, kamir, bakteri lain yang sesuai.",
    "Aktif",
  ],
  [
    "0106020106",
    "Keju Parmesan",
    "Keju parmesan adalah keju khas Italia (Parma) yang diperoleh dari<br> susu yang dipanaskan dan digumpalkan sebelum semua krim<br> dipisahkan. Gumpalan dipotong dan dipanaskan pada suhu 52\xBAC,<br> dimasak sampai suhu 55\xBAC, dibentuk lalu diperam dalam air garam.<br> Keju parmesan dapat juga diproses pada suhu dan lama<br> pemeraman yang berbeda, tergantung dari teknologi yang dipakai.",
    "Aktif",
  ],
  [
    "0106020107",
    "Keju Swiss",
    "Keju swiss adalah keju dengan kulit keras dan berlubang-lubang di bagian dalamnya karena gas yang terbentuk selama pemeraman.",
    "Aktif",
  ],
  [
    "0106020108",
    "Keju Edam",
    "Keju edam adalah keju semi keras khas Belanda. Keju edam juga dibuat di berbagai negara. Tekstur keju ini elastis, liat, lebih lembut dari keju gouda. Lubang gasnya (gas holes) sedikit.<br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 30%",
    "Aktif",
  ],
  [
    "0106020109",
    "Keju Cheddar",
    "Keju cheddar adalah keju keras yang dibuat dari susu sapi dengan pemeraman pada suhu tidak kurang dari 35\xBAC dan waktu tidak kurang dari 60 hari. Keju cheddar dapat juga diproses pada suhu dan lama pemeraman yang berbeda, tergantung dari teknologi yang dipakai.<br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 22%.",
    "Aktif",
  ],
  [
    "0106020110",
    "Keju Camembert",
    "Keju camembert adalah keju lunak yang diperam dengan kapang Penicillium candidum, dan/atau Penicillium camembertii dan Penicillium caseicolum.<br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "0106020111",
    "Keju Bath",
    "Keju bath adalah keju lunak khas Inggris. Keju ini dibuat dari susu<br> sapi yang tidak dipasteurisasi.",
    "Aktif",
  ],
  [
    "0106020112",
    "Keju Bondard",
    "Keju bondard adalah keju khas Perancis. Keju ini dibuat dari susu<br> sapi yang tidak dipasteurisasi",
    "Aktif",
  ],
  [
    "0106020113",
    "Keju Bougon",
    "Keju bougon adalah keju lunak khas Perancis. Keju ini dibuat dari<br> susu kambing",
    "Aktif",
  ],
  [
    "0106020114",
    "Keju Bouquet des moines",
    "Keju bouquet des moines adalah keju khas Belgia. Dibuat dari susu<br> sapi",
    "Aktif",
  ],
  [
    "0106020115",
    "Keju Peram Lainnya",
    "Keju peram lainnya adalah keju peram yang tidak termasuk keju<br> peram di atas, misalnya keju feta",
    "Aktif",
  ],
  [
    "01060202",
    "Kulit Keju Peram",
    "Kulit keju peram adalah kulit keju yang telah mengalami proses<br> pemeraman dan perendaman dalam larutan garam. Kulit keju<br> adalah bagian terluar dari keju yang dapat saja memiliki komposisi<br> yang sama dari bagian dalam keju, namun dapat kering setelah<br> proses pemeraman dan perendaman dalam larutan garam.<br> Beberapa jenis keju menggunakan pelapis lilin untuk kulit yang<br> mungkin ditambah pewarna yang diizinkan untuk melindungi keju.",
    "Aktif",
  ],
  [
    "01060203",
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju)",
    "Keju bubuk adalah hasil pengeringan dari aneka jenis keju olahan. Keju bubuk direkonstitusi dengan air atau susu untuk pembuatan saus, atau digunakan sebagai ingredien (misalnya untuk makaroni dan keju), termasuk keju yang diproses dengan pengering semprot.",
    "Aktif",
  ],
  [
    "010602A0",
    "Keju Peram",
    "Keju peram adalah keju yang tidak dapat dikonsumsi setelah pembuatannya tetapi diperam pada kondisi tertentu agar terjadi perubahan fisik dan biokimiawi yang diinginkan. Untuk keju yang diperam dengan kapang maka pemeraman dicapai dengan menumbuhkan kapang di seluruh bagian dalam dan atau luar keju tersebut. Termasuk keju cheddar, keju cheddar untuk bahan baku, keju edam, keju camembert dan keju feta.",
    "Tidak Aktif",
  ],
  [
    "010602A1",
    "Keju Cheddar",
    "Keju cheddar adalah keju keras yang dibuat dari susu sapi dengan pemeraman pada suhu tidak kurang dari 35\xBAC dan waktu tidak kurang dari 60 hari. Keju cheddar dapat juga diproses pada suhu dan lama pemeraman yang berbeda, tergantung dari teknologi yang dipakai.<br> <br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 22%",
    "Tidak Aktif",
  ],
  [
    "010602A3",
    "Keju Edam",
    "Keju edam adalah keju semi keras khas Belanda. Keju edam juga dibuat di berbagai negara. Tekstur keju ini elastis, liat, lebih lembut dari keju gouda. Lubang gasnya (gas holes) sedikit.<br> <br> Karakteristik dasar:<br> Lemak susu dihitung terhadap bahan kering tidak kurang dari 30%",
    "Tidak Aktif",
  ],
  [
    "010602A4",
    "Keju Camembert",
    "Keju camembert adalah keju lunak yang diperam dengan kapang Penicillium candidum, dan atau Penicillium camembertii dan Penicillium caseicolum. Karakteristik dasar : Lemak susu dihitung terhadap bahan kering tidak kurang dari 30%",
    "Tidak Aktif",
  ],
  [
    "010602A5",
    "Keju Bath",
    "Keju bath adalah keju lunak khas Inggris. Keju ini dibuat dari susu sapi yang tidak dipasteurisasi.",
    "Aktif",
  ],
  [
    "010602A6",
    "Keju Bondard",
    "Keju bondard adalah keju khas Perancis. Keju ini dibuat dari susu sapi yang tidak dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "010602A7",
    "Keju Bougon",
    "Keju bougon adalah keju lunak khas Perancis. Keju ini dibuat dari susu kambing.",
    "Tidak Aktif",
  ],
  [
    "010602A8",
    "Keju Bouquet des moines",
    "Keju bouquet des moines adalah keju khas Belgia. Dibuat dari susu sapi.",
    "Tidak Aktif",
  ],
  [
    "010602A9",
    "Keju Boursault",
    "Keju boursault adalah keju lunak khas Perancis. Dibuat dari susu sapi.",
    "Aktif",
  ],
  [
    "010603",
    "Keju Whey",
    "Keju whey adalah produk padat atau semipadat yang diperoleh dari pemekatan whey dengan atau tanpa penambahan susu, krim susu atau komponen susu lainnya dan dibentuk.<br> Termasuk didalamnya adalah keju whey berkrim, keju whey, dan keju whey berskim.",
    "Aktif",
  ],
  [
    "0106040102",
    "Keju Amerika (American Cheese)",
    "",
    "Tidak Aktif",
  ],
  [
    "0106040104",
    "Keju Olahan Plain",
    "Keju olahan plain adalah produk olahan keju tanpa penambahan perisa, bumbu, buah, sayur atau daging. Contoh meliputi American cheese, requeson",
    "Aktif",
  ],
  [
    "0106040201",
    "Keju Neufchatel dan Sayuran Untuk Olesan",
    "",
    "Tidak Aktif",
  ],
  [
    "0106040203",
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging",
    "Keju olahan berperisa adalah produk olahan keju yang mengandung bahan tambahan perisa, pewarna, dan pengemulsi, bumbu, buah, sayur dan atau daging.",
    "Aktif",
  ],
  [
    "010604A0",
    "Keju Olahan",
    "Keju olahan adalah produk yang diperoleh dengan menggiling,<br> mencampur, melelehkan dan mengemulsikan dengan pemanasan<br> dan pengemulsi dari satu atau lebih jenis keju dengan atau tanpa<br> penambahan komponen susu dan atau bahan pangan lainnya<br> seperti bumbu dan buah, sayur atau daging. Produk ini dapat<br> berbentuk olesan atau diiris menjadi irisan.",
    "Tidak Aktif",
  ],
  [
    "010604A1",
    "Keju Cheddar Olahan",
    "Keju cheddar olahan adalah keju yang diperoleh dengan mencampurkan keju cheddar.",
    "Tidak Aktif",
  ],
  [
    "010605",
    "Analog keju",
    "Analog keju adalah produk keju yang sebagian atau seluruh lemak susunya digantikan dengan lemak lain.",
    "Aktif",
  ],
  [
    "010606",
    "Keju Protein Whey (Misal Keju Ricotta)",
    "Keju protein whey adalah keju yang dibuat dari protein yang diekstrak dari whey. Produk ini pada prinsipnya dibuat dari koagulasi protein whey. Contohnya adalah keju ricotta. Tidak sama dengan keju whey (kategori pangan 01.6.3)",
    "Aktif",
  ],
  ["010607", "Keju Haloumy", "-", "Tidak Aktif"],
  ["0106A3", "Keju Haloumy", "", "Tidak Aktif"],
  [
    "010701",
    "Es Krim",
    "Es krim adalah produk beku yang diperoleh dari susu atau produk susu atau campurannya yang sebagian lemak susu diganti dengan lemak nabati, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 5%;<br> \xE2\x{20AC}\xA2 Total padatan susu tidak kurang dari 5%;<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 31%.",
    "Aktif",
  ],
  [
    "010702",
    "Yogurt Berperisa/Rasa",
    "Yogurt berperisa/rasa adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Lactobacillus bulgaricus dan Streptococcus thermophilus, dapat ditambahkan bakteri lain yang sesuai, dengan penambahan perisa/rasa.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4,6%;<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 1,6%;<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%.",
    "Aktif",
  ],
  [
    "010703",
    "Es Susu",
    "Es susu adalah produk beku yang dibuat dari campuran susu dan/atau produk susu dengan air, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 1%",
    "Aktif",
  ],
  [
    "010704",
    "Junket",
    "Junket adalah makanan pencuci mulut seperti custard manis yang dibuat dari susu berperisa yang diatur dengan rennet.",
    "Aktif",
  ],
  [
    "010705",
    "Dulce de leche",
    "Dulce de leche adalah susu yang telah dimasak dengan gula dan bahan pangan lainnya seperti kelapa atau cokelat.",
    "Aktif",
  ],
  [
    "010706",
    "Puding Butterscotch atau Puding Susu",
    "Puding Butterscotch atau Puding Susu adalah makanan pencuci mulut berbentuk padat lunak yang terbuat dari susu segar atau produk susu atau campurannya yang ditambah dengan pati atau bahan pembentuk gel dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> Kandungan susu dan atau turunannya tidak kurang dari 50%",
    "Aktif",
  ],
  ["010707", "Mousse Cokelat", "", "Tidak Aktif"],
  [
    "010708",
    "Kembang Gula Susu/Permen Susu",
    "Kandungan susu tidak kurang dari 5%",
    "Aktif",
  ],
  ["010709", "Non Dairy Pudding", "", "Tidak Aktif"],
  [
    "010710",
    "Puding berbahan dasar susu",
    "Puding berbahan dasar susu.<br> <br> Status diubah menjadi TIDAK AKTIF, sudah ada kategori baru : Puding Butterscotch atau Puding Susu (010706)",
    "Tidak Aktif",
  ],
  [
    "010711",
    "Bubuk Puding Butterscotch/Puding Susu",
    "Bubuk Puding Butterscotch/Puding Susu adalah makanan pencuci mulut berbentuk bubuk yang terbuat dari susu segar atau produk susu atau campurannya yang ditambah dengan pati atau bahan pembentuk gel dengan atau tanpa penambahan bahan pangan lain dan harus ditambahkan air sebelum diolah lebih lanjut menjadi puding.<br> <br> Kandungan padatan susu dan atau turunannya tidak kurang dari<br> 5%\"<br>",
    "Aktif",
  ],
  [
    "010712",
    "Premiks Es Krim (Bubuk)",
    "Premiks es krim bubuk adalah produk berbentuk bubuk dengan bahan dasar susu atau produk susu atau campurannya dengan penambahan bahan pangan lain yang dapat ditambahkan air sebelum diolah lebih lanjut menjadi es krim.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 4.5%<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 15% dan kadar lemak susu tidak kurang dari 4.8%<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  ["010713", "Topping Berbasis Susu", "-", "Tidak Aktif"],
  [
    "010714",
    "Makanan Pencuci Mulut Berbahan Dasar Susu",
    "Termasuk produk pencuci mulut berbasis susu dan bubuk instan<br> pencuci mulut, confectionery susu beku, bahan isian berbasis susu, yogurt berperisa. Produk ini berbeda dari kategori pangan 03.0 (es<br> yang dapat dimakan, termasuk sherbet dan sorbet), dimana pro",
    "Aktif",
  ],
  [
    "010715",
    "Premiks Es Krim (Cair)",
    "Premiks es krim cair adalah produk berbentuk cair dengan bahan dasar susu atau produk susu atau campurannya dengan penambahan bahan pangan lain yang dapat ditambahkan air sebelum diolah lebih lanjut menjadi es krim.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak total tidak kurang dari 5%<br> \xE2\x{20AC}\xA2 Total padatan susu tidak kurang dari 5%<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 31%<br>",
    "Aktif",
  ],
  ["010716", "Yogurt Berperisa/Rasa Bubuk", "-", "Aktif"],
  [
    "010717",
    "Es Mengandung Susu",
    "Es mengandung susu adalah produk beku yang dibuat dari campuran susu dengan air dan gula, dapat ditambahkan bahan pangan lain.<br> Karakteristik dasar :<br> - Kadar lemak susu lebih dari 0.5% dan kurang dari 2%<br> - Total padatan susu bukan lemak tidak kurang dari 1.1%",
    "Tidak Aktif",
  ],
  [
    "010718",
    "Kefir Berperisa/rasa",
    "Kefir berperisa/rasa adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan kultur starter yang dibuat dari biji kefir, Lactobacillus kefiri, spesies dari genus Leuconostoc, Lactococcus dan Acetobacter yang tumbuh saling sinergi. Biji kefir mengandung khamir yang mampu memfermentasi laktosa (Kluyveromyces marxianus) dan khamir yang tidak mampu memfermentasi laktosa (Saccharomyces unisporus, Saccharomyces cerevisiaem, dan Saccharomyces exiguus), dapat ditambahkan bakteri lain yang sesuai, dengan penambahan perisa/rasa.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4.6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 1.6%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.6%<br>",
    "Aktif",
  ],
  ["010719", "Es Krim Modifikasi", "-", "Tidak Aktif"],
  [
    "010720",
    "Es Krim Susu (Dairy Ice Cream)",
    "Es Krim Susu (Dairy Ice Cream) adalah produk beku yang diperoleh dari susu atau produk susu atau campurannya, tanpa penambahan lemak selain lemak susu, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik Dasar :<br> Kadar protein susu tidak kurang dari 2.7%<br> Kadar lemak susu tidak kurang dari 5%<br> Total padatan tidak kurang dari 31%",
    "Aktif",
  ],
  [
    "010721",
    "Premiks Es Susu (Bubuk)",
    "Premiks Es Susu (bubuk) adalah produk berbentuk bubuk dengan bahan dasar susu atau produk susu atau campurannya dengan atau tanpa penambahan bahan pangan lain yang dapat ditambahkan air sebelum diolah lebih lanjut menjadi es susu.<br> <br> Karakteristik Dasar :<br> Bentuk Bubuk<br> - kadar protein susu tidak kurang dari 3%<br>",
    "Aktif",
  ],
  [
    "010722",
    "Premiks Es Susu (Cair)",
    "Premiks Es Susu (cair) adalah produk berbentuk cair dengan bahan dasar susu atau produk susu atau campurannya dengan atau tanpa penambahan bahan pangan lain yang dapat ditambahkan air sebelum diolah lebih lanjut menjadi es susu.<br> <br> Karakteristik Dasar :<br> Bentuk Cair<br> - kadar protein susu tidak kurang dari 1%",
    "Aktif",
  ],
  [
    "010723",
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt)",
    "Yogurt kultur lain adalah produk susu yang diperoleh dari fermentasi susu dengan menggunakan bakteri asam laktat Streptococcus thermophilus dan spesies Lactobacillus, dapat ditambahkan bakteri lain yang sesuai. Penamaan produk mengikuti ketentuan Standar Codex untuk Susu Fermentasi, dengan penambahan perisa/rasa.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4.6%<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 1.6%<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0.5%<br>",
    "Aktif",
  ],
  [
    "010724",
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa",
    "Susu fermentasi atau susu berkultur berperisa/rasa adalah produk susu yang dihasilkan dari fermentasi susu segar dengan atau tanpa pasteurisasi, susu rekonstitusi atau susu rekombinasi yang diperoleh dari fermentasi dengan mikroba yang sesuai, dengan penambahan perisa/rasa.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan susu bukan-lemak tidak kurang dari 4,6%;<br> \xE2\x{20AC}\xA2 Kadar protein susu tidak kurang dari 1,6%;<br> \xE2\x{20AC}\xA2 Kadar asam laktat tidak kurang dari 0,5%.",
    "Aktif",
  ],
  [
    "010725",
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk)",
    "",
    "Aktif",
  ],
  [
    "01080101",
    "Whey",
    "Whey adalah cairan yang dipisahkan dari susu setelah penggumpalan susu, krim, susu skim atau buttermilk dengan rennet atau enzim lainnya dalam pembuatan keju, kasein dan produk lain yang sejenis.",
    "Aktif",
  ],
  [
    "01080102",
    "Whey Asam",
    "Whey asam adalah cairan yang dipisahkan setelah penggumpalan susu dengan asam, khususnya dalam pembuatan keju mentah (tanpa pemeraman).",
    "Aktif",
  ],
  [
    "01080201",
    "Bubuk Whey",
    "Bubuk whey adalah produk whey yang diperoleh dari pengeringan (baik oleh pengering semprot atau drum) whey atau whey asam yang sebagian besar lemaknya telah diambil.",
    "Aktif",
  ],
  [
    "01080202",
    "Bubuk Whey yang Telah Didemineralisasi",
    "Bubuk whey yang telah didemineralisasi adalah produk whey yang diperoleh dari pengeringan (baik pengering semprot atau drum) whey atau whey asam yang sebagian besar lemaknya telah diambil dan telah dilakukan pengurangan pada kandungan mineralnya sesuai dengan kebutuhan.",
    "Aktif",
  ],
  [
    "01080203",
    "Bubuk Whey Permeate",
    "Bubuk whey permeate adalah produk whey yang diperoleh dari<br> pengeringan whey yang telah dipisahkan proteinnya.",
    "Aktif",
  ],
  [
    "02010101",
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil)",
    "Lemak susu anhidrat (AMF), minyak mentega (butter oil) adalah produk lemak dan minyak yang diperoleh secara khusus dari susu,<br> krim, atau mentega melalui proses pengolahan untuk menghilangkan air dan padatan bukan-lemak sampai hampir sempurna.<br> <br> Karakteristik dasar :<br> - Lemak susu anhidrat :<br> Kadar lemak susu tidak kurang dari 99,8%;<br> - Minyak mentega anhidrat :<br> Kadar lemak susu tidak kurang dari 99,8%;<br> - Minyak mentega :<br> Kadar lemak susu tidak kurang dari 99,3%.",
    "Aktif",
  ],
  [
    "02010102",
    "Ghee",
    "Ghee adalah produk khusus dari susu, krim atau mentega yang<br> diperoleh melalui proses pengolahan untuk menghilangkan air dan<br> padatan bukan-lemak sampai hampir sempurna, serta mempunyai<br> aroma dan tekstur yang khas.<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,1%;<br> - Kadar asam lemak bebas (sebagai asam oleat) tidak lebih dari 0,4%.",
    "Aktif",
  ],
  [
    "02010201",
    "Lemak dan Minyak Nabati",
    "Lemak dan minyak nabati adalah lemak dan minyak yang diperoleh dari tanaman. Produk lemak dan minyak ini dapat berasal dari sumber tunggal atau campuran, dan dipasarkan dengan istilah minyak makan, minyak masak atau minyak sayur, minyak goreng, minyak meja atau minyak salad, minyak nabati dan lemak nabati.<br> <br> Karakteristik dasar :<br> - Lemak dan Minyak yang telah dimurnikan/rafinasi (refined oil)<br> a. Kadar air tidak lebih dari 0,15%;<br> b. Kadar asam lemak bebas tidak lebih dari 0,3%;<br> - Minyak mentah (crude oil)<br> a. Kadar air tidak lebih dari 0,5%;<br> b. Kadar asam lemak bebas tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    "02010202",
    "Virgin Oil",
    "Virgin oil adalah produk minyak yang diperoleh secara mekanis (contohnya dengan pengepresan atau dikempa) tanpa pemanasan atau dengan pemanasan api kecil pada suhu kurang dari 60\xB0C dan tanpa penggunaan bahan kimia. Minyak dapat dimurnikan dengan pencucian menggunakan air, pengendapan, penyaringan dan atau sentrifugasi. Virgin oil dapat berasal dari berbagai bahan (zaitun, kelapa, wijen, dan lain-lain), contoh Virgin Coconut Oil (VCO)<br> <br> Karakteristik dasar :<br> - Bilangan peroksida tidak lebih dari 10 mek O2/kg;<br> - Lihat tabel komposisi asam lemak minyak nabati sesuai asalnya.",
    "Aktif",
  ],
  [
    "02010203",
    "Cold Pressed Oils",
    "Cold pressed oils adalah produk minyak yang diperoleh secara mekanis tanpa pemanasan. Minyak dapat dimurnikan dengan pencucian menggunakan air, pengendapan, penyaringan dan atau sentrifugasi. Contohnya adalah minyak zaitun, minyak biji kapas, minyak kacang tanah, minyak kelapa, dan minyak inti sawit.",
    "Aktif",
  ],
  [
    "02010204",
    "Minyak Goreng (Frying oil atau frying fat)",
    "Minyak goreng (frying oil atau frying fat) adalah minyak dan lemak yang digunakan untuk menggoreng yang diperoleh dari proses rafinasi /pemurnian (refining/purifying) minyak nabati, dalam bentuk tunggal atau campuran.",
    "Tidak Aktif",
  ],
  [
    "02010205",
    "Minyak Masak atau Minyak Sayur (Cooking Oil)",
    "Minyak masak atau minyak sayur (cooking oil) adalah minyak yang digunakan untuk memasak (seperti menumis atau shallow frying/stirfry/ pan frying), diperoleh dari proses rafinasi /pemurnian minyak nabati, dapat berasal dari sumber tunggal atau campuran.<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,15%;<br> - Kadar asam lemak bebas tidak lebih dari 0,3%;<br> - Bilangan peroksida tidak lebih dari 10 mek O2/kg.",
    "Aktif",
  ],
  [
    "02010206",
    "Minyak Salad (Salad Oil)",
    "Minyak salad adalah minyak yang diperoleh dari proses rafinasi/pemurnian (refining/purifying) minyak nabati, digunakan untuk pembuatan mayonais, salad dressing dan saus.<br> <br> Karakteristik dasar :<br> - Cair pada temperatur ruang;<br> - Kadar air tidak lebih dari 0,15%;<br> - Kadar asam lemak bebas tidak lebih dari 0,2%.",
    "Aktif",
  ],
  [
    "02010207",
    "Serbuk Minyak",
    "Serbuk minyak adalah produk minyak yang dikeringkan menjadi serbuk dengan tambahan tepung atau sejenisnya.",
    "Tidak Aktif",
  ],
  [
    "02010208",
    "Vanaspati atau Minyak Samin (Vegetable Ghee)",
    "Vanaspati atau minyak samin (vegetable ghee) adalah produk semi padat/padat yang diperoleh dari proses rafinasi/pemurnian minyak dan atau lemak nabati.<br> <br> Karakteristik dasar :<br> - Kadar lemak nabati tidak kurang dari 97%;<br> - Tidak mengandung lemak atau minyak hewani;<br> - Titik leleh/lebur 30oC hingga 48\\xB0C;<br> - Kadar air tidak lebih dari 0,25%;<br> - Kadar bahan tak tersabunkan tidak lebih dari 12,5 g/kg;<br> - Kadar asam lemak bebas (sebagai asam oleat) tidak lebih dari 0,5%.",
    "Aktif",
  ],
  [
    "02010209",
    "Lemak Reroti (Shortening)",
    "Lemak reroti (shortening) adalah produk hasil olahan lemak/minyak nabati dengan atau tanpa penambahan lemak hewani dan atau lemak susu yang berbentuk semi padat/padat.<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,15%;<br> - Kadar asam lemak bebas (dihitung sebagai asam lemak dominan dari minyak nabati yang digunakan) tidak lebih dari 0,3%, yaitu :<br> a. Jika berasal dari minyak sawit, asam lemak bebas dihitung sebagai asam palmitat;<br> b. Jika berasal dari minyak kelapa atau minyak inti sawit, asam lemak bebas dihitung sebagai asam laurat;<br> c. Jika berasal dari minyak nabati lainnya, asam lemak bebas dihitung sebagai asam oleat.",
    "Aktif",
  ],
  [
    "02010210",
    "Pengganti Minyak Mentega (Butter Oil Substitute)",
    "Pengganti minyak mentega (butter oil substitute) adalah minyak nabati dengan atau tanpa penambahan lemak hewani dan atau lemak susu yang digunakan sebagai pengganti minyak mentega dengan sifat fisik dan rasa seperti mentega.<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,15%;<br> - Kadar asam lemak bebas (dihitung sebagai asam lemak dominan<br> dari minyak nabati yang digunakan) tidak lebih dari 0,3%, yaitu :<br> a. Jika berasal dari minyak sawit, asam lemak bebas dihitung sebagai asam palmitate;<br> b. Jika berasal dari minyak kelapa atau minyak inti sawit, asam lemak bebas dihitung sebagai asam laurat;<br> c. Jika berasal dari minyak nabati lainnya, asam lemak bebas dihitung sebagai asam oleat.",
    "Aktif",
  ],
  [
    "02010214",
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO)",
    "Minyak kelapa sawit adalah minyak yang diperoleh dari hasil proses rafinasi / pemurnian minyak kelapa sawit mentah.<br> <br> Karakteristik dasar:<br> - Kadar air dan kotoran tidak lebih dari 0.1%;<br> - Bilangan iod 50 - 55 g I2/100 g;<br> - Bilangan peroksida tidak lebih dari 10 mek O2/kg;<br> - Kadar asam lemak bebas dihitung sebagai asam palmitat tidak lebih dari 0.1%.",
    "Aktif",
  ],
  [
    "02010215",
    "Serbuk Minyak Kelapa Sawit",
    "Serbuk minyak kelapa sawit adalah minyak kelapa sawit yang dikeringkan menjadi serbuk dengan tambahan tepung atau sejenisnya.",
    "Tidak Aktif",
  ],
  [
    "02010218",
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein)",
    "Minyak olein kelapa sawit adalah fraksi cair minyak kelapa sawit yang berwarna kekuningan yang diperoleh dari hasil proses rafinasi / pemurnian minyak olein kelapa sawit mentah (Crude Palm Oil / CPO) atau fraksinasi minyak kelapa sawit yang sudah dirafina",
    "Aktif",
  ],
  [
    "02010219",
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin)",
    "Minyak stearin kelapa sawit adalah fraksi padat minyak kelapa sawit yang berwarna kekuningan yang diperoleh dari hasil proses rafinasi /<br> pemurnian stearin kelapa sawit mentah (crude palm stearin), atau fraksinasi minyak kelapa sawit (RBD palm oil).",
    "Aktif",
  ],
  [
    "02010221",
    "Serbuk Minyak Kelapa Virgin",
    "Serbuk minyak kelapa virgin adalah minyak kelapa virgin yang dikeringkan menjadi serbuk dengan tambahan tepung atau sejenisnya.",
    "Tidak Aktif",
  ],
  [
    "02010222",
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil )",
    "Minyak kelapa adalah minyak yang diperoleh dari hasil proses rafinasi / pemurnian dari minyak kelapa mentah (crude coconut oil).",
    "Aktif",
  ],
  [
    "02010223",
    "Serbuk Minyak Kelapa",
    "Serbuk minyak kelapa adalah minyak kelapa yang dikeringkan menjadi serbuk dengan tambahan tepung atau sejenisnya.",
    "Tidak Aktif",
  ],
  [
    "02010224",
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/<br> Refined Bleached Deodorized Groundnut Oil)",
    "Minyak kacang tanah adalah minyak makan yang diperoleh dari biji kacang tanah (Arachis hypogea L.) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010225",
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil)",
    "Minyak jagung adalah minyak makan yang diperoleh dari biji jagung (Zea mays L.) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010226",
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil)",
    "Minyak kemiri adalah minyak yang diperoleh dari biji kemiri (Aleurites mollucana Wild) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010227",
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil)",
    "Minyak kedelai adalah minyak makan yang diperoleh dari biji kedelai (Glycine max (L) Merr.) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010228",
    "Minyak Wijen (Sesame Oil)",
    "Minyak wijen adalah minyak yang diperoleh dari biji wijen (Sesamum indicum L) dengan atau tanpa mengalami proses sangrai (roasted).",
    "Aktif",
  ],
  [
    "02010229",
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil)",
    "Minyak zaitun adalah minyak yang diperoleh dari buah Zaitun (Olea europaea) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010230",
    "Minyak Safflower",
    "Minyak safflower adalah minyak makan yang diperoleh dari biji Carthamus tintorius dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010231",
    "Minyak Biji Bunga Matahari",
    "Minyak biji bunga matahari adalah minyak makan yang diperoleh dari biji bunga matahari (Helianthus annuus L.) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010232",
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached<br> Deodorized Rice Brand Oil)",
    "Minyak dedak atau minyak bekatul atau minyak katul adalah minyak dari katul beras pecah kulit tanaman padi (Oryza sativa) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010233",
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil)",
    "Minyak biji kapas adalah minyak yang diperoleh dari biji kapas (Gossypium sp.) dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010234",
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil)",
    "Rapeseed oil adalah minyak yang dihasilkan dari biji Brassica<br> napus L., Brassica rapa L., Brassica juncea L. dan Brassica<br> tournefortii Gouan",
    "Aktif",
  ],
  [
    "02010235",
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil)",
    "Mustardseed oil adalah minyak yang diperoleh dari biji Brassica juncea atau Brassica nigra dan telah mengalami proses rafinasi / pemurnian.",
    "Aktif",
  ],
  [
    "02010236",
    "Extra Virgin Olive Oil",
    "Extra virgin olive oil adalah virgin olive oil dengan kadar asam<br> lemak bebas sebagai asam oleat tidak lebih dari 0,8 gram per 100<br> gram",
    "Aktif",
  ],
  [
    "02010237",
    "Minyak Goreng Sawit",
    "Bahan pangan dengan komposisi utama trigliserida berasal dari minyak sawit, dengan atau tanpa perubahan kimiawi, pendinginan dan telah melalui proses pemurnian dengan penambahan vitamin A.",
    "Aktif",
  ],
  [
    "02010239",
    "Virgin olive oil",
    "Virgin olive oil adalah virgin olive oil dengan kadar asam lemak bebas sebagai asam oleat tidak lebih dari 2 gram per 100 gram",
    "Aktif",
  ],
  [
    "02010240",
    "Ordinary Virgin olive oil",
    "Ordinary virgin olive oil adalah virgin olive oil dengan kadar asam<br> lemak bebas sebagai asam oleat tidak lebih dari 3,3 gram per 100<br> gram",
    "Aktif",
  ],
  [
    "02010241",
    "Minyak Goreng Padat (Frying Fat)",
    "Minyak goreng yang dalam suhu ruang berbentuk padat atau semi padat atau semi liquid yang berasal dari minyak sawit dan atau dicampur dengan minyak nabati lainnya, dengan atau tanpa perubahan kimiawi, hidrogenasi penuh, pendinginan dan telah melalui proses pemurnian<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,1%;<br> - Kadar asam lemak bebas sebagai asam palmitat tidak lebih dari<br> 0.3%;<br> - Bilangan peroksida tidak lebih dari 10 mek O2/kg;<br> - Kadar asam lemak trans 0%<br>",
    "Aktif",
  ],
  [
    "02010242",
    "Serbuk Lemak (Fat Powder)",
    "Serbuk lemak adalah produk lemak nabati dan atau lemak hewani yang berbentuk serbuk dengan atau tanpa penambahan bahan pengisi. Contoh : Serbuk Lemak Kelapa Sawit, Serbuk Lemak Kelapa Virgin, Serbuk Lemak Kelapa, Serbuk Minyak Ikan.",
    "Aktif",
  ],
  [
    "02010243",
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil)",
    "Rapeseed oil\xE2\x{20AC}\x{201C}low erucic acid adalah minyak yang dihasilkan dari minyak rendah asam erusat biji Brassica napus L., Brassica rapa L. and Brassica juncea L.",
    "Aktif",
  ],
  [
    "02010244",
    "Minyak Goreng (Frying oil)",
    "Minyak Goreng (Frying oil) adalah bahan pangan dengan komposisi utama trigliserida berasal dari bahan nabati kecuali kelapa sawit, dengan atau tanpa perubahan kimiawi, termasuk hidrogenasi, pendinginan dan telah melalui proses rafinasi/pemurnian yang digunakan untuk menggoreng.<br> <br> Karakteristik dasar :<br> - Kadar air tidak lebih dari 0,15%;<br> - Bilangan asam tidak lebih dari 0,6%;<br> - Bilangan peroksida tidak lebih dari 10 mek O2/kg;<br> - Kadar asam lemak linolenat tidak lebih dari 2%;<br> - Kadar asam lemak trans 0%.<br>",
    "Aktif",
  ],
  [
    "02010245",
    "Serbuk Lemak Nabati (Fat Powder)",
    "Serbuk lemak adalah produk lemak nabati yang berbentuk serbuk dengan atau tanpa penambahan bahan pengisi. Contoh : Serbuk Lemak Kelapa Sawit, Serbuk Lemak Kelapa Virgin, dan Serbuk Lemak Kelapa.",
    "Aktif",
  ],
  [
    "02010248",
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil)",
    "Rapeseed oil adalah minyak yang dihasilkan dari biji Brassica napus L., Brassica rapa L., Brassica juncea L. dan Brassica tournefortii Gouan.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Bilangan penyabunan 168 mg KOH/g hingga 181 mg KOH/g<br> \xE2\x{20AC}\xA2 Bilangan iod 94 Wijs hingga 120 Wijs<br> \xE2\x{20AC}\xA2 Komposisi asam lemak minyak rapeseed lihat pada tabel komposisi asam lemak<br>",
    "Aktif",
  ],
  [
    "02010249",
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil",
    "Minyak biji rami/flaxseed oil/linseed oil merupakan minyak yang diperoleh dari biji tanaman Linum usitatissimum.",
    "Aktif",
  ],
  [
    "02010301",
    "Lemak Hewani",
    "Lemak hewani adalah lemak yang diperoleh dari hewan yang sehat pada saat disembelih dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010302",
    "Lemak Babi atau Lard",
    "Lemak babi atau lard adalah lemak yang diperoleh dari pelelehan (rendered) jaringan lemak babi (Sus scorfa) yang bersih dan segar, yang diperoleh dari babi yang sehat pada saat sticking (penusukan) dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010303",
    "Rendered Pork Fat",
    "Rendered pork fat adalah lemak yang diperoleh dari pelelehan (rendered) jaringan dan tulang babi (Sus scorfa) yang bersih dan segar, yang diperoleh dari babi yang sehat pada saat sticking (penusukan) dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010304",
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock))",
    "Lemak sapi utama atau (prime beef fat (premier jus atau oleo stock)) adalah lemak yang diperoleh dari pelelehan pada suhu rendah (50\\xB0C-55\\xB0C), lemak ini disayat dari jantung, caul, ginjal, mesentary yang diperoleh dari sapi yang sehat pada saat disembelih",
    "Aktif",
  ],
  [
    "02010305",
    "Lemak Sapi (Edible Beef Fat)",
    "Lemak sapi adalah lemak yang diperoleh dari pelelehan jaringan lemak sapi, bagian perut dan sekitar ginjal dan jantung serta bagian jaringan lemak lain yang utuh dari sapi yang sehat pada saat disembelih dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010306",
    "Dripping atau Edible Tallow",
    "Dripping atau edible tallow adalah lemak yang diperoleh dari pelelehan jaringan lemak sapi, domba atau kambing atau campurannya yang sehat pada saat disembelih dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010307",
    "Secunda Beef Fat",
    "Secunda beef fat adalah lemak yang memiliki bau dan rasa khas lemak sapi yang diperoleh dari pelelehan pada suhu 60\\xB0C-65\\xB0C dan penyaringan / pemisahan.",
    "Aktif",
  ],
  [
    "02010308",
    "Suet",
    "Suet adalah lemak yang diperoleh dari pelelehan jaringan lemak bagian ginjal, atau daging daerah pinggang atau caul dari sapi, kambing atau domba atau campurannya yang sehat pada saat disembelih dan aman untuk dikonsumsi manusia.",
    "Aktif",
  ],
  [
    "02010309",
    "Minyak Ikan",
    "Minyak ikan adalah minyak yang diperoleh dari ikan segar yang sesuai seperti ikan herring, sarden/tuna, sprat dan teri.",
    "Aktif",
  ],
  [
    "02010312",
    "Serbuk Lemak Hewani (Fat Powder)",
    "Serbuk lemak hewani adalah produk lemak hewani yang berbentuk serbuk dengan atau tanpa penambahan bahan pengisi. Contoh: Serbuk Minyak Ikan.<br>",
    "Aktif",
  ],
  [
    "0202010101",
    "Mentega",
    "Mentega adalah produk emulsi lemak berbentuk padat atau semi padat yang dibuat dari susu atau krim susu atau campurannya, dengan atau tanpa penambahan bahan makanan lain seperti garam.",
    "Aktif",
  ],
  [
    "0202010102",
    "Mentega Rekombinasi",
    "Mentega rekombinasi adalah produk emulsi lemak yang dibuat dari lemak susu anhidrat (AMF), air dan padatan susu atau susu skim, dengan atau tanpa penambahan bahan makanan lain seperti garam.",
    "Aktif",
  ],
  [
    "0202010201",
    "Margarin",
    "Margarin adalah produk emulsi lemak berbentuk padat atau semi padat, yang dibuat dari minyak atau lemak nabati dan air, dengan atau tanpa penambahan bahan makanan lain seperti garam.",
    "Tidak Aktif",
  ],
  [
    "02020103",
    "Campuran Margarin dan Mentega (Blends of butter and margarine)",
    "produk emulsi lemak berbentuk<br> padat/ semi padat yang dibuat dari campuran minyak/ lemak<br> nabati & lemak susu anhidrat (AMF)/ minyak mentega (butteroil)<br> & air, dengan/ tanpa penambahan bahan lain seperti garam",
    "Tidak Aktif",
  ],
  [
    "02020201",
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound",
    "Minarin, margarin krim, fat spread (margarin oles), margarine compound,bread compound dan bakery compound adalah produk emulsi lemak berbentuk padat atau semi padat dibuat dari minyak atau lemak dan airdengan atau tanpa penambahan bahan makanan lain seper",
    "Tidak Aktif",
  ],
  [
    "02020202",
    "Lemak Oles Loyang (Pan Release)",
    "Lemak oles loyang adalah produk emulsi lemak dan atau minyak<br> yang bersifat dapat dioles atau di spray pada loyang, berbentuk<br> emulsi air dalam minyak dan atau lemak, dapat digunakan untuk<br> melepaskan roti dan kue dari loyang.",
    "Aktif",
  ],
  [
    "02020203",
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound",
    "Margarin krim, fat spread (margarin oles), margarine compound,<br> bread compound dan bakery compound adalah produk emulsi<br> lemak berbentuk padat atau semi padat dibuat dari minyak atau<br> lemak dan air dengan atau tanpa penambahan bahan makanan<br> lain seperti garam",
    "Aktif",
  ],
  [
    "02020204",
    "Minarin atau Halvarine",
    "Minarin atau Halvarine adalah produk emulsi lemak berbentuk<br> padat atau semi padat dibuat dari minyak atau lemak dan air<br> dengan atau tanpa penambahan bahan makanan lain seperti<br> garam.",
    "Aktif",
  ],
  [
    "02020205",
    "Margarin",
    "Margarin adalah produk emulsi lemak berbentuk padat atau semi padat atau cair, yang dibuat dari minyak atau lemak nabati dan air, dengan atau tanpa penambahan bahan makanan lain seperti garam. Contoh : margarin meja, margarin dapur, margarin industri. Karakteristik dasar: Kandungan lemak tidak kurang dari 80%; Kadar air tidak lebih dari 18%; Untuk margarin meja harus ditambahkan vitamin A berkisar 2500 IU/100 g hingga 3500 IU/100 g dan vitamin D berkisar 250 IU/100 g hingga 350 IU/100 g.",
    "Aktif",
  ],
  [
    "02020206",
    "Campuran Margarin dan Mentega (Blends of butter and margarine)",
    "Campuran margarin dan mentega adalah produk emulsi lemak berbentuk padat atau semi padat atau cair yang dibuat dari campuran minyak atau lemak nabati dan lemak susu anhidrat (AMF) atau minyak mentega (butter oil) dan air, dengan atau tanpa penambahan bahan makanan lain seperti garam. Karakteristik dasar: Kandungan lemak tidak kurang dari 80%; Kadar air tidak lebih dari 18%; Untuk margarin meja harus ditambahkan vitamin A berkisar 2500 IU/100 g hingga 3500 IU/100 g dan vitamin D berkisar 250 IU/100 g hingga 350 IU/100 g.",
    "Aktif",
  ],
  [
    "02020207",
    "Margarin Meja",
    "Margarin meja adalah produk emulsi lemak berbentuk padat atau semi padat atau cair, yang dibuat dari minyak atau lemak nabati dan air, dengan atau tanpa penambahan bahan makanan lain seperti garam, dan peruntukannya sebagai margarin meja.",
    "Aktif",
  ],
  [
    "02020208",
    "Campuran Margarin Meja dan Mentega",
    "Campuran margarin meja dan mentega adalah produk emulsi lemak berbentuk padat atau semi padat atau cair yang dibuat dari campuran minyak atau lemak nabati dan lemak susu anhidrat (AMF) atau minyak mentega (butter oil) dan air, dengan atau tanpa penambahan bahan makanan lain seperti garam. Peruntukan margarin sebagai margarin meja.",
    "Aktif",
  ],
  [
    "02020209",
    "Minarin Meja atau Halvarine",
    "Minarin atau Halvarine adalah produk emulsi lemak berbentuk<br> padat atau semi padat dibuat dari minyak atau lemak dan air<br> dengan atau tanpa penambahan bahan makanan lain seperti<br> garam. Peruntukannya sebagai minarin meja.",
    "Aktif",
  ],
  [
    "020301",
    "Non-Dairy Toppings, Fillings, Frostings",
    "Non-dairy toppings, fillings, frostings adalah produk emulsi lemak<br> berbentuk semi padat atau cair yang terbuat dari minyak nabati<br> yang digunakan untuk topping, filling, dan frosting pada produk<br> makanan dan minuman.",
    "Aktif",
  ],
  [
    "020302",
    "Non-Dairy Whipped Cream",
    "Non-Dairy Whipped Cream adalah produk emulsi lemak yang<br> terbuat dari minyak tumbuhan berbentuk semi padat/semi cair,<br> yang siap dipakai atau dapat mengembang setelah dikocok.",
    "Aktif",
  ],
  ["020303", "Hasil Olahan Sawit - Pengganti Santan", "-", "Aktif"],
  [
    "020401",
    "Melorin atau Non-Dairy Ice Cream",
    "Melorin atau non-dairy ice cream adalah produk sejenis es krim yang dibuat dari minyak atau lemak makan nabati.",
    "Aktif",
  ],
  [
    "020402",
    "Non-Dairy Mousse",
    "Non-dairy mousse adalah produk mousse yang dibuat dari minyak atau lemak nabati.",
    "Aktif",
  ],
  [
    "0301",
    "Water Ices",
    "Water ices adalah pangan beku yang dibuat dari campuran air dan gula, dengan atau tanpa bahan pangan lain.",
    "Aktif",
  ],
  [
    "0302",
    "Es Buah (Fruit Ice)",
    "Es buah (fruit ice) adalah produk beku yang dibuat dari campuran air, sari buah/bubur buah/puree buah/potongan buah, gula, dengan atau tanpa bahan pangan lain.",
    "Aktif",
  ],
  [
    "0303",
    "Es Mambo",
    "Es mambo adalah produk beku yang dibuat dari campuran air dan gula, dengan atau tanpa bahan pangan lain, dikemas, berbentuk kecil panjang atau bentuk lain.",
    "Aktif",
  ],
  [
    "0304",
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok",
    "Es jepit atau es serut atau es gusruk /gosrok adalah es batu yang diserut, diberi gagang (stick), dijepit dan ditekan dalam batok kelapa atau cetakan yang bentuknya macam-macam lalu dibaluri sirup gula warna-warni.",
    "Tidak Aktif",
  ],
  [
    "0305",
    "Es Puter",
    "Es puter adalah produk beku yang dibuat dari pati dan/atau tepung, air, gula, santan, dengan atau tanpa bahan pangan lain yang proses pembekuannya sambil diaduk atau diputar sehingga teksturnya menyerupai es krim.",
    "Aktif",
  ],
  [
    "0306",
    "Es Lilin Goyang",
    "Es lilin goyang adalah campuran santan dengan pemanis, pewarna, perisa, dengan atau tanpa penambahan bahan pangan lainnya, dicetak dalam cetakan persegi panjang yang direndam dalam es batu dan garam dalam<br> gerobak atau yang lainnya. Campuran ingredien dibe",
    "Aktif",
  ],
  [
    "0307",
    "Es Lilin",
    "Es lilin adalah produk beku yang dibuat dari campuran air, santan, gula, dengan atau tanpa bahan pangan lain yang dicetak dan dikemas.",
    "Aktif",
  ],
  [
    "0308",
    "Es Kue",
    "Es kue adalah produk beku yang dibuat dari pati kacang hijau atau pati lain yang dimasak dengan gula, dengan atau tanpa bahan pangan lain, dicetak dan dikemas.",
    "Aktif",
  ],
  [
    "0309",
    "Sherbet",
    "Produk beku yang dibuat dari campuran air, sari buah/sayur dan/atau bubur buah/sayur (puree buah/sayur), gula, dan susu atau produk susu, dengan atau tanpa bahan pangan lain, melalui proses pembekuan sambil diaduk atau diputar sehingga memiliki<br> tekstur seperti es krim.",
    "Aktif",
  ],
  [
    "0310",
    "Sorbet",
    "Produk beku yang dibuat dari campuran air, sari buah/sayur dan/atau bubur buah/sayur (puree buah/sayur), gula, dengan atau tanpa bahan pangan lain, melalui proses pembekuan sambil diaduk atau diputar sehingga memiliki tekstur seperti es krim.",
    "Aktif",
  ],
  [
    "0311",
    "Es Stik (Ice Stick) atau Es Loli",
    "Es stik (ice stick) atau es loli adalah produk beku yang dibuat dari bahan utama air dan gula, dengan atau tanpa bahan pangan lain dan dilengkapi dengan gagang (stik).",
    "Aktif",
  ],
  ["0312", "Es Pelangi", "", "Tidak Aktif"],
  ["0313", "Es Tebak", "", "Tidak Aktif"],
  ["0314", "Es Loli", "", "Tidak Aktif"],
  [
    "0315",
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku",
    "Sediaan cair yang akan dikonsumsi dalam keadaan beku adalah sediaan cair dari produk es kategori 03.0 yang akan dikonsumsi dalam keadaan beku.",
    "Aktif",
  ],
  [
    "0316",
    "Es Batu Untuk Konsumsi",
    "Es batu untuk konsumsi adalah massa padat hasil pembekuan air<br> minum, tanpa bahan pangan lain, dikemas, serta aman untuk<br> dikonsumsi. Es batu dapat dalam bentuk kubus, tabung, keping, pelat, serut, atau bentuk lain",
    "Aktif",
  ],
  [
    "0317",
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril",
    "-",
    "Aktif",
  ],
  [
    "0318",
    "Es Rasa Susu",
    "Es rasa susu adalah produk beku yang dibuat dari campuran air, gula, dan susu, dan dapat ditambahkan bahan pangan lain.<br> Karakteristik dasar :<br> - Kadar lemak susu kurang dari 0.5%<br> - Total padatan susu bukan lemak tidak kurang dari 1.1%",
    "Aktif",
  ],
  [
    "0320",
    "Es Mengandung Susu",
    "Es mengandung susu adalah produk beku yang dibuat dari campuran air, susu dan/atau produk susu, dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar:<br> Kadar protein susu 0,3% sampai kurang dari 1%.",
    "Aktif",
  ],
  [
    "0321",
    "Premiks Es Bentuk Bubuk",
    "Premiks es bentuk bubuk adalah produk berbentuk bubuk yang digunakan untuk membuat produk es kategori 03.0.",
    "Aktif",
  ],
  [
    "0322",
    "Premiks Es Bentuk Cair",
    "Premiks es bentuk cair adalah produk berbentuk cair yang digunakan untuk membuat produk es kategori 03.0.",
    "Aktif",
  ],
  ["04010201", "Buah Beku", "", "Aktif"],
  [
    "0401020101",
    "Buah Beku",
    "Buah beku adalah produk buah yang diperoleh dari buah segar dan bersih dengan kematangan sesuai dengan tujuan penggunaan, dalam keadaan utuh atau potongan dengan atau tanpa penambahan gula atau sirup, yang dikemas dan dibekukan.<br> Sebelum pembekuan buah dapat diblansir. Pembekuan harus dilakukan sedemikian rupa sehingga kisaran suhu pembentukan kristal es dilalui secara cepat. Pembekuan cepat dianggap selesai apabila suhu pusat telah mencapai -18oC. Pengemasan ulang produk beku diperbolehkan dalam kondisi yang terkontrol.",
    "Tidak Aktif",
  ],
  [
    "0401020102",
    "Buah beku dalam gula kering",
    "Buah beku adalah produk buah yang diperoleh dari buah segar dan bersih dengan kematangan sesuai dengan tujuan penggunaan, dalam keadaan utuh atau potongan dengan atau tanpa penambahan gula atau sirup, yang dikemas dan dibekukan.<br> Sebelum pembekuan buah dapat diblansir. Pembekuan harus dilakukan sedemikian rupa sehingga kisaran suhu pembentukan kristal es dilalui secara cepat. Pembekuan cepat dianggap selesai apabila suhu pusat telah mencapai -18oC. Pengemasan ulang produk beku diperbolehkan dalam kondisi yang terkontrol.",
    "Tidak Aktif",
  ],
  [
    "0401020103",
    "Buah beku dalam sirup",
    "Buah beku adalah produk buah yang diperoleh dari buah segar dan bersih dengan kematangan sesuai dengan tujuan penggunaan, dalam keadaan utuh atau potongan dengan atau tanpa penambahan gula atau sirup, yang dikemas dan dibekukan.<br> Sebelum pembekuan buah dapat diblansir. Pembekuan harus dilakukan sedemikian rupa sehingga kisaran suhu pembentukan kristal es dilalui secara cepat. Pembekuan cepat dianggap selesai apabila suhu pusat telah mencapai -18oC. Pengemasan ulang produk beku diperbolehkan dalam kondisi yang terkontrol.",
    "Tidak Aktif",
  ],
  [
    "0401020104",
    "Buah Goreng Beku",
    "Untuk memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0401020201",
    "Buah Kering",
    "Buah kering adalah produk buah yang diperoleh dari buah yang segar dan bersih yang dikeringkan dengan pengeringan alami atau pengering buatan untuk mencegah terjadinya pertumbuhan mikroba, dengan atau tanpa penambahan gula, glukosa, gliserol, sorbitol, lemak dan minyak makan.",
    "Tidak Aktif",
  ],
  [
    "0401020202",
    "Buah Kering Campur",
    "Buah kering campur adalah produk buah yang diperoleh dari campuran dua jenis atau lebih buah kering dengan kandungan buah kering tidak kurang dari 70%.",
    "Tidak Aktif",
  ],
  [
    "0401020203",
    "Buah Kering Asin",
    "Buah kering asin adalah produk buah yang diperoleh dari proses penggaraman buah dengan atau tanpa gula, dan dikeringkan dengan pengering alami atau pengering buatan.",
    "Tidak Aktif",
  ],
  [
    "0401020204",
    "Kopra",
    "Kopra adalah daging buah tanaman kelapa Cocos nucifera Linn yang dikeringkan dengan penjemuran, pengasapan atau pengeringan mekanis lainnya.",
    "Tidak Aktif",
  ],
  [
    "0401020205",
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven",
    "Kelapa parut kering adalah produk pangan yang diperoleh dari proses pemarutan daging buah kelapa tua yang segar tanpa kulit ari.",
    "Aktif",
  ],
  ["0401020206", "-", "-", "Tidak Aktif"],
  [
    "0401020207",
    "Buah Kering dengan Penambahan Bahan Lain",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0401020208",
    "Buah Kering (Freeze Dried)",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0401020209",
    "Santan Bubuk",
    "Santan bubuk adalah produk berbentuk bubuk yang diperoleh dari pengeringan santan encer, santan, krim kelapa, dan/atau konsentrat krim kelapa.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar lemak kelapa tidak kurang dari 5% dihitung setelah rekonstitusi",
    "Aktif",
  ],
  [
    "0401020210",
    "Tepung Buah",
    "Tepung buah adalah produk tepung yang diperoleh dari proses pengeringan dan penggilingan atau penumbukan buah. Nama produk untuk kategori ini misal tepung kelapa.",
    "Aktif",
  ],
  [
    "0401020301",
    "Buah Asin",
    "Buah asin adalah produk buah yang diperoleh dari proses penggaraman buah atau perendaman buah dalam larutan garam.",
    "Tidak Aktif",
  ],
  [
    "0401020302",
    "Asinan Buah",
    "Asinan buah adalah produk buah yang diperoleh dari satu jenis atau lebih buah segar dan/atau manisan buah, dengan atau tanpa bahan pangan yang diberi kuah yang dibuat dari gula, cuka dan bahan pangan lain.",
    "Aktif",
  ],
  [
    "0401020303",
    "Rujak",
    "Rujak adalah produk buah yang diperoleh dari satu jenis atau lebih buah segar, dengan atau tanpa bahan pangan lain, yang diberi kuah kental yang terbuat dari gula merah dan/atau bahan pangan lain.",
    "Aktif",
  ],
  [
    "0401020401",
    "Buah Dalam Kaleng",
    "Buah dalam kemasan adalah produk buah yang diperoleh dari satu atau dua jenis buah yang bersih, baik yang berbentuk utuh atau potongan, dengan atau tanpa penambahan gula dan medium yang sesuai (seperti air, campuran air dan jus buah atau jus buah), yang dikemas secara kedap (hermetis) dan diproses dengan pemanasan (pasteurisasi/ sterilisasi) untuk mencegah kebusukan",
    "Aktif",
  ],
  [
    "0401020402",
    "Kolang Kaling Dalam Kemasan",
    "Kolang kaling dalam kemasan adalah produk buah yang diperoleh dari inti buah aren (Arenga pinnata MERR atau Arenga saccharifera LABELL) yang diolah dengan penambahan larutan gula dan dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    "0401020403",
    "Koktil Buah Dalam Kemasan",
    "Koktil buah dalam kemasan adalah produk buah yang diperoleh dari dua jenis atau lebih buah yang bersih, baik yang berbentuk utuh atau potongan, dengan medium yang sesuai (seperti air, campuran air dan jus buah, atau jus buah), dengan atau tanpa penambahan gula, yang dikemas secara kedap (hermetis) dan diproses dengan pasteurisasi/sterilisasi.",
    "Aktif",
  ],
  [
    "0401020404",
    "Buah dalam Kemasan",
    "Buah dalam kemasan adalah produk buah yang diperoleh dari satu jenis atau lebih buah yang bersih, baik yang berbentuk utuh atau potongan, dengan medium yang sesuai (seperti air, campuran air dan jus buah, atau jus buah), dengan atau tanpa penambahan gula yang dikemas secara kedap (hermetis) dan diproses (pasteurisasi/ sterilisasi). Nama jenis untuk kategori ini mengacu pada jenis buah yang digunakan.",
    "Aktif",
  ],
  [
    "0401020501",
    "Jem Buah atau Selai Buah",
    "Jem buah atau selai buah adalah produk buah yang kental dan dapat dioles, dibuat dari pendidihan satu jenis atau lebih buah utuh, potongan buah, bubur atau puree buah dengan tambahan gula dan/atau pemanis lain, dengan atau tanpa penambahan pektin. Termasuk dalam kategori ini preserve dan conserve.",
    "Aktif",
  ],
  [
    "0401020502",
    "Jeli Buah",
    "Jeli buah adalah produk buah berbentuk jel yang dapat dioles yang diperoleh dari pendidihan satu jenis buah atau lebih sari buah atau ekstrak air dari buah, dengan tambahan gula dan/atau pemanis lain, dengan atau tanpa penambahan pektin.",
    "Aktif",
  ],
  [
    "0401020503",
    "Marmalad",
    "Marmalad adalah produk bubur buah kental dan dapat dioles yang diperoleh dari pendidihan buah utuh, bubur buah atau puree buah dengan gula untuk mengentalkan. Dapat ditambahkan pektin, irisan buah dan irisan kulit buah. Termasuk dalam kategori ini marmalad sitrus dan jeli marmalad.",
    "Aktif",
  ],
  [
    "0401020601",
    "Chutney Mangga (Mango Chutney)",
    "Chutney mangga (mango chutney) adalah produk buah yang<br> diperoleh dari buah mangga yang bersih, yang telah dikupas,<br> dipotong, dirajang, diiris atau dihancurkan dengan penambahan bahan lain dan dipanaskan sebelum atau sesudah penutupan pengemas. Bahan lain terdiri dari gula, madu, buah lain dan sayur, garam, dan kondimen (seperti cuka, bawang putih, bawang bombay, jahe, dan lain-lain).<br> <br> Karakteristik dasar:<br> \x{2022}Kandungan buah mangga tidak kurang dari 40%;<br> \x{2022}Total padatan terlarut 50%;<br> \x{2022}Produk harus memiliki flavor chutneymangga.",
    "Aktif",
  ],
  [
    "0401020602",
    "Sambal Buah",
    "Antara lain sambal nanas, sambal mangga, sambal kueni, sambal gandaria, sambal tempoyak.",
    "Tidak Aktif",
  ],
  [
    "0401020603",
    "Produk Buah Oles",
    "Produk buah oles adalah produk yang diperoleh dari pencampuran hasil olahan buah dengan bahan pangan lain, dan diolah menjadi produk yang dapat dioles, Nama jenis produk ini misal olesan berbasis kelapa.<br>",
    "Aktif",
  ],
  [
    "0401020701",
    "Buah Bergula atau Buah Bersalut Gula",
    "Buah bergula atau buah bersalut gula adalah produk buah yang diperoleh dari pemberian gula, gliserol atau sorbitol terhadap bagian buah yang dapat dimakan atau campuran buah. Ceri (Cherry) bergula dapat mengandung pewarna.",
    "Tidak Aktif",
  ],
  [
    "0401020702",
    "Buah Berkristal",
    "Buah berkristal adalah buah yang dilumuri dengan tepung gula atau gula kristal dan dikeringkan sehingga permukaannya terdapat kristal gula.",
    "Aktif",
  ],
  [
    "0401020703",
    "Kulit Buah Bergula",
    "Kulit buah bergula adalah kulit buah yang diperoleh dengan memperlakukan (antara lain dicelupkan, direndam, disemprot) kulit buah dalam larutan gula dan dikeringkan.",
    "Aktif",
  ],
  [
    "0401020704",
    "Buah Bergula",
    "Buah bergula adalah buah bersalut yang dicelupkan dalam larutan gula dan dikeringkan sehingga buah tertutupi lapisan seperti permen.<br>",
    "Aktif",
  ],
  [
    "0401020705",
    "Buah Bersalut",
    "Buah bersalut adalah buah yang diperoleh dengan memperlakukan buah (antara lain dicelupkan, direndam, disemprot) dalam larutan gula dan dikeringkan.",
    "Aktif",
  ],
  [
    "0401020801",
    "Bubur Buah (Fruit Pulp)",
    "Bubur buah (fruit pulp) adalah produk buah yang diperoleh dari buah segar yang dihancurkan tanpa mengekstrak jusnya.",
    "Aktif",
  ],
  [
    "0401020802",
    "Puree Buah",
    "Puree buah adalah produk buah yang diperoleh dari buah segar atau buah yang didinginkan atau dibekukan dengan kematangan yang cukup yang dihancurkan tanpa mengekstrak sari buahnya.",
    "Aktif",
  ],
  [
    "0401020803",
    "Pasta Buah",
    "Pasta buah adalah produk buah yang dibuat dari puree buah yang telah mengalami pemekatan.",
    "Aktif",
  ],
  [
    "0401020804",
    "Saus Buah",
    "Saus buah adalah produk buah yang diperoleh dari pendidihan bubur buah dengan atau tanpa penambahan gula dan dapat mengandung potongan buah. Saus buah dapat digunakan sebagai topping untuk produk roti dan es krim sundaes.",
    "Aktif",
  ],
  [
    "0401020805",
    "Saus Apel (Applesauce)",
    "Saus apel (applesauce) adalah produk buah yang diperoleh dari buah apel yang dirajang atau dihancurkan, dengan atau tanpa kulit yang telah dipisahkan dari bijinya, dapat ditambahkan bahan lain. Saus apel mengandung air, jus apel, garam, gula dan asam orga",
    "Tidak Aktif",
  ],
  [
    "0401020806",
    "Topping Buah",
    "Topping buah adalah produk buah yang diperoleh dari pendidihan bubur buah, lebih encer dari pada saus buah dan dapat digunakan sebagai topping panekuk.",
    "Aktif",
  ],
  [
    "0401020807",
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa",
    "Santan adalah produk emulsi yang diperoleh dari ekstraksi daging buah kelapa (Cocos nucifera) yang cukup tua dan segar; atau rekonstitusi krim kelapa bubuk dengan air; atau dispersi endosperm kelapa kering halus dengan air; atau kombinasi ekstraksi daging buah kelapa yang cukup tua dan segar dengan dispersi endosperm kelapa kering halus dengan air. Bahan baku santan dapat terdiri dari krim kelapa bubuk, endosperm kelapa (Cocos nucifera), dan air.<br> <br> Karakteristik dasar:<br> \x{2022}Santan encer : kadar lemak kelapa tidak kurang dari 5%; total padatan 6,6-12,6%<br> \x{2022}Santan : kadar lemak kelapa tidak kurang dari 10%;total padatan 12,7-25,3%<br> \x{2022}Krim kelapa : kadar lemak kelapa tidak kurang dari 20%; total padatan 25,4-37,3%<br> \x{2022}Konsentrat krim kelapa : kadar lemak kelapa tidak kurang dari 29%, total padatan tidak kurang dari 37,4%",
    "Aktif",
  ],
  [
    "0401020808",
    "Santan Ekstraksi Air",
    "Santan ekstraksi air adalah adalah produk emulsi buah dengan proses ekstraksi air dari daging buah kelapa (Cocos nucifera) yang cukup tua dan sehat.",
    "Tidak Aktif",
  ],
  [
    "0401020809",
    "Krim Kelapa",
    "Krim kelapa adalah produk yang diperoleh dari santan atau santan ekstraksi air yang diambil krimnya dengan pemisahan airnya.",
    "Tidak Aktif",
  ],
  [
    "0401020810",
    "Pasta Kelapa",
    "Pasta kelapa adalah produk buah kelapa yang diperoleh dari ekstraksi air parutan kelapa atau kelapa kering dengan cara evaporasi sampai membentuk pasta.",
    "Tidak Aktif",
  ],
  [
    "0401020811",
    "Nata",
    "Nata merupakan selulosa mikrobia yang dihasilkan oleh bakteri<br> asam cuka (Acetobacter xilynum) dari hasil fermentasi air kelapa,<br> santan kelapa dan/atau bahan lainnya.",
    "Aktif",
  ],
  [
    "0401020812",
    "Konsentrat Asam Jawa/Tamarin",
    "Konsentrat asam jawa/tamarin adalah produk tamarin yang diperoleh dari ekstrak bersih buah tamarin dengan total padatan terlarut tidak kurang dari 65%.",
    "Aktif",
  ],
  [
    "0401020813",
    "Bubuk Asam Jawa/Tamarin",
    "Bubuk asam jawa/tamarin adalah produk tamarin yang diperoleh dari pasta tamarin yang dicampur dengan pati.",
    "Aktif",
  ],
  [
    "0401020814",
    "Toffee Asam Jawa/Tamarin",
    "Toffee asam jawa/tamarin adalah produk tamarin yang diperoleh dari hancuran buah tamarin yang dicampur dengan gula, padatan susu, dan lain-lain.",
    "Tidak Aktif",
  ],
  [
    "0401020815",
    "Bars Buah",
    "Bars buah adalah produk buah yang diperoleh dari hancuran buahbuahan (mangga, nanas atau jambu) yang dicampur dengan gula, lalu dikeringkan sampai berbentuk lembaran.",
    "Aktif",
  ],
  [
    "0401020816",
    "Tepung Buah",
    "Tepung buah adalah produk halus dan bersih yang diperoleh dari penggilingan atau penumbukan buah.",
    "Tidak Aktif",
  ],
  [
    "0401020817",
    "Saus Buah dalam Kaleng",
    "Saus buah adalah produk buah yang diperoleh dari pendidihan<br> bubur buah dengan atau tanpa penambahan gula dan dapat<br> mengandung potongan buah. Saus buah dapat digunakan sebagai<br> topping untuk produk roti dan es krim sundaes. Produk dikemas dalam kaleng.",
    "Aktif",
  ],
  ["0401020818", "Tepung Kelapa", "-", "Aktif"],
  [
    "0401020901",
    "Manisan Buah",
    "Manisan buah adalah produk buah yang diperoleh dari potongan<br> buah atau buah utuh segar yang sehat dengan penambahan gula.<br> Selain itu dapat ditambahkan bahan pangan lain. Manisan buah<br> dapat dikeringkan ataupun tidak.",
    "Aktif",
  ],
  [
    "0401020902",
    "Nata Dalam Kemasan",
    "Nata dalam kemasan adalah produk nata bertekstur kenyal yang dikemas dalam medium air dengan atau tanpa penambahan gula dengan atau tanpa penambahan bahan pangan lain, kemudian dilakukan proses pasteurisasi atau sterilisasi. Termasuk dalam kategori ini nata de coco dalam sirup.<br> <br> Karakteristik dasar:Bobot tuntas tidak kurang dari 50%.",
    "Aktif",
  ],
  [
    "0401020903",
    "Jeli Agar",
    "Jeli agar adalah produk gel buah yang diperoleh dari ekstrak atau<br> sari rumput laut dengan atau tanpa penambahan bahan pangan<br> lain.",
    "Aktif",
  ],
  [
    "0401020904",
    "Sale Pisang",
    "Sale pisang adalah produk buah semi basah yang diperoleh dari buah pisang segar dengan cara pengeringan dan atau pengasapan dan dikemas secara kedap (hermetis).",
    "Aktif",
  ],
  [
    "0401020905",
    "Cincau Hijau",
    "Cincau hijau adalah produk gel buah tradisional yang diperoleh dari<br> ekstrak atau sari daun tanaman jenis Premna oblongifolia, Cyclea<br> barbata, Melastoma polyanthum dan Stephania hermandifolia. Gel<br> cincau hijau terbentuk dalam kondisi dingin dan tidak<br> membutuhkan komponen pati. Cincau hijau dikonsumsi sebagai<br> makanan atau minuman pencuci mulut.",
    "Aktif",
  ],
  [
    "0401020906",
    "Cincau Hitam",
    "Cincau hitam adalah produk gel buah tradisional yang diperoleh<br> dari ekstrak tanaman janggelan (Mesona palustris, Mesona sinensis).<br> Gel cincau hitam terbentuk melalui proses panas dan<br> membutuhkan komponen pati. Cincau hitam dikonsumsi sebagai<br> makanan atau minuman pencuci mulut.",
    "Aktif",
  ],
  [
    "0401020907",
    "Siwalan",
    "Siwalan adalah daging buah tanaman palma Borassus flabellifer. Buah dapat diolah menjadi daging buah siwalan dalam kaleng dengan medium sirup atau air yang mengandung gula dan mengikuti kaidah proses pengalengan.",
    "Aktif",
  ],
  [
    "0401020908",
    "Mitsumame",
    "Mitsumame adalah produk makanan pencuci mulut yang berbentuk jeli agar serupa gelatin dengan potongan buah dan sirup.",
    "Aktif",
  ],
  [
    "0401020909",
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin",
    "",
    "Tidak Aktif",
  ],
  [
    "0401020910",
    "Puding Rasa/Berperisa",
    "Puding rasa/berperisa adalah produk gel siap konsumsi yang dibuat dari bahan pembentuk gel selain tepung atau pati, dan dapat ditambahkan bahan pangan lain.<br>",
    "Aktif",
  ],
  [
    "0401020911",
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah",
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah<br> Termasuk : Makanan Pencuci Mulut Berbahan Baku Kelapa",
    "Aktif",
  ],
  [
    "0401020913",
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar)",
    "Bubuk agar (agar-agar tepung/tepung agar-agar) adalah polisakarida berupa tepung yang diperoleh dari ekstraksi rumput laut alga merah Agarophyte, bersifat koloid bila dilarutkan dalam air mendidih dan menjedal bila didinginkan (reversible).",
    "Aktif",
  ],
  [
    "0401020914",
    "Agar-Agar Kertas",
    "Agar-agar kertas adalah produk olahan hasil perikanan dengan bahan baku rumput laut kering Gracilaria spp. atau Gelidium spp. yang mengalami perebusan, penyaringan, penjendalan, pemotongan, pengepresan, dan pengeringan.",
    "Aktif",
  ],
  [
    "0401020915",
    "Tepung Gelatin (Bubuk Gelatin)",
    "Tepung gelatin adalah tepung pembentuk gel yang dibuat dari gelatin.",
    "Aktif",
  ],
  [
    "0401020916",
    "Tepung Karagenan (Bubuk Karagenan)",
    "Tepung karagenan (bubuk karagenan) adalah produk bubuk pembentuk gel yang dibuat dari karagenan.",
    "Aktif",
  ],
  [
    "0401020917",
    "Jeli Agar Bubuk",
    "Jeli agar bubuk adalah produk bubuk pembentuk gel yang dibuat dari rumput laut dengan campuran bahan pembentuk gel lainnya.",
    "Aktif",
  ],
  [
    "0401020918",
    "Bubuk Puding Rasa/Berperisa",
    "Bubuk puding rasa/berperisa adalah produk bubuk yang dibuat<br> dari bahan pembentuk gel selain tepung atau pati, dapat<br> ditambahkan bahan pangan lain, dan digunakan untuk membuat puding rasa atau berperisa.",
    "Aktif",
  ],
  [
    "0401021001",
    "Pikel Pir (Pear Pickles)",
    "Pikel pir (pear pickles) adalah produk buah yang diperoleh dari buah pir /pear yang dikupas, dibuang bagian hatinya, diiris dan dipotong-potong, diberi larutan vinegar dengan atau tanpa bahan lain hingga larutan menyerupai sirup dan dikemas secara kedap (",
    "Tidak Aktif",
  ],
  [
    "0401021002",
    "Pikel Persik (Plum Pickles)",
    "Pikel persik (plum pickels) adalah produk buah diperoleh dari buah persik /plum yang dikupas, dibuang bagian hatinya, diiris dan dipotong-potong, diberi larutan vinegar dengan atau tanpa bahan lain hingga larutan menyerupai sirup, dan dikemas secara kedap",
    "Tidak Aktif",
  ],
  [
    "0401021003",
    "Tempoyak / Pakasam",
    "Tempoyak / pakasam adalah produk buah yang diperoleh dari daging buah durian yang melalui proses fermentasi asam laktat secara alami.",
    "Aktif",
  ],
  [
    "0401021004",
    "Fermentasi Buah (termasuk sari buah fermentasi)",
    "-",
    "Aktif",
  ],
  [
    "0401021005",
    "Pikel Buah",
    "Pikel buah adalah produk buah yang diperoleh dari buah yang dikupas, dan dibersihkan, dalam bentuk utuh, diiris, atau potongan, diberi larutan dan difermentasi dengan bakteri asam laktat.",
    "Aktif",
  ],
  ["04010211", "Produk Buah Untuk Isi Pastri", "", "Aktif"],
  [
    "0401021201",
    "Keripik Apel",
    "Keripik apel adalah produk buah yang diperoleh dari daging buah apel masak yang diiris dan digoreng secara vakum atau freeze drying, atau proses lain, dengan atau tanpa penambahan bahan lain.",
    "Tidak Aktif",
  ],
  [
    "0401021202",
    "Keripik Nangka",
    "Keripik nangka adalah produk buah yang diperoleh dari buah nangka yang diiris dan digoreng secara vakum atau freeze drying, atau proses lain, dengan atau tanpa penambahan bahan lain.",
    "Tidak Aktif",
  ],
  [
    "0401021203",
    "Keripik Nenas",
    "Keripik nenas adalah produk buah yang diperoleh dari daging buah nenas masak yang diiris dan digoreng secara vakum atau freeze drying, atau proses lain, dengan atau tanpa penambahan bahan lain.<br> Karakteristik dasar: Bertekstur renyah<br>",
    "Tidak Aktif",
  ],
  [
    "0401021204",
    "Keripik Pisang",
    "Keripik pisang adalah produk buah yang diperoleh dari daging buah pisang yang diiris dan digoreng atau proses lain, dengan atau tanpa penambahan bahan lain.<br> Karakteristik dasar:<br> - Memiliki rasa khas<br> - Bertekstur renyah",
    "Tidak Aktif",
  ],
  [
    "0401021205",
    "Keripik Salak",
    "Keripik salak adalah produk buah yang diperoleh dari daging buah salak masak yang diiris dan digoreng secara vakum atau freeze drying, atau proses lain, dengan atau tanpa penambahan bahan lain.<br> Karakteristik dasar:<br> - Memiliki rasa khas<br> - Bertekstur renyah",
    "Tidak Aktif",
  ],
  [
    "0401021206",
    "Keripik Sukun",
    "Keripik sukun adalah produk buah yang diperoleh dari buah sukun yang diiris dan digoreng atau proses lain, dengan atau tanpa penambahan garam atau bahan lain.<br> Karakteristik dasar:<br> - Tekstur renyah<br> - Keutuhan tidak kurang dari 90%<br> <br>",
    "Tidak Aktif",
  ],
  [
    "0401021207",
    "Keripik Buah Simulasi",
    "Keripik buah simulasi adalah produk buah yang diperoleh dari buah yang dibuat tepung dan digoreng, dengan atau tanpa penambahan bahan lain.",
    "Aktif",
  ],
  [
    "0401021208",
    "Dodol atau Lempok Buah",
    "Dodol atau lempok buah adalah produk buah yang diperoleh dari daging buah matang yang dihancurkan dan dimasak dengan atau tanpa penambahan gula.",
    "Aktif",
  ],
  [
    "0401021209",
    "Wajit Buah",
    "Wajit buah adalah produk buah yang diperoleh dari campuran buah, tepung ketan, kelapa parut dan gula.",
    "Aktif",
  ],
  [
    "0401021210",
    "Geplak",
    "Geplak adalah produk buah yang diperoleh dari campuran kelapa parut dan gula yang dikeringkan.",
    "Aktif",
  ],
  [
    "0401021211",
    "Keripik Buah",
    "Keripik buah adalah produk buah yang diperoleh dari buah yang digoreng secara vakum atau freeze drying atau proses lain, dengan atau tanpa penambahan bahan lain.",
    "Aktif",
  ],
  [
    "0402020101",
    "Sayur Beku",
    "Sayur beku adalah produk sayur yang diperoleh dari sayur segar,<br> sehat dan bersih, disimpan dalam keadaan beku dengan suhu<br> dibawah -18\xEF\x{201A}\xB0C dan tidak dicairkan (thawing) sebelum dijual.<br> Sebelum pembekuan, dilakukan blansir secukupnya untuk<br> mempertahankan warna dan flavor, dan ditiriskan. Produk dapat<br> mengandung kondimen2, daun atau minyak mint, garam dan bahan<br> lain.<br> Pengemasan ulang produk beku diperbolehkan pada kondisi yang<br> terkontrol.",
    "Tidak Aktif",
  ],
  [
    "0402020102",
    "Buncis Beku",
    "Buncis beku adalah produk sayur beku yang diperoleh dari polong buncis (Phaseolus vulgaris L.) yang segar, bersih, sehat, tanpa tangkai, dicuci dan diblansir untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020103",
    "Kacang Kapri Beku",
    "Kacang kapri beku adalah produk sayur beku yang diperoleh dari kacang kapri (Pisum sativum L.) yang segar, bersih dan sehat, dicuci dan diblansir untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020104",
    "Brokoli Beku",
    "Brokoli beku adalah produk sayur beku yang diperoleh dari brokoli (Brassica oleracea L. var. italica Plenck) yang segar, bersih, sehat, dibersihkan, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020105",
    "Brussel Sprout Beku",
    "Brussel sprout beku adalah produk sayur beku yang diperoleh dari brussel sprout (Brassica oleracea L. var gemmifera (DC) Schultz) yang segar, bersih, sehat, dibersihkan, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan",
    "Tidak Aktif",
  ],
  [
    "0402020106",
    "Bayam Beku",
    "Bayam beku adalah produk sayur beku yang diperoleh dari daun bayam yang segar, bersih, sehat, dibersihkan, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020107",
    "Wortel Beku",
    "Wortel beku adalah produk sayur beku yang diperoleh dari umbi wortel (Daucus carrota L.) yang segar, bersih dan sehat, tanpa daun, tanpa bagian atas yang berwarna hijau, tanpa akar-akar sekunder, serta dikupas dan dicuci, dengan terlebih dahulu diblansir ataupun tidak sebelum pembekuan",
    "Tidak Aktif",
  ],
  [
    "0402020108",
    "Jamur Beku",
    "Jamur beku adalah produk sayur beku yang diperoleh dari satu jenis jamur yang dapat dimakan, setelah terlebih dahulu dibersihkan, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020109",
    "Biji Jagung Beku",
    "Biji jagung beku adalah produk sayur beku yang diperoleh dari biji jagung manis (Zea mays L. convar saccharata Koern) varietas kuning atau putih yang segar, bersih dan sehat, yang telah mengalami pemipilan biji dari tongkol, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan",
    "Tidak Aktif",
  ],
  [
    "0402020110",
    "Jagung Bertongkol Beku",
    "Jagung bertongkol beku adalah produk sayur beku yang diperoleh dari jagung utuh (Zea mays L. convar saccharata Koern) yang dikupas dan dihilangkan rambutnya, dicuci dan diblansir sebelum pembekuan untuk mempertahankan warna dan flavor selama penyimpanan.",
    "Tidak Aktif",
  ],
  [
    "0402020111",
    "Kentang Goreng Beku (Frozen French Fries)",
    "Kentang goreng beku atau frozen french fries adalah produk sayur beku yang diperoleh dari kentang (Solanum tuberosum L.) yang bersih, tua dan sehat. Kentang telah mengalami pemilihan, pencucian, pengupasan dan pengirisan menjadi berbentuk batang dan diberi perlakuan untuk mempertahankan warna dan digoreng dalam minyak atau lemak makan. Proses pengolahan awal dan penggorengan harus mempertahankan warna dan flavor. Dapat ditambahkan gula, garam, dan rempah-rempah.",
    "Aktif",
  ],
  [
    "0402020112",
    "Terong Beku",
    "Terong beku adalah produk sayur beku yang diperoleh dari jenis terong (Solanum melongena) yang dapat dibekukan. Sebelum dibekukan, terong dibersihkan, dipotong, diblansir atau dikukus, didinginkan kemudian dibekukan cepat.",
    "Tidak Aktif",
  ],
  [
    "0402020113",
    "Ubi Beku",
    "Ubi beku adalah produk sayur beku yang diperoleh dari umbi tanaman Ipomea batatas yang dibekukan. Sebelum dibekukan, umbi dibersihkan, dipanggang atau direbus atau dikukus, didinginkan (kalau sebelumnya direbus, maka perlu ditiriskan sesegera mungkin), kulit dikupas, umbi dikemas dengan kemasan untuk produk beku kemudian dibekukan secara cepat.",
    "Tidak Aktif",
  ],
  [
    "0402020114",
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0402020115",
    "Sayur Goreng Beku",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0402020116",
    "Perkedel Kentang Beku",
    "Perkedel kentang beku adalah produk kentang beku yang diperoleh dari kentang (Solanum tuberosum L.), yang telah mengalami pengolahan (pengukusan/perebusan/penggorengan) dan penghancuran dengan atau tanpa penambahan bahan pangan lain dan dibekukan secara cepat.",
    "Aktif",
  ],
  [
    "0402020201",
    "Sayur Kering",
    "Sayur kering adalah produk sayur yang diperoleh dari proses pengeringan sayur, dengan atau tanpa penambahan gula, daun atau minyak mint dan pemanis, pengawet dan pewarna. Pengeringan dilakukan secara alami atau buatan. Produk dapat direhidrasi atau tidak sebelum dikonsumsi.",
    "Tidak Aktif",
  ],
  [
    "0402020202",
    "Cabe Kering",
    "Cabe kering adalah produk sayur yang diperoleh dari proses pengeringan cabe (Capsicum sp) secara alami atau pengeringan buatan.",
    "Tidak Aktif",
  ],
  [
    "0402020203",
    "Jamur Kering",
    "Jamur kering adalah produk sayur yang diperoleh melalui proses pengeringan termasuk pengeringan beku dari jamur yang dapat dimakan, baik dalam bentuk utuh maupun irisan.",
    "Tidak Aktif",
  ],
  [
    "0402020204",
    "Rumput Laut Kering",
    "Rumput laut kering adalah produk rumput laut jenis Euchema, Gellidium, Gracillaria dan Hypenea yang telah dibersihkan dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    "0402020205",
    "Nori",
    "Nori adalah produk hasil perikanan yang dibuat dari rumput laut jenis Pyropia yang mengalami perlakukan pengeringan, dan setelah dikeringkan produk akan dipanggang dan/atau diberi penambahan bumbu. Bentuk produk akhir meliputi: serpihan, lembaran, lembar gulungan, gumpalan bulat. Jenis produk antara lain: nori kering, nori panggang, nori bumbu.",
    "Aktif",
  ],
  [
    "0402020206",
    "Sayur Asin Kering",
    "Sayur asin kering adalah produk sayur yang diperoleh dari bagian sayur yang diberi garam dan dikeringkan dengan pengeringan alami atau buatan.",
    "Tidak Aktif",
  ],
  [
    "0402020207",
    "Kacang Kering dan Polong Kacang Kering",
    "Kacang kering dan polong kacang kering adalah produk kering yang<br> diperoleh dari biji tanaman leguminosa yang dibedakan dari biji<br> leguminosa sumber minyak berdasarkan kadar minyaknya yang<br> rendah. Polong kacang adalah bagian dari kacang yang telah dilepas<br> kulitnya.<br> Jenis yang termasuk dalam kelompok ini: Beans dari Phaseolus spp<br> (termasuk Phaseolus mungo L.syn. Vigna mungo (L.) Hepper dan<br> Phaseolus aureus Roxb.syn.Phaseolus radiatur L.Vigna radiata (L.)<br> Wilczek; Lentils dari Lens culinaris Medic.Syn.Lens esculenta<br> Moench; Peas dari Pisum sativum L.; Chick peas dari Cicer<br> arientinum L.; Kacang tanah dari Arachis hypogaea L. Kacang koro<br> dari Vicia faba L.; Cow peas dari Vigna unguiculata (L.) Walp., syn.<br> Vigna sesquipedalis Fruhw., Vigna sinensis (L.) Savi exd Hassk.",
    "Tidak Aktif",
  ],
  [
    "0402020208",
    "Biji Bunga Matahari",
    "Biji bunga matahari adalah produk kering yang diperoleh dari biji bunga matahari yang dapat dimakan, dapat digunakan untuk pangan dan pakan sebagai sumber minyak.",
    "Tidak Aktif",
  ],
  [
    "0402020209",
    "Biji Saga",
    "Biji saga adalah produk kering yang diperoleh dari biji tanaman saga yang dikeringkan dan dibersihkan.",
    "Tidak Aktif",
  ],
  [
    "0402020210",
    "Biji Wijen",
    "Biji wijen adalah produk kering yang diperoleh dari biji tanaman wijen (Sesamun indicum L) yang dikeringkan dan dibersihkan.",
    "Tidak Aktif",
  ],
  [
    "0402020211",
    "Kuaci",
    "Kuaci adalah produk kering yang diperoleh dari biji semangka, biji labu parang, biji bunga matahari yang telah dikeringkan dan ditambah garam.",
    "Aktif",
  ],
  [
    "0402020212",
    "Emping Melinjo",
    "Emping melinjo adalah produk kering yang diperoleh dari pemipihan daging melinjo tua (Gnetum gnemon).",
    "Aktif",
  ],
  [
    "0402020213",
    "Emping Jengkol",
    "Emping jengkol adalah produk kering yang diperoleh dari daging buah jengkol segar yang diolah melalui proses perebusan dan pemipihan kemudian dikeringkan, dengan atau tanpa bumbu-bumbu.",
    "Tidak Aktif",
  ],
  [
    "0402020214",
    "Mete Gelondong",
    "Mete gelondong adalah produk kering yang diperoleh dari buah tanaman jambu mede (Anacardium occidaentale Linn.) yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    "0402020215",
    "Kentang Kering Serpih (Flakes)",
    "Kentang kering serpih (flakes) adalah produk kering yang diperoleh dari mashed potato (puree kentang) yang dikeringkan dan dibentuk serpihan.",
    "Tidak Aktif",
  ],
  [
    "0402020216",
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering",
    "Tepung tomat adalah produk tepung yang diperoleh dari buah tomat yang dihancurkan / dihaluskan dengan atau tanpa serangkaian proses ekstraksi untuk memperoleh sari tomat, pemekatan, penghilangan busa (defoaming), pengeringan dan pengemasan. Selama proses dapat ditambahkan bahan lain yang sesuai",
    "Tidak Aktif",
  ],
  [
    "0402020217",
    "Tepung Bit",
    "Tepung bit adalah produk tepung bit berwarna merah gelap yang<br> diperoleh dari proses pengeringan umbi bit yang sehat, masak dan<br> bermutu baik.",
    "Aktif",
  ],
  [
    "0402020218",
    "Kelp / Kombu",
    "Kelp / kombu adalah sea tangle kering.",
    "Tidak Aktif",
  ],
  [
    "0402020219",
    "Shio-Kombu",
    "Shio-kombu adalah sea tangle kering dengan bumbu.",
    "Tidak Aktif",
  ],
  [
    "0402020220",
    "Tororo-Kombu",
    "Tororo-kombu adalah rumput laut kering.",
    "Tidak Aktif",
  ],
  [
    "0402020221",
    "Kampyo",
    "Kampyo adalah labu (manis) kupas kering.",
    "Tidak Aktif",
  ],
  [
    "0402020222",
    "Wakame",
    "Wakame adalah laminariales kering.",
    "Tidak Aktif",
  ],
  [
    "0402020223",
    "Acar Sayur",
    "Status tidak aktif, diperbaiki ke kategori pangan : Acar Sayur (0402020320).",
    "Tidak Aktif",
  ],
  ["0402020224", "Biji Selasih", "-", "Tidak Aktif"],
  [
    "0402020225",
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia)",
    "-",
    "Tidak Aktif",
  ],
  [
    "0402020226",
    "Bubur Kacang ..... Bubuk / Instan",
    "-",
    "Tidak Aktif",
  ],
  ["0402020227", "Tepung Melinjo", "-", "Tidak Aktif"],
  [
    "0402020228",
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain",
    "-",
    "Aktif",
  ],
  [
    "0402020229",
    "Tepung Daun Kelor",
    "Tepung daun kelor adalah produk tepung daun kelor yang diperoleh<br> dari proses pengeringan daun kelor yang sehat, masak dan bermutu<br> baik",
    "Aktif",
  ],
  [
    "0402020230",
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting)",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "0402020232",
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang)",
    "Memfasilitasi Registrasi Ulang",
    "Aktif",
  ],
  [
    "0402020301",
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain",
    "Jamur dalam minyak zaitun atau jamur dalam minyak nabati lain adalah produk jamur yang diperoleh dari jamur segar, ataupun dari jamur yang telah diasinkan, baik bentuk utuh maupun irisan, dimasukkan dalam minyak zaitun atau minyak nabati lain, dikemas secara kedap (hermetis), disterilisasi dengan pemanasan untuk mencegah kerusakan.<br> Karakteristik dasar: Kadar garam tidak lebih dari 1% (jika produk jamur diasinkan).<br>",
    "Aktif",
  ],
  [
    "0402020302",
    "Sayur Asin",
    "Sayur asin adalah produk sayur yang diperoleh dari sayur yang diberi garam.",
    "Aktif",
  ],
  [
    "0402020303",
    "Jamur Asin",
    "Jamur asin adalah produk jamur yang diperoleh dari satu jenis jamur segar, berbentuk utuh atau irisan, yang dibersihkan, dicuci, diblansir dan diawetkan dalam air garam.",
    "Aktif",
  ],
  [
    "0402020304",
    "Acar Jamur",
    "Acar jamur adalah produk acar yang diperoleh dari jamur dari satu spesies atau lebih yang dibersihkan, dicuci, diblansir, dan diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, rempah-rempah, gula, minyak makan, asam asetat, asam laktat, asam sitrat atau asam askorbat, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020305",
    "Acar Timun Mentah",
    "Acar timun mentah adalah produk acar yang diperoleh dari mentimun yang dibersihkan, diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020306",
    "Acar Bawang Putih",
    "Acar bawang putih adalah produk acar yang diperoleh dari bawang putih yang dibersihkan, dikupas kulitnya, diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020307",
    "Acar Jahe",
    "Acar jahe adalah produk acar yang diperoleh dari jahe matang dan sehat yang dibersihkan, dikupas, diiris dan diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020308",
    "Acar Cabe",
    "Acar cabe adalah produk acar yang diperoleh dari cabe yang bersih dan sehat diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020309",
    "Acar Lobak",
    "Acar lobak adalah produk acar yang diperoleh dari umbi lobak sehat yang dibersihkan, dikupas, diiris dan diawetkan dalam larutan cuka dengan atau tanpa penambahan garam, dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020310",
    "Jantung Artichoke yang Diasinkan",
    "",
    "Tidak Aktif",
  ],
  ["0402020311", "Picalili", "", "Tidak Aktif"],
  [
    "0402020312",
    "Tsukemono",
    "Tsukemono adalah sayur pikel dengan kulit nasi (nuka-zuke).",
    "Tidak Aktif",
  ],
  [
    "0402020313",
    "Vegetable Koji-zuke",
    "Vegetable koji-zuke adalah sayur pikel-koji.",
    "Tidak Aktif",
  ],
  [
    "0402020314",
    "Vegetable Kasu-zuke",
    "Vegetable kasu-zuke adalah sayur pikel-sedikit sake.",
    "Tidak Aktif",
  ],
  [
    "0402020315",
    "Vegetable Miso-zuke",
    "Vegetable miso-zuke adalah sayur pikel-miso.",
    "Tidak Aktif",
  ],
  [
    "0402020316",
    "Vegetable Shoyu-zuke",
    "Vegetable shoyu-zuke adalah sayur pikel-saus kedelai.",
    "Tidak Aktif",
  ],
  [
    "0402020317",
    "Vegetable Su-zuke",
    "Vegetable su-zuke adalah sayur pikel-vinegar.",
    "Tidak Aktif",
  ],
  [
    "0402020318",
    "Vegetable Shio-zuke",
    "Vegetable shio-zuke adalah sayur pikel-garam.",
    "Tidak Aktif",
  ],
  [
    "0402020319",
    "Acar (Sweet Pickle)...Steril",
    "-",
    "Tidak Aktif",
  ],
  ["0402020320", "Acar Sayur", "-", "Tidak Aktif"],
  [
    "0402020322",
    "Acar (Sweet Pickle)",
    "Acar adalah produk acar yang diperoleh dari sayur yang<br> dibersihkan, dicuci, diblansir, dan diawetkan dalam larutan cuka<br> dengan atau tanpa penambahan garam, rempah-rempah, gula,<br> minyak makan, asam asetat, asam laktat, asam sitrat atau asam<br> askorbat, dapat dipanaskan atau dipasteurisasi. Contohnya adalah acar jamur, acar timun, acar bawang putih, acar jahe, acar cabe,<br> dan acar lobak.",
    "Aktif",
  ],
  [
    "0402020323",
    "Asinan Jahe",
    "Asinan jahe adalah produk jahe (Zingiber officinale atau Zingiber officinale var Rubrum) yang diperoleh dari proses pengawetan jahe dengan penambahan garam dan larutan cuka atau larutan asam sitrat, atau asam lain yang sesuai. Dapat ditambahkan gula atau bahan pangan lain.",
    "Aktif",
  ],
  [
    "04020204",
    "Sayur Dalam Kemasan, Botol atau Dalam Retort Pouch",
    "Sayur dalam kemasan, botol atau dalam retort pouch adalah produk awetan dari sayur yang dibersihkan, diblansir dan ditempatkan dalam kemasan dengan penambahan air dan dipasteurisasi atau disterilisasi dengan pemanasan.",
    "Aktif",
  ],
  [
    "0402020401",
    "Sayur Dalam Kemasan",
    "Sayur dalam kemasan adalah produk sayur yang diperoleh dari sayur yang telah disterilisasi atau dipasteurisasi dan dikemas secara kedap (hermetis).",
    "Aktif",
  ],
  [
    "0402020402",
    "Tomat Dalam Kemasan",
    "Tomat dalam kemasan adalah produk tomat yang diperoleh dari<br> tomat matang yang bersih dan sehat yang dicuci, dimasukkan ke<br> dalam medium dan bahan lain yang sesuai, diproses dengan<br> pemanasan sebelum atau sesudah kemasan ditutup untuk<br> mencegah pembusukan.<br> Medium yang digunakan dapat berupa air, jus tomat, puree atau<br> bubur tomat dan pasta tomat. Bahan lain yang ditambahkan<br> adalah rempah-rempah, minyak dan pati.",
    "Aktif",
  ],
  [
    "0402020403",
    "Jagung Manis Dalam Kemasan",
    "Produk jagung yg diperoleh dari pipilan jagung manis (Zea mays L.) yang bersih, dimasukkan ke dalam medium sesuai dan diproses dengan pemanasan sebelum atau sesudah kemasan ditutup untuk mencegah pembusukan. Medium yang digunakan dapat berupa larutan yang mengandung pati jagung, gula, bumbu dan bahan lain yang sesuai.",
    "Aktif",
  ],
  [
    "0402020404",
    "Jamur Dalam Kemasan",
    "Jamur dalam kemasan adalah produk jamur yang diperoleh dari<br> jamur sehat yang dapat dimakan yang dibersihkan dalam keadaan<br> utuh atau diiris, serpihan, dan akar, diblansir, dimasukkan ke<br> dalam medium dengan penambahan bumbu yang sesuai, diproses<br> dengan pemanasan sebelum dan sesudah penutupan pengemas<br> untuk mencegah pembusukan. Medium yang digunakan dapat<br> berupa air, larutan garam, jus jamur, mentega, saus krim, vinegar,<br> dan minyak.",
    "Aktif",
  ],
  [
    "0402020405",
    "Asparagus Dalam Kemasan",
    "Asparagus dalam kemasan adalah produk asparagus yang diperoleh dari batang tanaman asparagus (Asparagus officinales L) dengan atau tanpa dikupas yang dimasukkan ke dalam air atau medium cair lain yang cocok, dikemas secara kedap (hermetis) dan diproses dengan panas untuk mencegah kerusakan.",
    "Aktif",
  ],
  [
    "0402020406",
    "Wortel Dalam Kemasan",
    "Wortel dalam kemasan adalah produk wortel yang diperoleh dari<br> wortel (Daucus carota Linn.) yang bersih, sehat, daun dan bagian<br> atas yang hijau telah dihilangkan, dikupas, dan dimasukkan ke<br> dalam air atau medium yang sesuai, diproses dengan pemanasan<br> sebelum atau setelah penutupan pengemas untuk mencegah<br> pembusukan. Medium yang digunakan adalah air, bumbu dan<br> bahan lain yang sesuai dengan produk. Jika ditambahkan mentega atau minyak dan lemak nabati atau lemak hewani maka kadarnya<br> tidak kurang dari 3% berat produk akhir.",
    "Aktif",
  ],
  [
    "0402020407",
    "Rebung Bambu Dalam Kemasan",
    "Rebung bambu dalam kemasan adalah produk rebung bambu yang<br> diperoleh dari irisan rebung bambu (Bambusa, Dendroclamus,<br> Gigantochola dan Phyllostachys) yang dimasukkan ke dalam air atau<br> medium yang sesuai, dikemas secara kedap (hermetis) dan<br> disterilisasi dengan pemanasan. Medium yang digunakan adalah air,<br> atau larutan garam.",
    "Aktif",
  ],
  [
    "0402020408",
    "Kacang Kapri (Green Peas) Dalam Kemasan",
    "Kacang kapri (green peas) dalam kemasan adalah produk kacang<br> kapri yang diperoleh dari kacang kapri (Pisum sativum L.) tetapi<br> tidak meliputi subsp. Macrocarpum, yang telah dikupas, bersih,<br> dimasukkan ke dalam medium yang sesuai, dikemas secara kedap<br> (hermetis) dan disterilkan dengan pemanasan. Medium yang<br> digunakan adalah air atau medium lain yang sesuai. Dapat<br> ditambahkan gula, bumbu dan bahan lain yang sesuai dengan<br> produk.",
    "Aktif",
  ],
  [
    "0402020409",
    "Buncis Dalam Kemasan",
    "Buncis dalam kemasan adalah produk buncis yang diperoleh dari<br> polong buncis segar (Phaseolus vulgaris) tanpa batang dan<br> tangkainya, yang dimasukkan ke dalam medium, dan disterilkan<br> dengan pemanasan. Medium yang digunakan adalah air atau<br> medium lainnya. Dapat ditambahkan gula, bumbu dan bahan lain yang sesuai dengan produk. Jika ditambahkan mentega, maka<br> kadarnya tidak kurang dari 3% dari produk akhir.",
    "Aktif",
  ],
  [
    "0402020410",
    "Manisan Rumput Laut Dalam Kemasan",
    "Manisan rumput laut dalam kemasan adalah produk rumput laut jenis Euchema sp yang ditambahkan larutan gula serta dikemas secara kedap (hermetis) dan dipasteurisasi.",
    "Aktif",
  ],
  [
    "0402020411",
    "Lidah Buaya Dalam Kemasan",
    "Lidah buaya dalam kemasan adalah produk pangan yang diperoleh dari daun lidah buaya (Aloe vera) dengan medium sirup atau air atau larutan garam dengan asidulan. Dikemas secara kedap (hermetis) dan dipasteurisasi atau disterilisasi.",
    "Aktif",
  ],
  ["0402020412", "Chesnut Dalam Kaleng", "", "Tidak Aktif"],
  ["0402020413", "Puree Chestnut Dalam Kaleng", "", "Tidak Aktif"],
  [
    "0402020414",
    "Pink Beans yang telah Dimasak Dalam Kaleng",
    "",
    "Tidak Aktif",
  ],
  ["0402020415", "Sayur dalam Kaleng", "&nbsp;", "Aktif"],
  ["0402020416", "Kacang Ginko Dalam Kemasan", "&nbsp;", "Aktif"],
  [
    "0402020417",
    "Akar/Umbi/Polong-polongan Dalam Kemasan",
    "Akar/umbi/polong-polongan dalam kemasan adalah produk akar/umbi/polong-polongan yang diperoleh dari akar/umbi/polong-polongan sehat yang dapat dimakan yang dibersihkan dalam keadaan utuh atau diiris, serpihan, dan akar, diblansir, dimasukkan ke dalam medium dengan penambahan bumbu yang sesuai, diproses dengan pemanasan sebelum dan sesudah penutupan pengemas untuk mencegah pembusukan. Medium yang digunakan dapat berupa air, larutan garam, jus jamur, mentega, saus krim, vinegar dan minyak. Contohnya chestnut dalam kaleng, puree chestnut dalam kaleng, pink beans yang telah dimasak dalam kaleng.",
    "Aktif",
  ],
  [
    "0402020501",
    "Puree Tomat",
    "Puree tomat adalah produk tomat yang diperoleh dari proses penguapan air dari sari tomat yang diperoleh dari tomat bersih, sehat dan matang yang biji dan kulitnya telah dihilangkan. Produk dikemas dalam kemasan kedap (hermetis) dan diproses dengan pemanasan",
    "Aktif",
  ],
  [
    "0402020502",
    "Selai Kacang",
    "Selai kacang adalah produk kacang tanah atau kacang lainnya yang<br> diperoleh dari penggilingan kacang kupas yang bersih dan bermutu<br> baik, disangrai dan/atau digoreng dan/atau dipanggang, serta<br> dihilangkan lembaganya. Dapat ditambahkan bahan pangan lain.<br> Produk dapat digunakan sebagai olesan atau isian pangan lainnya.<br> Nama jenis mengikuti sumber kacangnya seperti selai kacang<br> (peanut butter), selai kacang mede (cashew butter), selai almond<br> (almond butter), selai kacang tanah dan almond.",
    "Aktif",
  ],
  [
    "0402020503",
    "Selai Kacang Mede (Cashew Butter)",
    "",
    "Tidak Aktif",
  ],
  ["0402020504", "Selai Kacang Lainnya", "", "Tidak Aktif"],
  ["0402020505", "Selai Labu (Pumpkin Butter)", "", "Tidak Aktif"],
  ["0402020506", "Olesan Berbasis Sayur", "&nbsp;", "Aktif"],
  [
    "0402020507",
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng",
    "-",
    "Aktif",
  ],
  ["0402020508", "Olesan Berbasis Kacang", "-", "Tidak Aktif"],
  [
    "0402020509",
    "Olesan Kacang",
    "Olesan kacang adalah produk olesan yang diperoleh dari<br> penggilingan satu jenis kacang atau lebih yang dikupas, bersih dan<br> bermutu baik, direbus dan/atau dikukus dan/atau disangrai<br> dan/atau digoreng dan/atau dipanggang (oven). Dapat ditambahkan<br> bahan pangan lain. Produk dapat digunakan sebagai olesan atau<br> isian pangan lainnya. Nama jenis produk ini misal olesan kacang<br> mede (cashew spread), olesan kacang merah, olesan (kacang)<br> almond (almond spread), olesan (kacang) kenari, olesan kacang<br> tanah dan mede.<br> <br> Karakteristik dasar:<br> Kandungan total kacang tidak kurang dari 40%.",
    "Aktif",
  ],
  [
    "0402020510",
    "Olesan Mengandung Kacang",
    "Olesan mengandung kacang adalah produk olesan yang diperoleh dari pencampuran bahan pangan dan kacang. Produk dapat digunakan sebagai olesan atau isian pangan lainnya. Nama jenis produk ini misalnya olesan mengandung kacang mede, olesan mengandung kacang tanah, olesan mengandung almond,olesan mengandung kacang tanah dan kacang mede.<br> <br> Karakteristik dasar:<br> Kandungan total kacang tidak kurang dari 15%",
    "Aktif",
  ],
  [
    "0402020511",
    "Selai Sayur",
    "Selai sayur adalah produk yang diperoleh dari proses penghancuran satu atau lebih jenis sayur yang bersih dan bermutu baik, dan diolah sehingga bisa dioles. Dapat ditambahkan bahan pangan lain. Contohnya selai labu (pumpkin butter).",
    "Aktif",
  ],
  [
    "0402020601",
    "Pasta Tomat",
    "Pasta tomat adalah produk tomat yang diperoleh dari proses<br> pemekatan sari buah tomat atau bubur buah tomat dapat<br> ditambahkan bahan pangan lain yang sesuai.",
    "Aktif",
  ],
  [
    "0402020602",
    "Bubur (Pulp) Tomat",
    "Bubur (pulp) tomat adalah produk tomat yang diperoleh dari tomat utuh, matang atau tomat yang sudah dibersihkan (trimming), diproses dengan pemanasan dan dipekatkan. Produk ini dikemas secara kedap (hermetis) dan dipanaskan.",
    "Tidak Aktif",
  ],
  ["0402020603", "Bubur (Pulp) Kentang", "", "Tidak Aktif"],
  ["0402020604", "Bubur (Pulp) Horseadish", "", "Tidak Aktif"],
  ["0402020605", "Ekstrak Aloe", "", "Tidak Aktif"],
  [
    "0402020606",
    "Salsa",
    "Contohnya adalah potongan kentang, bawang, lada (pepper),<br> rempah-rempah dan herba.",
    "Tidak Aktif",
  ],
  ["0402020607", "Pasta Kacang Merah Manis", "", "Tidak Aktif"],
  [
    "0402020608",
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi)",
    "",
    "Tidak Aktif",
  ],
  ["0402020609", "Jahe Kristalisasi", "", "Tidak Aktif"],
  [
    "0402020610",
    "Namagashi",
    "Namagashi adalah makanan pencuci mulut sayur berbasis kacang.",
    "Tidak Aktif",
  ],
  ["0402020611", "Topping Berbasis Sayur dan Kacang", "-", "Aktif"],
  [
    "0402020612",
    "Hasil Olah Iles-iles Dalam Bentuk Jeli",
    "-",
    "Aktif",
  ],
  [
    "0402020613",
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng",
    "&nbsp;",
    "Aktif",
  ],
  [
    "0402020614",
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan",
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan selain Kemasan Kaleng",
    "Aktif",
  ],
  [
    "0402020615",
    "Pasta Umbi",
    "Pasta umbi adalah produk berbentuk pasta yang dibuat dari umbi yang direbus atau dikukus atau proses lain yang sesuai, kemudian dihancurkan, dapat ditambahkan bahan pangan lain yang sesuai.<br> Nama produk untuk kategori ini misal pasta talas, pasta wortel, dan pasta ubi.",
    "Aktif",
  ],
  [
    "0402020616",
    "Bubur (Pulp) Sayur",
    "Bubur sayur adalah produk sayur yang diperoleh dari sayur yang sudah dibersihkan, dihancurkan dan diolah lebih lanjut seperti pemanasan, pemekatan dan/atau pengeringan.",
    "Aktif",
  ],
  [
    "0402020617",
    "Produk Jeli Tidak Siap Konsumsi",
    "Produk jeli tidak siap konsumsi adalah produk jeli berupa lembaran atau bentuk lainnya yang dibuat dari bahan hidrokoloid dan masih harus diolah untuk menjadi produk siap konsumsi. Contoh produk ini jeli dari iles iles.",
    "Aktif",
  ],
  [
    "0402020701",
    "Pikel (fermentasi)",
    "Pikel adalah produk sayur yang diperoleh dari sayur yang<br> difermentasi dalam larutan garam, dengan atau tanpa penambahan<br> gula dan rempah-rempah, dapat dilakukan pasteurisasi atau proses<br> pemanasan. Contohnya pikel mentimun (Cucumis sativus L.), jahe,<br> dan zaitun. Ada 3 jenis produk pikel zaitun, yaitu :<br> \xE2\x{20AC}\xA2 Pikel Zaitun Hitam (Black Ripe Olives) dibuat dari zaitun yang<br> masak dan sebelum disimpan dalam larutan garam diproses<br> dengan basa dan dilanjutkan dengan aerasi untuk membuat<br> kulit buah menjadi gelap<br> \xE2\x{20AC}\xA2 Pikel Zaitun Hijau (Green Olives) dibuat dari zaitun yang sehat<br> dan masak dan dipanen pada saat buah berwarna ungu muda<br> atau pada tahap semburat kuning (straw-yellow), selama proses<br> pencucian dihindari terjadinya proses penggelapan kulit buah<br> (darkening) dan difermentasi dengan larutan garam encer<br> \xE2\x{20AC}\xA2 Pikel Zaitun Ala Yunani (Greek-Style Olives) dibuat dari zaitun<br> yang sehat dan masak dan dipanen pada saat buah telah<br> berwarna ungu atau hitam, tanpa diproses dengan basa sebelum<br> fermentasi.",
    "Aktif",
  ],
  [
    "0402020702",
    "Sawi Asin",
    "Sawi asin adalah produk sayur yang diperoleh dari daun sawi yang difermentasi oleh bakteri asam laktat dalam larutan garam.",
    "Aktif",
  ],
  [
    "0402020703",
    "Sauerkraut",
    "Sauerkraut adalah produk sayur berupa irisan atau cincangan kubis<br> dalam garam yang difermentasi oleh bakteri asam laktat. Produk<br> dapat diawetkan dalam larutan garam atau cairan kubis hasil<br> fermentasi, dikemas, dan dipanaskan.<br> <br> Karakteristik dasar:<br> \x{2022} Bau, rasa, warna dan tekstur khas sauerkraut;<br> \x{2022} Bobot tuntas tidak kurang dari 60%.",
    "Aktif",
  ],
  [
    "0402020704",
    "Jamur Fermentasi",
    "Jamur fermentasi adalah produk sayur yang diperoleh dari jamur<br> segar yang dapat dimakan, berbentuk utuh atau irisan yang<br> dibersihkan, dicuci, dan difermentasi oleh bakteri asam laktat dalam<br> larutan garam.<br> <br> Karakteristik dasar:<br> Kadar asam laktat sebagai hasil fermentasi 1%.",
    "Aktif",
  ],
  [
    "0402020705",
    "Pikel Mentimun",
    "Pikel mentimun adalah produk sayur yang diperoleh dari buah mentimun (Cucumis sativus L.) yang bersih, sehat, dengan atau tanpa pengupasan, dengan atau tanpa penghilangan biji, yang dikemas dengan atau tanpa medium yang sesuai dan bumbu yang sesuai dengan jenis produk, dan diawetkan. Pengawetan meliputi pengasaman sampai PH 4,6 atau kurang dengan fermentasi alami atau terkontrol atau dengan penambahan cuka atau asam yang dapat dimakan dan dapat dilakukan pasteurisasi",
    "Tidak Aktif",
  ],
  [
    "0402020706",
    "Pikel Jahe",
    "Pikel jahe adalah produk sayur yang diperoleh dari rimpang jahe sehat dan bersih yang telah dikupas, berbentuk utuh atau irisan dikemas dengan atau tanpa medium dan bumbu yang sesuai dengan jenis produk, yang diawetkan sebelum atau setelah penutupan pengemas. Pengawetan meliputi pengasaman sampai PH 4,6 atau kurang dengan fermentasi alami atau terkontrol atau dengan penambahan cuka atau asam yang dapat dimakan dan dapat dilakukan pasteurisasi",
    "Tidak Aktif",
  ],
  [
    "0402020707",
    "Pikel Zaitun (Olives)",
    "Pikel zaitun (olives) adalah produk yang diperoleh dari buah zaitun yang sehat dan bersih, yang difermentasi dengan penambahan garam. Produk dikemas dalam larutan garam dan diawetkan dengan pemanasan atau pasteurisasi.",
    "Tidak Aktif",
  ],
  [
    "0402020708",
    "Kimchi",
    "Kimchi adalah produk sayur yang diperoleh dari kubis cina yang difermentasi dan dicampur dengan sayur atau bahan lain.",
    "Aktif",
  ],
  [
    "0402020709",
    "Gochujang",
    "Gochujang adalah produk pangan fermentasi tradisional khas Korea Selatan berbentuk pasta berwarna merah atau merah gelap yang dibuat dengan mencampurkan bubuk cabai merah dengan kedelai yang difermentasi dan pati. Rasa manis dan pedas yang muncul disebabkan karena adanya hidrolisis pati, dan rasa gurih muncul karena hidrolisis protein.",
    "Aktif",
  ],
  [
    "0402020710",
    "Tempe Selain Kedelai",
    "Tempe Selain Kedelai adalah produk yang diperoleh dari fermentasi polong-polongan (leguminosae) dengan menggunakan kapang Rhizopus spp., produk ini berbentuk padatan kompak dan berbau khas serta berwarna putih atau sedikit keabu-abuan. Nama jenis produk disesuaikan dengan jenis polong-polongan (leguminosae) yang digunakan. Misalnya : Tempe Koro Pedang dan Tempe Koro Benguk.",
    "Aktif",
  ],
  [
    "0402020801",
    "Keripik Bayam",
    "Keripik bayam adalah produk keripik yang diperoleh dari daun bayam yang bersih dan bermutu baik, yang dilapis dengan adonan encer tepung berbumbu, kemudian digoreng.",
    "Aktif",
  ],
  [
    "0402020802",
    "Keripik Jamur Kancing",
    "Keripik jamur kancing adalah produk keripik yang diperoleh dari jamur kancing genus agaricus (A. bisforus, A.campesfris, A. biforqis) yang dikukus, diiris tipis sehingga berbentuk lempeng, diberi bumbu, kemudian digoreng dengan atau tanpa penambahan tepung.",
    "Aktif",
  ],
  [
    "0402020803",
    "Getuk Singkong",
    "Getuk singkong adalah produk singkong semi basah yang diperoleh dari singkong yang dikukus, dicampur dengan gula, digiling/dilumatkan kemudian dibentuk dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  ["0402020804", "Simmered Beans", "-", "Tidak Aktif"],
  ["0402020805", "Pre-Fried Potatoes", "-", "Tidak Aktif"],
  ["0402020806", "Okra yang Digoreng", "-", "Tidak Aktif"],
  [
    "0402020807",
    "Vegetable Tsukudani",
    "Vegetable tsukudani adalah produk sayur yang diperoleh dari sayur yang direbus dalam saus kedelai.",
    "Aktif",
  ],
  [
    "0402020808",
    "Kerupuk Jengkol",
    "Kerupuk jengkol adalah produk yang diperoleh dari buah jengkol segar yang dicampur dengan adonan tepung, dikukus, dibentuk, dan dikeringkan.",
    "Aktif",
  ],
  [
    "0402020809",
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog)",
    "-",
    "Aktif",
  ],
  [
    "0402020810",
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya",
    "Dodol rumput laut adalah produk olahan dengan bahan baku rumput laut kering atau bahan baku setengah jadi, dicampur gula dengan atau tanpa santan, dengan atau tanpa tepung beras ketan dan bahan lainnya yang selanjutnya mengalami pemasakan, pencetakan, pemotongan, dan pengeringan. Termasuk jenang rumput laut, gelamai rumput laut, lempok rumput laut, dan produk rumput laut sejenis lainnya.",
    "Aktif",
  ],
  [
    "0402020811",
    "Keripik Bonggol Pisang",
    "Keripik bonggol pisang adalah produk keripik yang dibuat dari bonggol pohon pisang yang bersih dan bermutu baik, melalui proses pengolahan tertentu (misal: pengirisan, pencucian, perendaman), dengan atau tanpa pelapisan tepung dan/atau bumbu, kemudian digoreng sampai kering.<br>",
    "Aktif",
  ],
  [
    "05010101",
    "Kakao Bubuk",
    "Kakao Bubuk dihasilkan dari pengurangan lemak yang terkandung pada kakao massa (cocoa liquor) dan pencetakan menjadi keik kakao.<br> Keik kakao (cocoa cake) dihancurkan dan dihaluskan menjadi kakao bubuk.",
    "Aktif",
  ],
  [
    "05010102",
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa)",
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) adalah kakao bubuk yang ditambahkan susu, mentega, bumbu dan rempah lain.",
    "Tidak Aktif",
  ],
  [
    "05010105",
    "Debu Kakao (Cocoa Dust)",
    "Debu Kakao (Cocoa Dust) adalah fraksi dari biji kakao yang didapatkan dari proses pengupasan dan pemisahan kulit biji kakao (winnowing).",
    "Aktif",
  ],
  [
    "05010107",
    "Nib Kakao",
    "Nib kakao adalah produk yang diperoleh dari pemisahan kulit melalui proses kuring, pembersihan, pengeringan dan peretakan biji kakao. Kakao nib, atau biji kakao disini dapat diproses dengan pemanasan dengan satu atau lebih jenis alkali.",
    "Aktif",
  ],
  [
    "05010108",
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat",
    "Massa kakao dan cairan kental (liquor) cokelat adalah produk yang diperoleh dari penggilingan nib kakao dengan atau tanpa penyanggraian, dan dengan atau tanpa pemisahan atau penambahan bahan lain.",
    "Tidak Aktif",
  ],
  [
    "05010109",
    "Keik Kakao/Bungkil Kakao",
    "Keik kakao/bungkil kakao adalah produk kakao yang diperoleh dari pemisahan sebagian lemak dari keping biji kakao atau kakao massa.<br> <br> PerBPOM Nomor 34 Tahun 2019 tentang Kategori Pangan",
    "Aktif",
  ],
  [
    "05010110",
    "Minuman Kakao (Drinking Cocoa)",
    "Minuman kakao (drinking cocoa) adalah campuran bubuk kakao dengan atau tanpa penambahan perisa, rempah-rempah atau oleoresin serta bahan lainnya.",
    "Tidak Aktif",
  ],
  [
    "05010112",
    "Cokelat Instan",
    "Dibuat dari kakao massa, yang ditambahkan edible wetting agent (humektan), atau telah dilakukan proses instanisasi, dengan atau<br> tanpa penambahan bahan pangan lain.<br>",
    "Aktif",
  ],
  [
    "05010114",
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes)",
    "Bubuk minuman kakao (drinking cocoa mixes) adalah produk minuman dalam bentuk bubuk yang dibuat dari kakao bubuk dengan penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    "05010115",
    "Bubuk Minuman Cokelat (Drinking Chocolate)",
    "Bubuk minuman cokelat (drinking chocolate) adalah produk<br> minuman dalam bentuk bubuk yang dibuat dari kakao bubuk dengan/atau tanpa penambahan kakao massa, lemak kakao, dapat<br> ditambahkan bahan pangan lain.",
    "Aktif",
  ],
  [
    "05010116",
    "Lemak Kakao (Cocoa Butter)",
    "Lemak kakao (cocoa butter) adalah lemak yang diperoleh dari biji kakao.<br>",
    "Aktif",
  ],
  [
    "05010117",
    "Campuran kakao-gula (cocoa-sugar mixtures)",
    "Campuran kakao-gula (cocoa-sugar mixtures) hanya terdiri dari bubuk kakao dan gula.",
    "Tidak Aktif",
  ],
  [
    "05010118",
    "Kakao Instan",
    "Kakao instan adalah produk minuman dalam bentuk bubuk yang dibuat dari kakao bubuk yang diproses sedemikian rupa sehingga mudah larut air, dengan atau tanpa penambahan gula atau bahan pangan lain.<br> Karakteristik dasar :<br> Kandungan kakao (total cocoa solids) tidak kurang dari 10% dihitung sebagai berat kering.",
    "Aktif",
  ],
  [
    "05010119",
    "Cokelat Bubuk",
    "Cokelat bubuk adalah campuran kakao bubuk dan gula, mengandung tidak kurang dari 32% kakao bubuk (29% dihitung terhadap basis kering).",
    "Aktif",
  ],
  [
    "05010120",
    "Kakao Massa (Cocoa liquor)",
    "Kakao massa (Cocoa liquor) adalah produk kakao berupa pasta yang diperoleh dari kakao nib (keping biji kakao) melalui penggilingan tanpa menghilangkan kandungan lemaknya.",
    "Aktif",
  ],
  [
    "05010121",
    "Biji cokelat yang disangrai atau roasting",
    "Untuk memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    "05010201",
    "Sirup Cokelat",
    "Sirup cokelat adalah produk yang terbuat dari campuran gula dengan atau tanpa bahan pemanis lainnya, satu atau lebih produk kakao, dengan atau tanpa penambahan air dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar : Kandungan kakao (total cocoa solids) tidak kurang dari 8%",
    "Aktif",
  ],
  [
    "05010301",
    "Cokelat Pasta",
    "Cokelat pasta adalah produk makanan yang berbentuk pasta yang dibuat dari campuran kakao bubuk, gula dan lemak.",
    "Tidak Aktif",
  ],
  [
    "05010302",
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread)",
    "Olesan berbasis kacang-cokelat (nut-chocolate based spread) adalah jenis olesan berbahan dasar lemak cokelat yang ditambahkan kacang (kacang tanah, hazelnut, almond).",
    "Aktif",
  ],
  [
    "05010303",
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread)",
    "Olesan cokelat berbasis air (chocolate water-based spread) adalah produk yang terbuat dari bubuk kakao yang didispersikan dalam sirup gula, gula invert dan kadang-kadang sirup glukosa.",
    "Tidak Aktif",
  ],
  [
    "05010304",
    "Cokelat Pasta (berbasis minyak)",
    "Cokelat pasta (berbasis minyak) adalah produk yang berbentuk pasta berbasis lemak yang dibuat dari campuran satu atau lebih produk kakao dengan atau tanpa bahan pangan lain. Produk tersebut dapat digunakan sebagai olesan atau isian, misalnya olesan kakao-kacang, olesan kakao-susu.<br> Karakteristik dasar :<br> \x{2022} Kadar air tidak lebih dari 2%;<br> \x{2022} Kadar lemak tidak kurang dari 25%.",
    "Aktif",
  ],
  [
    "05010305",
    "Cokelat Pasta (berbasis air)",
    "Cokelat pasta (berbasis air) adalah produk yang berbentuk pasta, berbasis air, yang dibuat dari campuran satu atau lebih produk kakao dengan atau tanpa bahan pangan lain.",
    "Aktif",
  ],
  [
    "05010401",
    "Cokelat",
    "Cokelat adalah produk homogen yang dihasilkan melalui proses pencampuran produk kakao (kakao massa dan atau lemak kakao dan atau kakao bubuk) dengan atau tanpa penambahan susu, dan gula.",
    "Tidak Aktif",
  ],
  [
    "05010402",
    "Lemak Kakao (Cocoa Butter)",
    "Lemak kakao (cocoa butter) adalah lemak yang diperoleh dari biji kakao.",
    "Tidak Aktif",
  ],
  [
    "05010403",
    "Bonbon Cokelat/Permen Isi Cokelat",
    "Bonbon coklat/permen coklat adalah produk permen yang bagian dalamnya lunak dan terbuat dari campuran cairan kental (liquor) kakao, susu dan sirup gula. Kandungan susu tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    "05010404",
    "Truffles",
    "Truffles adalah produk permen yang dibuat dari campuran cokelat hitam atau cokelat susu dengan lemak kakao, minyak nabati dan bahan lainnya. Tipe Eropa mengkombinasikan sirup dengan bahan-bahan berbasis cokelat (bubuk kakao, susu bubuk, lemak, gula, sirup",
    "Aktif",
  ],
  [
    "05010406",
    "Cokelat Putih",
    "Cokelat putih adalah produk padat atau semiplastis yang diperoleh dari hasil pencampuran dan penggilingan lemak kakao dengan satu atau lebih produk susu dan satu atau lebih pemanis nutritif karbohidrat dan bahan-bahan lain.",
    "Tidak Aktif",
  ],
  [
    "05010407",
    "Cokelat Drop atau Chip",
    "Cokelat drop atau chip adalah produk yang dibuat dari adonan kental cokelat dan dibentuk dengan cara melewatkannya melalui nozzle kecil dan dijatuhkan pada ban berjalan sehingga membentuk piramid atau kubah kecil.",
    "Tidak Aktif",
  ],
  [
    "05010408",
    "Cokelat Susu",
    "Cokelat susu adalah produk yang dibuat dari campuran cairan kental cokelat, gula atau pemanis lain, lemak kakao atau lemak lain dan produk susu (susu bubuk penuh dan susu bubuk tanpa lemak). Kandungan susu tidak lebih dari 5%.",
    "Tidak Aktif",
  ],
  [
    "05010409",
    "Cokelat Krim",
    "Coklat krim adalah cokelat dengan penambahan gula, krim dan padatan susu.",
    "Tidak Aktif",
  ],
  [
    "05010410",
    "Cokelat Manis",
    "Cokelat manis adalah produk padat atau semiplastis yang diperoleh dari proses pencampuran dan penggilingan cokelat liquor dengan satu atau lebih pemanis karbohidat nutritif. Dapat ditambahkan bahan lainnya.",
    "Tidak Aktif",
  ],
  [
    "05010411",
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati",
    "produk yang sama dg definisi & standar untuk cokelat manis, kecuali dalam penyiapan produk, kakao atau campuran dari kakao dan cokelat liquor digunakan dlm jumlah tertentu sehingga produk akhir mengandung tidak kurang dari 6.8% pada padatan kakao bkn lema",
    "Tidak Aktif",
  ],
  [
    "05010412",
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam",
    "Cokelat semi-manis atau cokelat pahit-manis atau cokelat hitam adalah cokelat manis yang mengandung tidak kurang dari 35% cokelat liquor.",
    "Tidak Aktif",
  ],
  [
    "05010413",
    "Cokelat Isi (Filled Chocolate)",
    "Cokelat Isi (filled chocolate) adalah produk yang dilapisi dengan satu atau lebih lapisan cokelat dan cokelat berperisa dimana bagian tengah dapat dibedakan dengan lapisan luarnya. Cokelat isi tidak termasuk produk tepung confectionery, pastri dan biskuit",
    "Tidak Aktif",
  ],
  [
    "05010414",
    "Cokelat Tawar (Unsweetened Chocolate)",
    "Cokelat tawar (unsweetened chocolate) adalah cokelat tanpa penambahan gula.",
    "Tidak Aktif",
  ],
  [
    "05010416",
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel",
    "Meses/cokelat butir/cokelat vermicelli/streusel adalah butiran atau kepingan dari salah satu atau campuran dari kakao massa, kakao bubuk termasuk<br> kakao bubuk yang dikurangi lemaknya dengan atau tanpa penambahan lemak kakao, dan bahan pangan lain.",
    "Aktif",
  ],
  [
    "05010417",
    "Cokelat Serpih",
    "Cokelat serpih adalah cokelat dengan penambahan gula dan dibentuk menjadi serpihan.",
    "Tidak Aktif",
  ],
  [
    "05010418",
    "Cokelat Susu Serpih",
    "Cokelat susu serpih adalah susu dengan penambahan gula dan lemak susu dan dibentuk menjadi bentuk serpihan atau batangan.",
    "Tidak Aktif",
  ],
  [
    "05010419",
    "Cokelat Berperisa",
    "Cokelat berperisa adalah produk cokelat yang diberi senyawa perisa seperti kopi atau senyawa perisa lain untuk klaim sesuai dengan karakteristik organoleptik.",
    "Tidak Aktif",
  ],
  [
    "05010420",
    "Cokelat Aerasi",
    "Cokelat aerasi adalah produk cokelat yang mengalami proses aerasi sehingga terbentuk rongga-rongga kecil di dalamnya.",
    "Aktif",
  ],
  [
    "05010421",
    "Cokelat Laminasi",
    "Cokelat laminasi adalah produk cokelat yang berlapis-lapis dibuat dengan menggunakan roller dan dalam kondisi plastis dipotong-potong menjadi batangan atau serpihan.",
    "Tidak Aktif",
  ],
  [
    "05010422",
    "Cokelat Komposit",
    "Cokelat komposit adalah produk cokelat berperisa yang ditambah dengan bahan lain yang dapat dimakan tidak termasuk tepung, pati dan lemak kecuali jika telah ada di dalam ingredien yang digunakan.",
    "Aktif",
  ],
  [
    "05010423",
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ...",
    "Cokelat hitam, diperhitungkan dalam kondisi tanpa kandungan air, mengandung tidak kurang dari 35% padatan kakao, tidak kurang dari 18% lemak kakao, dan tidak kurang dari 14% padatan kakao tanpa lemak.<br> <br> Untuk Cokelat Hitam Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).<br>",
    "Aktif",
  ],
  [
    "05010424",
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ...",
    "Cokelat hitam manis, diperhitungkan dalam kondisi tanpa kandungan air, mengandung tidak kurang dari 30% padatan kakao, tidak kurang dari 18% lemak kakao, dan tidak kurang dari 12% padatan kakao tanpa lemak.<br> <br> Untuk Cokelat Hitam Manis Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010425",
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ...",
    "Cokelat hitam kovertur, diperhitungkan dalam kondisi tanpa kandungan air, mengandung tidak kurang dari 35% padatan kakao, tidak kurang dari 31% lemak kakao, dan tidak kurang dari 2.5% padatan kakao tanpa lemak.<br> <br> Untuk Cokelat Hitam Kovertur Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010426",
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ...",
    "Cokelat susu kovertur, diperhitungkan dalam kondisi tanpa kandungan air, semestinya mengandung tidak kurang dari 25% padatan kakao, tidak kurang dari 15% lemak kakao, tidak kurang dari 2,5% padatan kakao tanpa lemak, tidak kurang dari 12% padatan susu, dan tidak kurang dari 31% total lemak.<br> <br> Untuk Cokelat Susu Kovertur Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010427",
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ...",
    "Cokelat putih kovertur, diperhitungkan dalam kondisi tanpa kandungan air, semestinya mengandung tidak kurang dari 20% lemak kakao, tidak kurang dari 14% padatan susu dan tidak kurang dari 25% total lemak.<br> <br> Untuk Cokelat Putih Kovertur Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010428",
    "Praline",
    "Praline adalah produk cokelat (real chocolate) dengan ukuran satu suapan penuh, dimana dapat berupa cokelat isi (filled chocolate), atau kombinasi dari berbagai tipe cokelat dengan bahan makanan lain.",
    "Aktif",
  ],
  [
    "05010429",
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ...",
    "Cokelat putih, diperhitungkan dalam kondisi tanpa kandungan air, semestinya mengandung tidak kurang dari 20% lemak kakao, dan tidak kurang dari 14% padatan susu.<br> <br> Untuk Cokelat Putih Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010430",
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ...",
    "Cokelat susu, diperhitungkan dalam kondisi tanpa kandungan air, mengandung tidak kurang dari 25% padatan kakao, tidak kurang dari 2,5% padatan kakao tanpa lemak, dan tidak kurang dari 12% padatan susu.<br> <br> Untuk Cokelat Susu Isi : jumlah komponen cokelat untuk pelapisan tidak kurang dari 25% dari berat total produk akhir (dari 25% tsb min 60% merupakan komponen cokelat). Sehingga jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010431",
    "Cokelat Isi (Filled Chocolate)",
    "Cokelat Isi (filled chocolate) adalah produk yang dilapisi dengan satu atau lebih lapisan cokelat dan cokelat berperisa dimana bagian tengah dapat dibedakan dengan lapisan luarnya. Cokelat isi tidak termasuk produk tepung confectionery, pastri dan biskuit.",
    "Tidak Aktif",
  ],
  [
    "05010432",
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli",
    "Meses susu/cokelat susu butir/cokelat susu vermicelli adalah butiran atau kepingan dari salah satu atau campuran dari kakao massa, kakao bubuk termasuk kakao bubuk yang dikurangi lemaknya dengan atau tanpa penambahan lemak kakao, susu, dan bahan pangan lain.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Padatan kakao tanpa lemak tidak kurang dari 2.5%;<br> \xE2\x{20AC}\xA2 Total padatan kakao tidak kurang dari 20%;<br> \xE2\x{20AC}\xA2 Padatan susu tidak kurang dari 12%.",
    "Aktif",
  ],
  [
    "05010501",
    "Cocoa Butter Equivalent",
    "Cocoa butter equivalent adalah lemak yang memiliki seluruh sifat fisik dan kimia lemak kakao tetapi komponen gliserida penyusunnya diturunkan dari sumber selain biji kakao. Karakter flavor tidak harus sama dengan lemak kakao. Produk ini terbuat dari lemak",
    "Aktif",
  ],
  [
    "05010502",
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/<br> Substitute=CBS Lauric)",
    "Pengganti lemak kakao laurat (lauric cocoa butter replacer/ substitute=CBS lauric) adalah lemak yang memiliki sifat mirip dengan lemak kakao, tetapi tidak sama dengan lemak kakao. Produk ini terutama berbasis minyak sawit dan minyak inti sawit.",
    "Aktif",
  ],
  [
    "05010503",
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/<br> Substitute = CBS Non-Lauric)",
    "Pengganti lemak kakao non-laurat (nonlauric cocoa butter replacer/ substitute = CBS non-lauric) adalah lemak yang kesetaraan fase lemaknya 20% hingga 25% dengan lemak kakao. Teksturnya menyerupai lilin (waxy).",
    "Aktif",
  ],
  [
    "05010504",
    "Carob Coatings",
    "Carob coatings adalah produk pengganti lemak cokelat yang berasal dari sejenis kacang (locus bean) dengan dominasi kandungan karbohidrat tetapi tidak mengandung kafein dan teobromin.",
    "Aktif",
  ],
  [
    "05010505",
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ<br> Coating)",
    "Coating dari lembaga gandum bebas lemak (deffated wheat germ coating) adalah pengganti lemak cokelat dari lembaga gandum bebas lemak yang melalui proses penyangraian dan proses spesifik lainnya.",
    "Aktif",
  ],
  [
    "05010506",
    "Cokelat Compound Butir/Cokelat Paduan Butir",
    "Cokelat compound butir/cokelat paduan butir adalah cokelat paduan/cokelat compound dengan penambahan gula dan dibentuk menjadi butiran.",
    "Aktif",
  ],
  [
    "05010508",
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ...",
    "Cokelat Paduan/Cokelat compound hitam pahit (bitter dark compound chocolate) adalah produk cokelat dimana sebagian atau seluruh lemak kakaonya diganti dengan lemak nabati. Padatan kakao tidak kurang dari 20%.<br> <br> Untuk Cokelat Compound Hitam Pahit Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010509",
    "Minuman Cokelat Paduan (Bubuk)",
    "Minuman Cokelat Paduan (Bubuk) dibuat dari kakao bubuk dan/atau padatan kakao dengan penambahan bahan pangan lainnya. Kandungan kakao (total cocoa solid) tidak kurang dari 5% (dihitung dari basis berat kering)",
    "Aktif",
  ],
  [
    "05010510",
    "Cokelat Imitasi",
    "Cokelat imitasi adalah produk serupa cokelat paduan/cokelat<br> compound dimana karakteristik dasarnya tidak memenuhi<br> karakteristik dasar cokelat paduan/cokelat compound.",
    "Aktif",
  ],
  [
    "05010511",
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ...",
    "Cokelat paduan/Cokelat compound hitam (dark compound chocolate) adalah produk cokelat dimana sebagian atau seluruh lemak kakaonya diganti dengan lemak nabati. Padatan kakao tidak kurang dari 13,0%.<br> <br> Untuk Cokelat Compound Hitam Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010512",
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ...",
    "Cokelat paduan/Cokelat compound hitam manis (sweet dark compound chocolate) adalah produk cokelat dimana sebagian atau seluruh lemak kakaonya diganti dengan lemak nabati. Padatan kakao tidak kurang dari 7,0%, diperhitungkan atas dasar berat kering dalam produk.<br> <br> Untuk Cokelat Compound Hitam Manis Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010513",
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ...",
    "Cokelat paduan/Cokelat compound susu (milk compound chocolate) adalah produk cokelat dimana sebagian atau seluruh lemak kakaonya diganti dengan lemak nabati. Padatan kakao tidak kurang dari 5,0% dan padatan susu tidak kurang dari 9,0%, diperhitungkan atas dasar berat kering dalam produk.<br> <br> Untuk Cokelat Compound Susu Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Aktif",
  ],
  [
    "05010514",
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ...",
    "Cokelat Paduan/Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) adalah produk cokelat dimana sebagian atau seluruh kakaonya diganti dengan lemak nabati. Padatan kakao tidak kurang dari 5% dan padatan susu tidak kurang dari 5%. Persentase diperhitungkan atas dasar berat kering dalam produk.<br> <br> Untuk Cokelat Compound Susu Manis Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).<br>",
    "Aktif",
  ],
  [
    "05010515",
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ...",
    "Cokelat Paduan/Cokelat Compound Putih (White Compound Chocolate) adalah produk cokelat dimana sebagian atau seluruh kakaonya diganti dengan lemak nabati. Padatan susu tidak kurang dari 14%. Persentase diperhitungkan atas dasar berat kering dalam produk.<br> <br> Untuk Cokelat Compound Putih Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Tidak Aktif",
  ],
  [
    "05010516",
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ...",
    "Cokelat Paduan/Cokelat Compound Putih Manis (Sweet White Compound Chocolate) adalah produk cokelat dimana sebagian atau seluruh kakaonya diganti dengan lemak nabati. Padatan susu tidak kurang dari 5%. Persentase diperhitungkan atas dasar berat kering dalam produk.<br> <br> Untuk Cokelat Compound Putih Manis Isi : jumlah maksimal bahan isian adalah 75% (tidak termasuk produk tepung, confectionery, pastry dan biskuit).",
    "Tidak Aktif",
  ],
  [
    "05010517",
    "Minuman Cokelat Paduan (Siap minum, Konsentrat)",
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) dibuat dari kakao bubuk dan/atau padatan kakao dengan penambahan bahan pangan lainnya. Kandungan kakao (total cocoa solid) tidak kurang dari 5% (dihitung dari basis berat kering)",
    "Aktif",
  ],
  [
    "05010518",
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial)",
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) yang diproses steril komersial.",
    "Tidak Aktif",
  ],
  [
    "05020101",
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet",
    "Kembang gula keras/permen keras / hard candy / boiled sweet adalah produk berbentuk padat yang terbuat dari gula atau pemanis bukan gula (non nutritif) dengan atau tanpa pemanis lain, sirup glukosa dengan atau tanpa penambahan bahan pangan lain. Produk in",
    "Aktif",
  ],
  [
    "05020102",
    "Pastiles",
    "Pastiles adalah produk confectionery yang mengikutsertakan gelatin selain gom arab dan sirup glukosa yang lebih banyak sehingga berpengaruh pada tekstur permen yang lebih lunak. Pastiles biasanya berlapis granula atau tepung gula.",
    "Aktif",
  ],
  [
    "05020103",
    "Pressed Candy/Lozenges",
    "Pressed candy/lozenges adalah sejenis permen yang terbuat dari tepung gula yang dibentuk menjadi pasta dapat ditambahkan gom, larutan gelatin atau keduanya.",
    "Aktif",
  ],
  [
    "05020104",
    "Kembang Gula Isi Susu/Permen Isi Susu",
    "",
    "Aktif",
  ],
  [
    "05020105",
    "Hasil Olah Gula (Butiran, dll)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    "05020106",
    "Kembang Gula/Permen Isi lainnya",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    "05020201",
    "Kembang Gula Lunak/Permen Lunak",
    "Kembang gula lunak/permen lunak adalah kembang gula/permen yang bertekstur relatif lunak apabila dikunyah. Dapat dilapisi dengan pelapis gula atau cokelat atau bahan lainnya.<br> Karakteristik dasar :<br> \x{2022} Kadar air permen lunak tidak lebih dari 7,5%;<br> \x{2022} Kadar air permen lunak jeli tidak lebih dari 20%.",
    "Aktif",
  ],
  [
    "05020202",
    "Kembang Gula Karamel/Permen Karamel",
    "Kembang gula karamel/permen karamel adalah kembang gula/permen yang terbuat dengan tambahan susu lemak penuh dan sumber lemak lain dari lemak nabati atau hewani dan terjadi reaksi pencoklatan (reaksi maillard) pada produk. Dari teksturnya dibedakan menjadi tiga jenis yaitu lunak, medium dan keras tergantung dari suhu pendidihan. Karamel lunak biasanya digunakan untuk pelapisan confectionery batangan dan untuk pelapisan dengan ekstrusi.",
    "Aktif",
  ],
  [
    "05020203",
    "Fudge",
    "Fudge adalah kembang gula karamel / permen karamel yang memiliki tekstur lebih berpasir akibat proses kristalisasi karena kandungan gula yang lebih tinggi dari kembang gula karamel/ permen karamel.",
    "Aktif",
  ],
  [
    "05020204",
    "Butterscotch",
    "Butterscotch adalah kembang gula karamel/permen karamel yang hanya menggunakan butter sebagai sumber lemak di luar bahan dasar gula dan glukosa.",
    "Aktif",
  ],
  [
    "05020205",
    "Licorice",
    "Licorice adalah kembang gula lunak/permen lunak yang dibuat dari ekstrak tanaman licorice (leguminous weed), tepung terigu, gula, sirup glukosa, gelatin, serta air. Proses utama adalah pemanasan sampai tergelatinisasi sempurna dengan kadar air rendah, pencetakan dengan ekstruder dan pengeringan.",
    "Aktif",
  ],
  [
    "05020206",
    "Toffee",
    "Toffee adalah kembang gula/permen dengan tekstur yang keras dan agak chewy yang dibuat dari campuran gula, susu, mentega atau lemak lain, garam, lesitin dengan atau tanpa penambahan kacang. Kandungan lemak dari permen toffee lebih rendah dari permen karamel.",
    "Aktif",
  ],
  [
    "05020207",
    "Krokant/Nugat (Praline)/Brittles",
    "Krokant / nugat (praline)/ brittles adalah kembang gula /permen sejenis toffee tetapi tidak menggunakan susu dalam formulasinya dan didominasi oleh rasa kacang (almond, hazelnut atau kacang tanah) yang ditambahkan pada adonan dalam bentuk hancuran agak ka",
    "Tidak Aktif",
  ],
  [
    "05020208",
    "Marshmallow",
    "Marshmallow adalah kembang gula /permen lunak dan beraerasi yang dibuat dari gelatin/pektin/agar/gom arab, albumin telur, gula, glukosa dan gula invert.",
    "Aktif",
  ],
  [
    "05020209",
    "Kembang Gula Jeli Pati (Starch Jelly)",
    "Kembang gula jeli pati (starch jelly) adalah kembang gula jeli/permen jeli yang menggunakan pati (pati jagung, pati gandum atau pati lainnya) sebagai salah satu bahan selain bahan-bahan lain yang biasa digunakan untuk produk confectionery.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 20%.",
    "Aktif",
  ],
  [
    "05020210",
    "Kembang Gula Jeli Agar dan Gelatin",
    "Kembang gula jeli agar dan gelatin adalah kembang gula jeli/permen jeli yang dibuat dari bahan dasar agar, gelatin atau pektin sehingga merupakan produk gel yang kenyal.<br> Jeli agar lebih keras dan menyerupai karet (rubbery) dari jeli gelatin tetapi tekstur jeli gelatin tergantung dari jumlah gelatin yang digunakan. Jeli pektin lebih lunak dan lebih mudah terdispersi di dalam mulut.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 20%.",
    "Aktif",
  ],
  [
    "05020211",
    "Gula Kapas (Cotton Candy)/Arumanis",
    "Gula kapas (cotton candy) / arumanis adalah kembang gula /permen yang terbuat dari 100% gula yang dilelehkan dan diputar dengan mesin pemutar (spin) dimana cairan gula dilewatkan pada lubang kecil yang berputar sehingga membentuk massa seperti kapas.",
    "Aktif",
  ],
  [
    "05020212",
    "Krokant/Brittles",
    "Krokant/brittles adalah kembang gula/permen sejenis toffee menggunakan susu dalam formulasinya dan didominasi oleh rasa kacang (almond, hazelnut atau kacang tanah) yang ditambahkan pada adonan dalam bentuk hancuran agak kasar (chopped).",
    "Aktif",
  ],
  [
    "05020213",
    "Gulali",
    "Gulali adalah produk yang terbuat dari gula dan air yang dipanaskan membentuk adonan pasta atau semi plastis dan dicetak menjadi berbagai macam bentuk.",
    "Aktif",
  ],
  [
    "05020301",
    "Nougat",
    "Nougat adalah produk yang berbahan dasar gula dan whipping agent atau putih telur, dengan atau tanpa penambahan bahan pangan lain misalnya madu, kakao, kacang-kacangan, buah kering, yang dibentuk untuk langsung dikonsumsi, atau dapat digunakan sebagai bahan pengisi untuk produk cokelat. Nougat dapat bertekstur keras atau lunak.",
    "Aktif",
  ],
  [
    "05020302",
    "Gulali",
    "Gulali adalah produk yang terbuat dari gula, air dan pewarna yang dipanaskan membentuk adonan pasta atau semiplastis dan dicetak menjadi berbagai macam bentuk.",
    "Tidak Aktif",
  ],
  [
    "05020303",
    "Permen Enting-Enting atau Nut Brittles",
    "Nut brittles atau permen enting-enting adalah permen keras dengan kandungan lemak dan susu lebih rendah dari karamel yang terbuat dari gula, mentega dan hancuran kacang-kacangan.",
    "Aktif",
  ],
  [
    "05020304",
    "Enting-Enting Kacang Gepuk",
    "Enting-enting kacang gepuk adalah makanan ringan berbentuk lempengan padat, prisma atau bentuk lainnya, dibuat dari kacang tanah (Arachis hypogeae L), dan gula pasir dan atau gula merah.",
    "Aktif",
  ],
  [
    "05020305",
    "Raw Marzipan, Base Almond Paste",
    "Raw marzipan, base almond paste adalah massa yang diproduksi dari almond yang diblansir, mengandung tidak lebih dari 17% air dan 35% gula, dan 10% dari keseluruhan massa adalah gula invert.<br> Kadar minyak almond tidak kurang dari 28%, mengandung tidak lebih dari 12% komponen pahit dari almond. Tanpa penghilangan rasa pahit.",
    "Aktif",
  ],
  [
    "05020306",
    "Marzipan, Almond Paste",
    "Marzipan, almond paste adalah campuran dari raw marzipan dengan komposisi tidak melebihi proporsi gula. Gula dapat digantikan dengan sirup glukosa hingga 3,5% dan/atau larutan sorbitol 70% hingga 5% dari total berat marzipan.",
    "Aktif",
  ],
  [
    "050301",
    "Kembang Gula Karet/Permen Karet",
    "Kembang gula karet/permen karet adalah produk yang terbuat dari bahan dasar gom alami atau sintetis, pemanis, dan bahan pangan lain.<br> Karakteristik dasar :<br> \x{2022} Kadar air tidak lebih dari 5%;<br> \x{2022} Gom tidak kurang dari 12%.",
    "Aktif",
  ],
  [
    "050401",
    "Icing",
    "Icing adalah bahan pelapis kue atau kukis yang terbuat dari bahan dasar gula, susu dan bahan lain dan lapisan membentuk massa yang keras setelah beberapa saat setelah dilapiskan.",
    "Aktif",
  ],
  [
    "050402",
    "Frosting",
    "Frosting adalah bahan pelapis berbentuk krim untuk kue yang terbuat dari bahan dasar gula, susu, lemak dan bahan lain.",
    "Aktif",
  ],
  [
    "050403",
    "Saus Butterscotch",
    "Saus butterscotch adalah sejenis sirup untuk dekorasi puding, baking product dan es krim yang terbuat dari gula, gula merah, cokelat, sirup jagung, margarin.",
    "Aktif",
  ],
  [
    "050404",
    "Saus/Topping/Olesan Cokelat",
    "Saus/topping/olesan cokelat adalah produk yang terbuat dari campuran gula, air dan atau minyak/lemak, satu atau lebih produk kakao, dengan atau tanpa bahan pangan lain, yang digunakan sebagai topping atau dekorasi.",
    "Aktif",
  ],
  [
    "050405",
    "Bahan pengisi roti berbasis cokelat",
    "Bahan pengisi roti berbasis cokelat",
    "Tidak Aktif",
  ],
  [
    "050406",
    "Bahan pengisi roti berbasis selain cokelat dan kacang",
    "Produk oles untuk salad (misalnya salad makaroni, salad kentang) dan sandwich, tidak termasuk produk oles berbasis cokelat dan kacang",
    "Tidak Aktif",
  ],
  [
    "050407",
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah)",
    "-",
    "Aktif",
  ],
  [
    "050408",
    "Saus/Topping/Olesan Manis",
    "Saus/topping/olesan manis adalah produk yang terbuat dari<br> campuran gula, air dan atau minyak/lemak, dengan atau tanpa<br> bahan pangan lain, yang digunakan sebagai topping atau dekorasi.",
    "Aktif",
  ],
  ["050409", "Premiks Pengisi Roti (Serbuk)", "&nbsp;", "Aktif"],
  [
    "050410",
    "Taburan Berbasis Gula",
    "Taburan berbasis gula adalah produk pangan berbentuk butiran atau kepingan dibuat dari gula dan lemak dengan atau tanpa penambahan bahan pangan lain, digunakan sebagai dekorasi atau topping es krim, kue atau pangan lain.",
    "Aktif",
  ],
  [
    "050411",
    "Saus/Topping/Olesan (non buah)",
    "Saus/topping/olesan (non buah) adalah produk untuk dekorasi/topping makanan atau minuman yang dibuat dengan gula dan/atau pemanis lain, dan bahan pangan lain. Topping (non buah) tidak termasuk non-dairy topping dari kategori pangan 02.3, topping buah dari kategori pangan 04.1.2.8, dan sirup cokelat dari kategori 05.1.2.",
    "Aktif",
  ],
  [
    "060101",
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia)",
    "Biji-bijian dan kacang- kacangan utuh adalah biji-bijian atau<br> serealia utuh, serta kacang-kacangan baik yang berkulit atau tidak<br> dan belum mengalami proses pengolahan.",
    "Tidak Aktif",
  ],
  [
    "060106",
    "Beras Diperkaya",
    "Beras diperkaya adalah beras giling yang telah mengalami penambahan zat gizi.",
    "Aktif",
  ],
  [
    "060109",
    "Emping Beras",
    "Emping beras adalah produk beras ketan yang diperoleh dari beras ketan sosoh yang direndam dalam air dan dipanaskan hingga patinya tergelatinisasi sempurna, lalu dipipihkan dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    "060111",
    "Gandum Patah (Cracked Wheat)",
    "Gandum patah (cracked wheat) adalah biji tanaman gandum yang mengalami pemecahan atau pemotongan, tetapi tidak termasuk gandum durum dan gandum durum merah.<br> Karakteristik dasar:<br> - Kadar air tidak lebih dari 15%<br> - Kehalusan : tidak kurang dari 90% lolos ayakan 8 mesh dan tidak lebih dari 20% lolos ayakan 20 mesh",
    "Tidak Aktif",
  ],
  [
    "060112",
    "Gandum Hancur (Crushed Wheat)",
    "Gandum hancur (crushed wheat) adalah biji tanaman gandum yang bersih dan telah mengalami penghancuran, tetapi tidak termasuk gandum durum dan gandum durum merah.<br> Karakteristik dasar:<br> - Kadar air tidak lebih dari 15%<br> - Kehalusan : lebih dari 40% lolos ayakan 8 mesh dan kurang dari 50% lolos ayakan 20 mesh",
    "Tidak Aktif",
  ],
  [
    "060113",
    "Jagung Pipil",
    "Jagung pipil adalah biji utuh tanaman jagung yang berasal dari tanaman Zea mays indentata L.,atau Zea mays indurata L., serta hasil hibridanya.",
    "Tidak Aktif",
  ],
  [
    "060119",
    "Bubur Instan",
    "Bubur Instan adalah produk bubur yang dibuat dari beras atau tepung beras yang mengalami proses pemasakan dan pengeringan. Dapat ditambahkan bumbu dan bahan pangan lain.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 14%",
    "Aktif",
  ],
  [
    "060120",
    "Nasi Instan",
    "Nasi Instan adalah nasi yang diperoleh dari beras sosoh yang direndam dalam air dan dipanaskan hingga patinya tergelatinisasi sempurna lalu dikeringkan. Dapat ditambahkan bumbu dan bahan pangan lainnya.<br> <br> Karakteristik dasar:<br> Kadar air tidak lebih dari 14%<br>",
    "Aktif",
  ],
  [
    "060121",
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain",
    "-",
    "Aktif",
  ],
  [
    "06020101",
    "Tepung Beras",
    "Tepung beras adalah tepung yang diperoleh dari penggilingan atau penumbukan beras (Oryza sativa L) yang telah maupun belum disosoh.",
    "Aktif",
  ],
  [
    "06020102",
    "Tepung Beras Ketan",
    "Tepung beras ketan adalah tepung yang diperoleh dari penggilingan atau penumbukan beras ketan (varietas putih maupun hitam). Pati beras ketan hampir seluruhnya terdiri dari amilopektin.",
    "Aktif",
  ],
  [
    "06020103",
    "Tepung Jagung",
    "Tepung jagung adalah tepung yang diperoleh dari penggilingan atau penumbukan biji jagung (Zea mays Linn) dari berbagai varietas. Termasuk tepung jagung putih dan tepung jagung kuning.",
    "Aktif",
  ],
  [
    "06020105",
    "Tepung Kacang Hijau Utuh",
    "Tepung kacang hijau utuh adalah tepung yang diperoleh dari penggilingan atau penumbukan biji tanaman kacang hijau (Phaseolus radiatus L.) yang belum dihilangkan kulitnya.",
    "Aktif",
  ],
  [
    "06020106",
    "Tepung Kacang Merah",
    "Tepung kacang merah adalah tepung yang diperoleh dari penggilingan atau penumbukan biji tanaman kacang merah yang sudah dihilangkan kulitnya.",
    "Aktif",
  ],
  [
    "06020107",
    "Tepung Kedelai (Soybean Flour)",
    "Tepung kedelai adalah tepung yang diperoleh dari penggilingan atau penumbukan kedelai (Glycine max L).",
    "Aktif",
  ],
  [
    "06020108",
    "Semolina Gandum Durum dan Tepung Gandum Durum",
    "Semolina gandum durum dan tepung gandum durum adalah tepung dan semolina yang diperoleh dari penggilingan atau penumbukan biji gandum durum (Triticum durum Desf) yang bersih, bebas dari kulit ari dan lembaga.",
    "Aktif",
  ],
  [
    "06020109",
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh",
    "Semolina gandum durum utuh dan tepung gandum durum utuh adalah tepung yang diperoleh dari penggilingan atau penumbukan biji gandum durum (Triticum durum Desf) yang bersih, tetapi masih mengandung kulit ari dan lembaga.",
    "Aktif",
  ],
  [
    "06020110",
    "Tepung Jewawut (Pearl Millet Flour)",
    "Tepung jewawut (pearl millet flour) adalah tepung yang diperoleh dari penggilingan atau penumbukan endosperm biji pearl millet (Pennisetum americanum L.) yang telah dikupas dan dipisahkan dari lembaganya.",
    "Aktif",
  ],
  [
    "06020111",
    "Tepung Sorgum",
    "Tepung sorgum adalah tepung yang diperoleh dari hasil penggilingan atau penumbukan endosperm biji Shorgum bicolor (L.) Moench yang telah dikupas dan dipisahkan dari lembaganya.",
    "Aktif",
  ],
  [
    "06020112",
    "Tepung Terigu",
    "Tepung terigu adalah tepung yang dibuat dari hasil penggilingan atau penumbukan endosperma biji gandum Triticum aestivum L (club wheat) dan atau Triticum compactum Host atau campuran keduanya dengan penambahan Fe, Zn, vitamin B1, vitamin B2, dan asam folat sebagai fortifikan.",
    "Aktif",
  ],
  [
    "06020113",
    "Tepung Terigu Self-Raising",
    "Tepung terigu self-raising adalah tepung terigu atau tepung terigu terklorinasi atau campurannya, dengan bahan pengembang kue/leavening agent atau ingredien lain maupun kombinasinya.",
    "Aktif",
  ],
  [
    "06020114",
    "Tepung Terigu Terklorinasi",
    "Tepung terigu terklorinasi adalah tepung terigu yang telah diberi perlakuan dengan klorin.",
    "Tidak Aktif",
  ],
  [
    "06020115",
    "Tepung Gluten Terigu (Wheat Gluten Powder)",
    "Tepung gluten terigu adalah tepung yang diperoleh dari tepung terigu yang telah mengalami pemisahan sebagian besar patinya.",
    "Aktif",
  ],
  [
    "06020116",
    "Tepung Terigu dengan Penambahan Protein",
    "Tepung terigu dengan penambahan protein adalah tepung yang diperoleh dari tepung terigu dengan penambahan protein hingga kandungan nitrogen tidak kurang dari 2,7% (bk).",
    "Aktif",
  ],
  [
    "06020117",
    "Tepung Terigu Utuh (Wholemeal Wheat Flour)",
    "Tepung terigu utuh (wholemeal wheat flour) adalah tepung yang bersih dan baik, diperoleh dari gandum utuh yang bersih dan baik yang telah digiling.",
    "Aktif",
  ],
  [
    "06020118",
    "Tepung Kulit Ari (Fine Bran)",
    "Tepung kulit ari (fine bran) adalah tepung yang diperoleh dari penggilingan atau penumbukan kulit ari biji-bijian seperti beras, gandum, oats, dan lain-lain yang terpisah dari endospermanya dan dalam keadaan bersih dan baik, dengan tingkat kehalusan tertentu",
    "Aktif",
  ],
  [
    "06020119",
    "Tepung Singkong",
    "Tepung singkong adalah tepung yang diperoleh dari penggilingan atau penumbukan umbi singkong (Manihot sp.) Umbi singkong yang digunakan adalah yang aman dikonsumsi.",
    "Aktif",
  ],
  [
    "06020120",
    "Tepung Gaplek",
    "Tepung gaplek adalah tepung yang diperoleh dari penggilingan atau penumbukan gaplek (umbi singkong kering utuh atau dipotong-potong). Umbi singkong yang digunakan adalah yang aman dikonsumsi.",
    "Aktif",
  ],
  [
    "06020121",
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.)",
    "Tepung umbi lainnya (tepung kentang, tepung ubi jalar, tepung garut, tepung ganyong dan lain-lain) adalah tepung yang diperoleh dari penggilingan atau penumbukan umbi. Umbi yang digunakan adalah yang aman dikonsumsi.",
    "Aktif",
  ],
  [
    "06020122",
    "Tepung Aren",
    "Tepung aren adalah tepung yang diperoleh dari penggilingan atau penumbukan empulur pohon aren (Arenga pinnata Merr).",
    "Aktif",
  ],
  [
    "06020123",
    "Kinako",
    "Kinako adalah tepung kedelai panggang.",
    "Aktif",
  ],
  [
    "06020124",
    "Konjac Flour",
    "Tepung konjac adalah tepung glukomanan yang diperoleh hasil<br> ekstraksi umbi iles-iles (Amorphophallus konjac).",
    "Aktif",
  ],
  [
    "06020126",
    "Tepung Iles-iles",
    "Tepung iles-iles adalah tepung yang diperoleh dari penggilingan atau penumbukan umbi tanaman Amorphophallus muelleri.",
    "Aktif",
  ],
  ["06020127", "Tepung Ceshnut", "-", "Aktif"],
  ["06020128", "Tepung Almond", "&nbsp;", "Aktif"],
  ["06020129", "Tepung Flaxseed", "-", "Aktif"],
  ["06020130", "Tepung Hazelnut", "-", "Aktif"],
  [
    "06020131",
    "Tepung Mokaf",
    "Tepung Mokaf adalah Tepung yang diperoleh dari ubi kayu (Manihot sp.) dengan proses fermentasi asam laktat.<br> <br> Karakteristik dasar:<br> \xB7 Kadar air tidak lebih dari 13%<br> \xB7 Kehalusan: tidak kurang dari 90% lolos ayakan 100 mesh, dan 100% lolos ayakan 80 mesh<br>",
    "Aktif",
  ],
  ["06020132", "Tepung Kacang Lainnya", "-", "Aktif"],
  [
    "06020133",
    "Tepung Campur",
    "Tepung campur adalah produk campuran 2 (dua) atau lebih jenis tepung dan/atau pati.",
    "Aktif",
  ],
  ["06020134", "Tepung Buckwheat", "", "Aktif"],
  [
    "06020201",
    "Pati Garut",
    "Pati garut adalah pati yang diperoleh dari sari umbi garut (Maranta arundinaceace L).",
    "Aktif",
  ],
  [
    "06020202",
    "Pati Jagung atau Maizena",
    "Pati jagung atau maizena adalah pati yang diperoleh dari biji jagung (Zea mays Linn) berbagai varietas.<br> <br> Karakteristik dasar:<br> Kadar air tidak lebih dari 14%",
    "Aktif",
  ],
  [
    "06020203",
    "Pati Sagu",
    "Pati sagu adalah pati yang diperoleh dari sari empulur pohon sagu (Metroxylon sp).",
    "Aktif",
  ],
  [
    "06020204",
    "Pati Kacang Hijau/Hunkwee",
    "Pati kacang hijau atau hunkwee adalah pati yang diperoleh dari kacang hijau (Phaseolusradiatus).",
    "Aktif",
  ],
  [
    "06020205",
    "Tapioka/Pati Singkong/Pati Ubi Kayu",
    "Tapioka/pati singkong/pati ubi kayu adalah pati yang diperoleh dari singkong/ubi kayu (Manihot sp.)",
    "Aktif",
  ],
  [
    "06020206",
    "Dekstrin",
    "Dekstrin adalah produk pati yang diperoleh dari pati yang dihidrolisis dengan pemanasan kering, perlakuan asam atau enzimatik.",
    "Aktif",
  ],
  [
    "06020207",
    "Pati Termodifikasi",
    "Pati termodifikasi adalah pati yang diperoleh dari modifikasi molekuler pati baik secara fisik, kimia, enzimatis maupun genetis untuk memperoleh sifat fungsional pati yang unggul.",
    "Aktif",
  ],
  ["06020209", "Pati Gandum", "-", "Aktif"],
  [
    "06020210",
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll)",
    "-",
    "Aktif",
  ],
  [
    "060302",
    "Keping Jagung (Corn Flake)",
    "Keping jagung (corn flake) adalah produk jagung yang diperoleh dari proses gelatinisasi pati jagung dengan berbagai teknik misalnya ekstrusi, lalu dikeringkan.",
    "Aktif",
  ],
  [
    "060303",
    "Meal",
    "Meal adalah produk serealia yang diperoleh dari penggilingan serealia. Produk ini dapat berupa campuran serealia.",
    "Aktif",
  ],
  [
    "060304",
    "Meal Lembaga Gandum (Wheat Germ Meal)",
    "Meal lembaga gandum (wheat germ meal) adalah produk meal yang diperoleh dari lembaga atau embrio biji gandum, bersama dengan kulit ari dan bagian lain. Kandungan lembaga tidak kurang dari 60%<br>",
    "Aktif",
  ],
  [
    "060305",
    "Oatmeal",
    "Oatmeal adalah produk meal yang diperoleh dari penggilingan atau penumbukan biji oat dan telah dipisahkan dari kulitnya. Kandungan lemak tidak kurang dari 5%<br>",
    "Aktif",
  ],
  [
    "060306",
    "Whole Maize (Corn) Meal",
    "Whole maize (corn) meal adalah produk meal yang diperoleh dari penggilingan atau penumbukan biji jagung (Zea mays L.) yang telah tua, belum berkecambah, sampai tingkat kehalusan tertentu. Pada persiapan penggilingan, partikel kasar dapat dipisahkan, digiling ulang, dan dikombinasi kembali dengan bahan asalnya. Kadar air tidak lebih dari 15%, Kehalusan: tidak kurang dari 95% lolos ayakan 10 mesh dan 45% lolos ayakan 24 mesh dan tidak kurang dari 35% lolos ayakan 65 mesh",
    "Aktif",
  ],
  [
    "060307",
    "Degermed Maize (Corn) Meal",
    "Degermed maize (corn) meal adalah produk meal yang diperoleh dari penggilingan atau penumbukan biji jagung (Zea mays L.) yang telah tua, bersih dari jamur, bersih dari biji gulma dan bersih dari serealia lain, sampai tingkat kehalusan tertentu dan selanjutnya dipisahkan lembaga dan kulit ari. Pada persiapan penggilingan, partikel kasar dapat dipisahkan, digiling ulang, dan dikombinasi kembali dengan bahan asalnya. Kadar air tidak lebih dari 15%, Kehalusan: tidak kurang dari 95% lolos ayakan 0,85 mm dan tidak kurang dari 45% lolos ayakan 24 mesh dan tidak kurang dari 25% lolos ayakan 65 mesh",
    "Aktif",
  ],
  [
    "060308",
    "Nasi Jagung",
    "Nasi jagung adalah produk jagung yang diperoleh dari penggilingan atau penumbukan kasar jagung pipil yang kemudian diolah lebih lanjut seperti memasak nasi.",
    "Aktif",
  ],
  [
    "060309",
    "Sereal Siap Santap termasuk Sereal Sarapan",
    "Produk serealia yang diperoleh dari satu atau campuran beberapa jenis serealia baik yang belum dimasak, telah dimasak sebagian, atau dimasak sempurna dengan ditambahkan bahan lain seperti : gula, malt, madu, garam, dan bahan pangan lain. Produk biasa dikonsumsi untuk sarapan dan/atau untuk tujuan lain. Bentuk produk dapat berupa<br> flake, keping, batang, dan bubur.<br> Karakteristik dasar:<br> Kandungan serealia tidak kurang dari 50%",
    "Aktif",
  ],
  [
    "060310",
    "Tiwul",
    "Produk yang diperoleh dari tepung gaplek kemudian direndam dalam air dan dikukus.",
    "Aktif",
  ],
  [
    "060311",
    "Degermed Maize (Corn) Grits",
    "Produk jagung yang diperoleh dari penggilingan atau penumbukan biji jagung (Zea mays<br> L.) yang telah tua, bersih dari jamur, bersih dari biji gulma dan bersih dari serealia lain; sampai tingkat kehalusan tertentu dan selanjutnya dipisahkan seluruh lembaga dan kulit ari. Karakteristik dasar:<br> - Kadar air tidak lebih dari 15%<br> - Kehalusan : tidak kurang dari 95% lolos ayakan 9 mesh dan tidak kurang dari 20% lolos ayakan 24 mesh",
    "Aktif",
  ],
  [
    "060313",
    "Serbuk Minuman Sereal",
    "Serbuk minuman/minuman serbuk serealia adalah produk minuman serealia dalam bentuk bubuk yang diperoleh dari satu atau lebih serealia dengan atau tanpa tambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> Kandungan serealia tidak kurang dari 25%",
    "Aktif",
  ],
  ["060314", "Sereal untuk Sarapan dengan Susu", "&nbsp;", "Aktif"],
  [
    "060315",
    "Sereal Siap Saji (Steril Komersial)",
    "&nbsp;",
    "Aktif",
  ],
  [
    "060316",
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh",
    "Sereal Sarapan dengan Serealia Utuh adalah produk sereal siap santap yang diperoleh dari serealia sebagai bahan baku utama dimana sebagian atau keseluruhannya adalah serealia utuh dan dapat dicampur beberapa serealia yang belum dimasak, telah dimasak sebagian, atau dimasak sempurna dengan<br> ditambahkan bahan lain seperti : gula, malt, madu, garam, dan bahan pangan lain, dimana produk akhirnya dapat berbentuk flake<br> , keping, batang, atau bubur.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kandungan serealia utuh tidak kurang dari 25%<br> \xE2\x{20AC}\xA2 Kadar serat pangan tidak kurang dari 3 g/100g",
    "Aktif",
  ],
  [
    "060317",
    "Granola",
    "Granola adalah produk sereal yang merupakan campuran gandum, kacang-kacangan, madu, buah kering dan dapat ditambahkan dengan ingredient lainnya. Produk ini dapat dikonsumsi dengan susu maupun yoghurt.",
    "Aktif",
  ],
  [
    "06040101",
    "Mi Basah Mentah",
    "Mi basah mentah adalah produk pangan yang diperoleh dari tepung terigu dengan atau tanpa penambahan bahan lain, berbentuk khas mi yang yang diperoleh melalui proses sheeting dan slittering (belum dipanaskan, direbus, dikukus, dimasak, di-pragelatinisasi,a",
    "Aktif",
  ],
  [
    "06040102",
    "Kulit Pangsit/Risol/Lumpia",
    "Kulit pangsit adalah produk tepung yang diperoleh dari adonan tepung dengan air dengan atau tanpa penambahan bahan pangan lain. Produk ini berbentuk lembaran tipis, dan dapat digunakan sebagai pembungkus pangsit, siomay, atau risol.",
    "Aktif",
  ],
  ["06040103", "Tortilla", "-", "Tidak Aktif"],
  [
    "06040104",
    "Mi Basah Mentah lainnya",
    "Mi basah mentah lainnya adalah mi basah mentah yang dibuat dari selain tepung terigu. Nama jenis untuk kategori ini misalnya mi basah mentah jagung",
    "Aktif",
  ],
  [
    "06040105",
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah",
    "Pangsit/pastel/lumpia/risol/samosa mentah adalah produk yang dibuat dari adonan tepung dengan air dengan atau tanpa penambahan bahan pangan lain, dan belum dimasak. Produk ini dapat diisi dengan daging, ikan, sayuran, atau bahan pangan lain. Termasuk dalam kategori ini adalah produk lain yang sejenis.",
    "Aktif",
  ],
  [
    "06040201",
    "Kuetiaw Kering",
    "Kuetiaw kering adalah produk pangan kering yang diperoleh dari tepung beras, berbentuk khas kuetiaw.",
    "Aktif",
  ],
  [
    "06040202",
    "Makaroni",
    "Makaroni adalah produk pangan yang diperoleh dari adonan semolina, tepung durum, farina, tepung terigu dan kombinasinya, dengan air dan bahan pangan lain seperti putih telur, putih telur beku, tepung putih telur dan kombinasinya dengan padatan 0,5% hingga",
    "Aktif",
  ],
  [
    "06040205",
    "Produk Pasta Gandum Utuh",
    "Produk pasta gandum utuh adalah pasta yang diperoleh dari tepung<br> gandum utuh atau tepung gandum durum utuh, dan dapat<br> ditambahkan bahan pangan lain. Karakteristik dasar:<br> \xEF\x{201A}\xB7 Kadar air tidak lebih dari 12,5%<br> \xEF\x{201A}\xB7 Kadar protein tidak kurang dari 10%",
    "Aktif",
  ],
  [
    "06040206",
    "Produk Pasta Gandum dan Kedelai",
    "Produk pasta gandum dan kedelai adalah pasta yang diberi<br> tambahan tepung kedelai, dan dapat ditambahkan bahan pangan<br> lain.<br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Penambahan tepung kedelai tidak kurang dari 12,5%<br> \xEF\x{201A}\xB7 Kadar protein tidak kurang dari 13%",
    "Aktif",
  ],
  [
    "06040207",
    "Produk Pasta Susu",
    "Produk pasta susu adalah pasta yang menggunakan susu atau<br> ingredien susu sebagai pelarut adonannya, dengan atau tanpa<br> penambahan air.<br> Susu yang digunakan berupa susu konsentrat, susu bubuk, susu<br> evaporasi, dan campuran butter dengan susu skim, konsentrat susu<br> skim, susu skim evaporasi, susu bubuk tanpa lemak atau<br> campuran dua atau lebih komponen tersebut dengan proporsi berat<br> padatan susu tanpa lemak dalam campuran tidak lebih dari 2,275<br> kali berat lemak susu.<br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Total padatan susu tidak kurang dari 3,8%<br> \xEF\x{201A}\xB7 Kadar protein tidak kurang dari 11%<br>",
    "Tidak Aktif",
  ],
  [
    "06040208",
    "Produk Pasta Sayur",
    "Produk pasta sayur adalah pasta yang diberi tambahan sayur<br> seperti tomat, artichoke (Cynara cardunculus), bit, wortel, atau<br> bayam, dan dapat ditambahkan bahan pangan lain.<br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Penambahan sayur tidak kurang dari 3% (dihitung sebagai bahan<br> segar)<br> \xEF\x{201A}\xB7 Kadar protein tidak kurang dari 9%",
    "Aktif",
  ],
  [
    "06040213",
    "Produk Mi Gandum dan Kedelai",
    "Produk mi gandum dan kedelai adalah mi dari tepung gandum<br> dengan penambahan tepung kedelai.<br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Penambahan tepung kedelai tidak kurang dari 12,5%<br> \xEF\x{201A}\xB7 Kadar protein tidak kurang dari 13%",
    "Aktif",
  ],
  [
    "06040214",
    "Produk Mi Sayur",
    "Produk mi sayur adalah mi yang diberi tambahan sayur seperti tomat, artichoke, bit, wortel, bayam atau sayur lainnya. Sayur yang ditambahkan dapat berupa sayuran segar, kering, tepung, hancuran, ekstrak, atau konsentrat.<br> Karakteristik dasar:<br> Sayur yang ditambahkan tidak kurang dari 3% dihitung sebagai sayuran segar.",
    "Aktif",
  ],
  [
    "06040216",
    "Sohun",
    "Sohun adalah produk kering yang diperoleh dari tepung ubi kayu.<br> <br> Kategori Pangan Sohun (06040216) ini statusnya diubah menjadi Tidak Aktif karena sudah digantikan dengan Kategori Pangan : Sohun (06040318), menyesuaikan dengan PerKBPOM No.21 Tahun 2016.",
    "Tidak Aktif",
  ],
  ["06040217", "Mi Kering", "-", "Tidak Aktif"],
  [
    "06040218",
    "Pasta",
    "Pasta adalah produk yang dibuat dari semolina gandum durum sebagai bahan utama dan dapat mengandung pangan sumber karbohidrat lain, tepung, telur, garam, dan bahan pangan lain, yang diperoleh melalui ekstrusi atau pencetakan adonan. Produk dicetak menjadi berbagai bentuk dan dikeringkan. Produk pasta mengandung bahan dari gandum tidak kurang dari 80%. Termasuk makaroni, spagheti, fettuccini, penne, farfale, fusilli, ravioli, lasagna, cannelloni, rigatoni.<br> Karakteristik dasar : Kadar air tidak lebih dari 12,5%. Kadar protein tidak kurang dari 10%",
    "Aktif",
  ],
  [
    "06040219",
    "Pasta lainnya",
    "Pasta lainnya adalah produk pasta yang dibuat dari selain gandum sebagai bahan utama dan bahan pangan lainnya, yang diperoleh melalui ekstrusi atau pencetakan adonan. Nama jenis untuk kategori ini misalnya pasta jagung. Karakteristik dasar : Kadar air tidak lebih dari 12.5%",
    "Aktif",
  ],
  ["06040220", "Kuetiaw Lainnya", "-", "Aktif"],
  [
    "06040301",
    "Bihun",
    "Bihun adalah produk pangan kering yang diperoleh dari tepung beras dengan atau tanpa bahan lain.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 13%",
    "Aktif",
  ],
  [
    "06040302",
    "Makaroni",
    "Makaroni adalah produk pangan yang diperoleh dari adonan semolina, tepung durum, farina, tepung terigu dan kombinasinya, dengan air dan bahan pangan lain seperti utih telur, putih telur beku, tepung putih telur dan kombinasinya 0,5% hingga 2% dari produk",
    "Tidak Aktif",
  ],
  [
    "06040303",
    "Mi Kering Gandum",
    "Mi kering gandum adalah produk mi kering yang diperoleh dari tepung terigu dengan atau tanpa penambahan bahan lain dan telah mengalami pengeringan atau penggorengan. Produk mi kering gandum mengandung tidak kurang dari 60% bahan dari gandum. Karakteristik dasar kadar air tidak lebih dari 11% dan kadar protein tidak kurang dari 6%.",
    "Aktif",
  ],
  [
    "06040304",
    "Mi Kering Lainnya",
    "Mi kering lainnya adalah produk mi kering yang diperoleh dari bahan selain tepung terigu seperti tepung jagung, ubi jalar dan lain-lain, dengan atau tanpa penambahan bahan lain dan telah mengalami pengeringan atau penggorengan. Nama jenis untuk kategori ini misalnya mi kering jagung dan mi kering ubi jalar. Karakteristik dasar produk ini adalah kadar air tidak lebih dari 10%.",
    "Aktif",
  ],
  [
    "06040305",
    "Bihun Instan",
    "Bihun instan adalah produk bihun kering yang sebelumnya telah mengalami proses pemasakan sehingga patinya tergelatinisasi. Bihun instan akan matang setelah dimasak dengan air mendidih dalam waktu 4 menit. Karakteristik dasar: Kadar air tidak lebih dari 13%.",
    "Aktif",
  ],
  [
    "06040306",
    "Kuetiaw Instan",
    "Kuetiaw instan adalah kuetiaw kering yang sebelumnya telah mengalami proses pemasakan sehingga patinya tergelatinisasi. Kuetiaw instan akan matang setelah dimasak atau diseduh dengan air mendidih dalam waktu 4 menit.",
    "Aktif",
  ],
  [
    "06040307",
    "Makaroni Instan",
    "Makaroni instan adalah makaroni kering yang sebelumnya telah mengalami proses pemasakan sehingga patinya tergelatinisasi. Makaroni instan akan matang setelah dimasak atau diseduh dengan air mendidih dalam waktu 4 menit.",
    "Aktif",
  ],
  [
    "06040308",
    "Mi Basah Matang",
    "Mi basah matang adalah produk makanan yang dibuat dari tepung terigu dengan atau tanpa penambahan bahan pangan lain, yang telah mengalami pengukusan atau perebusan.",
    "Aktif",
  ],
  [
    "06040309",
    "Mi Instan",
    "Mi instan adalah produk yang dibuat dari bahan baku utama tepung terigu dengan atau tanpa penambahan bahan pangan lainnya, dikukus, dan digoreng atau dikeringkan, dan matang<br> setelah dimasak atau diseduh menggunakan air mendidih atau air panas dalam waktu singkat beserta bumbu dan atau tanpa pelengkapnya yang terdapat dalam kemasan.<br> Karakteristik dasar:<br> - Kadar air tidak lebih dari 10% jika diolah dengan proses<br> penggorengan<br> - Kadar air tidak lebih dari 14% jika diolah dengan proses<br> pengeringan",
    "Aktif",
  ],
  [
    "06040310",
    "Mi Instan Lainnya",
    "Mi instan lainnya adalah produk yang diperoleh dari selain tepung<br> terigu seperti tepung jagung, dan lainnya, dengan atau tanpa<br> penambahan bahan pangan lain, dengan atau tanpa dikukus,<br> digoreng atau dikeringkan, dan matang setelah dimasak atau<br> diseduh dengan air mendidih atau air panas dalam waktu singkat<br> beserta bumbu dan atau tanpa pelengkap pangan yang terdapat dalam kemasan<br>",
    "Aktif",
  ],
  [
    "06040311",
    "Nasi Instan",
    "Nasi instan adalah produk nasi instan yang hanya mengandung bumbu dan tidak mengandung kacang, daging, sayur dan bahan pangan lainnya.",
    "Tidak Aktif",
  ],
  ["06040312", "Bubur Serealia Instan", "", "Aktif"],
  [
    "06040313",
    "Bubur Instan",
    "Kategori Pangan Bubur Instan (06040313) ini statusnya diubah menjadi Tidak Aktif karena sudah digantikan dengan Kategori Pangan : Bubur Instan (060119), menyesuaikan dengan PerKBPOM No.21 Tahun 2016.",
    "Tidak Aktif",
  ],
  [
    "06040314",
    "Nasi Instan Steril",
    "Nasi instan adalah produk nasi instan yang hanya mengandung bumbu dan tidak mengandung kacang, daging, sayur dan bahan pangan lainnya serta diproses secara steril.",
    "Tidak Aktif",
  ],
  ["06040315", "Bubur Siap Saji Dalam Kemasan", "&nbsp;", "Aktif"],
  [
    "06040316",
    "Mi Basah Matang Lainnya",
    "Mi basah matang lainnya adalah mi basah matang yang dibuat selain dari tepung terigu.",
    "Aktif",
  ],
  [
    "06040317",
    "Bihun Lainnya",
    "Bihun lainnya adalah bihun yang dibuat dari tepung selain dari tepung beras dengan atau tanpa bahan lain. Nama jenis untuk produk ini misalnya bihun jagung.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 13%",
    "Aktif",
  ],
  [
    "06040318",
    "Sohun",
    "Sohun adalah produk berbentuk untaian kering yang diperoleh dari<br> pati kacang hijau (hunkwee).<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 13 %.",
    "Aktif",
  ],
  [
    "06040319",
    "Sohun Lainnya",
    "Sohun lainnya adalah produk berbentuk mi kering yang diperoleh dari pati sagu, pati aren, pati jagung (maizena), dan pati lainnya.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 13 %",
    "Aktif",
  ],
  [
    "06040320",
    "Pasta Instan Lainnya",
    "Pasta instan lainnya adalah produk pasta yang dibuat dari selain gandum<br> sebagai bahan utama dan bahan pangan lainnya, melalui proses pemasakan (gelatinisasi pati) dan pengeringan. Nama jenis untuk kategori ini misalnya makaroni jagung dan makaroni ubi jalar. Karakteristik dasar: Kadar air tidak lebih dari 12,5%.",
    "Aktif",
  ],
  [
    "06040321",
    "Pasta Instan",
    "Pasta instan adalah produk pasta yang telah dimasak lalu dikeringkan dan dapat ditambah bumbu.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 12,5%<br> Kadar protein tidak kurang dari 10%",
    "Aktif",
  ],
  [
    "06040322",
    "Mi Soa",
    "Mi Soa adalah mi kering dengan diameter untaian yang kecil dibuat dari tepung terigu dengan penambahan bahan pangan lain dan berwarna putih<br>",
    "Aktif",
  ],
  ["06040323", "Sohun Instan", "&nbsp;", "Aktif"],
  ["06040324", "Kerupuk Mentah", "-", "Aktif"],
  [
    "06040325",
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog)",
    "",
    "Aktif",
  ],
  [
    "06040326",
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak",
    "Pangsit/pastel/lumpia/risol/samosa pramasak adalah produk yang dibuat dari adonan tepung dengan air dengan atau tanpa penambahan bahan pangan lain, dan dimasak. Produk ini dapat diisi dengan daging, ikan, sayuran, atau bahan pangan lain. Termasuk dalam kategori ini adalah produk lain yang sejenis.",
    "Aktif",
  ],
  [
    "0604A0",
    "Pasta",
    "Pasta adalah produk yang dibuat dari meal serealia seperti semolina sebagai bahan utama dan dapat mengandung pangan sumber karbohidrat, tepung, telur, garam, dan bahan pangan lain, yang diperoleh melalui ekstrusi atau pencetakan adonan. Termasuk mi, makar",
    "Aktif",
  ],
  [
    "060501",
    "Tepung Custard Tanpa Telur (Eggless Custard)",
    "Tepung custard tanpa telur (eggless custard) adalah tepung yang dibuat dari campuran tapioka, pati jagung atau pati sagu, dengan maupun tanpa bahan lain.",
    "Aktif",
  ],
  ["060509", "Brem", "", "Aktif"],
  [
    "060510",
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati",
    "Premiks untuk makanan pencuci mulut berbasis serealia dan pati adalah produk berbentuk bubuk dengan bahan dasar tepung<br> serealia atau pati atau campurannya dengan penambahan gula dan bahan pangan lain. Dalam penyiapannya harus ditambahkan air atau susu dan/atau krim sebelum diolah lebih lanjut menjadi makanan pencuci mulut.",
    "Aktif",
  ],
  [
    "060511",
    "Sagu/Pati Mutiara",
    "Sagu/pati mutiara adalah produk dengan tekstur kenyal terbuat dari tepung sagu atau tepung serealia atau pati dengan campuran bahan pangan lain.",
    "Aktif",
  ],
  [
    "060601",
    "Tepung Bumbu",
    "Tepung bumbu adalah campuran tepung, serpihan atau hancuran serealia atau biji-bijian yang jika dikombinasikan dengan bahan lain dapat digunakan sebagai pelapis ikan, daging unggas, dan pangan lainnya. Tidak termasuk adonan (contohnya untuk produk bakeri)",
    "Aktif",
  ],
  [
    "060602",
    "Tepung Bakso",
    "Tepung bakso adalah campuran tepung (dapat berupa tepung gandum atau pati tapioka) dengan atau penambahan bahan pangan lain. Digunakan untuk membuat adonan bakso dengan<br> penambahan daging giling.",
    "Aktif",
  ],
  [
    "060603",
    "Tepung Pelapis",
    "Tepung Pelapis adalah campuran tepung, serpihan atau hancuran serealia atau biji-bijian, yang dapat dikombinasikan dengan bahan lain (seperti telur, air, susu) dapat digunakan sebagai pelapis bahan pangan hewani (daging sapi, daging unggas, daging ikan atau hasil laut lainnya (udang, cumi, dan lainnya), dan bahan pangan nabati (pisang, umbi-umbian, sayur-sayuran).",
    "Aktif",
  ],
  [
    "060604",
    "Tepung Bakwan",
    "Tepung bakwan adalah campuran tepung (dapat berupa tepung gandum atau tepung tapioka) dengan bahan pangan dan bahan tambahan pangan lainnya. Digunakan untuk membuat bakwan dengan penambahan bahan pangan lainnya seperti telur, air, sayuran (wortel, tauge, kubis, dan lainnya).",
    "Aktif",
  ],
  [
    "060605",
    "Tepung Bakso",
    "Tepung bakso adalah campuran tepung (dapat berupa tepung gandum atau pati tapioka) dengan atau penambahan bahan pangan lainnya. Digunakan untuk membuat adonan bakso dengan penambahan daging giling.",
    "Tidak Aktif",
  ],
  [
    "060701",
    "Dodol/Jenang/Gelamai",
    "Dodol/jenang /gelamai adalah produk pangan yang diperoleh dari tepung beras ketan, santan kelapa dan gula dengan atau tanpa penambahan bahan makanan lain dimasak hingga mencapai tekstur yang diinginkan.",
    "Aktif",
  ],
  [
    "06070101",
    "Nasi Beku",
    "Nasi instan adalah produk olahan beras yang telah dimasak menjadi nasi kemudian disimpan pada suhu dingin/beku. Produk ini tidak ditambahkan kacang-kacangan, ikan, daging, sayur dan/atau bahan pelengkap lainnya.",
    "Aktif",
  ],
  [
    "060703",
    "Kue Mochi",
    "Kue mochi adalah produk khas Jepang yang terbuat dari tepung beras ketan, dibentuk, dan ditaburi dengan tepung maizena atau wijen.",
    "Aktif",
  ],
  [
    "060704",
    "Kue Teuck/Tteok",
    "Kue teuck/tteok adalah kue khas Korea yang dibuat dari serealia terutama beras atau beras ketan.",
    "Aktif",
  ],
  [
    "060709",
    "Kue Mangkok (dari Tepung Beras)",
    "Kue mangkok adalah produk roti kukus berbentuk mangkok yang dibuat dari tepung beras yang terlebih dahulu difermentasi dengan ragi atau air soda atau tape.",
    "Aktif",
  ],
  [
    "060710",
    "Jongkong Kelapa Muda",
    "Jongkong kelapa muda adalah produk pangan berbahan dasar tepung beras dalam bentuk adonan, dimasak, dibungkus bersama daun pandan, gula merah, daging buah kelapa dan santan dengan daun pisang atau lainnya dan dikukus hingga matang.",
    "Aktif",
  ],
  [
    "060711",
    "Talam Ebi",
    "Talam ebi adalah produk pangan berbahan dasar tepung beras yang dimasak dengan santan, gula dan bahan lainnya hingga membentuk adonan. Adonan terdiri dari 2 lapisan, dicetak, dikukus dan diberi taburan ebi diatasnya.",
    "Aktif",
  ],
  [
    "060712",
    "Kue Lapis Beras",
    "Kue lapis beras adalah produk pangan berbahan dasar tepung beras<br> yang dimasak dengan tepung sagu, santan, gula pasir, dan bahan<br> lainnya hingga membentuk adonan. Adonan dibagi menjadi<br> beberapa bagian yang berbeda warna, dicetak didalam loyang,<br> dikukus dengan beberapa tahap pelapisan.",
    "Aktif",
  ],
  [
    "060713",
    "Juadah Kering/Mayang Papan",
    "Juadah kering/mayang papan adalah produk pangan berbahan<br> dasar tepung beras yang telah disanggrai dan digoreng hingga<br> matang. Pelapis juadah dibuat dari campuran air, gula merah/gula<br> palem, gula pasir, vanili, durian dan bahan lainnya yang dimasak<br> sampai kental. Juadah kemudian dimasukkan ke dalamnya, diaduk<br> cepat sampai gula menempel pada juadah.",
    "Aktif",
  ],
  [
    "060714",
    "Petah",
    "Petah adalah produk pangan berbahan dasar tepung beras yang<br> dimasak dengan air, campuran air daun suji dan air kapur sirih dan<br> bahan lainnya hingga matang dan kental. Adonan kemudian<br> dituang dalam loyang, dikukus hingga matang dan dipotong<br> menurut selera. Petah disajikan dengan saus yang dibuat dari<br> santan yang direbus sampai matang.<br>",
    "Aktif",
  ],
  [
    "060727",
    "Kekicak/Gegicak",
    "Kekicak/gegicak adalah produk pangan berbahan dasar tepung ketan putih yang dimasak dengan air kapur sirih hingga membentuk adonan licin, dibentuk bulatan kecil, dalam loyang, bagian tengah dilubangi kemudian dikukus hingga matang. Kekicak<br> disajikan dengan taburan parutan kelapa muda dan saus gula merah.",
    "Aktif",
  ],
  [
    "060728",
    "Lalampa",
    "Lalampa adalah produk pangan berbahan dasar beras ketan putih yang dikukus bersama santan hingga matang kemudian dibungkus dengan daun pisang atau lainnya dengan isian ikan tongkol kemudian dipanggang hingga matang.",
    "Aktif",
  ],
  [
    "060729",
    "Katrisolo",
    "Katrisolo adalah produk pangan berbahan dasar beras ketan putih<br> yang dikukus dengan santan kental, daun pandan, garam dan<br> bahan lainnya. Setelah beras ketan putih dalam loyang cukup<br> panas, tuangkan kocokan tepung, gula, tepung beras dan dikukus<br> hingga matang. Dapat dipotong sesuai selera.",
    "Aktif",
  ],
  [
    "060730",
    "Eko Tukir",
    "Eko tukir adalah produk pangan berbahan dasar beras ketan putih yang dikukus dengan santan, dengan penambahan bawang merah, merica dengan atau tanpa bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    "060731",
    "Lapek Bugis",
    "Lapek bugis adalah produk pangan berbahan dasar tepung beras ketaLapek bugis adalah produk pangan berbahan dasar tepung beras<br> ketan hitam dan tepung ketan hitam yang dimasak dengan santan<br> sebagai adonan utama. Adonan isi dibuat dari kelapa parut, gula<br> pasir,vanili dan bahan lainnya yang dimasak sampai kelapa matang.<br> Adonan utama yang telah diiisi dengan adonan isi, diberi kuah<br> santan kelapa matang, dibungkus dengan daun pisang atau lainnya<br> dan dikukus. pangan lain.",
    "Aktif",
  ],
  [
    "060732",
    "Lamang",
    "Lamang adalah kue berbahan dasar beras dengan penambahan santan, garam dengan atau tanpa bahan lain, dimasukkan kedalam bambu yang berlapis daun pisang muda dan dibakar.",
    "Aktif",
  ],
  [
    "060733",
    "Kue Berbahan Dasar Beras Lainnya",
    "Kue berbahan dasar beras lainnya adalah kue yang berbahan dasar beras dan beras ketan baik dalam bentuk utuh maupun tepung. Contohnya : uli, buras, lontong, arem-arem, lupis, gendar, wingko, yangko, krasikan, dan lainnya.",
    "Aktif",
  ],
  [
    "060734",
    "Ombus-ombus",
    "Ombus-ombus adalah produk pangan berbahan dasar tepung beras putih yang dicampur dengan kelapa parut dan gula merah/gula putih. Campuran tersebut kemudian dimasukkan dalam helai daun pisang membentuk kerucut dan dikukus hingga matang.",
    "Aktif",
  ],
  [
    "060735",
    "Legomoro",
    "Legomoro adalah produk pangan berbahan dasar beras ketan putih yang dimasak dengan santan dan bahan pangan lain hingga membentuk adonan. Adonan kemudian diisi dengan daging cincang, dibungkus dengan daun pisang, diikat dan dikukus hingga matang.",
    "Aktif",
  ],
  [
    "06080101",
    "Sari Kedelai",
    "Sari kedelai adalah produk emulsi yang diekstrak dari kedelai yang telah direbus dan digiling dengan penambahan air. Kadar minimum protein (N x 6.25) tidak kurang dari 2% (b/v)",
    "Aktif",
  ],
  [
    "06080102",
    "Sari Kedelai Steril (Khusus Registrasi Ulang)",
    "\"Sari kedelai adalah produk emulsi yang diekstrak dari kacang kedelai<br> yang telah direbus dan digiling dengan penambahan air serta diproduksi secara steril komersil.\"<br>",
    "Aktif",
  ],
  [
    "06080103",
    "Serbuk Minuman Kedelai",
    "Serbuk minuman kedelai adalah produk berbentuk bubuk berbahan baku kedelai dengan atau tanpa penambahan bahan pangan lain, yang digunakan untuk minuman. Kadar minimum protein (N x 6.25) tidak kurang dari 0.8g/100g.",
    "Aktif",
  ],
  [
    "06080104",
    "Konsentrat Sari Kedelai",
    "Produk konsentrat dari emulsi yang diekstrak dari kedelai yang telah direbus dan digiling dengan penambahan air dan/atau penambahan bahan pangan lain. Cara mengkonsumsinya adalah cukup ditambahkan air.",
    "Aktif",
  ],
  [
    "06080201",
    "Kembang Tahu",
    "Kembang tahu adalah produk berupa lapisan tipis kering yang diperoleh dari pemanasan cairan yang didapat dari kedelai yang digiling dengan penambahan air.",
    "Aktif",
  ],
  ["06080202", "Kembang Tahu dalam Kaleng", "&nbsp;", "Aktif"],
  [
    "06080301",
    "Tahu",
    "Tahu adalah produk berupa padatan yang dibuat dari ekstrak kedelai melalui proses penggumpalan protein dengan penambahan koagulan. Tahu dapat memiliki tekstur yang beragam (seperti lembut, semi keras dan keras). Dapat ditambahkan bahan pangan lain. Kadar protein tidak kurang dari 9%",
    "Aktif",
  ],
  [
    "06080401",
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental",
    "Tahu semi kering yang dimasak (ditumis) dengan saus kental (misal saus miso). Tahu semi kering ini menyerap saus, sehingga memiliki tekstur seperti aslinya.",
    "Aktif",
  ],
  [
    "0608040203",
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried)",
    "Tahu semi kering yang digoreng dengan minyak banyak (deep fried). Tahu ini dapat langsung dikonsumsi atau dimasak lagi (contohnya dengan direndam dalam saus) setelah penggorengan. Termasuk dalam kategori ini tahu Sumedang dan tahu yang digunakan untuk pembuatan tahu isi.<br>",
    "Aktif",
  ],
  [
    "06080403",
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2",
    "",
    "Aktif",
  ],
  [
    "060805",
    "Tahu Kering",
    "Tahu yang seluruh kandungan airnya telah dikeluarkan. Dapat direkonstitusi dengan air atau saus untuk dapat dikonsumsi, atau dapat digunakan secara langsung dalam sebuah masakan. Selain itu dapat pula digoreng deep fried atau direndam dalam saus.",
    "Aktif",
  ],
  [
    "06080601",
    "Dou chi",
    "Dou chi adalah produk yang dibuat dari fermentasi dan penggaraman kedelai hitam dengan rasa dan aroma yang khas.<br>",
    "Aktif",
  ],
  [
    "06080602",
    "Natto",
    "Natto adalah produk kedelai yang diperoleh dari fermentasi kedelai yang memiliki penampakan berlendir, lengket dengan aroma khas.<br>",
    "Aktif",
  ],
  [
    "06080603",
    "Tempe",
    "Tempe kedelai adalah produk kedelai yang diperoleh dari fermentasi kedelai dengan menggunakan kapang Rhizopus sp, produk ini berbentuk padatan kompak dan berbau khas serta berwarna putih atau sedikit keabu-abuan.<br>",
    "Aktif",
  ],
  [
    "06080604",
    "Tauco",
    "Tauco adalah produk kedelai yang diperoleh dari hasil fermentasi kacang kedelai dalam larutan garam, berbau khas dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    "06080605",
    "Tauco Steril",
    "Tauco adalah produk kedelai yang diperoleh dari kacang kedelai hasil fermentasi kacang kedelai dalam larutan garam, berbau khas dengan atau tanpa penambahan bahan pangan lainnya dan diproses secara steril.",
    "Tidak Aktif",
  ],
  [
    "06080606",
    "Tauco",
    "Tauco adalah produk kedelai yang diperoleh dari hasil fermentasi kacang kedelai dalam larutan garam, berbau khas dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    "060807",
    "Tahu Fermentasi (Contohnya Keju Kedelai)",
    "",
    "Aktif",
  ],
  [
    "06080801",
    "Produk Protein Kedelai",
    "Produk protein kedelai adalah produk yang diperoleh dari proses pengurangan atau penghilangan komponen-komponen utama nonprotein (air, minyak, pati dan karbohidrat lain) dari kacang kedelai untuk mencapai kadar protein (N \xC3\x{2014} 5,71):<br> (1) Tepung protein kedelai 50% hingga 65%;<br> (2) Konsentrat protein kedelai 65% hingga 90%;<br> (3) Isolat protein 90% atau lebih;<br> Kadar protein dihitung terhadap bobot kering tanpa vitamin dan mineral yang ditambahkan. Ingredien yang dapat digunakan adalah karbohidrat termasuk gula, lemak dan minyak makan, produk protein lain, vitamin dan mineral, garam, herba dan rempah.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 10% (bk)",
    "Aktif",
  ],
  [
    "06080802",
    "Texturized Vegetable Protein (TVP)",
    "Texturized Vegetable Protein (TVP) adalah produk yang dibuat dari tepung protein kedelai, konsentrat protein kedelai, atau isolat protein kedelai melalui proses ekstrusi untuk menghasilkan tekstur mirip seperti daging.",
    "Aktif",
  ],
  [
    "0701010101",
    "Roti Buah/Roti Kismis/Roti Chocochips",
    "Roti buah/roti kismis/roti chocochips adalah produk roti dengan atau tanpa rempah, dengan penambahan buah kering, misalnya kismis, dan chocochips. Mengandung buah kering atau kismis tidak kurang dari 10% jumlah adonan.",
    "Aktif",
  ],
  [
    "0701010103",
    "Roti Kadet",
    "Roti kadet adalah produk roti yang dibuat untuk membuat roti lapis<br> (sandwich) atau untuk membuat roti isi (burger, hotdog, atau sosis).",
    "Aktif",
  ],
  [
    "0701010104",
    "Roti Tawar",
    "Roti tawar adalah produk roti yang adonannya terbuat dari tepung terigu, lemak, gula dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.<br> <br> Karakteristik dasar:<br> Kadar gula total tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "0701010105",
    "Roti Putih",
    "Roti putih adalah produk roti yang adonannya terbuat dari tepung gandum (sosoh penuh) dan air yang mengalami fermentasi oleh ragi (kamir) sebagai senyawa pengembang.",
    "Aktif",
  ],
  [
    "0701010106",
    "Roti Tawar Kupas",
    "Roti tawar kupas adalah roti tawar yang telah dikupas seluruh bagian kulitnya.<br> <br> Karakteristik dasar:<br> Kadar gula total tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "0701010107",
    "Roti Susu, Roll Susu, Bun Susu",
    "Roti susu, roll susu, bun susu adalah produk roti yang adonannya terbuat dari tepung terigu atau tepung terigu utuh, atau campurannya, padatan susu bukan lemak, lemak dan air yang mengalami fermentasi oleh ragi (kamir) sebagai senyawa pengembang dan atau bahan pengembang lain. Mengandung padatan susu bukan lemak tidak kurang dari 4% dari jumlah terigu.",
    "Aktif",
  ],
  [
    "0701010108",
    "Roti Wheat-Germ",
    "Roti wheat-germ adalah produk roti yang adonannya terbuat dari tepung terigu atau tepung terigu utuh atau campurannya, lemak, wheat germ (lembaga gandum), air dan yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang dan atau bahan pengembang lain. Kandungan wheatgerm tidak kurang dari 5% dari total tepung.",
    "Aktif",
  ],
  [
    "0701010109",
    "Roti Meal",
    "Roti meal adalah produk roti yang adonannya terbuat dari tepung serealia (meal) atau campuran tepung meal atau tepung terigu yang mengandung tidak kurang dari 60% tepung meal, lemak dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang dan atau bahan pengembang lain.",
    "Aktif",
  ],
  [
    "0701010110",
    "Roti Meal Utuh (Whole Meal)",
    "Roti meal utuh (whole meal) adalah produk roti yang adonannya terbuat dari tepung serealia (meal) utuh, lemak dan air yang mengalami fermentasi oleh ragi (kamir) sebagai senyawa pengembang dan atau bahan pengembang lain.",
    "Aktif",
  ],
  [
    "0701010111",
    "Roti Gandum Utuh (WholeWheat)",
    "Roti gandum utuh (wholewheat) adalah produk roti yang adonannya terbuat dari tepung gandum utuh, lemak, gula, dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar gula total tidak lebih dari 5%<br> \xE2\x{20AC}\xA2 Kadar tepung gandum utuh tidak kurang dari 10% dari total tepung<br>",
    "Aktif",
  ],
  [
    "0701010112",
    "Roti Rye",
    "Roti rye adalah produk roti yang adonannya terbuat dari campuran tepung rye dan tepung terigu, lemak dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang dan atau bahan pengembang lain. Tepung rye tidak lebih dari 70% tepung terigu.",
    "Aktif",
  ],
  [
    "0701010113",
    "Roti Pumpernickel",
    "Roti pumpernickel adalah produk roti yang yang adonannya terbuat dari campuran tepung terigu, tepung cornmeal, tepung rye, dan/atau tepung lain dengan penambahan rempah fennel atau biji jinten (caraway), lemak dan air yang mengalami fermentasi oleh ragi (kamir) dan atau bahan pengembang lain.",
    "Aktif",
  ],
  ["0701010114", "Bread Stick", "-", "Aktif"],
  [
    "0701010115",
    "Roti Tawar dengan penambahan bahan pangan lain",
    "Roti tawar adalah produk roti yang adonannya terbuat dari tepung terigu, lemak, gula dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang dengan penambahan bahan pangan lain.<br> Nama jenis untuk kategori ini misalnya roti tawar pandan (yang ditambahkan ekstrak pandan dan berwarna hijau), roti tawar cokelat (yang diberi bubuk cokelat), roti tawar dengan chocochips, roti tawar dengan kismis.<br> <br> Karakteristik dasar :<br> Kadar gula total tidak lebih dari 5%<br> Bahan pangan lain yang ditambahkan tidak lebih dari 10%<br>",
    "Aktif",
  ],
  [
    "0701010116",
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran)",
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum adalah produk roti yang adonannya terbuat dari campuran tepung terigu, kulit gandum (fine bran), lemak, gula, dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.<br> <br> Karakteristik dasar :<br> Kadar gula total tidak lebih dari 5%<br> Kulit gandum yang ditambahkan tidak kurang dari 2% dari total tepung<br>",
    "Aktif",
  ],
  [
    "0701010117",
    "Roti Perancis (Baguette/pain courant francais)",
    "Roti Perancis adalah produk roti berbentuk memanjang dengan tekstur keras yang adonannya terbuat dari tepung terigu atau terigu yang dicampur dengan kulit gandum, lemak, gula dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.<br> Karakteristik dasar :<br> Kadar gula total tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "0701010118",
    "Roti Malt",
    "Roti Malt adalah produk roti yang adonannya terbuat dari tepung gandum, ekstrak malt, lemak, gula dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.",
    "Aktif",
  ],
  [
    "0701010119",
    "Roti Kadet Gandum",
    "Roti kadet gandum adalah produk roti kadet yang dibuat dari tepung gandum utuh atau campuran tepung terigu dan kulit gandum (fine bran).",
    "Aktif",
  ],
  [
    "0701010120",
    "Roti Kadet Susu",
    "Roti kadet susu adalah produk roti yang adonannya terbuat dari tepung terigu atau tepung terigu utuh, atau campurannya, padatan susu bukan lemak, lemak dan air yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang dan atau bahan pengembang lain.<br> <br> Karakteristik dasar:<br> Mengandung padatan susu bukan lemak tidak kurang dari 4% dari jumlah terigu",
    "Aktif",
  ],
  [
    "0701010201",
    "Roti Soda",
    "Roti soda adalah produk roti yang dibuat dengan bahan pengembang selain ragi (kamir) yaitu senyawa pengembang kimia seperti baking powder atau baking soda, juga disebut sebagai quickbread.",
    "Aktif",
  ],
  [
    "070101A0",
    "Roti",
    "Roti adalah produk pangan yang diperoleh dengan memanggang adonan yang diperoleh dari tepung terigu dan/atau tepung lain, air, lemak dan bahan lainnya yang mengalami fermentasi oleh ragi (kamir).",
    "Tidak Aktif",
  ],
  [
    "07010201",
    "Krekers",
    "Krekers adalah jenis biskuit yang dalam pembuatannya memerlukan proses fermentasi atau tidak, serta melalui proses laminasi sehingga menghasilkan bentuk pipih dan bila dipatahkan penampangnya tampak berlapis-lapis.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "07010202",
    "Krekers Krim",
    "Krekers krim adalah jenis krekers fermentasi yang pada proses laminasinya menggunakan cracker dust di antara lapisan-lapisannya.<br> <br> Karakteristik dasar :<br> Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "07010203",
    "Krekers Sandwich",
    "Krekers sandwich adalah jenis krekers dengan menggunakan krim filling (rasa keju, rasa coklat, rasa buah, dan lain-lain) sedikitnya terdiri dari 2 (dua) keping krekers.",
    "Tidak Aktif",
  ],
  [
    "07010204",
    "Malkist",
    "Malkist adalah krekers krim yang permukaannya ditaburi gula.",
    "Tidak Aktif",
  ],
  [
    "07010205",
    "Water Biscuit",
    "Water biscuit adalah jenis krekers non-fermentasi yang pada proses laminasinya tidak menggunakan cracker dust, lemak atau pengisi apapun di antara lapisan-lapisannya.",
    "Aktif",
  ],
  [
    "07010206",
    "Krekers Soda",
    "Krekers soda adalah produk bakeri tipis, renyah dan tidak manis yang adonannya terbuat dari tepung terigu dan air yang dibuat dengan bahan pengembang selain ragi (kamir) yaitu senyawa pengembang kimia seperti baking powder atau baking soda, dan melalui proses laminasi berlapis-lapis lalu dipanggang sehingga ada rongga didalamnya",
    "Aktif",
  ],
  [
    "07010207",
    "Krekers Gurih (Savoury Cracker), Snack Cracker",
    "Krekers gurih (savoury cracker), snack cracker adalah jenis krekers sedikit manis atau asin, yang pada proses pembuatannya menggunakan enzim, sehingga memiliki tekstur yang berongga, sangat renyah dan produk akhirnya dapat divariasikan dengan disemprot mi",
    "Aktif",
  ],
  [
    "07010301",
    "Biskuit",
    "Biskuit adalah sejenis roti soda atau shortened bread atau quickbread yang adonannya terbuat dari tepung terigu, mentega/margarin, telur, susu dan sedikit gula pasir. Biskuit berukuran kecil, ringan, berserpih (flaky) dengan crust (kulit) berwarna emas.",
    "Tidak Aktif",
  ],
  [
    "07010302",
    "Bagel",
    "Bagel adalah sejenis roti berbentuk cincin dengan tekstur liat dan padat dengan rasa tawar yang adonannya dapat dibuat dari tepung terigu atau rye. Bagel juga dapat ditambah antara lain kismis dan buah kecil atau kacang, sayur, bawang, dan sebagainya.",
    "Aktif",
  ],
  [
    "07010303",
    "Roti Pita",
    "Roti pita adalah roti berbentuk lingkaran atau oval dan relatif tipis (pipih), lembut, dan bagian tengahnya berongga.",
    "Aktif",
  ],
  [
    "07010304",
    "Muffin Inggris (English Muffin)",
    "Muffin inggris (english muffin) adalah sejenis roti yang menggunakan kamir sebagai bahan pengembang, dibentuk bulat dimasak diatas pemanggang lalu dibelah dua. Permukaannya datar dengan warna kecoklatan di bagian luar dan berpori di dalamnya.",
    "Aktif",
  ],
  [
    "07010305",
    "Shortened Bread",
    "Shortened bread atau quickbread adalah produk sejenis biskuit yang<br> adonannya terbuat dari tepung terigu, mentega/margarin, telur,<br> susu dan sedikit gula pasir, dibuat dengan baking powder atau<br> baking soda, berukuran kecil, ringan, berserpih (flaky) dengan crust<br> (kulit) berwarna emas",
    "Aktif",
  ],
  [
    "07010306",
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam",
    "Roti canai/roti cane/roti kane/roti kanai/roti maryam adalah roti<br> berbentuk lingkaran, tipis (pipih), lembut, dibuat dengan cara<br> diputar hingga tipis, atau bisa pula dengan menebarkan adonan<br> setipis mungkin di atas panggangan, dapat dilipat, dipanggang<br> dengan sedikit minyak atau margarin. Roti ini biasanya dikonsumsi<br> dengan kari atau dikonsumsi langsung dengan penambahan bahan<br> pangan lain seperti cokelat, stroberi, keju, dan lain-lain",
    "Aktif",
  ],
  [
    "07010307",
    "Roti Jala",
    "Roti Jala adalah roti yang dibuat dengan cara menyemprotkan adonan membentuk jala atau renda, dipanggang dengan sedikit minyak atau margarin, dilipat, digulung, atau dibentuk lain. Roti ini biasanya dikonsumsi dengan kari atau masakan lain.<br>",
    "Aktif",
  ],
  ["07010308", "Tortilla", "-", "Aktif"],
  [
    "07010401",
    "Crouton",
    "Crouton adalah potongan roti tawar berbentuk kubus atau bentuk lain, dapat dioles mentega atau bahan pangan lain, lalu dipanggang hingga kering. Pada umumnya disajikan bersama sup",
    "Aktif",
  ],
  [
    "07010402",
    "Tepung Panir",
    "Tepung panir adalah produk yang diperoleh dari roti tawar yang dikeringkan dengan oven lalu digiling. Umumnya digunakan untuk menyalut bahan pangan lain untuk digoreng.",
    "Aktif",
  ],
  [
    "07010403",
    "Tepung Roti / Bread Crumb",
    "Tepung Roti/Bread crumb adalah roti tawar yang dihancurkan menjadi serpihan lalu dikeringkan, berukuran kasar (lebih kasar dari tepung panir) untuk menyalut bahan pangan lain dengan formulasi yang sesuai peruntukannya.",
    "Aktif",
  ],
  [
    "07010404",
    "Roti Untuk Stuffing",
    "Roti untuk stuffing adalah semacam crouton yang digunakan untuk mengisi karkas kalkun/karkas unggas atau karkas lain untuk dipanggang.",
    "Aktif",
  ],
  [
    "07010405",
    "Premiks Untuk Stuffing",
    "Premiks untuk stuffing adalah campuran tepung dan bahan pangan lain untuk pembuatan roti untuk stuffing.",
    "Aktif",
  ],
  [
    "07010406",
    "Adonan Shortened Bread",
    "Adonan Shortened Bread adalah adonan siap panggang untuk membuat Shortened Bread seperti dimaksud dalam kategori 07.1.3.",
    "Aktif",
  ],
  [
    "07010501",
    "Mantao",
    "Mantao adalah produk roti kukus tanpa isi.",
    "Aktif",
  ],
  [
    "07010502",
    "Bakpao/Pao",
    "Bakpao / pao adalah produk roti kukus yang diisi dengan daging, kacang, atau bahan pangan lain.",
    "Aktif",
  ],
  [
    "07010503",
    "Apem",
    "Apem adalah roti kukus yang dibuat dari tepung beras dan gula yang terlebih dahulu difermentasi dengan ragi atau tape.",
    "Aktif",
  ],
  [
    "07010504",
    "Bolu Kukus",
    "Bolu kukus adalah produk bakeri kukus berbentuk mangkok yang dibuat dari tepung terigu yang terlebih dahulu difermentasi dengan ragi atau tape atau dengan penambahan bahan pengembang.",
    "Tidak Aktif",
  ],
  [
    "07010505",
    "Bun Kukus",
    "Bun kukus adalah roti oriental yang diperoleh dari tepung terigu atau tepung beras yang diolah dengan pengukusan. Dengan atau tanpa isi (daging, jam)<br>",
    "Aktif",
  ],
  [
    "07010601",
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar",
    "Premiks untuk roti dan produk bakeri tawar adalah campuran bahan kering yang bisa ditambahkan dengan ingredien basah (seperti air, susu, minyak, mentega, telur) untuk membuat adonan untuk produk bakeri dari kategori 07.1.1, 07.1.2, 07.1.3, 07.1.4 dan 07.1.5<br>",
    "Aktif",
  ],
  [
    "07020101",
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie)",
    "Keik (cake), kukis (cookies) dan pai (pie) adalah produk bakeri yang dapat digunakan sebagai hidangan penutup atau pencuci mulut.",
    "Aktif",
  ],
  [
    "07020102",
    "Keik (Cake)",
    "Keik (cake) adalah produk bakeri manis yang dibuat dari adonan yang terdiri dari tepung terigu, gula, telur, dan bahan pangan lainnya. Adonan umumnya dituang ke dalam cetakan untuk dipanggang atau dikukus.",
    "Aktif",
  ],
  [
    "07020103",
    "Keik Mentega (Butter Cake)",
    "Keik mentega (butter cake) adalah keik yang mengandung mentega atau lemak lainnya (margarin, shortening), berperisa, dengan tekstur dan volume yang baik. Keik mentega merupakan bentuk pengembangan dari pound cake. Keik mentega dapat juga ditambah dengan taburan gula, frosting (icing), kacang dan sebagainya.",
    "Aktif",
  ],
  [
    "07020104",
    "Keik Keju (Cheese Cake)",
    "Keik keju (cheese cake) adalah keik yang dibuat dengan keju, keju krim (cream cheese), keju cottage atau keju ricotta yang dicampur dengan telur, gula, dan bahan pangan lainnya. Kulitnya dapat dibuat dari gilingan krekers, kacang atau pastri.",
    "Aktif",
  ],
  [
    "07020105",
    "Keik Pound (Pound Cake Atau Quatre Quarts)",
    "Keik pound (pound cake atau quatre quarts) adalah keik yang dibuat dari 1 pound (lbs=454 g) tepung terigu, 1 pound gula, 1 pound mentega dan 1 pound telur.",
    "Aktif",
  ],
  [
    "07020107",
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers",
    "Biskuit (manis) atau kukis atau sweet crackers adalah produk bakeri kering yang dibuat dengan cara memanggang adonan yang terbuat dari lemak dan bahan pengembang dengan atau tanpa bahan pangan lainnya. Termasuk snack biscuit atau biskuit yang bentuknya ke",
    "Aktif",
  ],
  [
    "07020108",
    "Biskuit Marie",
    "Biskuit marie adalah sejenis biskuit manis dengan penambahan<br> perisa khas marie, dibuat dari tepung terigu, air atau susu, dan<br> dapat ditambahkan bahan pangan lainnya.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Rasa dan warna normal<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "07020109",
    "Biskuit Marie Salut / Biskuit Salut",
    "Biskuit marie salut / biskuit salut adalah biskuit marie / biskuit yang diberi salutan coklat atau bahan pangan lain di bagian luarnya.",
    "Aktif",
  ],
  [
    "07020110",
    "Roti Bagelen",
    "Roti bagelen adalah roti yang dipanggang setelah dioles dengan lemak dan gula atau krim, dan dapat ditambahkan bahan pangan lainnya.",
    "Aktif",
  ],
  [
    "07020112",
    "Wafer",
    "Wafer adalah sejenis biskuit5 manis yang dibuat dari adonan cair, berporipori kasar, renyah dan bila dipatahkan penampang potongannya berongga.",
    "Aktif",
  ],
  [
    "07020113",
    "Wafer Roll / Wafer Stick",
    "Wafer roll/wafer stick adalah sejenis biskuit manis yang dibuat dari adonan cair, berbentuk roll dengan atau tanpa isi, dan renyah.",
    "Aktif",
  ],
  [
    "07020114",
    "Wafer Salut",
    "Wafer salut adalah sejenis wafer yang diberi salutan cokelat atau<br> bahan pangan lain di bagian luarnya",
    "Aktif",
  ],
  [
    "07020115",
    "Kukis",
    "Kukis adalah jenis biskuit yang terbuat dari adonan lunak, renyah dan bila dipatahkan penampangnya tampak bertekstur kurang padat.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Rasa dan warna normal<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "07020116",
    "Kukis Gula",
    "Kukis gula adalah jenis biskuit manis yang terbuat dari adonan lunak, berkadar lemak tinggi, renyah dan bila dipatahkan penampang potongannya bertekstur kurang padat serta pada permukaan terdapat taburan gula.",
    "Aktif",
  ],
  ["07020117", "Kukis Oatmeal", "", "Aktif"],
  [
    "07020118",
    "Bika Ambon",
    "Bika ambon adalah sejenis kue yang dibuat dari pati sagu atau tapioka dan tepung terigu serta santan yang difermentasi dengan<br> kamir atau bahan lain melalui proses pemanggangan",
    "Aktif",
  ],
  ["07020119", "Serabi", "", "Aktif"],
  [
    "07020126",
    "Egg Roll",
    "Egg roll adalah jenis kukis gulung dengan kadar telur tidak kurang dari 35%.",
    "Aktif",
  ],
  [
    "07020127",
    "Biskuit Colek",
    "Biskuit Colek adalah biskuit yang dilengkapi dengan krim cokelat atau krim lainnya yang dikonsumsi dengan cara dicolek",
    "Aktif",
  ],
  [
    "07020128",
    "Biskuit Lapis/Biskuit Sandwich",
    "Biskuit lapis/Biskuit Sandwich adalah biskuit yang terdiri dari 2 lapis atau lebih dan diantara lapisan diberi isi. Jika produknya disalut, nama jenisnya adalah biskuit lapis salut. Contoh dari produk ini biskuit lapis salut cokelat.",
    "Aktif",
  ],
  ["07020129", "Kue Berbahan Dasar Terigu", "-", "Aktif"],
  [
    "07020130",
    "Biskuit Bar Sereal Isi",
    "Biskuit bar sereal isi adalah sejenis biskuit manis berbentuk bar yang diisi dengan hasil olahan buah, cokelat, kacang atau lainnya.",
    "Aktif",
  ],
  [
    "07020131",
    "Brownies",
    "Brownies adalah jenis keik yang dibuat dari adonan tepung terigu atau tepung lainnya, gula, telur, cokelat, dan bahan pangan lainnya. Adonan dipanggang atau dikukus.",
    "Aktif",
  ],
  [
    "07020132",
    "Biskuit non terigu",
    "Biskuit non terigu adalah produk bakeri kering yang dibuat dengan cara memanggang adonan yang terbuat dari non terigu, minyak/lemak, dengan atau tanpa penambahan bahan pangan lain.<br> Nama jenis untuk produk ini, misalnya biskuit beras, biskuit jagung, dan lain-lain.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Rasa dan warna normal<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%<br>",
    "Aktif",
  ],
  [
    "07020133",
    "Kukis Lunak (Soft Cookies)",
    "Kukis lunak adalah jenis kukis yang bertekstur lunak.<br> Karakteristik dasar :<br> Kadar air berkisar lebih dari 5 % dan tidak lebih dari 10 %",
    "Aktif",
  ],
  [
    "07020134",
    "Nastar",
    "Nastar adalah jenis kukis yang berbentuk bulat atau bentuk lainnya dan diisi dengan selai nanas atau bahan pangan lainnya.<br> Karakteristik dasar :<br> Kadar air berkisar lebih dari 5% dan tidak lebih dari 10%",
    "Aktif",
  ],
  [
    "07020135",
    "Kastengel",
    "Kastengel adalah jenis kukis yang dibuat dengan penambahan keju, baik dalam adonannya atau ditaburkan.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 10%",
    "Aktif",
  ],
  [
    "07020136",
    "Pai",
    "Pai adalah jenis biscuit berserpih (flaky) yang dibuat dari adonan<br> dilapis dengan lemak padat atau emulsi lemak, sehinga<br> mengembang selama pemanggangan dan bila dipatahkan<br> penampangnya tampak berlapis-lapis. Yang termasuk pai adalah<br> puff.<br> Karakteristik dasar:<br> Kadar air tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    "07020137",
    "Pai Isi",
    "Pai isi adalah jenis pai yang diisi dengan selai, cokelat atau bahan pangan lainnya.<br> Karakteristik dasar : Kadar air berkisar lebih dari 5 % dan tidak lebih dari 10 %",
    "Aktif",
  ],
  [
    "07020138",
    "Bolu Kukus",
    "Bolu kukus adalah produk bakeri kukus berbentuk mangkok,<br> ataubentuk lainnya yang dibuat dari tepung terigu dengan<br> penambahan bahan pengembang.<br>",
    "Aktif",
  ],
  [
    "07020139",
    "Biskuit",
    "Biskuit adalah produk bakeri kering yang dibuat dengan cara memanggang adonan yang terbuat dari tepung terigu dengan atau tanpa substitusinya, minyak/lemak, dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> Rasa dan warna normal<br> Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    "07020142",
    "Crepes",
    "Crepes adalah produk sejenis panekuk tipis, dapat digulung atau dilipat, terbuat dari terigu, renyah, diberi isi atau tidak.",
    "Aktif",
  ],
  [
    "07020201",
    "Pastri",
    "Pastri adalah produk bakeri yang ringan dan berserpih (flaky) yang dibuat dari adonan dilapis dengan mentega atau lemak padat lainnya secara berulang-ulang sehingga mengembang selama pemanggangan di oven.",
    "Aktif",
  ],
  [
    "07020202",
    "Roti Manis",
    "Roti manis adalah produk roti yang memiliki rasa manis, adonannya terbuat dari tepung terigu, garam dan gula, yang mengalami fermentasi oleh ragi (kamir) sebagai bahan pengembang.",
    "Aktif",
  ],
  [
    "07020203",
    "Roti Isi",
    "Roti isi adalah produk roti dengan kadar gula tidak kurang dari 15% dan diisi dengan bahan lain seperti keju, cokelat, selai, krim dan lain-lain.",
    "Aktif",
  ],
  [
    "07020204",
    "Scone",
    "Scone adalah biskuit (definisi Codex) yang adonannya mengandung lebih banyak gula.",
    "Aktif",
  ],
  [
    "07020205",
    "Donat",
    "Donat adalah kue berbentuk cincin atau bentuk bulat lainnya yang adonannya difermentasi dengan ragi atau bahan pengembang lainnya kemudian digoreng.",
    "Aktif",
  ],
  [
    "07020206",
    "Muffin Amerika (American Muffin)",
    "Muffin amerika (american muffin) atau muffin (di Indonesia) adalah sejenis quickbread berbentuk mangkok.",
    "Aktif",
  ],
  [
    "07020207",
    "Roti Buaya",
    "Roti buaya adalah produk roti khas Betawi yang berbentuk seperti buaya",
    "Aktif",
  ],
  [
    "07020208",
    "Kue Tambang",
    "Kue berbentuk seperti untaian tali yang dibuat dari adonan terigu<br> yang digoreng.",
    "Aktif",
  ],
  ["07020209", "Pizza", "-", "Aktif"],
  [
    "07020210",
    "Bakpia",
    "Produk bakeri yang adonannya dibuat dari tepung terigu, air, lemak/minyak, dan isinya terbuat dari campuran gula dan kacang hijau yang dihaluskan, lalu dipanggang. Isi bakpia dapat diganti dengan cokelat, selai buah, atau bahan pangan lainnya.",
    "Aktif",
  ],
  [
    "07020211",
    "Wafel",
    "Wafel adalah kue yang dibuat dari adonan terigu yang dicetak diantara dua plat logam yang umumnya bermotif persegi.",
    "Aktif",
  ],
  [
    "07020212",
    "Stroopwafel",
    "Stroopwafel adalah sejenis wafel yang terdiri dari dua lapisan tipis berisi sirup karamel.",
    "Aktif",
  ],
  [
    "07020213",
    "Cone untuk Es Krim",
    "Cone untuk es krim adalah sejenis wafer yang berbentuk corong digunakan sebagai wadah es krim.<br>",
    "Aktif",
  ],
  [
    "07020214",
    "Panekuk",
    "Panekuk adalah kue berbentuk bundar tipis yang umumnya dibuat dari tepung terigu, gula, telur, susu dan dipanaskan pada permukaan yang panas.<br>",
    "Aktif",
  ],
  [
    "07020215",
    "Bolu Emprit",
    "Kue kering tradisional yang terbuat dari adonan tapioka, gula pasir, kelapa parut dan pengembang yang dicetak dan dipanggang.<br>",
    "Aktif",
  ],
  ["07020216", "Remahan Biskuit", "-", "Aktif"],
  ["07020217", "Nopia", "", "Tidak Aktif"],
  [
    "07020301",
    "Premiks Untuk Produk Bakeri Istimewa",
    "Premiks untuk produk bakeri istimewa adalah campuran bahan kering yang dapat ditambahkan dengan ingredien basah (seperti air, susu, minyak, mentega, telur) untuk membuat adonan untuk pembuatan produk bakeri.",
    "Aktif",
  ],
  [
    "08010201",
    "Patties Daging Sapi Segar (Burger)",
    "Patties daging sapi segar (burger) adalah produk yang terbuat dari hasil pencincangan daging mamalia dengan atau tanpa tambahan bahan tambahan pangan lain (seperti tepung, air, bumbu dan rempah, dan bahan tambahan pangan seperti bahan pengikat dan sebagai<br>",
    "Tidak Aktif",
  ],
  ["08010202", "Boerewors", "", "Tidak Aktif"],
  [
    "08010203",
    "Sosis Mentah Daging Babi",
    "Sosis mentah daging babi adalah sosis yang dibuat dari hasil penghalusan tetelan daging babi, dengan penambahan garam dan rempah-rempah.",
    "Aktif",
  ],
  [
    "08010204",
    "Sosis Mentah (Breakfast Sausage)",
    "Sosis mentah (breakfast sausage) adalah sosis yang dibuat dari hasil penghalusan daging selain daging babi dan bahan-bahan lain selain babi, dengan penambahanan garam dan rempah-rempah.",
    "Tidak Aktif",
  ],
  [
    "08010205",
    "Daging Cincang",
    "Daging cincang adalah daging mentah yang telah dikecilkan ukurannya dengan dicincang atau dicacah.",
    "Aktif",
  ],
  [
    "08010206",
    "Daging Giling",
    "Daging giling adalah daging yang dikecilkan ukurannya dengan alat grinder/mincer.",
    "Aktif",
  ],
  [
    "08010207",
    "Daging Murni Giling Tanpa Lemak",
    "Daging murni giling tanpa lemak adalah daging murni (lean meat)<br> yang dikecilkan ukurannya dengan alat grinder/mincer. Daging<br> cincang atau daging giling yang dinyatakan sebagai daging murni<br> giling tanpa lemak tidak boleh mengandung total lemak lebih dari 7%.<br> Misal Breakfast Sausage<br>",
    "Aktif",
  ],
  [
    "08010208",
    "Sosis Mentah Tanpa Fermentasi (Loganiza)",
    "Sosis mentah tanpa fermentasi (loganiza) adalah sosis yang dibuat dari daging tanpa fermentasi dan dikonsumsi dalam keadaan mentah.",
    "Tidak Aktif",
  ],
  ["08010209", "Bakso Daging Mentah", "", "Tidak Aktif"],
  [
    "08010210",
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan)",
    "",
    "Aktif",
  ],
  [
    "08010211",
    "MDM (Mechanically Deboned Meat)",
    "MDM (Mechanically Deboned Meat) adalah daging yang dihasilkan dari pemisahan daging yang menempel pada tulang dengan perlakuan mekanis.",
    "Aktif",
  ],
  [
    "08010212",
    "Sosis Segar",
    "Sosis segar adalah sosis yang terbuat dari daging mentah dengan kadar daging tidak kurang dari 50%, tidak dikuring dengan nitrit, dihaluskan (umumnya kasar), tidak diemulsifikasi, diberi garam fosfat dan bumbu dan dikemas dalam selongsong sosis, tidak har",
    "Tidak Aktif",
  ],
  [
    "08010213",
    "Sosis Mentah (Sosis Daging)",
    "Sosis mentah adalah sosis yang dibuat dari hasil penghalusan daging<br> mamalia dan atau unggas, selain daging babi dengan penambahan<br> garam dan rempah-rempah antara lain : sosis breakfast mentah<br>",
    "Aktif",
  ],
  [
    "08010214",
    "Sosis Mentah (Sosis Daging Kombinasi)",
    "Sosis mentah adalah sosis yang dibuat dari hasil penghalusan daging<br> mamalia dan atau unggas, selain daging babi dengan penambahan<br> garam dan rempah-rempah antara lain : sosis breakfast mentah<br>",
    "Aktif",
  ],
  [
    "08010215",
    "DMM (Desinewed Minced Meat)",
    "DMM (Desinewed Minced Meat) adalah daging yang dihasilkan dari<br> pemisahan daging yang menempel pada tulang dengan perlakuan<br> mekanis, menghasilkan produk yang lebih kasar dari MDM.",
    "Aktif",
  ],
  [
    "08010216",
    "Patties",
    "Patties adalah produk yang terbuat dari hasil pencincangan daging mamalia dan atau unggas dengan atau tanpa penambahan bahan pangan lain (seperti tepung, air, bumbu dan rempah). Campuran dicetak atau diisikan dalam selongsong plastik dan didinginkan atau dibekukan sebagian sebelum diiris membentuk bulat atau bentuk lainnya.",
    "Aktif",
  ],
  [
    "0802010101",
    "Bacon",
    "Bacon (yang di-curing, di-curing kering, di-curing rendam, di-curing<br> injeksi) adalah daging babi yang di-curing dari bagian iga (belly bacon).<br> Bacon dapat diasap maupun tidak diasap.",
    "Aktif",
  ],
  [
    "0802010102",
    "Bacon Sapi",
    "Bacon sapi adalah produk olahan daging sapi yang dilakukan curing,<br> pengasapan yang berasal dari bagian sandung lamur (brisket) sapi,<br> dapat diasap maupun tidak diasap.",
    "Aktif",
  ],
  [
    "0802010104",
    "Daging Kornet Mentah",
    "Daging kornet mentah adalah produk yang dibuat dari potongan daging sapi segar atau beku (yang telah memenuhi persyaratan dan peraturan yang berlaku), tanpa tulang, boleh dicampur dengan daging bagian kepala dan hati dengan atau tanpa penambahan bahan lai",
    "Tidak Aktif",
  ],
  [
    "0802010105",
    "Daging Sapi yang Dimarinasi",
    "Daging sapi yang dimarinasi adalah potongan daging sapi yang direndam/dimarinasi dengan bumbu seperti garam dan rempah-rempah dengan cara perendaman, pengadukan atau injeksi.",
    "Aktif",
  ],
  [
    "0802010106",
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi",
    "Daging ayam yang dimarinasi adalah potongan daging ayam dengan atau tanpa tulang yang direndam / dimarinasi dengan bumbu seperti garam dan rempah-rempah dengan cara perendaman, pengadukan atau injeksi.",
    "Tidak Aktif",
  ],
  [
    "0802010107",
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke).",
    "",
    "Tidak Aktif",
  ],
  [
    "0802010108",
    "Daging Asap",
    "Daging asap adalah produk yang diperoleh dengan mengasapi daging<br> dan/atau daging curing atau olahannya dengan sumber asap yang<br> diizinkan (batangan kayu, serbuk gergaji, atau berupa pelet kayu dan<br> lainnya, cairan asap natural) yang bebas dari cat atau bahan<br> pengawet kayu.<br> Produk yang diasapkan juga dapat terbuat dari bagian selain daging,<br> misalnya lidah sapi.",
    "Aktif",
  ],
  [
    "0802010110",
    "Daging Sei",
    "Daging sei adalah produk olahan daging sapi tradisonal khas Kupang,<br> Nusa Tenggara Timur yang diolah dengan cara dicuring dan<br> dilanjutkan dengan pengasapan menggunakan bahan bakar kayu<br> kusambi (Scheiechera oleosa, Merr).",
    "Aktif",
  ],
  [
    "0802010111",
    "Daging Marinasi",
    "Daging marinasi adalah potongan daging yang berasal dari mamalia<br> dan unggas dengan atau tanpa tulang yang dimarinasi dengan<br> bumbu seperti garam dan rempah-rempah. Proses marinasi<br> dilakukan dengan cara perendaman, pengadukan atau injeksi.<br> Contohnya : sayap ayam marinasi, steik sapi marinasi, sate ayam<br> marinasi.",
    "Aktif",
  ],
  [
    "0802010112",
    "Daging Ayam yang Dimarinasi",
    "Daging ayam yang dimarinasi adalah potongan daging ayam dengan atau tanpa tulang yang direndam/dimarinasi dengan bumbu seperti garam dan rempah-rempah dengan cara perendaman, pengadukan atau injeksi. Termasuk yang ditusuk sate.",
    "Aktif",
  ],
  ["0802010201", "Daging Babi Asin Kering", "", "Tidak Aktif"],
  ["0802010202", "Jerky", "", "Tidak Aktif"],
  [
    "0802010203",
    "Daging Sapi Kering (Dried Beef)",
    "Daging sapi kering (dried beef) adalah daging sapi yang dikuring,<br> dikeringkan dan dapat diasap, tetapi tidak dimasak, dengan kadar air rendah (25% hingga 35%). Umumnya daging sapi dikuring dengan garam, gula, nitrat dan nitrit.",
    "Tidak Aktif",
  ],
  [
    "0802010204",
    "Ham Tipe Prosciutto (Italian Style Ham)",
    "Ham tipe proscuitto (Italian style ham) adalah ham yang terbuat dari daging babi dengan berat antara 5,4 kg hingga 6.8 kg, dengan lapisan lemak dibawah kulit tidak lebih dari 1,3 hingga 5,1 cm. Ham dibalur dengan campuran garam-rempah mengandung gula, garam, lada hitam, lada putih, allspice, pala, biji mustard, coriander, Na-nitrat dan Na-nitrit. 113,4 hingga 184,3 g campuran garam rempah digunakan untuk 45,4 kg ham. Mula-mula ham dengan posisi kulit di bawah dikuring pada suhu 2 C hingga 3 C selama 10 hari , kemudian dibalik sehingga bagian daging ada di bawah dan dikuring lagi selama 10 hari. Ham dikuring dengan total waktu selama 40 hari 45 hari. Sesudah kuring, ham direndam dalam air bersuhu 21 C selama tidak lebih dari 15 jam, dengan air diganti 1 kali selama perendaman. Ham kemudian diasap di ruang asap pada suhu 54 C selama 24 jam, 60 C selama 2 jam, lalu suhunya diturunkan menjadi 49 C selama 8 jam. Pemanasan dihentikan dan ham dibiarkan dalam ruang asap hingga suhu di dalam ham mencapai 38 C. Produk ini dimakan mentah.",
    "Tidak Aktif",
  ],
  [
    "0802010205",
    "Daging Paha Babi Kuring Mentah",
    "Daging paha babi curing mentah adalah produk yang diproses dari<br> daging paha babi belakang, baik utuh maupun deboning, atau berupa<br> potongan, di-curing, diasap maupun tanpa asap, tanpa pemasakan.<br> Semua tulang dan tulang rawan, urat dan jaringan ikat harus<br> dibuang. Kulit dan lemak dapat dibuang atau tidak. Daging harus<br> di-curing dan dapat diasap, diberi bumbu dan/atau perisa.",
    "Aktif",
  ],
  [
    "0802010206",
    "Daging Paha Babi Kuring Matang",
    "Daging paha babi kuring matang adalah produk yang diolah dari daging paha babi belakang, dibelah melintang dari sisa bagian sisi pada suatu titik yang tidak lebih ke depan (arah anterior) dari ujung tulang pinggang. Semua tulang dan tulang rawan, urat dan",
    "Tidak Aktif",
  ],
  [
    "0802010207",
    "Dendeng Daging (tanpa perlakuan panas)",
    "Dendeng daging adalah produk makanan yang berbentuk lempengan<br> terbuat dari irisan atau gilingan daging segar yang berasal dari hewan<br> sehat yang telah diberi bumbu dan dikeringkan.<br> Daging yang dapat diolah menjadi dendeng dapat berupa daging sapi,<br> daging kerbau, daging babi, daging rusa, daging ayam dan lain-lain.",
    "Aktif",
  ],
  [
    "0802010301",
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef)",
    "Daging sapi yang difermentasi dalam keramik (potted beef) adalah daging yang dicacah kasar, dimasukkan ke dalam wadah keramik dan difermentasi.",
    "Aktif",
  ],
  [
    "0802010303",
    "Daging Cangkuk",
    "Daging cangkuk adalah produk olahan daging tradisional khas Jambi berupa daging sapi atau kerbau yang difermentasi bersama garam dan rebung, di dalam suatu wadah bambu yang tertutup rapat selama tujuh hari, sehingga terjadi fermentasi spontan.",
    "Aktif",
  ],
  [
    "08020201",
    "Daging Paha Babi Kuring Matang",
    "Daging paha babi curing matang adalah produk yang diolah dari<br> daging paha babi belakang-dibelah melintang dari sisa bagian sisi<br> pada suatu titik yang tidak lebih ke depan (arah anterior) dari ujung<br> tulang pinggang. Semua tulang dan tulang rawan, urat dan jaringan<br> ikat harus dibuang. Kulit dan lemak dapat dibuang atau tidak.<br> Daging harus di-curing dan dapat diasap, diberi bumbu dan atau<br> perisa.",
    "Aktif",
  ],
  [
    "08020203",
    "Ham Sapi (Daging Paha Sapi Kuring) Matang",
    "Ham sapi (daging paha sapi curing) matang adalah produk yang diolah dari daging paha sapi belakang-dibelah melintang dari sisa bagian sisi pada suatu titik yang tidak lebih ke depan (arah anterior) dari ujung tulang pinggang. Semua tulang dan tulang rawan, urat dan jaringan ikat harus dibuang. Kulit dan lemak dapat dibuang atau tidak. Daging harus dicuring dan dapat diasap, diberi bumbu dan atau perisa.",
    "Aktif",
  ],
  [
    "08020204",
    "Bahu Babi Curing Matang",
    "Bahu babi kuring matang adalah produk yang terbuat dari daging kaki depan babi. Tidak mengandung tulang dan urat, dapat mengandung kulit dan lemak. Daging dicuring dan diasap, serta dapat dibumbui.",
    "Aktif",
  ],
  [
    "08020205",
    "Bahu Sapi Curing Matang",
    "Bahu sapi kuring matang adalah produk yang terbuat dari daging kaki depan sapi. Tidak mengandung tulang dan urat, dapat mengandung kulit dan lemak. Daging dicuring dan diasap, serta dapat dibumbui.",
    "Aktif",
  ],
  [
    "08020206",
    "Daging Ayam Yang Dikalengkan",
    "Daging ayam yang dikalengkan adalah daging ayam segar yang dikemas dalam wadah bersih, yang ditutup secara kedap (hermetis), dan diproses panas untuk menjamin keawetannya. Dapat mengandung garam, air dan air garam.",
    "Tidak Aktif",
  ],
  [
    "08020208",
    "Daging Olahan Khas Indonesia Berbentuk Potongan",
    "Daging olahan khas indonesia berbentuk potongan adalah berbagai jenis olahan/masakan khas Indonesia dengan bahan utama berupa daging, daging unggas maupun daging hewan buruan, berbentuk potongan yang dimasak dengan suhu tinggi hingga matang, dengan atau t",
    "Tidak Aktif",
  ],
  [
    "08020210",
    "Daging Kuah Dalam Kemasan",
    "Daging kuah dalam kemasan adalah hasil olahan daging yang berbentuk potongan atau irisan dengan atau tanpa penambahan bahan makanan lain, bumbu, dikemas secara kedap (hermetis) dalam kemasan kaleng, aluminium foil atau pengemas lain yang sesuai dan dister",
    "Aktif",
  ],
  [
    "08020211",
    "Daging Dalam Kaleng (Tanpa Kuah)",
    "Daging dalam kaleng (tanpa kuah) adalah daging segar atau daging asapyang dikemas dalam wadah bersih, yang ditutup secara kedap (hermetis), dan diproses panas untuk menjamin keawetannya. Dapat mengandung garam, dan air.",
    "Tidak Aktif",
  ],
  [
    "08020213",
    "Abon Daging",
    "Abon daging adalah makanan kering berbentuk khas dibuat dari daging, direbus, disayat-sayat / disuwir, dibumbui, digoreng dan dapat juga dipres. Abon terbuat dari daging berbagai jenis hewan seperti sapi, ayam, babi, dan lain-lain.",
    "Aktif",
  ],
  [
    "08020214",
    "Kerupuk Kulit/Rambak",
    "Kerupuk kulit/rambak adalah produk makanan ringan dibuat dari kulit sapi atau kerbau melalui tahap pembuangan bulu, pengembangan kulit, perebusan, pengeringan, dan diungkep untuk kerupuk kulit mentah atau dilanjutkan dengan penggorengan untuk kerupuk kul",
    "Aktif",
  ],
  [
    "08020215",
    "Keripik Paru",
    "Keripik paru adalah makanan kering yang dibuat dari paru hewan yang diolah dengan cara perebusan, diiris tipis sehingga berbentuk lempeng, diberi bumbu kemudian digoreng dengan atau tanpa penambahan tepung. Keripik paru dapat dibuat dari paru beberapa je",
    "Aktif",
  ],
  [
    "08020216",
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan",
    "Kerupuk berbasis daging, daging unggas dan daging hewan buruan adalah makanan kering yang terbuat dari bagian yang diperoleh dari hewan mamalia maupun unggas, yang kering dan renyah setelah proses penggorengan, dengan atau tanpa penambahan tepung. Contoh",
    "Aktif",
  ],
  ["08020217", "Kerupuk Kulit Ayam", "", "Tidak Aktif"],
  [
    "08020222",
    "Dendeng Daging dengan Perlakuan Panas",
    "Dendeng daging adalah produk makanan yang berbentuk lempengan terbuat dari irisan atau gilingan daging segar yang berasal dari hewan sehat yang telah diberi garam atau bumbu dan dikeringkan. Daging yang dapat diolah menjadi dendeng dapat berupa daging sap",
    "Tidak Aktif",
  ],
  [
    "08020223",
    "Nasi Dengan Lauk Daging Dalam Kaleng",
    "-",
    "Tidak Aktif",
  ],
  [
    "08020224",
    "Usus Ayam Goreng",
    "Usus ayam goreng adalah usus ayam yang dipotong-potong, dicampur bumbu, kemudian digoreng dengan atau tanpa tepung pelapis<br>",
    "Aktif",
  ],
  [
    "08020225",
    "Daging Olahan Berbumbu",
    "Daging olahan berbumbu adalah berbagai jenis olahan dengan bahan utama berupa daging berbentuk utuh atau potongan yang dimasak hingga matang, dengan maupun tanpa penambahan bahan pangan dan bumbu-bumbu lainnya, dengan maupun tanpa kuah/saus. Contohnya adalah rendang daging, gulai ayam, gepuk daging sapi, sate ayam, sate kambing, ayam bumbu sukabumi, ayam bumbu gudeg, ayam bakakak, ayam goreng rica-rica, sambal goreng hati, ayam betutu, pepes ayam, daging sie reuboh, ayam bolognes, daging sapi saus lada hitam, daging ayam saus barbekyu dan lain lain.<br>",
    "Aktif",
  ],
  [
    "08020226",
    "Daging dalam Kaleng",
    "Daging dalam kaleng (tanpa kuah) adalah daging segar atau daging asapyang dikemas dalam wadah bersih, yang ditutup secara kedap (hermetis), dan diproses panas untuk menjamin keawetannya. Dapat mengandung garam dan air/saus/minyak.<br>",
    "Aktif",
  ],
  [
    "08020227",
    "Foie Gras and Pates",
    "Foie gras and pates adalah pasta daging yang dapat dioles",
    "Aktif",
  ],
  [
    "08020228",
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll)",
    "-",
    "Aktif",
  ],
  [
    "08020301",
    "Ayam Katsu (Chicken Katsu)",
    "Ayam katsu adalah dada ayam dengan atau tanpa marinasi, dengan atau tanpa tepung pelapis (predust), kemudian dilapis batter dan bread crumb/tepung panir/tepung roti, digoreng dan dibekukan.",
    "Aktif",
  ],
  [
    "08020303",
    "Ayam Goreng (Fried Chicken)",
    "Ayam goreng adalah potongan ayam dengan atau tanpa marinasi, dengan atau tanpa melalui proses breading, digoreng dan dibekukan.<br> Contohnya drumstick, popcorn chicken, dan lain-lain.",
    "Aktif",
  ],
  [
    "08020305",
    "Sayap Beku Marinasi",
    "Sayap beku marinasi adalah produk potongan daging sayap yang<br> dimarinasi dan dibekukan.",
    "Tidak Aktif",
  ],
  [
    "08020306",
    "Ayam Pop-Corn Beku",
    "Ayam pop-corn beku adalah daging ayam tanpa tulang yang dipotongpotong berbentuk dadu, dimarinasi, di-coating dan digoreng sebelum dibekukan.",
    "Tidak Aktif",
  ],
  [
    "08020307",
    "Chicken Strip Beku",
    "Chicken strip beku adalah daging ayam tanpa tulang yang dipotong-potong memanjang, dimarinasi, di-coating dan digoreng sebelum dibekukan.",
    "Aktif",
  ],
  [
    "08020308",
    "Ayam Cordon Bleu (Chicken Cordon Bleu)",
    "Ayam Cordon Bleu adalah daging ayam tanpa tulang yang utuh dari dada, dimarinasi dan diberi isi (filling) dengan keju dan irisan daging ayam asap atau daging sapi asap. Produk ini kemudian melalui proses breading dan digoreng sebelum dibekukan.",
    "Aktif",
  ],
  [
    "08020309",
    "Ayam Karage (Chicken karage)",
    "Ayam karage adalah dada ayam atau paha ayam dengan atau tanpa marinasi,dengan atau tanpa tepung pelapis (predust), kemudian dilapis batter dan breader, digoreng dan dibekukan.",
    "Aktif",
  ],
  [
    "08020310",
    "Daging Marinasi (Beku)",
    "Daging marinasi adalah potongan ayam atau daging yang dimarinasi, dimasak dan dibekukan. Contohnya sayap ayam marinasi, spicy wing, spicy chick, drumstick marinasi, dan lain-lain.<br>",
    "Aktif",
  ],
  [
    "08020311",
    "Kulit Ayam Goreng",
    "Kulit ayam goreng adalah kulit ayam yang dipotong-potong, dicampur bumbu bumbu, kemudian digoreng dengan atau tanpa tepung pelapis, dibekukan dan dikemas.<br>",
    "Aktif",
  ],
  [
    "08020312",
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan",
    "Potongan daging dengan saus dalam kemasan yang dibekukan adalah hasil olahan potongan daging, daging unggas maupun daging hewan buruan yang ditambah saus dengan atau tanpa penambahan rempah-rempah dan atau bumbu-bumbu, dimasak dengan perlakuan panas, dikemas secara kedap atau hermetis dalam kemasan kaleng, alumunium foil atau pengemas lain yang sesuai dan dibekukan. Contoh: potongan daging sapi dengan saus Bolognese, potongan daging ayam dengan saus carbonara, potongan daging sapi dengan saus blackpepper, potongan daging ayam dengan saus barbeque, potongan daging dada asap dengan bumbu nasi goreng, dll<br>",
    "Aktif",
  ],
  [
    "08020313",
    "Daging Olahan Berbumbu Beku",
    "Daging olahan berbumbu beku adalah berbagai jenis olahan/masakan khas dengan bahan utama daging, daging unggas maupun daging hewan buruan, berbentuk potongan yang dimasak dengan suhu tinggi hingga matang, dengan atau tanpa penambahan bahan pangan dan bumbu-bumbu lainnya, dengan atau tanpa kuah dikemas secara aseptik; kemudian dibekukan. Contohnya adalah rendang daging, gulai ayam, gepuk daging sapi, sate ayam, sate kambing, ayam bumbu sukabumi, ayam bumbu gudeg, ayam bakakak, ayam goreng rica-rica, sambal goreng hati, ayam betutu, pepes ayam, daging sie reuboh, ayam bolognes, daging sapi saus lada hitam, daging ayam saus barbekyu, dan lain lain.<br>",
    "Aktif",
  ],
  [
    "0803010102",
    "Salami dan Produk Sejenisnya",
    "Salami dan produk sejenisnya adalah daging giling kasar, difermentasi dengan starter bakteri pada suhu 26\\xB0C, kelembaban 95% selama 3 hari hingga 7 hari, kemudian dilanjutkan dengan fermentasi pada suhu 16\\xB0C, kelembaban 75% hingga mengering selama 3 minggu",
    "Tidak Aktif",
  ],
  [
    "0803010106",
    "Sosis Asap",
    "Sosis asap adalah sosis yang mengalami pengasapan dalam ruang asap (smoked house) untuk menghasilkan cita rasa asap yang khas.",
    "Aktif",
  ],
  [
    "0803010107",
    "Titiles",
    "Titiles adalah produk khas Bali.",
    "Tidak Aktif",
  ],
  [
    "0803010108",
    "Sosis Asap Kombinasi",
    "Sosis asap adalah sosis yang mengalami pengasapan dalam ruang asap (smoked house) untuk menghasilkan cita rasa asap yang khas.<br>",
    "Aktif",
  ],
  [
    "0803010109",
    "Sosis Daging (Tanpa Perlakuan Panas)",
    "Sosis daging adalah produk berbahan baku daging yang dihaluskan dengan atau tanpa penambahan bahan pangan lain dan dimasukkan ke dalam selongsong sosis. Daging yang digunakan dapat berupa daging sapi, kerbau, kambing, domba, ayam, babi atau daging hewan ternak lainnya yang layak dimakan, dan atau hewan unggas, dengan menyebut jenis dagingnya.<br>",
    "Aktif",
  ],
  [
    "0803010110",
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas)",
    "Sosis daging adalah produk berbahan baku daging yang dihaluskan dengan atau tanpa penambahan bahan pangan lain dan dimasukkan ke dalam selongsong sosis. Daging yang digunakan dapat berupa daging sapi, kerbau, kambing, domba, ayam, babi atau daging hewan ternak lainnya yang layak dimakan, dan atau hewan unggas, dengan menyebut jenis dagingnya.<br>",
    "Aktif",
  ],
  [
    "0803010111",
    "Kornet Daging non sterilisasi",
    "Kornet daging non sterilisasi adalah produk yang dibuat dari potongan daging ternak tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, diproses tanpa sterilisasi dan dikemas dalam wadah tertutup.<br>",
    "Aktif",
  ],
  [
    "0803010112",
    "Kornet Daging Kombinasi non sterilisasi",
    "Kornet daging kombinasi non sterilisasi adalah produk yang dibuat dari potongan daging ternak tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, diproses tanpa sterilisasi dan dikemas dalam wadah tertutup.<br>",
    "Aktif",
  ],
  [
    "0803010113",
    "Kornet Unggas non sterilisasi",
    "Kornet unggas non sterilisasi adalah produk yang dibuat dari potongan daging unggas tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, diproses tanpa sterilisasi dan dikemas dalam wadah tertutup.<br>",
    "Aktif",
  ],
  [
    "0803010114",
    "Kornet Unggas Kombinasi non sterilisasi",
    "Kornet unggas kombinasi non sterilisasi adalah produk yang dibuat dari potongan daging unggas tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, diproses tanpa sterilisasi dan dikemas dalam wadah tertutup.<br>",
    "Aktif",
  ],
  [
    "0803010115",
    "Urutan",
    "Urutan adalah sosis tradisional khas Bali yang terbuat dari daging babi yang dihaluskan, yang difermentasi dengan bakteri alami pada usus babi, dikemas dalam selongsong usus halus babi.",
    "Aktif",
  ],
  [
    "0803010203",
    "Sosis yang Dikuring dan Dikeringkan",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    "0803010205",
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong",
    "Sosis cina (termasuk sosis tradisional yang dikuring atau diasap) atau lup cheong adalah sosis dari daging babi, ayam atau kalkun. Daging dipotong manual menjadi irisan tipis dan lemak dari bagian punggung (backfat) dipotong kubus 10 mm. Daging dan lemak",
    "Tidak Aktif",
  ],
  [
    "0803010207",
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap)",
    "Sosis cina (termasuk sosis tradisional yang dicuring atau diasap) atau lup cheong adalah sosis dari daging babi, ayam atau kalkun. Daging dipotong manual menjadi irisan tipis dan lemak dari bagian punggung (backfat) dipotong. Daging dan lemak kemudian dicampur merata dengan campuran bumbu (yang khas: kecap dan gula) dan dibiarkan terendam dalam bumbu selama beberapa jam sebelum diisi. Selongsong sosis yang digunakan umumnya usus halus babi. Sosis kemudian dikeringkan.",
    "Aktif",
  ],
  [
    "0803010208",
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap)",
    "Sosis cina (termasuk sosis tradisional yang dicuring atau diasap) atau lup cheong adalah sosis kombinasi dengan daging babi, ayam atau kalkun. Daging dipotong manual menjadi irisan tipis dan lemak dari bagian punggung (backfat) dipotong. Daging dan lemak kemudian dicampur merata dengan campuran bumbu (yang khas: kecap dan gula) dan dibiarkan terendam dalam bumbu selama beberapa jam sebelum diisi. Selongsong sosis yang digunakan umumnya usus halus babi. Sosis kemudian dikeringkan.",
    "Aktif",
  ],
  [
    "0803010301",
    "Urutan",
    "Urutan adalah sosis tradisional khas Bali yang terbuat dari daging babi yang dihaluskan, yang difermentasi dengan bakteri alami pada usus babi, dikemas dalam selongsong usus halus babi.",
    "Tidak Aktif",
  ],
  [
    "0803010302",
    "Chorizos",
    "Chorizos adalah sosis daging babi yang menggunakan rempah rempah. Rempah yang digunakan dan bentuk olahannya dapat bervariasi misalnya sosis babi yang kering, semi kering, pedas, sedang, dicuring, berwarna merah hingga oranye pucat, dari daging yang digiling halus maupun kasar.<br>",
    "Aktif",
  ],
  [
    "0803010303",
    "Salami",
    "Salami adalah daging giling kasar, difermentasi dengan starter bakteri dengan atau tanpa penambahan bahan pangan lain. Dapat diasap sebelum atau selama pengeringan, dapat terjadi pertumbuhan kapang di permukaannya maupun tidak.<br>",
    "Aktif",
  ],
  [
    "08030201",
    "Patties Daging Panggang Setengah Matang",
    "Patties daging panggang setengah matang adalah produk yang terbuat dari hasil pencincangan daging mamalia maupun unggas, dengan bahan tambahan berupa tepung serealia, bahan pengikat, air, bumbu, dan bawang. Daging dicampur dengan bahan lain, dan campuran dicetak membentuk patties atau diisikan dalam selongsong plastik dan didinginkan atau dibekukan sebagian sebelum diiris membentuk patties. Patties kemudian dipanggang setengah matang.",
    "Aktif",
  ],
  [
    "08030202",
    "Foie Gras and Pates",
    "Foie gras and pates adalah pasta daging yang dapat dioles.",
    "Tidak Aktif",
  ],
  [
    "08030203",
    "Brawn and Head Cheese",
    "Brawn and head cheese adalah produk yang dibuat dengan merebus tulang-tulang, kulit, tulang rawan, daging dari bagian kepala, telinga, kaki, serta tetelan lain yang banyak mengandung jaringan ikat tetapi rendah lemak. Dapat mengandung daging matang, rusk,",
    "Aktif",
  ],
  ["08030204", "Daging Kuring Cacahan Matang", "", "Tidak Aktif"],
  [
    "08030206",
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan",
    "Kornet daging sapi (corned beef) dalam kemasan adalah produk yang dibuat dari potongan daging sapi segar atau beku, tanpa tulang, boleh dicampur dengan daging bagian kepala dan hati dengan atau tanpa penambahan bahan lain, dibuat dengan proses kuring, dik",
    "Tidak Aktif",
  ],
  [
    "08030207",
    "Daging Luncheon Matang",
    "Daging luncheon matang adalah produk yang terbuat dari daging atau campuran dua jenis daging atau lebih yang telah dihaluskan, dicuring dan dapat dimasak /dipanggang / telah diasap.",
    "Aktif",
  ],
  [
    "08030208",
    "Pasta Daging",
    "Pasta daging adalah daging yang dihaluskan menyerupai pasta dengan tekstur sedang. Dapat mengandung bagian non daging seperti rusk, air, atau bahan pengisi lain yang sesuai seperti konsentrat kedelai/Na-kaseinat. Produk disterilisasi setelah dikemas dalam",
    "Aktif",
  ],
  [
    "08030209",
    "Patties Daging Matang",
    "Patties Daging Matang adalah produk yang terbuat dari hasil pencincangan daging mamalia maupun unggas, dengan bahan tambahan berupa tepung serealia, bahan pengikat, air, bumbu, dan bawang. Daging dicampur dengan bahan lain, dan campuran dicetak membentuk",
    "Tidak Aktif",
  ],
  [
    "08030211",
    "Bakso Daging",
    "produk yang diperoleh dari campuran daging ternak<br> (kdr daging tidak kurang dari 50%) & pati/serealia dan bumbu2, dlm kondisi matang. Biasanya berbentuk bulat. Daging yang digunakan dpt berupa daging sapi, ayam, babi/daging lainnya dg menyebut jns dagingny",
    "Tidak Aktif",
  ],
  ["08030212", "Bakso Daging Kering", "", "Tidak Aktif"],
  [
    "08030214",
    "Sosis Sarapan Matang (Sosis Daging Babi Matang)",
    "Sosis sarapan matang (sosis daging babi matang) adalah sosis yang dibuat dari hasil penghalusan tetelan daging babi, dengan penambahanan garam dan rempah-rempah.",
    "Tidak Aktif",
  ],
  [
    "08030215",
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya)",
    "Sosis daging adalah produk dari campuran daging halus (mengandung<br> daging tidak kurang dari 75%) dengan tepung atau pati dengan atau tanpa<br> penambahan bumbu dan dimasukkan ke dalam selubung (selongsong)<br> sosis. Daging yang digunakan dapat berupa daging sapi, ayam, babi atau daging<br> lainnya dengan menyebut jenis dagingnya.",
    "Tidak Aktif",
  ],
  [
    "08030216",
    "Sosis Variasi",
    "Sosis variasi adalah sosis dari campuran daging halus dengan tambahan pangan lain seperti keju, sayur dan bahan lain-lain.",
    "Tidak Aktif",
  ],
  [
    "08030217",
    "Sosis Analog/Daging Analog/ Produk Analog",
    "Sosis analog adalah sosis dari campuran protein nabati dengan atau tanpa tambahan pangan lain seperti keju, sayur dan bahan lain-lain.",
    "Tidak Aktif",
  ],
  [
    "08030218",
    "Terrines (Campuran Cacahan Daging Matang)",
    "Terrines (campuran cacahan daging matang) adalah campuran daging cacahan yang dimasak di dalam wadah (vessel) dari tanah liat.",
    "Aktif",
  ],
  [
    "08030219",
    "Rolade Daging",
    "Rolade daging adalah produk dari lumatan daging atau daging giling dapat ditambah sayur, jamur diberi bumbu-bumbu, digulung dengan telur dadar atau bahan lainnya. Dimasak dan dapat diiris.",
    "Aktif",
  ],
  ["08030220", "Sosis Siap Santap", "-", "Tidak Aktif"],
  [
    "08030221",
    "Sosis Analog/Daging Analog/ Produk Analog Steril",
    "-",
    "Tidak Aktif",
  ],
  ["08030222", "Otak - Otak Ayam", "&nbsp;", "Tidak Aktif"],
  [
    "08030223",
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan",
    "-",
    "Tidak Aktif",
  ],
  [
    "08030224",
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril",
    "-",
    "Tidak Aktif",
  ],
  [
    "08030225",
    "Daging Luncheon Matang dalam Kaleng",
    "Daging luncheon matang dalam kaleng adalah produk yang terbuat dari daging atau campuran dua jenis daging atau lebih yang telah dihaluskan, dicuring dan dapat dimasak /dipanggang / telah diasap dan dikemas dalam kaleng.",
    "Aktif",
  ],
  [
    "08030226",
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng",
    "-",
    "Tidak Aktif",
  ],
  [
    "08030227",
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi",
    "-",
    "Tidak Aktif",
  ],
  [
    "08030228",
    "Kornet Daging Unggas Kombinasi",
    "-",
    "Tidak Aktif",
  ],
  [
    "08030229",
    "Salami Matang / Pepperoni Matang",
    "Produk daging giling, difermentasi dengan starter kultur, kemudian dimasak hingga matang. Salami matang dan produk sejenisnya adalah daging giling yang ditambah rempah-rempah dan memiliki rasa yang kuat, sudah dimasak yang mempunyai karakter khas salami.<br>",
    "Aktif",
  ],
  [
    "08030230",
    "Bakso Daging Kombinasi",
    "Bakso daging adalah produk olahan daging yang dibuat dari daging hewan ternak yang dicampur pati dan bumbu-bumbu, dengan atau tanpa penambahan bahan pangan lainnya, yang berbentuk bulat atau bentuk lainnya dan dimatangkan. Daging yang digunakan dapat berupa daging sapi, kerbau, kambing, domba, ayam, babi atau daging hewan ternak lainnya yang layak dimakan, dan atau hewan unggas, dengan menyebut jenis dagingnya.; serta dapat mengandung bagian bukan daging seperti urat dan hati.<br>",
    "Aktif",
  ],
  [
    "08030231",
    "Sosis Daging Kombinasi (dengan Perlakuan Panas)",
    "Sosis daging adalah produk berbahan baku daging yang dihaluskan dengan atau tanpa penambahan bahan pangan lain dan dimasukkan ke dalam selongsong sosis dengan proses pemasakan. Daging yang digunakan dapat berupa daging sapi, kerbau, kambing, domba, ayam, babi atau daging hewan ternak lainnya yang layak dimakan, dan atau hewan unggas, dengan menyebut jenis dagingnya.",
    "Aktif",
  ],
  [
    "08030232",
    "Pate Daging",
    "Pate daging adalah daging direbus, digiling, dimasukkan hati segar halus, digiling lagi, dimasukkan selongsong/kaleng/jar, dipanaskan.<br> Contohnya pate angsa.",
    "Aktif",
  ],
  [
    "08030233",
    "Daging Cincang Olahan Berbumbu",
    "Daging cincang olahan berbumbu adalah berbagai jenis olahan dengan bahan utama berupa daging cincang atau daging giling yang dimasak hingga matang, dengan atau tanpa penambahan bahan pangan dan bumbu-bumbu lainnya, dengan atau tanpa kuah/saus, dikemas secara aseptis dan disterilkan. Contoh : daging ayam dengan saus Bolognese, daging ayam dengan saus carbonara, daging sapi dengan saus blackpepper, daging ayam dengan saus barbekyu, daging curing cacahan matang.",
    "Aktif",
  ],
  [
    "08030234",
    "Kornet Daging Sterilisasi",
    "Produk yang dibuat dari potongan daging ternak atau unggas dan atau campurannya tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, dikemas dalam wadah tertutup, kedap udara atau secara hermetis dan diproses dengan sterilisasi.",
    "Aktif",
  ],
  [
    "08030235",
    "Kornet Daging Kombinasi Sterilisasi",
    "Produk yang dibuat dari potongan daging ternak atau unggas dan atau campurannya tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, dikemas dalam wadah tertutup, kedap udara atau secara hermetis dan diproses dengan sterilisasi.",
    "Aktif",
  ],
  [
    "08030236",
    "Kornet Unggas Sterilisasi",
    "Produk yang dibuat dari potongan daging ternak atau unggas dan atau campurannya tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, dikemas dalam wadah tertutup, kedap udara atau secara hermetis dan diproses dengan sterilisasi.",
    "Aktif",
  ],
  [
    "08030237",
    "Kornet Unggas Kombinasi Sterilisasi",
    "&nbsp;",
    "Aktif",
  ],
  [
    "08030238",
    "Sosis Daging Non Casing",
    "Sosis daging non casing adalah produk dari campuran daging halus yang diemulsikan, dengan penambahan tepung atau pati dengan atau tanpa penambahan bumbu dan bahan pangan lain yang diizinkan dan dicetak berbentuk sosis.",
    "Aktif",
  ],
  [
    "08030239",
    "Sosis Daging Kombinasi Non Casing",
    "Sosis daging kombinasi non casing adalah produk dari campuran daging halus yang diemulsikan, dengan penambahan tepung atau pati dengan atau tanpa penambahan bumbu dan bahan pangan lain yang diizinkan dan dicetak berbentuk sosis.<br>",
    "Aktif",
  ],
  [
    "08030240",
    "Daging Halus Olahan Berbumbu",
    "Daging halus olahan berbumbu adalah berbagai jenis olahan dengan bahan utama berupa daging, daging unggas maupun daging hewan buruan, yang dihaluskan yang dimasak dengan suhu tinggi hingga matang, dengan maupun tanpa penambahan bahan makanan dan bumbu-bumbu lainnya. Contohnya adalah perkedel daging, sambal goreng cincang, dll.<br> <br> <br> <br> <br> <br> <br>",
    "Aktif",
  ],
  [
    "08030241",
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan",
    "Potongan daging/daging cincang/daging giling dengan saus dalam kemasan adalah hasil olahan potongan daging, daging cincang atau daging giling yang ditambah saus dengan atau tanpa penambahan rempah-rempah dan dengan atau tanpa penambahan bumbu-bumbu, dimasak dengan perlakuan panas, dikemas secara kedap atau hermetis dalam kemasan kaleng, aluminium foil atau pengemas lain yang sesuai dan disterilkan.<br> Contoh: saus Bolognese untuk spaghetti, saus carbonara, daging sapi saus blackpepper, daging ayam saus barbeque, dll.",
    "Aktif",
  ],
  [
    "08030242",
    "Dendeng Daging (dengan perlakuan panas)",
    "Dendeng daging adalah produk dari lumatan daging, diberi bumbu dengan atau tanpa penambahan bahan tambahan pangan, dicetak dan dimasak. Daging yang dapat diolah menjadi dendeng dapat berupa daging sapi,<br> daging kerbau, daging babi, daging rusa, daging ayam dan lain lain.",
    "Aktif",
  ],
  [
    "08030243",
    "Pepperoni",
    "Pepperoni adalah daging giling yang ditambah rempah-rempah dan memiliki rasa yang kuat, sudah dimasak yang mempunyai karakter khas Pepperoni",
    "Aktif",
  ],
  [
    "08030244",
    "Bakso Daging",
    "Bakso daging adalah produk olahan daging yang dibuat dari daging hewan ternak yang dicampur pati dan bumbu-bumbu, dengan atau tanpa penambahan bahan pangan lainnya, yang berbentuk bulat atau bentuk lainnya dan dimatangkan.<br>",
    "Aktif",
  ],
  [
    "08030245",
    "Sosis Daging Siap Makan",
    "Sosis daging siap makan adalah produk dari campuran daging halus yang diemulsikan, dengan tambahan tepung atau pati dengan atau tanpa penambahan bumbu dan bahan pangan lain dan dimasukkan ke dalam kemasan yang kedap udara dan dilakukan sterilisasi, dapat dimakan langsung tanpa dimasak.",
    "Aktif",
  ],
  ["08030246", "Sosis Daging Kombinasi Siap Makan", "-", "Aktif"],
  [
    "08030247",
    "Sosis Daging (dengan Perlakuan Panas)",
    "Sosis daging adalah produk berbahan baku daging yang dihaluskan dengan atau tanpa penambahan bahan pangan lain dan dimasukkan ke dalam selongsong sosis dengan proses pemasakan. Daging yang digunakan dapat berupa daging sapi, kerbau, kambing, domba, ayam, babi atau daging hewan ternak lainnya yang layak dimakan, dan atau hewan unggas, dengan menyebut jenis dagingnya.",
    "Aktif",
  ],
  [
    "08030302",
    "Naget Ayam",
    "Naget ayam adalah produk olahan ayam yang dicetak, dimasak dan dibekukan, dibuat dari campuran daging ayam giling yang diberi bahan pelapis dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  ["08030303", "Naget Daging", "", "Tidak Aktif"],
  [
    "08030304",
    "Gyoza",
    "Gyoza adalah produk yang terbuat dari daging ayam, sapi, dan/atau daging hewan ternak lainnya yang dihaluskan, dengan atau tanpa hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, dan bahan pangan lain, dilapis dengan kulit yang terbuat dari adonan terigu dan air dan dibentuk, dimasak, dikemas, dan dibekukan. Jenis gyoza diantaranya Gyoza Ayam, Gyoza Daging, Gyoza Ayam dan Sayuran.",
    "Aktif",
  ],
  ["08030305", "Samosa Ayam", "&nbsp;", "Tidak Aktif"],
  ["08030306", "Naget Ayam Kombinasi", "-", "Aktif"],
  [
    "08030307",
    "Naget Daging Sapi Kombinasi",
    "Naget daging adalah produk olahan daging sapi yang dicetak dalam berbagai bentuk, dimasak, dan dibekukan, dibuat dari campuran daging sapi giling yang diberi bahan pelapis dengan atau tanpa penambahan bahan pangan lain; dengan atau tanpa isi di bagian tengahnya. Naget daging sapi kombinasi merupakan naget dengan kandungan daging sapi minimal 15%. Kadar protein naget daging sapi tidak kurang dari 9% dan kadar lemak tidak lebih dari 20%.",
    "Aktif",
  ],
  [
    "08030308",
    "Kornet Daging (Beku)",
    "Kornet daging adalah produk yang dibuat dari potongan daging ternak atau unggas dan atau campurannya tanpa tulang, segar atau beku, dapat dicampur dengan daging bagian kepala dan atau jantung, dengan proses curing, dengan atau tanpa penambahan bahan pangan lain, diproses, dikemas dalam wadah tertutup dan dibekukan.",
    "Aktif",
  ],
  ["08030309", "Kornet Daging Kombinasi (Beku)", "-", "Aktif"],
  ["08030310", "Kornet Unggas (Beku)", "-", "Aktif"],
  ["08030311", "Kornet Unggas Kombinasi (Beku)", "-", "Aktif"],
  [
    "08030312",
    "Smoked Chicken Breast (Daging Dada Ayam Asap)",
    "Smoked Chicken Breast (Daging Dada Ayam Asap) adalah produk yang terbuat dari hasil daging dada ayam, baik yang tidak dihaluskan maupun dihaluskan, dengan bahan tambahan berupa berbagai bumbu dan melalui proses curing; diisikan ke dalam selongsong plastik dan dimasak dengan pengasapan, didinginkan sebelum diiris membentuk potongan, lembaran atau gelondongan dan dibekukan.",
    "Aktif",
  ],
  [
    "08030313",
    "Swikiau/Kuotieh Daging",
    "Swikiau/Kuotieh daging adalah produk yang terbuat dari daging yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, sayuran, bumbu-bumbu, dan bahan tambahan, dilapis dengan kulit yang terbuat dari adonan terigu dan air dan dibentuk , dimasak, dikemas, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030314",
    "Lumpia Daging",
    "Lumpia daging adalah produk yang terbuat dari daging yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, sayuran, bumbu-bumbu, dan bahan tambahan, dilapis<br> dengan kulit yang terbuat dari adonan terigu dan air dan dibentuk silinder, dimasak, dikemas, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030315",
    "Pangsit Daging",
    "Pangsit daging adalah produk yang terbuat dari daging yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, dan bahan tambahan, dilapis dengan kulit pangsit, dimasak, dikemas, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030316",
    "Ebi Katsu",
    "Ebi Katsu adalah produk yang terbuat dari daging ayam yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, dan bahan tambahan, dicetak, diberi tepung pelapis, dimasak, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030317",
    "Keecho/Heecho",
    "Keecho/heecho adalah produk yang terbuat dari daging ayam yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, sayuran, dan bahan tambahan lainnya, dilapis dengan kulit tahu, dimasak, dikemas, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030318",
    "Bakso Goreng",
    "Bakso goreng adalah produk yang terbuat dari daging yang dihaluskan, dapat dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu dan bahan tambahan lainnya, lalu dibentuk bulat atau bentuk lainnya, digoreng, dibekukan, dikemas dan disimpan beku.<br> Bakso goreng merupakan bakso dengan kandungan daging minimal 45 %.<br> Karakteristik dasar :<br> \xEF\x{201A}\xB7 Kadar protein bakso goreng tidak kurang dari 11 %;<br> \xEF\x{201A}\xB7 Kadar lemak tidak lebih dari 10%;",
    "Aktif",
  ],
  [
    "08030319",
    "Bakso Goreng Kombinasi",
    "Bakso goreng adalah produk yang terbuat dari daging yang dihaluskan, dapat dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu dan bahan tambahan lainnya, lalu dibentuk bulat atau bentuk lainnya, digoreng, dibekukan, dikemas dan disimpan beku. Bakso goreng kombinasi merupakan bakso dengan kandungan daging minimal 20 %.<br> Karakteristik dasar :<br> \xEF\x{201A}\xB7 Kadar protein bakso goreng kombinasi tidak kurang dari 8 %;<br> \xEF\x{201A}\xB7 Kadar lemak tidak lebih dari 10%;",
    "Aktif",
  ],
  [
    "08030320",
    "Burger Daging",
    "Produk yang terbuat dari daging giling, dengan penambahan air, bumbu, dengan atau tanpa penambahan bahan pangan lain, kemudian dicetak, dibreading, dimasak, dan didinginkan",
    "Aktif",
  ],
  [
    "08030321",
    "Naget Ayam",
    "Naget ayam adalah produk olahan ayam yang dicetak, dimasak dan dibekukan, dibuat dari campuran daging ayam giling yang diberi bahan pelapis dengan atau tanpa penambahan bahan pangan lain dengan atau tanpa isi di bagian tengahnya.",
    "Aktif",
  ],
  [
    "08030322",
    "Naget Daging Sapi",
    "Naget daging adalah produk olahan daging sapi yang dicetak dalam berbagai bentuk, dimasak, dan dibekukan, dibuat dari campuran daging sapi giling yang diberi bahan pelapis dengan atau tanpa penambahan bahan pangan lain; dengan atau tanpa isi di bagian tengahnya. Naget daging sapi merupakan naget dengan kandungan daging sapi minimal 35%. Kadar protein naget daging sapi tidak kurang dari 12% dan kadar lemak tidak lebih dari 20%.",
    "Aktif",
  ],
  [
    "08030323",
    "Siomay Daging",
    "Siomay daging adalah produk yang terbuat dari daging ayam yang dihaluskan, dicampur dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, dan bahan tambahan lainnya, dilapis dengan kulit yang terbuat dari adonan terigu dan air dan dibentuk seperti cup, dimasak, dikemas, dan dibekukan. Persyaratan meat content minimal 30% (dengan kadar daging &gt;50%, kadar ikan &lt;50%).",
    "Aktif",
  ],
  [
    "08030324",
    "Ekado/ Moneybag",
    "Ekado adalah produk yang terbuat dari daging ayam yang dihaluskan, dicampur maupun tidak dengan hasil perikanan yang dihaluskan atau potongan, bumbu-bumbu, sayuran, dan bahan tambahan lainnya, dibentuk bulat seperti bakso dengan bagian tengahnya berisi telur; dilapis dengan kulit tahu, dimasak, dikemas, dan dibekukan.",
    "Aktif",
  ],
  [
    "08030325",
    "Daging Halus Olahan Berbumbu (Beku)",
    "Daging halus olahan berbumbu adalah berbagai jenis olahan dengan bahan utama berupa daging, daging unggas maupun daging hewan buruan yang dihaluskan, dalam bentuk mentah, setengah matang atau matang penuh, dengan maupun tanpa penambahan bahan makanan dan bumbu-bumbu lainnya. Contohnya adalah perkedel daging, sambal goreng cincang, dll.",
    "Aktif",
  ],
  [
    "09020116",
    "Udang Beku",
    "Udang beku adalah produk yang diperoleh dari spesies udang yang tergolong famili : (a) Penaeidae; (b) Pandalidae; (c) Crangonidae; (d)Palaemonidae dalam keadaan baik dan segar kemudian dicuci bersih, dan dibekukan dengan cepat hingga suhu pusat mencapai -18oC atau lebih rendah.",
    "Aktif",
  ],
  [
    "09020117",
    "Udang Kupas Mentah Beku",
    "Udang kupas mentah beku adalah produk dari udang segar yang mengalami perlakuan pencucian, dengan atau tanpa penyiangan, dengan atau tanpa pembelahan dan pembekuan hingga suhu pusat mencapai -18oC atau lebih rendah.",
    "Aktif",
  ],
  [
    "09020121",
    "Cumi-Cumi / Kerang / Ikan / ... Beku",
    "Cumi-Cumi / Kerang / Ikan / ... beku adalah produk spesies cumi-cumi, kerang, ikan segar dari famili (i) Loliginidae; (ii)Ommastrephidae atau bagiannya yang telah mengalami proses pencucian, dengan atau tanpa penyiangan, dengan atau tanpa pencucian, dan d",
    "Tidak Aktif",
  ],
  [
    "09020130",
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain",
    "Memfasilitasi pendaftaran pangan olahan selain PSAH",
    "Aktif",
  ],
  [
    "09020131",
    "Sidat Panggang Beku",
    "Sidat panggang beku adalah produk perikanan dengan bahan baku sidat (Anguilla spp.) yang mengalami perlakuan menjadi filet, pemanggangan, pengukusan, dan pemanggangan kembali dengan atau tanpa penambahan bahan peningkat aroma dan rasa, dan dibekukan.",
    "Aktif",
  ],
  [
    "09020132",
    "Pempek Ikan Rebus Beku",
    "Pempek ikan rebus beku adalah produk perikanan dengan bahan baku lumatan daging ikan segar dan/atau surimi dengan penambahan tepung, air, garam, dengan atau tanpa bahan pangan lain, yang mengalami perlakuan perebusan dan pembekuan.<br> Karakeristik dasar:<br> Kandungan lumatan daging ikan segar dan/atau surimi tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "09020133",
    "Bakso Ikan Beku",
    "Bakso ikan beku adalah produk ikan yang menggunakan lumatan daging ikan atau surimi dicampur tepung, dan bahan pangan lain bila diperlukan, yang mengalami pembentukan, perebusan, dan pembekuan. Bahan baku ikan yang digunakan dapat berupa semua jenis ikan dari kelas Pisces hasil penangkapan atau budidaya.<br> Karakteristik dasar:<br> Kandungan lumatan daging ikan atau surimi tidak kurang dari 40%.<br>",
    "Aktif",
  ],
  [
    "09020201",
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan",
    "Stik ikan, bagian ikan dan filet ikan berlapis tepung (breaded atau in batter) yang dibekukan adalah produk stik ikan, bagian ikan dan filet yang dilapisi dengan tepung roti atau tepung lain dengan atau tanpa penggorengan serta dibekukan.",
    "Aktif",
  ],
  [
    "09020202",
    "Stik Ikan (Fish Finger) Berlapis Tepung",
    "Stik ikan (fish finger) adalah produk perikanan yang dilapisi dengan tepung roti atau tepung lain dengan atau tanpa penggorengan yang memiliki berat antara 20 g hingga 50 g dengan panjang tidak lebih dari tiga kali lebar dan memiliki ketebalan 10 mm, atau",
    "Aktif",
  ],
  [
    "09020203",
    "Udang Lapis Tepung Beku",
    "Udang lapis tepung beku adalah produk dengan bahan baku udang (Penaeus Sp) segar atau jenis lain yang mengalami perlakuan sortasi, pengupasan, pembersihan, pemilihan ukuran, penyayatan dan pembentukan, dilapisi dengan tepung roti atau tepung lain dengan a",
    "Aktif",
  ],
  [
    "09020204",
    "Naget Ikan/Udang/Cumi/Kerang Beku",
    "Naget ikan/udang/cumi/kerang beku adalah produk perikanan dengan menggunakan lumatan daging ikan/udang/cumi/kerang dan/atau surimi, dicampur tepung dan bahanpangan lain, dikukus,<br> dicetak, dibaluri dengan tepung pengikat (predust6), dimasukkan dalam adonan batter5, kemudian dilapisi tepung roti/parutan kelapa kering, dengan atau tanpa penggorengan, dan dibekukan.<br> <br> Bahan baku yang digunakan meliputi ikan segar; udang segar; ikan beku; udang beku; lumatan daging ikan; surimi dengan mutu sesuai spesifikasi. Nama jenis produk ini diantaranya naget ikan, naget udang, naget ikan dan udang, kroket udang.",
    "Aktif",
  ],
  [
    "09020205",
    "Naget Udang",
    "Naget udang adalah produk dari daging udang giling yang dicampur dengan bumbu-bumbu dan bahan pengikat dan dicetak, dikukus, dilapisi dengan tepung roti atau tepung lain, dengan atau tanpa digoreng, dibekukan dan disimpan dalam keadaan beku.",
    "Tidak Aktif",
  ],
  [
    "09020206",
    "Tempura Beku",
    "Tempura beku adalah daging udang utuh yang dilapisi dengan bahan pengikat dan tepung roti atau tepung lainnya, dengan atau tanpa digoreng, dibekukan dan disimpan dalam keadaan beku.",
    "Aktif",
  ],
  [
    "0902040101",
    "Ikan dan Produk Ikan Kukus atau Rebus",
    "Ikan dan produk ikan kukus atau rebus adalah ikan dan produk ikan yang dimasak dengan cara pengukusan atau perebusan.",
    "Aktif",
  ],
  [
    "0902040104",
    "Ikan Pindang Garam",
    "Ikan pindang garam adalah produk ikan dengan bahan baku ikan yang mengalami perlakuan pengukusan dan setiap lapisannya ditaburi garam.",
    "Aktif",
  ],
  [
    "0902040105",
    "Bandeng Presto",
    "Bandeng presto adalah produk ikan dengan bahan baku ikan bandeng (Chanos chanos) utuh yang mengalami perlakuan perendaman dalam larutan garam atau bumbu dan pengukusan dengan tekanan tinggi.",
    "Aktif",
  ],
  [
    "0902040106",
    "Kamaboko",
    "Kamaboko adalah produk olahan dari daging ikan (atau dari surimi) yang mengalami proses pencucian, penggilingan dengan garam dan pemanasan sehingga membentuk tekstur yang kenyal (gel).",
    "Aktif",
  ],
  [
    "0902040107",
    "Bakso Ikan",
    "Bakso ikan adalah produk ikan yang menggunakan lumatan daging ikan atau surimi dicampur tepung dan bahan pangan lain bila diperlukan, yang mengalami pembentukan dan perebusan. Bahan baku ikan yang digunakan dapat berupa semua jenis ikan dari kelas Pisces hasil penangkapan atau budidaya.<br> <br> Karakteristik dasar:<br> Kandungan lumatan daging ikan atau surimi tidak kurang dari 40%.",
    "Aktif",
  ],
  ["0902040108", "Bakso Ikan Kering", "", "Tidak Aktif"],
  [
    "0902040109",
    "Otak-Otak Ikan",
    "Otak-otak ikan adalah produk perikanan yang menggunakan<br> lumatan daging ikan dan/atau surimi dicampur tepung/pati dengan atau tanpa bahan pangan lain, yang mengalami pembentukan, dengan atau tanpa dibungkus daun atau bahan lain yang sesuai, dan pemasakan. Bahan baku yang digunakan ikan segar; ikan beku; lumatan daging ikan; surimi dengan mutu sesuai spesifikasi.<br> <br> Karakteristik dasar:<br> Kandungan daging ikan dan/atau surimi tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "0902040110",
    "Kue Ikan Kukus (Steamed Fish Cake)",
    "Fish cake atau kue ikan adalah produk olahan dari bahan baku surimi yang telah mengalami pengukusan, dapat diberi potongan sayuran atau bahan pangan lain.",
    "Aktif",
  ],
  [
    "0902040111",
    "Siomay Ikan",
    "Siomay ikan adalah produk olahan ikan yang dibuat dari daging ikan giling, tapioka, terigu, telur dan bumbu-bumbu, dibentuk kotak atau bentuk lainnya, dapat ditempatkan pada lembaran tipis kulit pangsit atau bahan lainnya yang dapat dimakan, dan dikukus.",
    "Tidak Aktif",
  ],
  [
    "0902040112",
    "Pempek Ikan (Rebus)",
    "Definisi :<br> Pempek ikan (rebus) adalah produk perikanan dengan bahan baku lumatan daging ikan segar dan/atau surimi dengan penambahan tepung, air, garam, dengan atau tanpa bahan pangan lain, yang mengalami perlakuan perebusan.<br> Karakeristik dasar:<br> Kandungan lumatan daging ikan segar dan/atau surimi tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "0902040113",
    "Empek-Empek Palembang",
    "Empek-empek Palembang adalah produk olahan ikan yang dibuat dari daging ikan belida yang digiling, dicampur dengan tapioka atau campuran dengan tepung sagu, air dan garam dan dibentuk, kemudian direbus, digoreng atau dipanggang.",
    "Tidak Aktif",
  ],
  [
    "0902040114",
    "Pepes Ikan/Pepes Teri",
    "Pepes ikan/pepes teri adalah ikan/teri segar utuh yang telah mengalami penyiangan dan pembersihan, pelumuran bumbu-bumbu, dan pengemasan (daun) serta mengalami perebusan, penirisan, dengan atau tanpa pemanggangan.",
    "Aktif",
  ],
  ["0902040115", "Sosis Ikan", "", "Aktif"],
  ["0902040116", "Sosis Udang", "", "Tidak Aktif"],
  [
    "0902040117",
    "Palai Bada/Teri",
    "Palai bada/teri adalah ikan teri yang dicampur dengan kelapa giling dengan daun kunyit, daun mangkok, dan bumbu lainnya, dibungkus daun pisang dan dipanggang.",
    "Aktif",
  ],
  [
    "0902040118",
    "Otak-Otak Ikan Analog/Produk ikan Analog",
    "",
    "Tidak Aktif",
  ],
  [
    "0902040119",
    "Pangsit Seafood (Ikan, Udang, Cumi, dll)",
    "",
    "Aktif",
  ],
  ["0902040120", "Sosis Siap Santap", "&nbsp;", "Aktif"],
  [
    "0902040121",
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    "0902040122",
    "Olahan Ikan Berbumbu",
    "Olahan ikan berbumbu adalah berbagai jenis olahan ikan dengan bahan utama berupa daging ikan berbentuk potongan atau hancuran dengan bumbu, dengan atau tanpa penambahan bahan pangan lain, dimasak, dan dikemas.",
    "Aktif",
  ],
  [
    "0902040123",
    "Stik Kepiting Analog atau Imitation Crab Stick",
    "Stik kepiting analog atau imitation crab stick adalah produk berbahan baku surimi dengan warna pada permukaan atas menyerupai warna kepiting yang direbus, dan putih di bagian dalam, mempunyai tekstur berfilamen seperti daging kepiting, beraroma dan rasa khas kepiting.<br>",
    "Aktif",
  ],
  [
    "0902040124",
    "Bakwan Ikan (Rebus Atau Kukus)",
    "Bakwan ikan (rebus atau kukus) adalah produk ikan dari daging<br> ikan atau dari surimi yang mengalami proses pencucian; pengadonan<br> dengan garam, tepung, bumbu, dengan atau tanpa bahan pangan<br> lain; pencetakan (forming); dan perebusan atau pengukusan.<br> <br> Karakteristik dasar:<br> Kandungan daging ikan atau surimi tidak kurang dari 10%.",
    "Aktif",
  ],
  [
    "0902040125",
    "Bandeng Isi",
    "Bandeng isi adalah produk perikanan dengan bahan baku ikan<br> bandeng (Chanos chanos) yang diolah dari lumatan daging berbumbu<br> dan diisikan kembali ke dalam selubung (selongsong) kulit bandeng<br> dengan atau tanpa pelapisan daging berbumbu. Nama lain: otak-otak<br> bandeng.",
    "Aktif",
  ],
  [
    "0902040126",
    "Dimsum Ikan",
    "Dimsum ikan adalah produk perikanan dengan menggunakan<br> lumatan daging ikan dan/atau surimi, cacahan dan/atau potongan<br> daging ikan, tepung dan bahan pangan lain, dibentuk dan dibungkus<br> dengan kulit pangsit atau bahan pangan lain yang dapat dimakan<br> yang mengalami perlakuan pengukusan. Termasuk dalam produk ini<br> adalah siomay ikan, pangsit ikan, pastel ikan, samosa ikan, gyoza,<br> dan produk sejenis lainnya.<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan dan/atau surimi, cacahan<br> dan/atau potongan daging ikan tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "0902040127",
    "Tekwan Ikan",
    "Tekwan ikan adalah produk perikanan dengan bahan baku lumatan<br> daging ikan segar dan/atau surimi dengan penambahan tepung, air,<br> garam, dengan atau tanpa bahan pangan lain, yang dicampur dan<br> dibentuk potongan kecil-kecil dan mengalami perlakuan perebusan.<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan segar dan/atau surimi tidak kurang<br> dari 30%.",
    "Aktif",
  ],
  [
    "0902040128",
    "Sosis Ikan Kombinasi",
    "Sosis ikan kombinasi adalah produk perikanan dengan bahan baku<br> lumatan daging ikan atau surimi, dicampur tepung dan bahan<br> pangan lain, pengisian ke dalam selongsong sosis dan mengalami<br> perebusan atau pengukusan.<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan atau surimi tidak kurang dari 20%.",
    "Aktif",
  ],
  [
    "0902040129",
    "Rolade Ikan",
    "Rolade ikan adalah produk perikanan dengan bahan baku lumatan daging ikan atau surimi dengan penambahan tepung, bumbu, garam, dengan atau tanpa penambahan bahan pangan lain, dicetak, ditambahkan pelapis lalu digulung dan dikukus.<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan dan/atau surimi tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "0902040130",
    "Burger Ikan",
    "Burger ikan adalah produk perikanan yang dibuat dari daging ikan yang telah dilumatkan dan ditambah dengan tepung, bumbu, garam, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan tidak kurang dari 30%.<br>",
    "Aktif",
  ],
  [
    "0902040131",
    "Tsukudani",
    "Tsukudani adalah produk perikanan yang diperoleh dengan cara perebusan dalam kecap atau bahan pangan lain, kemudian dikeringkan dengan dioven atau cara lain untuk mengurangi kadar airnya.<br>",
    "Aktif",
  ],
  [
    "0902040132",
    "Telur Ikan Masak",
    "Telur ikan masak adalah produk perikanan dengan bahan baku telur ikan segar melalui proses perebusan atau pengukusan.",
    "Aktif",
  ],
  [
    "0902040201",
    "Daging Rajungan Rebus Dingin",
    "Daging rajungan rebus dingin adalah produk yang diolah dari rajungan segar yang mengalami pencucian, perebusan, pengambilan daging, pendinginan dan pengemasan.",
    "Aktif",
  ],
  [
    "0902040202",
    "Daging Kepiting Rebus Beku",
    "Daging kepiting rebus beku adalah kepiting segar dari spesies Portunnus pelagicus, Podopthalmus vigil, Scylla serrata yang mengalami pencucian, perebusan, pembekuan dan pengemasan.",
    "Aktif",
  ],
  [
    "0902040203",
    "Lobster Rebus Beku",
    "Lobster rebus beku adalah lobster segar dari spesies Panulirus dengan atau tanpa kepala yang mengalami pencucian, perebusan, pembekuan hingga suhu pusatnya mencapai -18 C atau lebih rendah dan pengemasan.",
    "Aktif",
  ],
  [
    "0902040204",
    "Udang Kupas Rebus Beku untuk Sushi Ebi",
    "Udang kupas rebus beku untuk sushi ebi adalah produk yang diolah dari udang segar yang mengalami perlakuan pemotongan kepala, perebusan dan pengupasan kulit dengan atau tanpa ekor sebelum atau sesudah pembelahan daging sehingga membentuk kupu-kupu, dan di",
    "Aktif",
  ],
  ["0902040205", "Bakso Udang / Bakso Cumi", "-", "Aktif"],
  ["0902040206", "Siomay Udang", "&nbsp;", "Aktif"],
  [
    "0902040207",
    "Pepes Udang",
    "pepes udang adalah udang segar utuh yang telah mengalami penyiangan dan pembersihan, pelumuran bumbu-bumbu, dan pengemasan (daun) serta mengalami perebusan, penirisan, dengan atau tanpa pemanggangan.",
    "Aktif",
  ],
  [
    "0902040208",
    "Sosis Udang",
    "Sosis udang adalah produk perikanan dengan bahan baku lumatan daging udang, dicampur tepung dan bahan pangan lain, pengisian ke dalam selongsong sosis dan mengalami perebusan atau pengukusan.<br> Bahan baku yang digunakan adalah udang segar; udang beku; dan lumatan daging udang sesuai dengan spesifikasi.",
    "Aktif",
  ],
  [
    "0902040209",
    "Udang dalam Saus (Tomat, Kari, Pedas, ...)",
    "-",
    "Aktif",
  ],
  [
    "0902040210",
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril)",
    "-",
    "Aktif",
  ],
  [
    "0902040211",
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng",
    "-",
    "Aktif",
  ],
  [
    "0902040212",
    "Kue Cumi/Sotong/Udang Kukus",
    "Kue cumi/sotong/udang kukus adalah produk olahan dari bahan baku lumatan daging cumi/sotong/udang yang telah mengalami pengukusan, dapat diberi potongan sayuran atau bahan pangan lain.",
    "Aktif",
  ],
  [
    "0902040213",
    "Dimsum Udang",
    "Dimsum udang adalah produk perikanan yang menggunakan udang kupas utuh, lumatan, cacahan dan/atau potongan, tepung dan bahan pangan lain, dibentuk dan dibungkus dengan kulit pangsit atau bahan pangan lainyang dapat dimakan yang mengalami perlakuan pengukusan. Termasuk dalam produk ini adalah siomay udang,pangsit udang, pastel udang, gyoza, hakau, dan produk sejenis lainnya.<br> <br> Karakeristik dasar: Kandungan udang kupas utuh, lumatan, cacahan dan/atau potongan tidak kurang dari 30%",
    "Aktif",
  ],
  [
    "0902040214",
    "Siomay Udang (Khusus Registrasi Ulang)",
    "",
    "Aktif",
  ],
  [
    "0902040301",
    "Sambal Goreng Udang",
    "Sambal goreng udang adalah makanan yang dibuat dengan<br> mengolah udang, cabai, dengan atau tanpa penambahan bahan<br> pangan lain. Bau, rasa dan warna normal khas udang.",
    "Aktif",
  ],
  [
    "0902040302",
    "Sambal Goreng Udang Kering (Ebi)",
    "Sambal goreng udang kering (ebi) adalah makanan kering yang dibuat dengan mengolah udang kering (ebi) dengan bumbu-bumbu. Bau, rasa dan warna normal khas udang.",
    "Tidak Aktif",
  ],
  [
    "0902040303",
    "Keripik Kulit Ikan Goreng",
    "Keripik kulit ikan goreng adalah produk perikanan yang dibuat dari kulit ikan segar yang mengalami proses pencucian, blansir, perendaman dalam larutan garam, penjemuran, dan penggorengan.",
    "Aktif",
  ],
  [
    "0902040304",
    "Abon Ikan",
    "Abon ikan adalah makanan kering berbentuk khas dibuat dari daging ikan, direbus, disayat-sayat / disuwir, dibumbui, digoreng dan dapat juga dipres. Abon terbuat dari berbagai jenis ikan.",
    "Aktif",
  ],
  ["0902040305", "Ikan Panggang", "-", "Aktif"],
  [
    "0902040306",
    "Cireng Seafood",
    "Cireng (singkatan dari aci digoreng, bahsa sunda untuk 'tepung kanji goreng') merupakan makanan ringan yang banyak dijumpai di daerah Jawa Barat, Cireng dibuat dengan cara menggoreng campuran adonan yang berbahan dasar tepung kanji/tapioka",
    "Aktif",
  ],
  ["0902040307", "Abon Udang", "-", "Aktif"],
  [
    "0902040308",
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara)",
    "&nbsp;",
    "Aktif",
  ],
  [
    "0902040309",
    "Udang Popcorn",
    "Udang popcorn adalah makanan terbuat dari udang yang dikupas kulitnya dalam bentuk potongan kecil, yang direndam atau dibalur dengan bumbu halus kemudian dilapisi tepung dan digoreng.",
    "Aktif",
  ],
  [
    "0902040310",
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering)",
    "Bakso ikan/ moluska/ krustase/ ekinodermata (kering) adalah produk perikanan yang menggunakan lumatan daging ikan/ moluska/ krustase/ ekinodermata atau surimi, dicampur tepung, dan bahan pangan lainnya bila diperlukan, yang mengalami pembentukan, perebusan, dan penggorengan atau proses pengeringan lainnya. Bahan baku ikan yang digunakan adalah semua jenis ikan dari kelas Pisceshasil penangkapan atau budidaya. Contohnya meliputi bakso ikan kering, bakso cumi kering, bakso udang kering.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2Kandungan lumatan daging ikan atau surimi tidak kurang dari 40% (untuk bakso ikan kering);<br> \xE2\x{20AC}\xA2Kandungan lumatan daging moluska/ krustase/ ekinodermata tidak kurang dari 30% (untuk bakso moluska/ krustase/ ekinodermata kering).",
    "Aktif",
  ],
  [
    "0902040311",
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang)",
    "Kue ikan/ kamaboko/ fish cake (goreng atau panggang) adalah produk perikanan yang menggunakandaging ikan atau surimi yang mengalami proses pencucian; pengadonan dengan garam, tepung, dan bumbu; pencetakan (forming); dengan atau tanpa pengukusan, kemudian digoreng atau dipanggang sehingga membentuk tekstur yang kenyal (gel). Jenis kamaboko: kamabokogoreng, chikuwa panggang.<br> <br> Karakteristik dasar: Kandungan surimi tidak kurang dari 30%",
    "Aktif",
  ],
  [
    "0902040312",
    "Sambal Goreng Ikan",
    "Sambal goreng ikan adalah produk perikanan berupa makanan kering yang dibuat dengan mengolah ikan yang dihaluskan dengan cabai dan atau bumbu-bumbu dan digoreng. Contoh produk diantaranya sambal goreng ikan roa.<br> <br> Karakteristik dasar:<br> Kandungan ikan tidak kurang dari 30%",
    "Aktif",
  ],
  [
    "0902040313",
    "Pempek Ikan (Goreng atau Panggang)",
    "Pempek ikan (goreng atau panggang) adalah produk perikanan dengan bahan baku lumatan daging ikan segar dan/atau surimi dengan penambahan tepung, air, garam, dengan atau tanpa bahan pangan lain, yang mengalami perlakuan perebusan dan penggorengan atau pemanggangan<br> <br> Karakeristik dasar:<br> Kandungan lumatan daging ikan segar dan/atau surimi tidak kurang dari 30%",
    "Aktif",
  ],
  [
    "0902040314",
    "Ikan Renyah",
    "Ikan renyah adalah produk perikanan dengan bahan baku ikan yang mengalami penambahan bumbu dengan dan atau tanpa tepung dan digoreng hingga renyah. Bahan baku adalah semua jenis ikan utuh segar. Contoh produk adalah ikan wader goreng, ikan bilis goreng.",
    "Aktif",
  ],
  [
    "0902040315",
    "Keripik Ikan",
    "Keripik ikan adalah produk perikanan dengan bahan baku ikan hidup atau bagian ikan yang mengalami perlakuan penambahan bumbu, dengan atau tanpa penambahan tepung dan digoreng. Produk sejenis lainnya antara lain keripik ikan teri, keripik kulit ikan, keripik lele, keripik patin, dan produk sejenis lainnya.<br> <br> Note: Keripik adalah produk buah, ubi, sayur, atau bahan lainnya berbentuk pipih atau bentuk lainnya dicampur atau tanpa dicampur dengan adonan tepung dan bumbu serta langsung digoreng.",
    "Aktif",
  ],
  [
    "0902040316",
    "Keripik Belut",
    "Keripik belut adalah produk perikanan dengan bahan baku belut (Monopterus albus) hidup yang mengalami perlakuan penambahan bumbu, dengan atau tanpa penambahan tepung dan digoreng.<br> <br> Note: Keripik adalah produk buah, ubi, sayur, atau bahan lainnya berbentuk pipih atau bentuk lainnya dicampur atau tanpa dicampur dengan adonan tepung dan bumbu serta langsung digoreng.",
    "Aktif",
  ],
  [
    "0902040317",
    "Tortila Ikan",
    "Tortila ikan adalah produk perikanan dengan bahan baku ikan,<br> dengan penambahan tepung, bumbu, pencetakan, dan digoreng.",
    "Aktif",
  ],
  [
    "0902040318",
    "Rendang Ikan Tuna",
    "Rendang ikan tuna adalah produk perikanan dengan bahan baku ikan tuna yang dimasak dalam santan dan bumbu rendang dengan atau tanpa penambahan bahan pangan lain.<br> Bumbu rendang terdiri dari campuran cabe merah, bawang merah, bawang putih, jahe,lengkuas, ketumbar, kunyit, dan sereh yang dihaluskan. Daun jeruk, daun kunyit dan asam kandis ditambahkan dalam bentuk utuh atau dihaluskan.",
    "Aktif",
  ],
  [
    "0902040319",
    "Rendang Kerang",
    "Rendang kerang adalah produk perikanan dengan bahan baku kerang lokan (Polymesoda expansa) yang dimasak dalam santan dan bumbu rendang dengan atau tanpa penambahan bahan pangan lain.<br> <br> Bumbu rendang terdiri dari campuran cabe merah, bawang merah, bawang putih, jahe, lengkuas, ketumbar, kunyit, dan sereh yang dihaluskan. Daun jeruk, daun kunyit dan asam kandis ditambahkan dalam bentuk utuh atau dihaluskan.<br>",
    "Aktif",
  ],
  [
    "09020501",
    "Ikan Asap",
    "Ikan asap adalah ikan segar yang mengalami perlakuan penyiangan, pencucian dengan atau tanpa perendaman dalam larutan garam, penirisan, pemberian rempah dan pengasapan menggunakan kayu, sabut atau tempurung kelapa.",
    "Aktif",
  ],
  [
    "09020503",
    "Ikan Asin Kering",
    "Ikan asin kering adalah produk olahan yang berasal dari ikan segar dalam bentuk utuh atau disiangi, dengan atau tanpa mengalami perlakuan (perebusan, pemasakan dengan penambahan garam, gula, vinegar atau rempah-rempah), selanjutnya dilakukan penggaraman d",
    "Aktif",
  ],
  [
    "09020504",
    "Ikan Teri Asin Kering",
    "Ikan teri asin kering adalah produk olahan ikan teri dengan perlakuan pencucian, penggaraman, dengan atau tanpa perebusan, pengeringan, pengemasan dan penyimpanan.",
    "Aktif",
  ],
  [
    "09020506",
    "Kerupuk Ikan",
    "Kerupuk ikan adalah produk pangan kering yang dibuat dari tepung pati atau tepung lainnya, daging ikan dengan atau tanpa penambahan bahan lainnya.",
    "Aktif",
  ],
  [
    "09020508",
    "Udang Kering",
    "Udang kering adalah produk olahan udang dengan perlakuan pencucian, perebusan dengan atau tanpa garam, pengeringan, pelepasan kulit dan kaki serta kepala udang, pengemasan dan penyimpanan.",
    "Aktif",
  ],
  [
    "09020510",
    "Kerupuk Udang Mentah",
    "Kerupuk udang adalah hasil olahan dari campuran yang terdiri dari udang segar, tepung tapioka dan bahan lain yang dicetak, dikukus dan dikeringkan.",
    "Aktif",
  ],
  [
    "09020517",
    "Terasi Udang",
    "Terasi udang adalah daging udang atau rebon segar atau campurannya yang dicampur dengan adonan dan bahan tambahan lainnya membentuk pasta kemudian dikeringkan dan difermentasi.",
    "Aktif",
  ],
  [
    "09020518",
    "Pasta Ikan",
    "Pasta ikan adalah produk bentuk pasta yang diperoleh dari fermentasi ikan.",
    "Aktif",
  ],
  [
    "09020521",
    "Masin",
    "Masin adalah produk yang diperoleh dari hasil fermentasi udang kecil segar atau rebon dari spesies Acetes dengan atau penambahan nasi atau karbohidrat lain (gula) serta bumbu.",
    "Aktif",
  ],
  [
    "09020522",
    "Tepung Ikan",
    "Tepung ikan adalah produk pangan yang dihasilkan dengan<br> mengeluarkan sebagian atau seluruh lemak dari daging ikan, dikeringkan dan digiling membentuk bubuk tepung kering.",
    "Aktif",
  ],
  [
    "09020523",
    "Pasta Gonad Bulu Babi",
    "Pasta gonad bulu babi adalah pasta yang diperoleh dari hasil fermentasi gonad atau telur bulu babi (baik jantan maupun betina) dengan penambahan garam 30% hingga 34%.",
    "Aktif",
  ],
  [
    "09020524",
    "Ikan Kering",
    "Ikan kering adalah produk olahan ikan dengan perlakukan penyiangan, pencucian, pengeringan dengan cara pengasapan dan atau penjemuran.",
    "Aktif",
  ],
  ["09020525", "Kitosan (Chitosan)", "-", "Aktif"],
  [
    "09020527",
    "Kerupuk Kulit Ikan Mentah",
    "Kerupuk kulit ikan mentah adalah produk perikanan yang dibuat dari kulit ikan segar yang mengalami proses pencucian, blansir, perendaman dalam larutan garam, dan pengeringan.",
    "Aktif",
  ],
  [
    "09020528",
    "Dendeng Ikan",
    "Dendeng ikan adalah produk perikanan dengan bahan baku ikan segar yang mengalami perlakukan penambahan bumbu-bumbu dengan rasa yang khas dan pengeringan.",
    "Aktif",
  ],
  [
    "09020529",
    "Ebi Bubuk",
    "Ebi bubuk adalah produk perikanan dengan bahan baku udang kering tanpa kulit yang digiling menjadi bentuk bubuk.",
    "Aktif",
  ],
  [
    "09020530",
    "Ikan Asin Jambal Roti",
    "Ikan asin jambal roti adalah produk perikanan hasil fermentasi dari bahan baku ikan manyung (genus Arius sp., Perciformes sp.) sehingga produk akhir mempunyai tekstur masir (berlapis berbutirbutir) dan aroma yang spesifik. Bentuk produk akhir: belah dengan atau tanpa kepala, dengan atau tanpa tulang belakang potongan daging, serta bentuk lain selain bentuk di atas.",
    "Aktif",
  ],
  [
    "09020531",
    "Ikan Peda",
    "Ikan peda adalah produk perikanan dari bahan baku ikan kembung (genus Rastrelliger) yang mengalami penggaraman dan fermentasi.",
    "Aktif",
  ],
  [
    "09020532",
    "Rusip",
    "Rusip adalah produk perikanan yang dibuat dari ikan teri melalui proses fermentasi dengan atau tanpa penambahan karbohidrat. Dapat mengandung bumbu dan bahan pangan lain untuk mendapatkan flavor yang diinginkan. Rusip berfungsi sebagai kondimen.",
    "Aktif",
  ],
  [
    "09020533",
    "Rebon",
    "Rebon adalah produk perikanan dengan bahan baku udang (Acetes sp.) yang telah mengalami perlakuan dengan atau tanpa perebusan atau pengukusan, dan pengeringan.",
    "Aktif",
  ],
  [
    "09020534",
    "Cumi dan Sotong Kering",
    "Cumi dan sotong kering adalah produk perikanan dari bahan baku cumi-cumi (Loligo spp) dan sotong (Sephia spp) dengan karakteristik produk akhir yang kering, rasa asin atau tawar, dan aroma spesifik.",
    "Aktif",
  ],
  [
    "09030101",
    "Rollmops",
    "Rollmops adalah suatu jenis ikan haring yang direndam dalam bumbu.",
    "Aktif",
  ],
  [
    "09030102",
    "Sea Gel",
    "Sea gel adalah dogfish dalam jeli",
    "Aktif",
  ],
  ["09030103", "Aspic Ikan", "", "Aktif"],
  ["09030104", "Fish Tsukudani", "", "Aktif"],
  [
    "09030201",
    "Fish Koji-zuke",
    "Fish koji-zuke adalah ikan pikel koji.",
    "Aktif",
  ],
  [
    "09030202",
    "Fish Kasu-zuke",
    "Fish kasu-zuke adalah ikan pikel lees.",
    "Aktif",
  ],
  [
    "09030203",
    "Fish Miso-zuke",
    "Fish miso-zuke adalah ikan pikel miso.",
    "Aktif",
  ],
  [
    "09030204",
    "Fish Shoyu-zuke",
    "Fish shoyu-zuke adalah ikan pikel saus kedelai.",
    "Aktif",
  ],
  [
    "09030205",
    "Fish Su-zuke",
    "Fish su-zuke adalah ikan pikel vinegar.",
    "Aktif",
  ],
  [
    "09030206",
    "Pikel Daging Anjing Laut (Pickled Whale)",
    "",
    "Aktif",
  ],
  [
    "09030301",
    "Telur Ikan",
    "Telur ikan dihasilkan dari pencucian, penggaraman dan pemeraman sampai dihasilkan produk yang transparan.",
    "Aktif",
  ],
  [
    "09030307",
    "Ikura",
    "Ikura adalah ikan salmon yang diolah dan digarami.",
    "Aktif",
  ],
  ["09030311", "Telur Ikan dalam Kaleng", "&nbsp;", "Aktif"],
  [
    "090401",
    "Ikan Kalengan",
    "Ikan kalengan adalah produk yang diperoleh dari ikan segar atau<br> potongan ikan segar dan dihilangkan isi perutnya, dicuci dengan air bersih, disusun dalam kaleng, dengan atau tanpa diberi media, dengan atau tanpa bumbu-bumbu atau bahan lainnya, kemudian di",
    "Aktif",
  ],
  [
    "090402",
    "Tuna Dalam Kemasan",
    "Tuna dalam kemasan adalah produk yang terdiri dari daging yang diolah dari jenis tuna (Thunnus spp.), tongkol (Euthynnus spp., Auxis spp.), cakalang (Katsuwonnus spp.), dan bonito (Sarda spp.) yang<br> dikemas secara hermetis dan menerima perlakuan proses yang cukup untuk menjamin sterilitas komersial.<br> Wujud produk akhir:<br> \x{2022} Solid \x{2013} potongan daging tuna yang utuh dan memenuhi seluruh penampang kemasan. Proporsi lempengan (flake) atau chunk tidak lebih dari 18% dari bobot tuntas.<br> \x{2022} Chunk \x{2013} potongan daging tuna dengan dimensi minimum 1,2 cm. Proporsi serpihan daging tuna dengan diameter kurang dari 1,2 cm tidak melebihi 30% dari bobot tuntas.<br> \x{2022} Flake atau flakes \x{2013} serpihan daging tuna dengan dimensi kurang dari 1,2 cm.<br> \x{2022} Grated atau shredded \x{2013} daging tuna yang lebih kecil dari serpihan.<br> <br> Karakteristik dasar:<br> Bobot tuntas tidak kurang dari 60%.",
    "Aktif",
  ],
  [
    "090404",
    "Kerang Dalam Kaleng",
    "Kerang dalam kaleng adalah kerang (arca spesies) segar tanpa kulit dalam larutan garam yang disterilisasi atau pasteurisasi dengan cara pemanasan.",
    "Aktif",
  ],
  [
    "090405",
    "Daging Rajungan Dalam Kaleng",
    "Daging rajungan dalam kaleng adalah produk dari daging bagian kaki, cakar, badan dan bahu rajungan segar dari sub ordo Brachyura dari ordo Decapoda dan semua spesies dari famili Lithodidae yang mengalami proses pencucian, perebusan, pengambilan daging, de",
    "Aktif",
  ],
  [
    "090408",
    "Sarden dan Makerel dalam Kemasan Kaleng",
    "Sarden dan makerel dalam kemasan kaleng diolah dari ikan segar atau beku dari genus berikut :<br> - Sardinella spp.<br> - Clupea spp.<br> - Scomber spp.<br> - Decapterus spp.<br> Produk mengacu pada SNI 8222 : 2016<br> Ruang lingkup : standar ini hanya berlaku untuk jenis ikan sarden dan makerel dalam medium air atau minyak atau medium lain yang sesuai yang dikemas dalam kaleng dengan bobot tuntas minimum 50%.<br>",
    "Aktif",
  ],
  [
    "090409",
    "Sarden Media Saus Tomat",
    "Sarden media saus tomat adalah produk yang dibuat dari jenis sarden segar maupun beku dari spesies: Sardina pilchardus; Sardinops melanostictus, S. neopilchardus, S. ocellatus, S. sagax S. caeruleus,; Sardinella aurita, S. brasiliensis, S. maderensis, S.",
    "Tidak Aktif",
  ],
  [
    "090410",
    "Moluska (Kerang, Bekicot, Siput Laut\xE2\x{20AC}\xA6.) dalam Kaleng",
    "Moluska (Kerang, Bekicot, Siput Laut\xE2\x{20AC}\xA6.) dalam kaleng adalah produk yang dibuat dari moluska segar, seperti bekicot segar dari spesies Achatina fulica, Helix aspersa, H. pomatia yang dikemas secara kedap (hermetis) dengan media air atau larutan garam, disterilkan dengan cara pemanasan.",
    "Aktif",
  ],
  ["090411", "Kornet Ikan", "-", "Aktif"],
  [
    "090412",
    "Nasi Dengan Lauk Ikan Dalam Kaleng",
    "-",
    "Tidak Aktif",
  ],
  [
    "090413",
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi)",
    "-",
    "Aktif",
  ],
  [
    "090414",
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap",
    "Sosis ikan/moluska/krustase/ekinodermata siap santap adalah produk dari lumatan daging ikan/moluska/krustase/ ekinodermata atau surimi, dengan tambahan tepung atau pati, dengan atau tanpa<br> penambahan bumbu dan bahan pangan lain dan dimasukkan ke dalam selongsong sosis yang kedap udara dan dilakukan sterilisasi, dapat dimakan langsung tanpa dimasak.<br> <br> Karakteristik dasar:<br> Kandungan lumatan daging ikan/moluska/krustase/ekinodermata<br> atau surimi tidak kurang dari 30%.<br>",
    "Aktif",
  ],
  [
    "090415",
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap",
    "Otak-otak ikan/moluska/krustase/ekinodermata siap santap adalah produk perikanan yang menggunakan lumatan daging ikan/moluska/krustase/ekinodermata dicampur tepung/pati dengan atau tanpa bahan pangan lain, dikemas dengan bahan yang sesuai, dan dilakukan sterilisasi, dapat dimakan langsung tanpa dimasak.<br> <br> Karakteristik dasar:<br> Kandungan daging ikan/moluska/krustase/ekinodermata tidak kurang dari 30%.",
    "Aktif",
  ],
  [
    "090416",
    "Cumi-cumi Dalam Kemasan",
    "Cumi-cumi dalam kemasan adalah produk perikanan dengan bahan<br> baku cumi (Loligo spp.) yang dikemas dalam suatu wadah hermetis<br> yang mengalami perlakuan pengolahan untuk menjamin sterilitas<br> komersial.",
    "Aktif",
  ],
  [
    "090417",
    "Sotong Dalam Kemasan",
    "Sotong dalam kemasan adalah produk perikanan dengan bahan<br> baku sotong segar yang mengalami perlakuan perebusan,<br> perendaman dalam air dingin, pengisian dan penimbangan,<br> pengisian media, penutupan kaleng secara hermetis, dan sterilisasi.",
    "Aktif",
  ],
  [
    "090418",
    "Ikan Dalam Kemasan",
    "Ikan dalam kemasan adalah produk perikanan yang dikemas secara<br> hermetis (misalnya plastik/laminat autoclavable/retortable) dalam<br> media air garam, minyak, atau media lain yang sesuai, dan<br> menerima perlakuan proses yang cukup untuk menjamin sterilitas<br> komersial. Kategori ini mencakup semua produk ikan dalam<br> kemasan yang tidak termasuk kategori di atas.",
    "Aktif",
  ],
  [
    "090419",
    "Olahan Ikan Dalam Kemasan",
    "Olahan ikan dalam kemasan adalah berbagai jenis olahan ikan<br> dengan bahan utama berupa daging ikan/ moluska/ krustase/<br> ekinodermata yang berbentuk potongan atau hancuran, dengan atau<br> tanpa penambahan bahan pangan lain, dikemas dalam kaleng atau<br> kemasan lain secara hermetis (misalnya plastik/laminat<br> autoclavable/retortable) dan diproses dengan perlakuan panas yang<br> cukup untuk menjamin stabilitas dan keamanan produk, dengan<br> bentuk akhir padat atau semi-padat. Jenis produk untuk kategori ini<br> antara lain tuna dalam mayonais, tuna berbumbu, kornet tuna.",
    "Aktif",
  ],
  [
    10020104,
    "Telur Cair Campuran /Premiks Telur Cair",
    "Telur cair campuran /premiks telur cair adalah produk dengan bahan utama telur cair (telur utuh, putih telur, kuning telur, atau campurannya) atau tepung telur (utuh, putih telur, atau kuning telur) dan ditambah bahan pangan lain. Nama jenis produk antara lain telur cair utuh campuran, putih telur cair campuran, kuning telur cair campuran.<br> <br> Karakteristik dasar:<br> Kandungan telur tidak kurang dari 50% dihitung sebagai telur cair atau tidak kurang dari 11,5% dihitung sebagai tepung telur.<br>",
    "Aktif",
  ],
  [
    10020201,
    "Telur Beku Utuh",
    "Telur beku utuh adalah produk telur yang diperoleh dari proses pembekuan telur cair utuh dengan atau tanpa penambahan bahan pangan lain. Termasuk produk tamagoyaki moto.",
    "Aktif",
  ],
  [
    10020202,
    "Putih Telur Beku",
    "Putih telur beku adalah produk telur yang diperoleh dari proses<br> pembekuan putih telur cair. Dapat ditambahkan ingredien lain untuk membantu pengembangan telur (whipping aids).",
    "Aktif",
  ],
  [
    10020203,
    "Kuning Telur Beku",
    "Kuning telur beku adalah produk telur yang diperoleh dari proses pembekuan kuning telur cair.",
    "Aktif",
  ],
  [
    10020204,
    "Telur Campuran Beku/Premiks Telur Beku",
    "Telur campuran beku/premiks telur beku adalah produk dengan bahan utama telur cair (telur utuh, putih telur, kuning telur, atau campurannya) atau tepung telur (utuh, putih telur, atau kuning telur) ditambah bahan pangan lain, kemudian dibekukan. Nama jenis produk antara lain telur utuh campuran beku, putih telur campuran beku, kuning telur campuran beku.<br> Karakteristik dasar:<br> Kandungan telur tidak kurang dari 50% dihitung sebagai telur cair atau tidak kurang dari 11,5% dihitung sebagai tepung telur.",
    "Aktif",
  ],
  [
    10020301,
    "Tepung Telur Utuh",
    "Tepung telur utuh adalah produk telur yang diperoleh dari proses pengeringan telur utuh cair dalam bentuk tepung atau granula.",
    "Aktif",
  ],
  [
    10020303,
    "Tepung Kuning Telur",
    "Tepung kuning telur adalah produk telur yang diperoleh dari proses pengeringan kuning telur cair. Sebelum proses pengeringan, kandungan glukosa kuning telur cair dapat dikurangi.",
    "Aktif",
  ],
  [10020304, "Produk Olahan Telur Bentuk Sosis", "-", "Aktif"],
  [
    10020305,
    "Rendang Telur",
    "Rendang telur adalah produk telur yang diperoleh dengan mencampurkan telur utuh atau telur dadar dengan bumbu rendang dan santan, dengan atau tanpa penambahan bahan pangan lain, dimasak sampai berminyak dan kering. Produk ini berwarna coklat kehitaman.<br>",
    "Aktif",
  ],
  [
    10020306,
    "Telur Matang/Setengah Matang",
    "Telur matang/setengah matang adalah telur utuh dalam kerabang yang dipanaskan sampai terkoagulasi sebagian (setengah matang) atau terkoagulasi seluruhnya (matang).",
    "Aktif",
  ],
  [
    10020307,
    "Tepung Telur Campuran/Premiks Tepung Telur",
    "Tepung telur campuran/premiks tepung telur adalah produk dengan bahan utama tepung telur (utuh, putih telur, atau kuning telur) dan bahan pangan lain. Nama jenis produk antara lain tepung telur utuh campuran, tepung putih telur campuran, tepung kuning telur campuran.<br> <br> Karakteristik dasar:<br> Kandungan tepung telur tidak kurang dari 11,5%",
    "Aktif",
  ],
  [
    100301,
    "Telur Asin Mentah",
    "Telur asin mentah adalah produk telur yang diperoleh dari telur itik yang telah diasinkan dengan proses tertentu sehingga kadar garam tidak kurang dari 2%, dan belum dimasak.",
    "Aktif",
  ],
  [
    100302,
    "Telur Asin Matang",
    "Telur asin matang adalah produk telur yang diperoleh dari telur itik yang telah diasinkan dengan proses tertentu sehingga kadar garam tidak kurang dari 2%, dibersihkan dan direbus hingga matang.",
    "Aktif",
  ],
  [
    100303,
    "Telur Pindang",
    "Telur pindang adalah produk telur yang diperoleh dari proses pengawetan telur tradisional dengan cara perebusan telur dalam air yang ditambahkan daun jambu biji/daun jati/daun teh, kulit bawang merah dan daun salam. Telur direbus dalam larutan yang ditambahkan garam untuk rasa gurih. Kerabang telur berwarna coklat kemerahan.",
    "Aktif",
  ],
  [
    100304,
    "Pidan atau Telur Hitam",
    "Pidan atau telur hitam adalah produk telur yang diperoleh dari proses pengawetan telur dengan cara diperam dalam adonan yang mengandung alkali sebagai bahan pengawet. Putih telur berbentuk padat seperti jeli, berwarna coklat kehitaman transparan. Kuning telur berwarna abu-abu kehijauan.",
    "Aktif",
  ],
  [
    100305,
    "Halidan",
    "Halidan adalah produk telur yang diperoleh dari proses pengawetan telur dengan cara pembungkusan telur dalam campuran tanah liat atau serbuk gergaji, garam, kapur yang kemudian dicampur dengan air teh.",
    "Aktif",
  ],
  [
    100306,
    "Dsaudan",
    "Dsaudan adalah produk telur yang diperoleh dari proses pengawetan dengan cara pembungkusan dengan nasi dan garam.",
    "Aktif",
  ],
  [100307, "Telur Diawetkan Dengan Cara Lain", "", "Aktif"],
  [100308, "Telur Fermentasi", "", "Aktif"],
  [
    100309,
    "Telur Olahan Steril",
    "Telur olahan steril adalah produk telur dengan atau tanpa kerabang, dengan atau tanpa bumbu, dikemas secara kedap (hermetis), dan diawetkan melalui proses sterilisasi. Contoh produk meliputi telur gulai steril, telur pindang steril, telur balado steril, telur asin steril.",
    "Aktif",
  ],
  [
    100401,
    "Selai Kaya",
    "Selai kaya adalah produk telur yang diperoleh dari pengolahan campuran telur, gula, santan dengan atau tanpa penambahan pati dan bahan pangan lain.",
    "Aktif",
  ],
  [
    100402,
    "Custard",
    "Custard adalah produk telur yang diperoleh dari campuran telur, susu dan lemak lain yang dikentalkan dengan bahan pengental, disajikan langsung maupun digunakan sebagai topping dan pengisi. Dapat berasa manis maupun asin.",
    "Aktif",
  ],
  [
    100403,
    "Custard Beku",
    "Custard beku adalah produk telur yang diperoleh dari custard yang dibekukan, sehingga memiliki karakteristik seperti es krim, tetapi dengan kadar air lebih rendah.",
    "Aktif",
  ],
  [
    100404,
    "Tepung Custard",
    "Tepung custard adalah produk tepung yang diperoleh dari custard yang dikeringkan.",
    "Aktif",
  ],
  [
    100405,
    "Martabak Telur",
    "Martabak telur adalah produk telur yang diperoleh dari penggorengan campuran telur ayam atau bebek dengan daging dan sayuran lain yang dibungkus dalam lapisan adonan tepung.",
    "Aktif",
  ],
  [100406, "Selai Kaya (Steril)", "", "Aktif"],
  [
    11010101,
    "Dekstrosa Anhidrat",
    "Dekstrosa anhidrat adalah D-glukosa yang dimurnikan dan dikristalkan tanpa kristalisasi air, mengandung D-glukosa tidak kurang dari 99,5% dan kadar total padatan tidak kurang dari 98%.",
    "Aktif",
  ],
  [
    11010102,
    "Dekstrosa Monohidrat",
    "Dekstrosa monohidrat adalah D-glukosa yang dimurnikan dan dikristalkan dengan kristalisasi satu molekul air, mengandung D-glukosa tidak kurang dari 99,5% dan kadar total padatan tidak kurang dari 90%.",
    "Aktif",
  ],
  [
    11010103,
    "Fruktosa",
    "Fruktosa adalah D-fruktosa yang dimurnikan dan dikristalkan, mengandung D-fruktosa tidak kurang dari 95% dan glukosa tidak lebih dari 0,5%.",
    "Aktif",
  ],
  [
    11010201,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus",
    "Gula serbuk (icing sugar) adalah gula putih yang digiling sampai halus dengan atau tanpa penambahan antikempal.",
    "Aktif",
  ],
  [
    11010202,
    "Dektrosa Serbuk (Icing Dextrose)",
    "Dektrosa serbuk (icing dextrose) adalah dekstrosa anhidrat atau dekstrosa monohidrat, atau campuran keduanya yang digiling sampai halus, dengan atau tanpa penambahan antikempal.",
    "Aktif",
  ],
  [
    11010302,
    "Gula Merah Lunak",
    "Gula merah lunak atau soft brown sugar adalah kristal halus gula yang telah dimurnikan dan berwarna coklat terang hingga coklat gelap. Gula merah lunak mengandung sukrosa dan gula invert tidak kurang dari 88%.",
    "Aktif",
  ],
  [
    11010303,
    "Sirup Glukosa",
    "Sirup glukosa adalah cairan kental dan jernih yang komposisi utamanya glukosa diperoleh dari hidrolisa pati dan/atau inulin. Kadar gula tidak kurang dari 20% dihitung sebagai D-glukosa.",
    "Aktif",
  ],
  [
    11010305,
    "Gula Pasir Mentah",
    "Gula pasir mentah adalah kristal sukrosa yang sebagian dimurnikan yang diperoleh dari cairan gula yang dimurnikan sebagian tanpa proses pemurnian lebih lanjut.",
    "Aktif",
  ],
  [
    11010306,
    "Glukosa",
    "Glukosa adalah padatan yang diperoleh dari proses hidrolisis pati. Mengandung gula pereduksi tidak kurang dari 70% yang dihitung sebagai dekstrosa anhidrat.",
    "Aktif",
  ],
  [11010309, "Sirup Maltosa", "&nbsp;", "Aktif"],
  [11010310, "Gula Kastor", "-", "Tidak Aktif"],
  [
    11010311,
    "Gula Tebu Mentah",
    "Gula tebu mentah adalah sukrosa yang peroleh dari proses pemurnian sebagian dari sari tebu dan dikristalkan.",
    "Aktif",
  ],
  [
    11010401,
    "Laktosa",
    "Laktosa adalah gula alami yang terdapat dalam susu dan diperoleh dari whey, dapat berbentuk anhidrat atau monohidrat atau campuran keduanya. Kandungan laktosa tidak kurang dari 99%.",
    "Aktif",
  ],
  [
    11010501,
    "Gula Kristal Putih atau Gula Pasir",
    "Gula kristal putih atau gula pasir adalah gula sukrosa kristal yang diproduksi dari bahan baku tebu atau bit melalui tahapan proses yang meliputi penggilingan, klarifikasi, penguapan, kristalisasi, fugalisasi, pengeringan dan pengemasan. Nilai polarisasi",
    "Tidak Aktif",
  ],
  [
    11010502,
    "Gula Kristal Putih (GKP1)",
    "Gula kristal yang dibuat dari tebu atau bit melalui proses sulfitasi/karbonatasi/fosfatasi atau proses lainnya sehingga langsung dapat dikonsumsi. Persyaratan mutu sesuai dengan syarat mutu gula kristal putih GKP1 sesuai SNI 3140.3:2010.",
    "Aktif",
  ],
  [
    11010503,
    "Gula Kristal Putih (GKP2)",
    "Gula kristal yang dibuat dari tebu atau bit melalui proses sulfitasi/karbonatasi/fosfatasi atau proses lainnya sehingga langsung dapat dikonsumsi. Persyaratan mutu sesuai dengan syarat mutu gula kristal putih GKP2 sesuai SNI 3140.3:2010.",
    "Aktif",
  ],
  [
    110201,
    "Gula Aren",
    "Gula aren adalah produk yang diperoleh dari pengolahan air nira pohon aren (Arenga pinnata Merr). Kadar gula tidak kurang dari 77% dihitung sebagai sakarosa.",
    "Aktif",
  ],
  [
    110202,
    "Gula Palma",
    "Gula palma adalah gula yang dihasilkan dari pengolahan nira pohon palma yaitu aren (Arenga pinata Merr), kelapa (Cocos nucifera), siwalan (Barassus flabellifer L) atau jenis palma lainnya, dan berbentuk sesuai cetakannya atau serbuk/granula.",
    "Aktif",
  ],
  [
    110203,
    "Gula Merah Tebu/Saka",
    "Gula merah tebu adalah gula yang berasal dari pengolahan air tebu melalui pemasakan dan berwarna kecoklatan bentuknya sesuai cetakan.",
    "Aktif",
  ],
  [
    110204,
    "Gula Kelapa",
    "Gula kelapa adalah produk yang diperoleh dari pengolahan air nira pohon kelapa (Cocos nucifera Linn) yang berbentuk hablur. Kadar gula tidak kurang dari 77% dihitung sebagai sakarosa.",
    "Aktif",
  ],
  [
    110205,
    "Gula Semut",
    "Gula semut adalah gula yang diperoleh dari pengolahan nira pohon palma (Famili Palmae) yang berbentuk hablur. Kadar gula tidak kurang dari 80% dihitung sebagai sakarosa",
    "Aktif",
  ],
  [
    110206,
    "Gula Coklat Sukrosa",
    "Gula Coklat Sukrosa adalah gula yang dihasilkan dari pengolahan gula sukrosa dengan atau tanpa penambahan nira pohon palma atau gula merah palma atau tetes tebu (molases) atau campurannya, berbentuk padat serbuk atau kristal dan berwarna coklat.",
    "Aktif",
  ],
  [
    110207,
    "Gula Palma Serbuk (Gula Semut)",
    "Gula palma (gula semut) adalah gula yang dihasilkan dari pengolahan nira pohon palma yaitu aren (Arenga pinata Merr), kelapa (Cocos nucifera), siwalan (Barassus flabellifer L) atau jenis palma lainnya, dan berbentuk serbuk/granula. Contoh nama jenis gula semut atau gula palma serbuk. Karakteristik dasar: Kadar air tidak lebih dari 3%.",
    "Aktif",
  ],
  [
    11030101,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42",
    "Sirup fruktosa (high fructose syrup/HFS) adalah cairan kental jernih dengan<br> kadar fruktosa tinggi, umumnya diperoleh dengan proses enzimatik pati.",
    "Aktif",
  ],
  [
    11030102,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55",
    "Sirup fruktosa (high fructose syrup/HFS) adalah cairan kental jernih dengan<br> kadar fruktosa tinggi, umumnya diperoleh dengan proses enzimatik pati.",
    "Aktif",
  ],
  [
    11030103,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55",
    "Sirup fruktosa (high fructose syrup/HFS) adalah cairan kental jernih dengan<br> kadar fruktosa tinggi, umumnya diperoleh dengan proses enzimatik pati.",
    "Aktif",
  ],
  [
    110302,
    "Tetes Tebu atau Molases",
    "Tetes tebu atau molases adalah hasil ikutan pabrik gula berupa cairan kental berwarna coklat kehitaman, berbau khas, memiliki rasa sepat manis sebagai produk dari proses pemisahan terakhir gula kristal dari masakan tebu (Saccharum officinarum L) tanpa pen",
    "Aktif",
  ],
  [
    110303,
    "Gula Invert",
    "Gula invert adalah campuran glukosa dan fruktosa dalam konsentrasi ekimolar yang sama dan merupakan hasil hidrolisis sukrosa.",
    "Aktif",
  ],
  [
    110305,
    "Sirup Jagung",
    "Sirup jagung adalah cairan gula kental yang dibuat dari hidrolisis pati jagung.<br>",
    "Aktif",
  ],
  [
    110306,
    "Sirup Tebu (Cane Syrup)",
    "Sirup tebu (cane syrup) adalah produk cair yang diperoleh dengan proses pemekatan dan pemanasan sari tebu (Saccharum officinarum L.) atau dari pelarutan pekatan gula tebu yang terbuat dari sari tebu.",
    "Aktif",
  ],
  [
    110307,
    "Gula Sukrosa Cair",
    "Gula sukrosa cair adalah produk gula berupa cairan jernih mengandung sukrosa yang diperoleh melalui proses pemekatan cairan dari tebu atau umbi bit, atau proses pelarutan gula pasir dalam air. Gula pasir (kristal sukrosa) dapat berupa gula kristal mentah, gula kristal putih, atau gula kristal rafinasi.<br> <br> Karakteristik dasar:<br> Kadar sukrosa minimal 65% \xBA Brix",
    "Aktif",
  ],
  [
    110401,
    "Sirup Tebu (Cane Syrup)",
    "Sirup tebu (cane syrup) adalah produk cair yang diperoleh dengan proses pemekatan dan pemanasan sari tebu (Saccharum officinarum L.) atau dari pelarutan pekatan gula tebu yang terbuat dari sari tebu.",
    "Tidak Aktif",
  ],
  [
    110402,
    "Sirup Maple (Maple Syrup)",
    "Sirup maple (maple syrup) adalah produk cairan yang diperoleh dengan proses pemekatan cairan eksudat (sap) pohon maple (Acer) atau larutan gula maple (maple concrete) yang dibuat dari cairan sap.",
    "Aktif",
  ],
  [
    110404,
    "Sirup/Sirup Meja (Table Syrup)",
    "Sirup meja (table syrup) adalah larutan 65% gula (sakarosa, gula invert dan fruktosa).",
    "Aktif",
  ],
  [
    110405,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma)",
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma)",
    "Aktif",
  ],
  [110406, "Gula Batu", "-", "Aktif"],
  [
    110407,
    "Sirup Agave",
    "Sirup Agave adalah sirup yang diperoleh dari tanaman Agave.",
    "Aktif",
  ],
  [
    110408,
    "Gula Hias",
    "Gula hias adalah gula untuk hiasan kue (contohnya kristal gula berwarna untuk kukis).",
    "Aktif",
  ],
  [110409, "Gula Aren Cair", "-", "Aktif"],
  [
    110501,
    "Madu",
    "Madu adalah cairan manis yang dihasilkan oleh lebah madu berasal dari berbagai sumber nektar. Aktivitas enzim diastase tidak kurang dari 3 DN.",
    "Aktif",
  ],
  [
    110502,
    "Serbuk Madu",
    "Serbuk madu adalah produk yang diperoleh dari campuran madu dengan tepung atau bahan lainnya yang dikeringkan.",
    "Aktif",
  ],
  [
    110503,
    "Madu Sarang (Comb Honey)",
    "Madu Sarang (Comb Honey) adalah madu yang disimpan dalam sarang madu (honeycomb) yang diproduksi oleh lebah dan belum mengalami pengolahan apapun untuk memisahkan madu dari lilin madu (beeswax). Madu Sarang (Comb Honey) harus bebas dari lebah atau potongannya (cemaran fisik).",
    "Aktif",
  ],
  [
    110601,
    "Gula Pasir dengan Pemanis Buatan",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [110602, "Sediaan Pemanis Alami", "-", "Aktif"],
  [110603, "Sediaan Pemanis Buatan", "-", "Aktif"],
  [110604, "Sediaan Pemanis Alami dan Buatan", "-", "Aktif"],
  [
    110605,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya",
    "-",
    "Aktif",
  ],
  [
    12010103,
    "Garam Konsumsi Beriodium",
    "Garam Konsumsi Beriodium adalah produk bahan makanan yang berbentuk padat dengan komponen utamanya klorida (NaCl) dengan penambahan/fortifikasi kalium iodat (KIO3)",
    "Aktif",
  ],
  [
    12010106,
    "Garam Campuran",
    "Garam campuran adalah campuran garam dengan bahan pangan lain. Produk garam campuran dapat mengandung monosodium<br> glutamat (MSG). Nama jenis produk diantaranya garam campur<br> gula, garam campur MSG.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar NaCl tidak kurang dari 50%;<br> \x{2022} Kadar iodium dihitung sebagai KIO3 tidak kurang dari 15,95 mg/kg.",
    "Aktif",
  ],
  [12010107, "Garam Gurih", "&nbsp;", "Aktif"],
  [
    12010108,
    "Garam Cair",
    "Garam cair adalah campuran garam dengan air dengan kadar NaCl tidak kurang dari 23%.",
    "Aktif",
  ],
  [
    12010109,
    "Garam Kurang Natrium",
    "Peraturan BPOM nomor 34 tahun 2019 tentang Kategori Pangan",
    "Aktif",
  ],
  [
    12010110,
    "Garam Berbumbu",
    "Garam berbumbu adalah campuran garam dengan rempah, dengan atau bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar NaCl tidak kurang dari 50%;<br> \xE2\x{20AC}\xA2 Kadar iodium dihitung sebagai KIO3 tidak kurang dari 15,95 mg/kg.",
    "Aktif",
  ],
  [
    12010111,
    "Garam Industri Aneka Pangan",
    "Garam industri aneka pangan adalah garam beriodium yang digunakan sebagai bahan baku untuk industri aneka pangan.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar NaCl tidak kurang dari 97% (basis kering);<br> \x{2022} Kadar iodium dihitung sebagai KIO3 tidak kurang dari 30 mg/kg.",
    "Aktif",
  ],
  [
    12010112,
    "Garam Diet",
    "Garam diet adalah garam beriodium yang mengandung natrium<br> klorida (NaCl) yang disesuaikan dengan keperluan.<br> Karakteristik dasar :<br> \x{2022} Kadar natrium klorida (NaCl) adbk (atas dasar bahan kering)<br> tidak lebih dari 60%;<br> \x{2022} Kadar klorida (KCl) adbk tidak lebih dari 40%;<br> \x{2022} Kadar iodium sebagai KIO3 tidak kurang dari 30 mg/kg.",
    "Aktif",
  ],
  [
    120102,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute)",
    "Pengganti garam adalah bumbu dengan kandungan natrium yang<br> dikurangi dan digunakan untuk menggantikan garam.<br> Syarat mutu :<br> - kandungan Na tidak lebih dari 0.12 g/100 g produk pengganti garam (sesuai dengan Codex Stan 53-1981 - Codex Standard for Special Dietary Food with Low-Sodium Content (including Salt Subtitutes) dan Australia New Zealand Food Standard, Standard 2.10.2 - Salt and Salt Products)<br> - Bahan Baku yang dapat digunakan antaran lain :<br> Garam Kalsium<br> Garam Kalium<br> Garam Magnesium<br> Garam Amonium<br> atau campurannya<br> - Kadar iodium dalam KIO3 minimal 30 mg/kg<br> - Uji organoleptik normal<br> - Analisis dilakukan terhadap kandungan natrium total pada produk akhir<br>",
    "Aktif",
  ],
  [
    12020102,
    "Rempah",
    "Rempah adalah bagian tanaman yang dapat berupa biji, buah, bunga, kulit batang dan rimpang untuk memberi aroma dan rasa pada pangan atau dapat mewarnai dan digunakan untuk meningkatkan selera makan; dapat berbentuk utuh, irisan, bubuk, pasta, baik segar maupun yang sudah dikeringkan, tunggal atau campuran tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    12020103,
    "Rempah Bubuk",
    "Rempah bubuk adalah rempah yang dihaluskan baik tunggal maupun campuran untuk memberikan rasa dan aroma yang khas bagi makanan tertentu.",
    "Tidak Aktif",
  ],
  [
    12020104,
    "Adas, Adas Pedas, Fennel, Jinten Manis",
    "Adas, adas pedas, fennel, jinten manis adalah produk rempah yang diperoleh dari buah kering dan masak dari tanaman Foeniculum vulgare atau Foeniculum officinale.",
    "Tidak Aktif",
  ],
  [
    12020105,
    "Adas Bubuk",
    "Adas bubuk adalah produk bubuk yang diperoleh dengan cara menggiling buah masak dan kering dari tanaman Foeniculum vulgare.",
    "Tidak Aktif",
  ],
  [12020106, "Asam Glugur", "", "Tidak Aktif"],
  [
    12020107,
    "Asam Jawa",
    "Asam jawa adalah produk rempah-rempah yang diperoleh dari buah tanaman Tamarindus indica atau T.officinalis.",
    "Tidak Aktif",
  ],
  [12020108, "Asam Kandis", "", "Tidak Aktif"],
  [
    12020109,
    "Allspice",
    "Allspice adalah produk rempah-rempah berbentuk utuh atau serbuk yang diperoleh dari buah Pimmento dioica (L) Merr yang belum matang dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020110,
    "Asinan Jahe",
    "Asinan jahe adalah produk jahe (Zingiber officinale) yang diperoleh dari proses pengawetan jahe dengan penambahan garam, dan larutan cuka atau larutan asam sitrat, atau asam lain yang sesuai. Dapat ditambahkan gula atau bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    12020112,
    "Basilla",
    "Basilla adalah herba berbentuk utuh atau bubuk yang diperoleh dari daun Deimun basilicum yang dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020113,
    "Bay Leaves",
    "Bay leaves adalah herba berbentuk utuh atau bubuk yang diperoleh dari daun Lurus nobilis L yang dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020114,
    "Bawang Putih",
    "Bawang putih adalah umbi dari tanaman Allium sativum. Bisa dalam bentuk segar, pasta, kering, irisan kering, bubuk dengan atau tanpa campuran dengan garam.",
    "Tidak Aktif",
  ],
  [
    12020115,
    "Bawang Merah (Shallot)",
    "Bawang merah (shallot) adalah umbi dari tanaman Allium cepa L. atau A.ascalonicum. Bisa dalam bentuk segar, kering, bubuk, atau irisan yang digoreng.",
    "Tidak Aktif",
  ],
  [
    12020116,
    "Bawang Batak/Lokio",
    "Bawang Batak/Lokio adalah daun dan umbi tanaman allium chinense",
    "Tidak Aktif",
  ],
  [
    12020117,
    "Bawang Daun",
    "Bawang daun adalah tanaman onion (Allium cepa) yang belum terbentuk umbinya (green onion) atau umbi baru terbentuk sedikit (spring onion) dan tanaman Allium porrum (leek). Bisa dalam bentuk segar, bubuk, atau irisan.",
    "Tidak Aktif",
  ],
  [
    12020118,
    "Biji Seledri",
    "Biji seledri adalah biji kering dari tanaman Apium graveolens.",
    "Tidak Aktif",
  ],
  [
    12020119,
    "Biji Sawi/Biji Mustard",
    "Biji sawi/biji mustard adalah biji kering dari beberapa spesies tanaman Brassica.",
    "Tidak Aktif",
  ],
  [
    12020120,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk",
    "Biji sawi atau biji mustard bubuk adalah produk bubuk yang diperoleh dari beberapa biji-bijian kering spesies Brassica.",
    "Tidak Aktif",
  ],
  [12020121, "Cabe Jawa", "", "Tidak Aktif"],
  [
    12020122,
    "Cabe Merah Segar",
    "Cabe merah segar adalah produk rempah yang diperoleh dari buah tanaman Capsicum annum L. yang dipetik pada tingkat ketuaan optimal.",
    "Tidak Aktif",
  ],
  [
    12020123,
    "Bubur Cabe",
    "Bubur cabe adalah produk bubur yang diperoleh dari proses penggilingan buah cabe (Capsicum annum atau C. fructessen) segar atau buah kering yang baik dengan penambahan air bersih. Dapat mengandung garam dan vinegar.",
    "Aktif",
  ],
  [
    12020124,
    "Cabe Bubuk",
    "Cabe bubuk adalah produk bubuk yang diperoleh dari proses<br> penggilingan buah cabe (Capsicum annum atau C. fructessen) kering yang baik.",
    "Tidak Aktif",
  ],
  [
    12020126,
    "Cengkeh",
    "Cengkeh adalah produk yang diperoleh dari bunga yang belum mekar dari tanaman cengkeh Eugenia caryophyllus famili Myrtaceae, yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020127,
    "Cengkeh Bubuk",
    "Cengkeh bubuk adalah produk bubuk yang diperoleh dari bunga yang belum mekar dari tanaman cengkeh Eugenia caryopyllus famili Myrtaceae, yang telah dikeringkan dan digiling.",
    "Tidak Aktif",
  ],
  [
    12020128,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender",
    "Biji dill (dill seed), adas manis, adas sowa, adas cina, ender adalah produk yang diperoleh dari buah tanaman Anethum graveolens yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020133,
    "Fenugreek, Kelabat, Kelabet, Klabat",
    "Fenugreek, kelabat, kelabet, klabat adalah produk yang diperoleh dari biji matang dan kering dari tanaman Trigonella foenumgraecum.",
    "Tidak Aktif",
  ],
  [
    12020134,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk",
    "Fenugreek bubuk, kelabat bubuk, kelabet bubuk, klabat bubuk adalah produk bubuk yang diperoleh dengan cara menggiling biji matang dan kering dari tanaman Trigonella foenumgraecum.",
    "Tidak Aktif",
  ],
  [
    12020135,
    "Fuli Kering",
    "Fuli kering adalah arillus yang berwarna merah yang terdapat diantara daging dan biji buah tanaman Myristica fragrans Hout yang telah dibersihkan kotorannya dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020136,
    "Fuli Bubuk",
    "Fuli bubuk adalah produk bubuk yang diperoleh dari arillus biji tanaman Myristica fragrans Hout yang telah dikeringkan dan digiling.",
    "Tidak Aktif",
  ],
  [
    12020137,
    "Jahe Segar",
    "Jahe segar adalah rimpang dari tanaman jahe (Zingiber officinale) yang sudah tua, berbentuk utuh dan segar serta dibersihkan.",
    "Tidak Aktif",
  ],
  [
    12020138,
    "Jahe Kering",
    "Jahe kering adalah produk rempah-rempah yang diperoleh dari rimpang dari tanaman jahe (Zingiber officinalle) yang telah dibersihkan berbentuk utuh atau irisan dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020139,
    "Bubur Jahe",
    "Bubur jahe adalah produk bubur yang diperoleh dari proses penggilingan rimpang dari tanaman jahe (Zingiber officinalle) segar atau kering yang baik dengan penambahan air bersih. Dapat mengandung garam dan vinegar.",
    "Aktif",
  ],
  [
    12020140,
    "Jahe Bubuk",
    "Jahe bubuk adalah produk bubuk yang diperoleh dari rimpang bersih tanaman Zingiber officinale yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020141,
    "Jintan/Caraway",
    "Jintan / caraway adalah biji kering yang diperoleh dari tanaman Carum carvi.",
    "Tidak Aktif",
  ],
  [
    12020142,
    "Jintan Bubuk",
    "Jintan bubuk adalah produk rempah-rempah yang diperoleh dari biji tanaman Carum carvi yang bersih, kering dan telah digiling.",
    "Tidak Aktif",
  ],
  [
    12020143,
    "Jintan Manis",
    "Jintan manis adalah produk rempah-rempah yang diperoleh dari buah matang tanaman Pimpinella anisum yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020144,
    "Jintan Hitam",
    "Jintan hitam adalah produk rempah-rempah yang diperoleh dari biji tanaman Nigella sativa yang bersih dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020145,
    "Jintan Hitam Bubuk",
    "Jintan hitam bubuk adalah produk bubuk yang diperoleh dengan<br> menggilling biji kering yang bersih dari tanaman Nigella sativa.",
    "Tidak Aktif",
  ],
  [
    12020146,
    "Jintan Putih, Cumin",
    "Jintan putih, cumin adalah produk rempah-rempah yang diperoleh dari buah kering tanaman Cuminum cyminum.",
    "Tidak Aktif",
  ],
  [
    12020147,
    "Jintan Putih Bubuk",
    "Jintan putih bubuk adalah produk bubuk yang diperoleh dari proses penggilingan biji kering tanaman Cuminum cyminum.",
    "Tidak Aktif",
  ],
  [
    12020148,
    "Kapulaga",
    "Kapulaga adalah rempah yang diperoleh dari buah kering yang masak dari tanaman Elettaria cardamomum.",
    "Tidak Aktif",
  ],
  [
    12020149,
    "Biji Kapulaga",
    "Biji kapulaga adalah rempah yang diperoleh dari biji kering yang diperoleh dengan pemisahan dari kapsul tanaman Elettaria cardamomum.",
    "Tidak Aktif",
  ],
  [
    12020150,
    "Kapulaga Lokal",
    "Kapulaga lokal adalah produk rempah yang diperoleh dari buah tanaman kapulaga lokal (Amomum cardamomum) yang sudah tua, telah dibuang tangkai buahnya, dibersihkan dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020151,
    "Kapulaga (Cardamom) Amomum",
    "Kapulaga (cardamom) amomum adalah rempah yang diperoleh dari buah tanaman Amomum subulatum yang telah matang dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020152,
    "Biji Kapulaga (Cardamom) Amomum",
    "Biji kapulaga (cardamom) amomum adalah rempah yang diperoleh dari biji buah Amomum subulatum yang telah dipisahkan dari kapsulnya.",
    "Tidak Aktif",
  ],
  [
    12020153,
    "Kapulaga Bubuk",
    "Kapulaga bubuk adalah produk bubuk yang diperoleh dari penggilingan biji kering bersih Elettaria cardamomum yang telah dipisahkan dari kapsulnya.",
    "Tidak Aktif",
  ],
  [
    12020154,
    "Kapulaga (Cardamom) Amomum Bubuk",
    "Kapulaga (cardamom) amomum bubuk adalah produk bubuk yang diperoleh dari penggilingan biji Amomum subulatum yang telah dipisahkan dari kapsulnya dan dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020155,
    "Kayu Manis",
    "Kayu manis adalah produk kering yang diperoleh dari kulit kayu bagian dalam tanaman Cinnamomum zeylanicum atau C. cassia atau C. burmanii atau C. sintok BI atau Cassia vera.",
    "Tidak Aktif",
  ],
  [
    12020156,
    "Kayu Manis Bubuk",
    "Kayu manis bubuk adalah produk bubuk yang diperoleh dari proses penggilingan kulit kayu bagian dalam tanaman Cinnamomum zeylanicum atau C. cassia atau C. burmanii atau C. sintok BI atau Cassia vera yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [12020157, "Kemiri Dengan Tempurung", "", "Tidak Aktif"],
  [
    12020158,
    "Kemiri",
    "Kemiri adalah rempah yang diperoleh dari daging biji kemiri (Alleurites mellucana (L) Wild) yang telah dipisahkan dari<br> tempurungnya.",
    "Tidak Aktif",
  ],
  [
    12020159,
    "Kencur",
    "Kencur adalah rimpang tanaman Kaempferia galanga L.",
    "Tidak Aktif",
  ],
  [
    12020160,
    "Kencur Bubuk",
    "Kencur bubuk adalah produk bubuk yang diperoleh dari rimpang tanaman kencur yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020161,
    "Ketumbar",
    "Ketumbar adalah buah tanaman Coriandrum sativum masak yang kering.",
    "Tidak Aktif",
  ],
  [
    12020162,
    "Daun Ketumbar",
    "Daun ketumbar adalah herba yang diperoleh dari daun tanaman Coriandrum sativum Linn.",
    "Tidak Aktif",
  ],
  [
    12020163,
    "Ketumbar Bubuk",
    "Ketumbar bubuk adalah produk bubuk yang diperoleh dari proses penggilingan buah kering tanaman Coriandrum sativum Linn. yang dibersihkan.",
    "Tidak Aktif",
  ],
  [
    12020164,
    "Picung",
    "Picung adalah produk buah tanaman Pangium edule.",
    "Tidak Aktif",
  ],
  [
    12020165,
    "Kluwek",
    "Kluwek adalah produk buah tanaman Pangium edule yang telah mengalami pengolahan dan pematangan.",
    "Tidak Aktif",
  ],
  [
    12020166,
    "Kunyit",
    "Kunyit adalah rimpang Curcuma domestica atau Curcuma longa.",
    "Tidak Aktif",
  ],
  [
    12020167,
    "Kunyit Bubuk",
    "Kunyit bubuk adalah produk bubuk yang diperoleh dari proses penggiligan rimpang kering Curcuma longa atau Curcuma domestica.",
    "Tidak Aktif",
  ],
  [
    12020168,
    "Lada Hitam",
    "Lada hitam adalah rempah yang diperoleh dari buah tanaman Piper nigrum Linn yang dipetik setelah sebagian besar buah lada matang dan telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020169,
    "Lada Hitam Bubuk",
    "Lada hitam bubuk adalah produk rempah yang diperoleh dari proses penggilingan lada hitam.",
    "Tidak Aktif",
  ],
  [
    12020170,
    "Lada Putih",
    "Lada putih adalah rempah buah tanaman Piper nigrum Linn. yang dipetik setelah sebagian besar buah lada matang penuh, kemudian dihilangkan kulit luarnya, dikeringkan dan dibersihkan.",
    "Tidak Aktif",
  ],
  [
    12020171,
    "Lada Putih Bubuk",
    "Lada putih bubuk adalah produk rempah yang diperoleh dari lada putih yang telah digiling.",
    "Tidak Aktif",
  ],
  [
    12020172,
    "Lada Bubuk Campuran",
    "Lada bubuk campuran adalah produk rempah yang diperoleh dari<br> campuran lada bubuk hitam dan lada bubuk putih.",
    "Tidak Aktif",
  ],
  [12020173, "Andaliman", "", "Tidak Aktif"],
  [
    12020174,
    "Lengkuas/Laos",
    "Lengkuas/laos adalah rimpang tanaman Alpinia galanga, Linn Sw.",
    "Tidak Aktif",
  ],
  [
    12020175,
    "Lengkuas/Laos Bubuk",
    "Lengkuas / laos bubuk adalah produk bubuk yang diperoleh dari rimpang bersih tanaman lengkuas yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020176,
    "Kecombrang/Sambuang/Kincong/Honje",
    "adalah bunga tanaman<br> Etlingera elatior (jack) R.M Sm.",
    "Tidak Aktif",
  ],
  [
    12020177,
    "Marjoram",
    "Marjoram adalah produk berbentuk utuh atau bubuk yang diperoleh dari daun Marjoram hortensis Moench yang dikeringkan, dengan atau tanpa pucuk bunga.",
    "Tidak Aktif",
  ],
  [
    12020178,
    "Mint",
    "Mint adalah produk herba yang diperoleh dari tanaman Mentha<br> arvensis atau Mentha piperit",
    "Tidak Aktif",
  ],
  [
    12020179,
    "Onion/Bawang Bombay",
    "Onion / bawang bombay adalah umbi dari tanaman bawang bombay Allium sp.",
    "Tidak Aktif",
  ],
  [12020180, "Onion Bubuk/Bawang Bombay Bubuk", "", "Tidak Aktif"],
  [
    12020181,
    "Oregano",
    "Oregano adalah produk herba berbentuk utuh atau bubuk yang diperoleh dari daun Origantum vulgare sp. yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020182,
    "Pala",
    "Pala adalah biji kering tanaman Myristica fragrans Hout dan dikupas kulit batoknya, berbentuk bulat atau lonjong dengan panjang 20 mm hingga 40 mm.",
    "Tidak Aktif",
  ],
  [
    12020183,
    "Pala Untuk Destilasi",
    "Pala untuk destilasi adalah produk rempah biji yang berasal dari buah tanaman Myristica fragrans yang dipetik pada waktu muda (berumur 2 hingga 5 bulan).",
    "Tidak Aktif",
  ],
  [
    12020184,
    "Pala Bubuk",
    "Pala bubuk adalah produk bubuk yang diperoleh dari biji kering tanaman Myristica fragrans",
    "Tidak Aktif",
  ],
  [
    12020185,
    "Parsley",
    "Parsley adalah daun dari tanaman Petroselinum hortense yang telah dikeringkan. Daun berwarna hijau terang.",
    "Tidak Aktif",
  ],
  [
    12020186,
    "Paprika Bubuk",
    "Paprika bubuk adalah produk rempah yang diperoleh dari buah matang tanaman Capsicum annuum yang telah dibersihkan, dikeringkan dan digiling.",
    "Tidak Aktif",
  ],
  [
    12020187,
    "Sweet Paprika Bubuk",
    "Sweet paprika bubuk adalah produk rempah yang diperoleh dari<br> campuran buah matang tanaman Capsicum annuum dan Capsicum longum yang telah dibersihkan, dikeringkan dan digiling.",
    "Tidak Aktif",
  ],
  [
    12020188,
    "Rosemari",
    "Rosemari adalah produk berbentuk utuh atau bubuk yang diperoleh dari daun Rosemarinus officinalis L yang dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020189,
    "Saga",
    "Saga adalah produk berbentuk utuh atau bubuk yang diperoleh dari<br> daun saga atau tanaman Abrus precatorius, Linn atau Salvia<br> officinalis L atau Salvia triloba L atau Salvia lavandulaefolia Vahl.",
    "Tidak Aktif",
  ],
  [
    12020190,
    "Saffron",
    "Saffron adalah stigmata atau pucuk bunga dari tanaman Crocus sativus yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020191,
    "Pekak/Bunga Lawang/Star Anise",
    "Pekak / bunga lawang /star anise adalah buah dari tanaman Illicium verum yang telah dikeringkan.",
    "Tidak Aktif",
  ],
  [
    12020192,
    "Temu Kunci",
    "Temu kunci adalah rimpang dari tanaman Gastrochillus panduratum yang telah dibersihkan.",
    "Tidak Aktif",
  ],
  [
    12020194,
    "Thymi/Thyme",
    "Thymi / thyme adalah herba yang diperoleh dari daun pucuk kering thymi dari tanaman Thymus vulgaris atau Thymus zugis L baik dalam bentuk utuh atau bubuk.",
    "Tidak Aktif",
  ],
  [12020195, "Bawang Goreng", "-", "Aktif"],
  [
    12020196,
    "Daun Jeruk Purut (Kaffir lime)",
    "Daun jeruk purut adalah produk herba yang diperoleh dari daun tanaman Citrus aerauntifolia.",
    "Tidak Aktif",
  ],
  [
    12020197,
    "Daun Pandan",
    "Daun pandan adalah produk herba yang diperoleh dari tanaman<br> Pandanus amaryllifolius Roxb.",
    "Tidak Aktif",
  ],
  [
    12020198,
    "Akar Chicory",
    "Akar chicory adalah produk herba yang diperoleh dari akar tanaman Cichorium intybus L.",
    "Tidak Aktif",
  ],
  [
    12020199,
    "Asam Sunti",
    "Asam sunti adalah produk rempah yang diperoleh dari buah masak tanaman Averrhoa bilimbi yang dikeringkan.",
    "Tidak Aktif",
  ],
  [
    "120201A1",
    "Bergamot",
    "Bergamot adalah produk herba yang diperoleh dari daun tanaman Monarda didyma.",
    "Tidak Aktif",
  ],
  [
    "120201A2",
    "Daun Peterseli",
    "Daun peterseli adalah produk herba yang diperoleh dari tanaman Petroselinum crispum",
    "Tidak Aktif",
  ],
  [
    "120201A3",
    "Daun Sembung",
    "Daun sembung adalah produk herba yang diperoleh dari tanaman<br> Blumea balsamifera (L) Dc.",
    "Tidak Aktif",
  ],
  [
    "120201A4",
    "Daun Suji",
    "Daun suji adalah produk herba yang diperoleh dari tanaman<br> Pleomele angustifolia N.E. Brown.",
    "Tidak Aktif",
  ],
  [
    "120201A5",
    "Lempuyang",
    "Lempuyang adalah produk yang diperoleh dari rimpang tanaman<br> Zingiber zerumbet.",
    "Tidak Aktif",
  ],
  [
    "120201A6",
    "Mesoyi",
    "Mesoyi adalah produk herba yang diperoleh dari biji tanaman<br> Cinnamomum sintoc atau Masoya aromatica",
    "Tidak Aktif",
  ],
  [
    "120201A7",
    "Sereh",
    "Sereh adalah produk herba yang diperoleh dari batang tanaman<br> Cymbopogon citrates (DC) Stapt",
    "Tidak Aktif",
  ],
  [
    "120201A8",
    "Wasabi",
    "Wasabi adalah produk yang diperoleh dari rimpang tanaman<br> Wasabia japonica",
    "Tidak Aktif",
  ],
  [
    "120201A9",
    "Wijen",
    "Wijen adalah produk yang diperoleh dari biji tanaman Sesamum<br> indicum L. syn./Sesamum orientalis L.",
    "Tidak Aktif",
  ],
  [
    "120201B3",
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan",
    "Memfasilitasi pendaftaran pangan olahan selain PSAT",
    "Aktif",
  ],
  [
    12020203,
    "Bubuk Ngohyang",
    "Bubuk ngohyang adalah campuran dari 5 macam rempah antara lain : bunga lawang, kayu manis, lada hitam, jintan dan cengkeh.",
    "Aktif",
  ],
  [
    12020205,
    "Bumbu Siap Pakai",
    "Bumbu siap pakai adalah produk bumbu yg diperoleh dari campuran rempah dg atau tanpa penambahan minyak untuk membuat masakan tertentu. Produk dapat ditambahkan bahan pangan lain. Produk dapat dikemas dalam kemasan plastik atau botol plastik atau botol kaca atau kemasan lainnya dan dapat diawetkan dengan pemanasan. bumbu siap pakai dapat berukuran basah atau kering",
    "Aktif",
  ],
  [
    12020206,
    "Furikake",
    "Furikake adalah taburan diatas nasi yang antara lain mengandung serpihan rumput laut kering, biji sesame dan bumbu lain.",
    "Tidak Aktif",
  ],
  [12020208, "Bumbu Mi Instan", "", "Tidak Aktif"],
  [12020209, "Bumbu Siap Pakai (Steril)", "&nbsp;", "Tidak Aktif"],
  [
    12020210,
    "Ragi Kering (Tidak Aktif)",
    "Regi Kering (Tidak Aktif) adalah produk yang dibuat dengan cara membiakkan kamir jenis Saccharomyces cerevisiae, Saccharomyces fragilis, dan Candida utilis dalam media serealia atau bahan lain yang sesuai, dalam keadaan bersih, kering, tidak aktif serta berfungsi sebagai bumbu dan kondimen.<br> Kadar air tidak lebih dari 7%.",
    "Aktif",
  ],
  [
    12020211,
    "Bawang Hitam",
    "Bawang hitam adalah produk yang diperoleh dari bawang putih<br> segar (Allium sativum L.) yang dipanaskan pada suhu umumnya 60-90\\xB0C dan kelembaban tinggi dalam waktu kurang lebih 1 bulan<br> sehingga dihasilkan siung bawang dengan warna gelap/hitam, rasa<br> manis, dan tekstur yang kenyal.<br> <br> Karakteristik Dasar:<br> Kadar air tidak lebih dari 50%",
    "Aktif",
  ],
  [
    12020212,
    "Bumbu Ekstrak Daging Sapi",
    "Bumbu ekstrak daging sapi adalah produk bumbu yang mengandung ekstrak daging sapi, dengan penambahan bahan pangan lain dalam bentuk bubuk atau blok/kubus.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar air tidak lebih dari 4%<br> \x{2022} Kadar protein tidak kurang dari 7%",
    "Aktif",
  ],
  [
    12020213,
    "Bumbu Rasa Sapi",
    "Bumbu rasa sapi adalah produk bumbu yang mengandung perisa daging sapi, dengan penambahan bahan pangan lain dan dalam bentuk bubuk atau blok/kubus.",
    "Aktif",
  ],
  [
    12020214,
    "Bumbu Ekstrak Daging Ayam",
    "Bumbu ekstrak daging ayam adalah produk bumbu yang mengandung ekstrak daging ayam baik dalam bentuk bubuk atau blok/kubus.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar air tidak lebih dari 4%<br> \x{2022} Kadar protein tidak kurang dari 6%",
    "Aktif",
  ],
  [
    12020215,
    "Bumbu Ekstrak Udang",
    "Bumbu ekstrak udang adalah produk bumbu yang mengandung udang baik dalam bentuk bubuk atau blok/kubus.<br> <br> Karakteristik dasar:<br> \x{2022} Kadar air tidak lebih dari 4%<br> \x{2022} Kadar udang tidak kurang dari 15%",
    "Aktif",
  ],
  [
    12020216,
    "Bumbu Ekstrak Cumi",
    "Bumbu ekstrak cumi adalah produk bumbu yang mengandung cumi dalam bentuk bubuk atau blok/kubus.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar air tidak lebih dari 4%<br> \x{2022} Kadar cumi tidak kurang dari 15%",
    "Aktif",
  ],
  [
    12020217,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam)",
    "Karakteristik dasar :<br> Kadar air tidak lebih dari 12,5%.<br>",
    "Aktif",
  ],
  [
    12020218,
    "Bumbu Rasa Ikan",
    "Bumbu rasa ikan adalah produk bumbu yang mengandung perisa ikan baik dalam bentuk bubuk atau blok/kubus.",
    "Aktif",
  ],
  [
    12020219,
    "Bumbu Rasa Udang",
    "Bumbu rasa udang adalah produk bumbu yang mengandung perisa udang baik dalam bentuk bubuk atau blok/kubus.",
    "Aktif",
  ],
  [
    12020220,
    "Bumbu Rasa Ayam",
    "Bumbu rasa ayam adalah produk bumbu yang mengandung perisa ayam baik dalam bentuk bubuk atau blok/kubus.",
    "Aktif",
  ],
  [
    12020221,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju",
    "Bubuk/blok/kubus/pasta ekstrak ayam/sapi/udang/keju adalah produk yang mengandung ayam/sapi/udang/keju baik dalam bentuk bubuk/blok/kubus/pasta dengan atau tanpa penambahan bahan pangan lain. Produk ini tanpa penambahan rempah",
    "Aktif",
  ],
  [
    120301,
    "Cuka Fermentasi, Vinegar",
    "Cuka fermentasi, vinegar adalah produk cair yang mengandung asam asetat, yang diperoleh melalui proses fermentasi bahan-bahan yang mengandung karbohidrat atau alkohol. Contoh : cuka apel,<br> cuka anggur.<br> <br> Karakteristik dasar :<br> Total asam tidak kurang dari 4 g/100 ml",
    "Aktif",
  ],
  [
    120302,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja)",
    "Cuka hasil pengenceran asam asetat glasial adalah produk cair yang diperoleh dari pengenceran asam asetat glasial (untuk makanan dan farmasi) dengan air minum.<br> Contoh : Cuka makan.<br> <br> Karakteristik dasar :<br> \x{2022} Bentuk cairan encer, jernih, tidak berwarna, bau khas asam asetat<br> \x{2022} Cuka meja : kadar asam asetat tidak kurang dari 4% dan tidak lebih dari 12,5 % v/b",
    "Aktif",
  ],
  [
    120303,
    "Arak Masak (Angciu)",
    "Arak masak adalah produk yang diperoleh dari hasil fermentasi beras, dapat diikuti dengan proses penyulingan, berwarna bening hingga bening kecoklatan dengan aroma ragi yang tajam, ditambahkan garam dan/atau rempah-rempah dan/atau bahan pangan lain yang menimbulkan rasa, digunakan sebagai penambah rasa pada hidangan oriental. Pada label wajib dicantumkan kadar alkohol dan keterangan 'hanya untuk memasak'.",
    "Aktif",
  ],
  [
    120304,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur)",
    "Cuka hasil pengenceran asam asetat glasial adalah produk cair yang diperoleh dari pengenceran asam asetat glasial (untuk makanan dan farmasi) dengan air minum. Contoh : Cuka makan.<br> <br> Karakteristik dasar :<br> \x{2022} Bentuk cairan encer, jernih, tidak berwarna, bau khas asam asetat<br> \x{2022} Cuka dapur : kadar asam asetat tidak kurang dari 12,5 % v/b<br>",
    "Aktif",
  ],
  [
    1204,
    "Mustard",
    "Produk kondimen yang disiapkan<br> dari biji mustard yang ditumbuk, umumnya dari biji mustard yang<br> telah ditumbuk dan dihilangkan minyaknya, yang dicampur/diolah<br> dengan menambahkan air, vinegar/cuka, garam, dan rempah-rempah<br> menjadi saus/pasta yang berwarna kuning cerah sampai kecoklatan.<br> Contoh : mustard Dijon dan mustard pedas (hot mustard) yang diperoleh dari biji dan kulit mustard.",
    "Aktif",
  ],
  [
    12050101,
    "Sari Pati Ayam",
    "Sari pati ayam adalah ekstrak karkas ayam pedaging dengan atau tanpa penambahan garam, sari simplisia, dalam bentuk siap dikonsumsi.<br> <br> Karakteristik dasar:<br> \x{2022} Bentuk cairan jernih<br> \x{2022} Kadar protein tidak kurang dari 7,7%<br>",
    "Aktif",
  ],
  [
    12050102,
    "Kaldu dan Konsome",
    "produk yang diperoleh dari daging sapi,<br> daging unggas, atau daging lainnya dengan cara memasak bahan kaya protein atau sarinya dan atau hidrolisatnya dengan air dengan atau tanpa penambahan bumbu dan atau bahan penyedap, lemak yang dapat dimakan, natrium klorida, rempah-rempah dan sari-sari alami atau destilatnya atau bahan makanan lain untuk meningkatkan rasa, atau dengan rekonstitusi dari campuran<br> komponen kering yang sesuai dengan petunjuk penggunaan.",
    "Aktif",
  ],
  [
    12050103,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll)",
    "",
    "Aktif",
  ],
  [12050105, "Sup Siap Saji", "", "Aktif"],
  [
    12050201,
    "Sup Instan",
    "Sup instan adalah produk pangan olahan kering instan yang dapat dibuat dari daging, ikan, sayuran, serealia atau campurannya, yang siap dikonsumsi setelah diseduh dengan air mendidih. Dapat ditambahkan bahan pangan lain.",
    "Aktif",
  ],
  [
    12050202,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan)",
    "Karakteristik dasar : Kadar air tidak lebih dari 12,5%",
    "Aktif",
  ],
  [
    12050203,
    "Sup Krim Instan",
    "Sup krim instan adalah produk pangan olahan kering instan yang dibuat dari tepung nabati dan atau hewani, yang siap dikonsumsi setelah diseduh dengan air mendidih menjadi larutan kental. Dapat ditambahkan bahan pangan lain.<br> Karakteristik dasar :Kadar air tidak lebih dari 8%",
    "Aktif",
  ],
  [
    12050204,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan)",
    "Karakteristik dasar :Kadar air tidak lebih dari 12,5%",
    "Aktif",
  ],
  [
    12050205,
    "Bumbu Ekstrak Daging Sapi",
    "Bumbu ekstrak daging sapi adalah produk bumbu yang mengandung ekstrak daging sapi, dengan penambahan bahan pangan lain dalam bentuk bubuk atau blok/kubus.",
    "Tidak Aktif",
  ],
  [
    12050206,
    "Bumbu Rasa Sapi",
    "Bumbu rasa sapi adalah produk bumbu yang mengandung perisa daging sapi, dengan penambahan bahan pangan lain dan dalam bentuk bubuk atau blok/kubus.",
    "Tidak Aktif",
  ],
  [
    12050207,
    "Bumbu Ekstrak Daging Ayam",
    "Bumbu ekstrak daging ayam adalah produk bumbu yang mengandung ekstrak daging ayam baik dalam bentuk bubuk atau blok/kubus.",
    "Tidak Aktif",
  ],
  [
    12050208,
    "Bumbu Rasa Ayam",
    "Bumbu rasa ayam adalah produk bumbu yang mengandung perisa daging ayam baik dalam bentuk bubuk atau blok/kubus.",
    "Tidak Aktif",
  ],
  [
    12050209,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam)",
    "Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Bau dan rasa normal<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 12,5%",
    "Tidak Aktif",
  ],
  [12050210, "Bumbu Lainnya (Basah)", "&nbsp;", "Tidak Aktif"],
  [12050211, "Bumbu Lainnya (Kering)", "&nbsp;", "Tidak Aktif"],
  [
    12050212,
    "Bumbu Penguat Rasa dan Garam",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    12050213,
    "Sup Instan (Steril)",
    "Sup instan adalah produk pangan olahan kering instan yang dapat dibuat dari daging, ikan, sayuran, serealia atau campurannya, yang siap dikonsumsi setelah diseduh dengan air mendidih diproses secara steril. Dapat ditambahkan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    12050214,
    "Sup Instan Dalam Kaleng",
    "Sup instan adalah produk pangan olahan kering instan yang dapat dibuat dari daging, ikan, sayuran, serealia atau campurannya, yang siap dikonsumsi setelah diseduh dengan air mendidih diproses secara steril (dalam kaleng). Dapat ditambahkan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    12050215,
    "Bumbu Rasa Ikan",
    "Bumbu rasa ikan adalah produk bumbu yang mengandung perisa<br> ikan baik dalam bentuk bubuk atau blok/kubus.<br>",
    "Tidak Aktif",
  ],
  [
    12050216,
    "Bumbu Rasa Udang",
    "Bumbu rasa udang adalah produk bumbu yang mengandung perisa<br> udang baik dalam bentuk bubuk atau blok/kubus.",
    "Tidak Aktif",
  ],
  [
    12060101,
    "Mayonais, Mayonnaise",
    "Mayonais adalah saus kondimen yang diperoleh dengan cara mengemulsikan minyak nabati dalam fase air yang mengandung<br> vinegar atau asam cuka atau pengasam lainnya dengan penambahan telur dalam bentuk segar, cair, bubuk, atau beku<br> untuk menghasilkan emulsi, dengan atau tanpa penambahan bahan pangan lain.<br> Bahan pangan lain yang dapat digunakan antara lain gula, garam, kondimen, rempah-rempah dan herba, buah dan sayuran termasuk jus buah dan jus sayuran, biji sawi/biji mustard, produk-produk susu, air.<br> <br> Karakteristik dasar :<br> Kadar lemak total tidak kurang dari 65%",
    "Aktif",
  ],
  [
    12060102,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll)",
    "Salad dressing adalah produk emulsi semisolid yang dibuat dari minyak nabati dengan penambahan bahan pengasam, dengan satu atau lebih ingredien yang mengandung kuning telur, putih telur dan pasta berpati. Ingredien mengandung kuning telur meliputi kuning",
    "Aktif",
  ],
  [
    12060103,
    "Saus Tar Tar (Tar Tar Sauce)",
    "Saus Tar Tar adalah saus yang berasal dari mayonais yang<br> ditambahkan bawang bombay dan acar mentimun, dengan atau<br> tanpa penambahan mentimun segar.<br> Karakteristik dasar :<br> Kadar lemak total tidak kurang dari 50%",
    "Aktif",
  ],
  [
    12060104,
    "French Dressing",
    "French dressing adalah saus kondimen yang merupakan produk<br> cairan yang dapat dipisahkan atau emulsi cairan yang dibuat dari<br> minyak makan dan satu atau lebih pengasam. Ingredien yang dapat<br> digunakan adalah vinegar atau vinegar encer atau vinegar, jus<br> lemon dan atau jus jeruk nipis, garam, pemanis nutritif rempah<br> atau perisa alami, pasta tomat, puree tomat, saus tomat, sherry<br> wine, telur.<br> Karakteristik dasar :<br> Kadar lemak total tidak kurang dari 35%",
    "Aktif",
  ],
  [12060105, "Sweet Mayo", "", "Tidak Aktif"],
  [12060106, "Saus Bumbu Teremulsi", "&nbsp;", "Aktif"],
  [
    12060107,
    "(Saus Teremulsi) untuk Saus Mayo",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    12060108,
    "Sandwich Spread",
    "Sandwich Spread adalah produk oles sandwich yang dibuat dari mayonais sebagai bahan dasar, paprika, dan acar mentimun.",
    "Aktif",
  ],
  [
    12060201,
    "Saus Cabe",
    "Saus cabe adalah produk saus siap konsumsi yang dibuat dari cabe<br> (Capsicum sp) atau turunannya, berbentuk cairan kental homogen,<br> yang telah mengalami proses pemanasan.",
    "Aktif",
  ],
  [12060202, "Sambal Kecap/Saus Sambal Kecap", "", "Tidak Aktif"],
  [
    12060203,
    "Saus Sambal Cabe Hijau",
    "Sambal adalah produk campuran cabe dengan bahan pangan lain yang<br> digunakan sebagai penyedap makanan<br> Sambal Siap Dikonsumsi : Termasuk diantaranya sambal bajak, sambal terasi, sambal kemiri, sambal rujak, sambal seafood, dan sambal lainnya.<br> Saus protein na",
    "Tidak Aktif",
  ],
  [
    12060205,
    "Sambal Siap Dikonsumsi",
    "Sambal Siap Dikonsumsi adalah produk siap konsumsi yang dibuat dari bahan<br> utama cabe (Capsicum sp) dengan penambahan bahan pangan lain,<br> berbentuk semi padat, dan telah mengalami proses pemasakan atau<br> pengawetan lain. Meliputi semua jenis sambal antara lain sambal<br> terasi, sambal bajak, sambal petai, sambal cabai hijau, tidak<br> termasuk cabe bubuk, cabe giling, saus cabe dan sambal yang<br> digunakan sebagai bumbu masak. Termasuk diantaranya sambal bajak, sambal terasi, sambal kemiri, sambal rujak, sambal seafood, dan sambal lainnya.",
    "Aktif",
  ],
  [
    12060208,
    "Saus Gado-gado",
    "Saus gado-gado adalah produk saus yang diperoleh dari kacang tanah yang telah digoreng atau disangrai dan dihaluskan dengan penambahan garam, gula atau bahan pangan lain dan rempah-rempah tertentu yang sesuai.",
    "Tidak Aktif",
  ],
  [
    12060209,
    "Saus Keju (Cheese Sauce)",
    "Saus keju adalah produk saus yang diperoleh dari keju dengan<br> penambahan garam, mustard dan bumbu.",
    "Aktif",
  ],
  [
    12060210,
    "Saus Lobak",
    "Saus lobak adalah produk saus yang diperoleh dari lobak yang diiris atau dihancurkan, dicampur dengan jus orange, air jeruk nipis, cilantro, minyak, garam dan lada.",
    "Aktif",
  ],
  [
    12060211,
    "Saus Panggang/Saus Barbekue (BBQ Sauce)",
    "Saus panggang/saus barbekue (BBQ sauce) adalah produk saus yang diperoleh dari campuran vinegar, gula, garam, saus worchester dan rempah-rempah seperti bawang putih, onion, paprika dan lada hitam dengan atau tanpa saus tomat atau pasta tomat, bahan pangan lainnya",
    "Aktif",
  ],
  [
    12060212,
    "Saus Pizza",
    "Saus pizza adalah produk saus yang diperoleh dari pasta tomat, saus tomat yang diberi garam dan rempah-rempah seperti biji anis, lada, bubuk bawang putih, oregano dan parsley.",
    "Aktif",
  ],
  [12060213, "Saus Sate", "", "Tidak Aktif"],
  [
    12060214,
    "Saus Spagheti (Spaghetti Sauce)",
    "Saus spagheti (spaghetti sauce) adalah produk saus yang diperoleh campuran rempah-rempah seperti bawang putih, bawang bombay, lada hitam, daun basil, oregano, thymi, gula, garam, vinegar dengan atau tanpa saus tomat atau pasta tomat, dan bahan pangan lainnya",
    "Aktif",
  ],
  [
    12060215,
    "Saus Tiram",
    "Saus tiram adalah produk cairan kental berwarna coklat sampai coklat kehitam-hitaman, diperoleh dari hasil olahan daging tiram (Crassostera calculata sp.) dengan penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    12060216,
    "Saus Perendam/Saus Marinasi (Marinated Sauce)",
    "Saus perendam/saus marinasi adalah produk saus yang digunakan untuk merendam ikan, daging, ayam, atau bahan pangan lainnya untuk memberi rasa dan aroma tertentu sebelum diolah lebih lanjut.",
    "Aktif",
  ],
  [
    12060217,
    "Saus Tomat",
    "Saus tomat adalah produk saus yang diperoleh dari buah segar, bubur tomat, pasta tomat, puree tomat atau padatan tomat, yang dicampur dengan gula, bahan pengasam, garam dan dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> Bau, rasa dan warna khas",
    "Aktif",
  ],
  [
    12060218,
    "Kecap Inggeris, Saus Worchester",
    "Kecap Inggeris, saus worchester adalah produk saus yang terdiri dari air, vinegar, garam dan rempah atau bahan pangan lainnya. Digunakan untuk memberi flavor dan saus barbekue serta saus asam manis.",
    "Aktif",
  ],
  [12060219, "Kecap Kelapa", "", "Aktif"],
  [12060220, "Sambal Terasi", "&nbsp;", "Aktif"],
  [
    12060221,
    "Saus Asam Manis",
    "Saus asam manis adalah produk saus yang terbuat dari tomat dan atau buah lain, gula dan bahan pengasam, dengan atau tanpa penambahan bahan pangan lain. Produk ini mempunyai rasa asam dan manis.",
    "Aktif",
  ],
  [12060222, "Saus Bumbu Non-Emulsi Lainnya", "-", "Aktif"],
  [
    12060223,
    "Saus Tomat Steril Komersial",
    "Saus tomat adalah produk saus yang diperoleh dari buah segar, bubur tomat, pasta tomat, puree tomat atau padatan tomat, yang dicampur dengan gula, bahan pengasam, garam dan dengan atau tanpa penambahan bahan pangan lain, diolah dengan proses sterilisai komersial.<br> Karakteristik dasar :<br> Bau, rasa dan warna khas",
    "Tidak Aktif",
  ],
  [
    12060224,
    "Saus Bumbu Non-Emulsi Steril (Aseptis)",
    "-",
    "Tidak Aktif",
  ],
  [
    12060225,
    "Saus Bumbu Non-Emulsi dalam Kaleng",
    "",
    "Tidak Aktif",
  ],
  [
    12060226,
    "Gochujang (Saus Fermentasi)",
    "Gochujang adalah pangan fermentasi berbentuk pasta yang berwarna merah atau warna gelap yang dihasilkan melalui fermentasi terhadap campuran bahan hasil sakarifikasi dengan garam, bubuk cabai merah, dan bahan pangan lain, yang dikemas secara kedap (hermetis) dan diproses dengan pemanasan untuk mencegah kebusukan. Bahan hasil sakarifikasi dihasilkan melalui sakarifikasi pati dengan malt atau dengan menumbuhkan Aspergillus sp (yang tidak patogen dan tidak menghasilkan toksin) pada biji-bijian.<br> <br> Kategori Pangan ini statusnya diubah menjadi Tidak Aktif, berdasarkan kajian terbaru dari Direktorat Standarisasi Pangan maka produk Gochujang masuk ke dalam kategori pangan Gochujang (0402020709).",
    "Tidak Aktif",
  ],
  [
    12060227,
    "Bumbu Kacang",
    "Bumbu kacang adalah bumbu yang terbuat dari kacang tanah yang telah digoreng atau disangrai dan dihaluskan dengan penambahan garam, gula atau bahan pangan lain dan rempah-rempah tertentu yang sesuai, dan langsung digunakan tanpa ditambah air terlebih dahulu. Nama jenis untuk produk ini antara lain bumbu gado-gado, bumbu pecel, bumbu sate, bumbu siomay, bumbu batagor, dan lain-lain.<br>",
    "Aktif",
  ],
  [
    12060228,
    "Saus Teriyaki",
    "Saus teriyaki adalah produk saus yang diperoleh dari campuran<br> kecap dengan bahan pangan yang sesuai.<br> Karakteristik dasar :<br> Bau dan rasa normal<br>",
    "Aktif",
  ],
  [
    12060229,
    "Saus Toping/Saus Siram",
    "Saus toping/saus siram adalah produk saus yang diperoleh dari campuran rempah-rempah dengan atau tanpa penambahan saus tomat atau pasta tomat dan dengan atau tanpa penambahan bahan pangan lain untuk digunakan sebagai toping atau siram pada masakan dengan atau tanpa dimasak terlebih dahulu. Misalnya: saus jamur, dan saus lainnya.<br>",
    "Aktif",
  ],
  [
    12060230,
    "Saus Salsa",
    "Saus salsa adalah saus yang mengandung cacahan tomat dan cabe, serta dapat ditambahkan bahan pangan lain.<br>",
    "Aktif",
  ],
  [12060231, "Saus Tinta Cumi", "-", "Aktif"],
  [
    12060232,
    "Saus Putih (Berbasis Krim)",
    "Saus putih (berbasis krim) adalah saus yang mengandung bahan<br> utama susu atau krim dengan sedikit penambahan lemak dan<br> tepung dengan atau tanpa bumbu atau rempah.",
    "Aktif",
  ],
  [
    120603,
    "Campuran Untuk Saus, Gravies, dan Dressing",
    "\"Produk konsentrat, biasanya berbentuk bubuk, untuk nantinya<br> dicampurkan dengan air, susu, minyak ataupun cairan lain untuk<br> menghasilkan produk siap saji berupa saus, gravies dan dressing.<br> Termasuk di dalamnya konsentrat dari saus teremulsi ataupun saus<br> non emulsi. Termasuk dalam kategori ini antara lain bumbu kacang<br> yang harus ditambah air sebelum digunakan\"<br>",
    "Aktif",
  ],
  [
    12060401,
    "Kecap Ikan",
    "Kecap ikan adalah produk cair yang diperoleh dari hasil fermentasi ikan atau hidrolisis dengan atau tanpa penambahan pangan lain.",
    "Aktif",
  ],
  [
    12060402,
    "Saus Tiram Bening",
    "Saus tiram bening adalah produk cairan bening, diperoleh dari hasil<br> olahan daging tiram (Crassostrea calculata sp.) dengan penambahan<br> bahan pangan lain<br>",
    "Aktif",
  ],
  [
    120701,
    "Produk Oles Untuk Salad",
    "Termasuk bahan-bahan salad, produk oles sandwich berbasis susu, produk oles sandwich menyerupai mayonais, dan dressing untuk<br> coleslaw (salad kubis), olesan roti rasa pedas, saus rasa bawang<br> (French onion dip), saus untuk salad (guacamole style dip), saus<br> savoury.",
    "Aktif",
  ],
  [
    120703,
    "Olesan/Saus",
    "Olesan/saus adalah produk berupa emulsi atau non emulsi yang<br> tidak termasuk kategori 12.6, mempunyai rasa savoury (gurih<br> manis), pedas, asam, atau rasa lain dan digunakan untuk olesan<br>",
    "Aktif",
  ],
  [
    120801,
    "Ragi Roti Kering",
    "Ragi roti kering adalah produk yang dibuat dengan cara membiakkan kamir jenis Saccharomyces cereviceae dalam media serealia atau bahanlain yang sesuai, dalam keadaan bersih, kering dan mempunyai kemampuan meragikan adonan tepung terigu dengan atau tanpa campuran tepung lain pada pembuatan roti dan kue. Ragi roti kering berbentuk serbuk atau butiran, berwarna kekuningan sampai kecoklatan.<br> Karakteristik dasar:Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    120802,
    "Ragi Tape",
    "Ragi tape adalah produk yang dibuat dari tepung beras yang telah<br> dicampur dengan beberapa rempah-rempah untuk menstimulir<br> pertumbuhan kapang dan kamir yang telah dikeringkan dan<br> berperan dalam pembuatan tape.",
    "Aktif",
  ],
  [
    120803,
    "Ragi Tempe",
    "Ragi tempe adalah produk yang dibuat dari bahan sumber<br> karbohidrat (pati) yang mengandung kapang Rhizopus oligosporus<br> yang telah dikeringkan dan digunakan dalam pembuatan tempe.",
    "Aktif",
  ],
  [
    120804,
    "Ragi Roti Semi Kering",
    "Ragi roti semi kering adalah produk yang dibuat dengan cara membiakkan kamir jenis Saccharomyces cereviceae dalam media serealia atau bahan lain yang sesuai, dalam keadaan bersih, semi kering dan mempunyai kemampuan meragikan adonan tepung terigu dengan atau tanpa campuran tepung lain pada pembuatan roti dan kue. Ragi roti semi kering berbentuk serbuk atau butiran, berwarna kekuningan sampai kecoklatan.<br> Karakteristik dasar :<br> Kadar air lebih dari 5% sampai dengan 20%",
    "Aktif",
  ],
  [
    120805,
    "Ragi Roti Padat (compressed yeast)",
    "Ragi roti padat adalah produk yang dibuat dengan cara membiakkan kamir jenis Saccharomyces cereviceae dalam media serealia atau bahan lain yang sesuai, dalam keadaan bersih, berbentuk padat dan mempunyai kemampuan meragikan adonan tepung terigu dengan atau tanpa campuran tepung lain pada pembuatan roti dan kue. Ragi roti padat berwarna kekuningan sampai kecoklatan.<br> Karakteristik dasar :<br> Kadar air 63% - 70%",
    "Aktif",
  ],
  [
    120806,
    "Ragi Roti Cair (cream yeast)",
    "Ragi roti cair adalah produk yang dibuat dengan cara membiakkan<br> kamir jenis Saccharomyces cereviceae dalam media serealia atau<br> bahan lain yang sesuai, dalam keadaan bersih, berbentuk cairan<br> kental dan mempunyai kemampuan meragikan adonan tepung<br> terigu dengan atau tanpa campuran tepung lain pada pembuatan<br> roti dan kue. Ragi roti cair berwarna kekuningan sampai<br> kecoklatan<br> Karakteristik dasar :<br> Kadar air lebih dari 70% sampai dengan 80%<br>",
    "Aktif",
  ],
  [
    120807,
    "Koji atau Ragi Tauco atau Ragi Kecap",
    "Koji atau ragi tauco atau ragi kecap adalah produk yang dibuat dari serealia yang ditumbuhi Aspergillus oryzae, yang telah dikeringkan dan digunakan untuk pembuatan kecap/tauco/miso.",
    "Aktif",
  ],
  [
    120808,
    "Ragi Untuk Minuman Beralkohol",
    "Ragi untuk minuman beralkohol adalah produk yang dibuat dari bahan sumber karbohidrat (pati) yang mengandung kamir yang telah dikeringkan dan digunakan dalam pembuatan minuman beralkohol.",
    "Aktif",
  ],
  [
    12090101,
    "Doujiang",
    "produk yang dibuat dari kedelai, garam, air dan ingredien lainnya dengan proses fermentasi yang dapat digunakan dalam persiapan sup, dressing atau bumbu.",
    "Aktif",
  ],
  [
    12090102,
    "Doenjang",
    "produk yang dibuat dari kedelai, garam, air dan ingredien lainnya dengan proses fermentasi yang dapat digunakan dalam persiapan sup, dressing atau bumbu<br>",
    "Aktif",
  ],
  [
    12090103,
    "Miso",
    "Miso adalah produk yang dibuat dari kedelai, beras/barley/koji, garam, air, dengan atau tanpa penambahan bahan pangan lain, dengan proses fermentasi, dan menghasilkan tekstur pasta yang halus, serta rasa, warna, aroma khas miso. Dapat digunakan untuk soup base, kondimen, maupun penyedap rasa.",
    "Aktif",
  ],
  [
    12090104,
    "Tauco",
    "Tauco adalah produk kedelai yang diperoleh dari kacang kedelai hasil fermentasi kacang kedelai dalam larutan garam, berbau khas dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [12090201, "Saus Kedelai Fermentasi", "", "Aktif"],
  [
    1209020101,
    "Kecap Kedelai Asin (Salty Soy Sauce)",
    "Kecap kedelai asin (salty soy sauce) adalah produk berbentuk cair yang diperoleh dari hasil fermentasi kacang kedelai (Glycine max L.) atau bungkil kedelai dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> - Bau dan rasa normal khas<br> - Kadar protein (N x 6,25) tidak kurang dari 4,0%",
    "Aktif",
  ],
  [
    1209020102,
    "Tauco",
    "Tauco adalah produk kedelai yang diperoleh dari kacang kedelai hasil fermentasi kacang kedelai dalam larutan garam, berbau khas dengan atau tanpa penambahan bahan pangan lainnya.",
    "Tidak Aktif",
  ],
  [
    1209020201,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat",
    "Kecap kedelai asin non fermentasi/hidrolisat adalah produk cair yang diperoleh dari hasil pengolahan dan atau cara kimia (hidrolisis) kacang kedelai (Glycine max L.) dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> - Kadar protein (N x 6,25) tidak kurang dari 4,0%",
    "Aktif",
  ],
  [
    1209020202,
    "Saus Kedelai Non-Fermentasi",
    "Saus kedelai non-fermentasi, yang sering disebut juga sebagai saus nonbrewed, dapat dibuat dari protein sayuran, seperti kedelai nonfermentasi yang dihidrolisis dengan asam (misalnya asam hidroklorat), dinetralkan (contohnya dengan natrium karbonat), dan disaring.",
    "Aktif",
  ],
  [
    1209020203,
    "Saus Protein Nabati Terhidrolisis",
    "Saus protein nabati terhidolisis adalah produk saus yang diperoleh dari protein nabati terhidrolisis.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Total nitrogen tidak kurang dari 2,75%<br> \xE2\x{20AC}\xA2 Kadar garam tidak kurang dari 10%",
    "Aktif",
  ],
  [
    1209020301,
    "Kecap Kedelai Manis (Sweet Soy Sauce)",
    "Kecap kedelai manis adalah produk berbentuk cair yang diperoleh dari hasil fermentasi kacang kedelai (Glycine max L.) atau bungkil kedelai ditambah gula dengan atau tanpa penambahan bahan pangan lain.<br>",
    "Aktif",
  ],
  [
    1209020302,
    "Kecap Asin (Salty Soy Sauce)",
    "Kecap asin (salty soy sauce) adalah produk cair yang diperoleh dari hasil fermentasi kacang kedelai (Glycine max L.) dan gula, gula merah, dengan atau tanpa proses karamelisasi dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    1209020303,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder)",
    "Kecap yang dikeringkan/ bubuk kecap (fermented soy sauce powder) adalah produk kering yang diperoleh dari pengeringan hasil fermentasi kedelai. Dapat mengandung bahan pangan atau bahan tambahan yang sesuai.",
    "Aktif",
  ],
  [
    1209020304,
    "Saus Kedelai Lainnya",
    "Saus kedelai lainnya adalah saus yang bukan emulsi, dibuat dengan saus kedelai fermentasi atau tanpa fermentasi, dengan atau tanpa penambahan gula, dengan atau tanpa proses karamelisasi, dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    1209020305,
    "Kecap Pedas",
    "Kecap pedas adalah produk campuran kecap manis dengan cabe dengan atau tanpa penambahan bahan pangan lain.<br>",
    "Aktif",
  ],
  [
    1209020306,
    "Kecap Bumbu",
    "Kecap bumbu adalah produk campuran kecap dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain.<br>",
    "Aktif",
  ],
  [
    1209020307,
    "Saus Campuran Protein Nabati Terhidrolisis",
    "Saus campuran protein nabati terhidrolisis adalah produk saus yang diperoleh dari campuran protein nabati terhidrolisis dengan cairan bening yang diperoleh dari fermentasi kacang kedelai (Glycine max) dan serealia atau tepung.<br> <br> Karakteristik dasar:<br> Total nitrogen tidak kurang dari 0,3%<br> Kadar garam tidak kurang dari 3%<br>",
    "Aktif",
  ],
  [
    1209020308,
    "Saus Kedelai Lainnya dalam Kaleng",
    "Saus kedelai lainnya adalah saus yang bukan emulsi, dibuat dengan<br> saus kedelai fermentasi atau tanpa fermentasi, dengan atau tanpa<br> penambahan gula, dengan atau tanpa proses karamelisasi, dengan<br> atau tanpa penambahan bahan pangan lain, dikemas dalam kaleng.",
    "Tidak Aktif",
  ],
  [
    12090204,
    "Saus Kedelai Fermentasi dalam Kaleng",
    "Saus dengan bahan dasar kedelai yang jernih, bukan emulsi, dengan campuran gandum, tepung, garam dan air melalui proses fermentasi",
    "Tidak Aktif",
  ],
  [
    121001,
    "Produk Protein Gandum",
    "Produk protein gandum adalah produk yang diperoleh dengan cara pengurangan atau penghilangan komponen-komponen utama nonprotein (air, minyak, pati dan karbohidrat lain) dari gandum atau tepung gandum. Ingredien yang dapat digunakan adalah karbohidrat termasuk gula, lemak dan minyak makan, produk protein lain, vitamin dan mineral, garam, herbadan rempah.",
    "Aktif",
  ],
  [
    121002,
    "Produk Protein Kedelai",
    "Produk protein kedelai adalah produk yang diperoleh dari proses pengurangan atau penghilangan komponen-komponen utama non-protein (air, minyak, pati dan karbohidrat lain) dari kacang kedelai untuk mencapai kadar protein (Nx6,25) :<br> (1) Tepung protein kedel",
    "Tidak Aktif",
  ],
  [
    121003,
    "Hydrolised Vegetable Protein (HVP)",
    "Hydrolised vegetable protein (HVP) adalah produk protein mengandung asam amino yang diperoleh dari hidrolisis protein kedelai atau lainnya, dapat berbentuk cair atau bubuk.",
    "Aktif",
  ],
  [121005, "Protein Susu", "-", "Aktif"],
  [
    121006,
    "Produk Olahan Gluten",
    "Produk olahan gluten adalah produk protein yang diperoleh dari ekstraksi/isolasi protein gandum, rye, barley,dan triticale atau lainnya, dapat berbentuk cair atau padat.",
    "Aktif",
  ],
  [
    121007,
    "Produk Protein Nabati (Vegetable Protein Products)",
    "-",
    "Aktif",
  ],
  [
    13010101,
    "Formula Bayi Bubuk",
    "Formula sebagai pengganti ASI untuk bayi (sampai umur 6 (enam) bulan, tidak lebih dari umur 12 (dua belas) bulan) yang secara khusus diformulasikan untuk menjadi satu-satunya sumber zat gizi dalam bulan-bulan pertama kehidupannya sampai bayi diperkenalkan",
    "Tidak Aktif",
  ],
  [
    13010102,
    "Formula Bayi Cair",
    "Formula sebagai pengganti ASI untuk bayi (sampai umur 6 (enam) bulan, tidak lebih dari umur 12 (dua belas) bulan) yang secara khusus diformulasikan untuk menjadi satu-satunya sumber zat gizi dalam bulan-bulan pertama kehidupannya sampai bayi diperkenalkan",
    "Tidak Aktif",
  ],
  [
    13010201,
    "Formula Lanjutan Bubuk",
    "Formula lanjutan adalah produk yang diperoleh dari susu sapi atau susu hewan lain dan atau bagian yang dapat dimakan dari hewan termasuk ikan, dan atau berasal dari tumbuh-tumbuhan yang semuanya telah dibuktikan cocok untuk digunakan sebagai makanan bayi",
    "Tidak Aktif",
  ],
  [13010202, "Formula Lanjutan Cair", "", "Tidak Aktif"],
  [13010401, "Formula Pertumbuhan Bubuk", "", "Tidak Aktif"],
  [13010402, "Formula Pertumbuhan Cair", "", "Tidak Aktif"],
  [
    130305,
    "Biskuit Diet Diabetes",
    "Biskuit diet diabetes adalah makanan yang diperoleh dengan memanggang adonan yang mengandung bahan dasar tepung terigu dan atau tepung pati lainnya, dengan atau tanpa tambahan bahan pemanis alami/buatan yang sesuai dengan penderita diabetes, serta tambaha",
    "Tidak Aktif",
  ],
  [
    130318,
    "Makanan Diet Diabetes Berbasis Susu (Padat)",
    "",
    "Tidak Aktif",
  ],
  [
    130319,
    "Makanan Diet Diabetes Berbasis Susu (Cair)",
    "",
    "Tidak Aktif",
  ],
  [
    130320,
    "Makanan Diet Diabetes Siap Masak (Padat)",
    "",
    "Tidak Aktif",
  ],
  [
    130321,
    "Makanan Diet Diabetes Siap Masak (Cair)",
    "",
    "Tidak Aktif",
  ],
  [
    130322,
    "Makanan Diet Diabetes Siap Santap (Padat)",
    "",
    "Tidak Aktif",
  ],
  [
    130323,
    "Makanan Diet Diabetes Siap Santap (Cair)",
    "",
    "Tidak Aktif",
  ],
  [130324, "Makanan Diet Diabetes Bubuk Instan", "", "Tidak Aktif"],
  [
    1304010101,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    1304010102,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [
    1304010201,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    1304010202,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [
    13050101,
    "Minuman untuk Ibu Hamil Pasteurisasi",
    "",
    "Tidak Aktif",
  ],
  [
    13050102,
    "Minuman untuk Ibu Hamil Sterilisasi",
    "",
    "Tidak Aktif",
  ],
  [13050103, "Minuman untuk Ibu Menyusui Bubuk", "", "Tidak Aktif"],
  [
    13050104,
    "Minuman untuk Ibu Menyusui Pasteurisasi",
    "",
    "Tidak Aktif",
  ],
  [
    13050105,
    "Minuman untuk Ibu Menyusui Sterilisasi",
    "",
    "Tidak Aktif",
  ],
  [13050106, "Minuman untuk Ibu Hamil Bubuk", "", "Tidak Aktif"],
  [
    13050501,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    13050502,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [
    13050503,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    13050504,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [
    13050505,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    13050506,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [
    13050507,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat",
    "-",
    "Tidak Aktif",
  ],
  [
    13050508,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril)",
    "-",
    "Tidak Aktif",
  ],
  [1307, "Formula Bayi Padat", "", "Aktif"],
  [1308, "Formula Bayi Cair", "", "Aktif"],
  [1309, "Formula Lanjutan Padat", "-", "Aktif"],
  [1310, "Formula Lanjutan Cair", "", "Aktif"],
  [1311, "Formula Pertumbuhan Padat", "", "Aktif"],
  [1312, "Formula Pertumbuhan Cair", "", "Aktif"],
  [
    1313,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat",
    "&nbsp;",
    "Aktif",
  ],
  [
    1314,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair",
    "&nbsp;",
    "Aktif",
  ],
  [
    1315,
    "MP ASI Pokok usia sampai 2 tahun Padat",
    "&nbsp;",
    "Aktif",
  ],
  [
    1316,
    "MP ASI Pokok usia sampai 2 tahun Cair",
    "&nbsp;",
    "Aktif",
  ],
  [
    1317,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat",
    "&nbsp;",
    "Aktif",
  ],
  [
    1318,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair",
    "&nbsp;",
    "Aktif",
  ],
  [
    1319,
    "MP ASI Kudapan usia sampai 2 tahun Padat",
    "&nbsp;",
    "Aktif",
  ],
  [
    1320,
    "MP ASI Kudapan usia sampai 2 tahun Cair",
    "&nbsp;",
    "Aktif",
  ],
  [1321, "Pangan Ibu Hamil Padat", "", "Aktif"],
  [1322, "Pangan Ibu Hamil Cair", "", "Aktif"],
  [1323, "Pangan Ibu Menyusui Padat", "", "Aktif"],
  [1324, "Pangan Ibu Menyusui Cair", "", "Aktif"],
  [1325, "Pangan Ibu Hamil dan Menyusui Padat", "", "Aktif"],
  [1326, "Pangan Ibu Hamil dan Menyusui Cair", "", "Aktif"],
  [
    1327,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat",
    "",
    "Tidak Aktif",
  ],
  [
    1328,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair",
    "",
    "Tidak Aktif",
  ],
  [
    1329,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat",
    "",
    "Tidak Aktif",
  ],
  [
    1330,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair",
    "",
    "Tidak Aktif",
  ],
  [
    1331,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat",
    "",
    "Tidak Aktif",
  ],
  [
    1333,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat",
    "",
    "Tidak Aktif",
  ],
  [
    1334,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair",
    "",
    "Tidak Aktif",
  ],
  [1335, "Pangan Untuk Kontrol Berat Badan Padat", "", "Aktif"],
  [1336, "Pangan Untuk Kontrol Berat Badan Cair", "", "Aktif"],
  [1337, "Pangan Diet Penurun Berat Badan Padat", "", "Aktif"],
  [1338, "Pangan Diet Penurun Berat Badan Cair", "", "Aktif"],
  [
    1339,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat",
    "",
    "Aktif",
  ],
  [
    1340,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair",
    "",
    "Aktif",
  ],
  [
    1341,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat",
    "",
    "Aktif",
  ],
  [
    1342,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair",
    "",
    "Aktif",
  ],
  [1343, "Human Milk Fortifier (HMF) Padat", "", "Aktif"],
  [1344, "Human Milk Fortifier (HMF) Cair", "", "Aktif"],
  [
    1345,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat",
    "",
    "Aktif",
  ],
  [
    1346,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair",
    "",
    "Aktif",
  ],
  [
    1347,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat",
    "",
    "Aktif",
  ],
  [
    1348,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair",
    "",
    "Aktif",
  ],
  [
    1349,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat",
    "",
    "Aktif",
  ],
  [
    1350,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair",
    "",
    "Aktif",
  ],
  [
    1351,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat",
    "",
    "Aktif",
  ],
  [
    1352,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair",
    "",
    "Aktif",
  ],
  [
    1353,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat",
    "",
    "Aktif",
  ],
  [
    1354,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair",
    "",
    "Aktif",
  ],
  [
    1355,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat",
    "",
    "Aktif",
  ],
  [
    1356,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair",
    "",
    "Aktif",
  ],
  [
    1357,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat",
    "",
    "Aktif",
  ],
  [
    1358,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair",
    "",
    "Aktif",
  ],
  [
    1363,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat",
    "",
    "Aktif",
  ],
  [
    1364,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair",
    "",
    "Aktif",
  ],
  [
    1365,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat",
    "",
    "Aktif",
  ],
  [
    1366,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair",
    "",
    "Aktif",
  ],
  [
    1367,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat",
    "",
    "Aktif",
  ],
  [
    1368,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair",
    "",
    "Aktif",
  ],
  [
    1369,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat",
    "",
    "Aktif",
  ],
  [
    1370,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair",
    "",
    "Aktif",
  ],
  [
    1371,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat",
    "",
    "Aktif",
  ],
  [
    1372,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair",
    "",
    "Aktif",
  ],
  [
    1373,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat",
    "",
    "Aktif",
  ],
  [
    1374,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair",
    "",
    "Aktif",
  ],
  [
    1375,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat",
    "",
    "Aktif",
  ],
  [
    1376,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair",
    "",
    "Aktif",
  ],
  [
    1377,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat",
    "Padat dan Cair",
    "Aktif",
  ],
  [
    1378,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair)",
    "-",
    "Tidak Aktif",
  ],
  [
    1379,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein",
    "Padat dan Cair",
    "Aktif",
  ],
  [1381, "Formula Khusus Untuk Anak", "-", "Aktif"],
  [
    1382,
    "PKMK Program Pemerintah Untuk Anak (Padat)",
    "-",
    "Aktif",
  ],
  [
    1383,
    "PKMK Program Pemerintah Untuk Dewasa (Padat)",
    "-",
    "Aktif",
  ],
  [
    1388,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein",
    "Padat dan Cair",
    "Aktif",
  ],
  [
    1390,
    "Makanan Selingan untuk Anak (Padat)",
    "Untuk anak usia 1-3 tahun",
    "Aktif",
  ],
  [
    1391,
    "Makanan Selingan untuk Anak - Cair (Steril)",
    "Untuk anak usia 1-3 tahun",
    "Aktif",
  ],
  [
    1392,
    "Minuman Olahraga (Padat)",
    "Minuman Olahraga diperuntukkan bagi orang yang melakukan olahraga endurance dengan mempertimbangkan kandungan cairan, elektrolit, dan energi digunakan untuk secara cepat menggantikan cairan tubuh, elektrolit dan energi sehingga dapat meningkatkan, mempertahankan dan memulihkan tenaga pada olahraga endurance.",
    "Aktif",
  ],
  [
    1393,
    "Minuman Olahraga (Cair)",
    "Minuman Olahraga diperuntukkan bagi orang yang melakukan olahraga endurance dengan mempertimbangkan kandungan cairan, elektrolit, dan energi digunakan untuk secara cepat menggantikan cairan tubuh, elektrolit dan energi sehingga dapat meningkatkan, mempertahankan dan memulihkan tenaga pada olahraga endurance.",
    "Aktif",
  ],
  [
    1394,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat)",
    "-",
    "Aktif",
  ],
  [
    1395,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair)",
    "-",
    "Aktif",
  ],
  [
    1396,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat)",
    "PKMK untuk Bayi Intoleransi Laktosa adalah pangan yang diformulasikan secara khusus bagi bayi yang mengalami intoleransi laktosa. PKMK untuk bayi intoleransi laktosa dapat digunakan sebagai makanan pengganti atau makanan tambahan, sehingga dapat memenuhi kebutuhan gizi bayi yang mengalami intoleransi laktosa.",
    "Aktif",
  ],
  [
    1397,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair)",
    "PKMK untuk Bayi Intoleransi Laktosa adalah pangan yang diformulasikan secara khusus bagi bayi yang mengalami intoleransi laktosa. PKMK untuk bayi intoleransi laktosa dapat digunakan sebagai makanan pengganti atau makanan tambahan, sehingga dapat memenuhi kebutuhan gizi bayi yang mengalami intoleransi laktosa.",
    "Aktif",
  ],
  [
    1398,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat)",
    "Pangan yang diformulasikan secara khusus bagi pasien penyakit ginjal kronik, dapat digunakan sebagai makanan pengganti ataupun makanan tambahan, dengan memperhitungkan kebutuhan dan asupan gizi per hari pasien penyakit ginjal kronik.",
    "Aktif",
  ],
  [
    1401010101,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water)",
    "Air mineral alami terkarbonasi secara alami adalah air mineral alami yang mengandung karbondioksida yang sama dengan kandungan karbondioksida yang terdapat pada sumber airnya dan jika kurang dapat diganti atau ditambah karbondioksida dari sumber airnya.",
    "Tidak Aktif",
  ],
  [
    1401010102,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian",
    "Air mineral alami dikarbonasi adalah air mineral alami yang dikarbonasi dengan karbondioksida dari sumber air lain.",
    "Tidak Aktif",
  ],
  [
    1401010103,
    "Air Mineral Alami yang Diperkaya",
    "Air mineral alami yang diperkaya adalah air mineral alami yang mengandung karbondioksida lebih tinggi dari sumbernya, dengan cara menambahkan gas karbondioksida dari mata air yang berasal dari sumbernya.",
    "Tidak Aktif",
  ],
  [
    1401010104,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water)",
    "Air mineral alami dikarbonasi adalah air mineral alami yang dikarbonasi dengan karbondioksida dari sumber air lain.",
    "Tidak Aktif",
  ],
  [
    1401010105,
    "Air Mineral Alami",
    "Air mineral alami adalah air minum yang diperoleh langsung dari air sumber alami atau di bor dari sumur dalam dengan proses terkendali yang menghindari pencemar atau pengaruh luar atas sifat kimia, fisika, dan mikrobiologi air mineral alami.<br> Klasifikasi air mineral alami yaitu:<br> a. Air mineral alami berkarbonasi alami<br> Air mineral alami yang secara alami mengandung karbondioksida pada suhu dan tekanan normal.<br> b. Air mineral alami tanpa karbonasi<br> Air mineral alami yang tidak mengandung karbondioksida bebas setelah dikemas.<br> c. Air mineral alami dekarbonasi<br> Air mineral alami yang mengandung karbondioksida lebih rendah dari sumbernya setelah dikemas.<br> d. Air mineral alami fortifikasi dengan karbon dioksida dari sumbernya<br> Air mineral alami dengan penambahan karbondioksida yang berasal dari sumbernya dan kandungan karbondioksida setelah dikemas lebih tinggi dari sumbernya.<br> e. Air mineral alami dikarbonasi<br> Air mineral alami yang ditambahkan karbondioksida dari sumber lain.",
    "Aktif",
  ],
  [
    1401010204,
    "Air Bermineral",
    "Air bermineral adalah air minum yang ditambahkan mineral.",
    "Tidak Aktif",
  ],
  [
    1401010205,
    "Air Soda",
    "Air soda adalah air minum yang mengandung gas karbondioksida, tidak berwarna, tidak berbau.<br> <br> Karakteristik dasar :<br> Kadar CO2 tidak kurang dari 5.890 mg/L",
    "Aktif",
  ],
  [
    1401010206,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen)",
    "Air yang dikemas di dalam botol atau bentuk kemasan lainnya dan ditambahkan gas oksigen.",
    "Aktif",
  ],
  [1401010207, "Air Minum Bervitamin", "", "Tidak Aktif"],
  [
    1401010209,
    "Air minum dalam kemasan (Air Demineral)",
    "Air minum dalam kemasan adalah air baku yang telah diproses, dikemas, dan aman diminum mencakup air mineral dan air demineral.<br> Air demineral adalah air minum dalam kemasan yang diperoleh melalui proses pemurnian seperti destilasi, deionisasi, reverse osmosis, dan proses setara.",
    "Aktif",
  ],
  [
    1401010211,
    "Air Minum Dalam Kemasan (Air Mineral)",
    "Air minum dalam kemasan adalah air baku yang telah diproses, dikemas, dan aman diminum mencakup air mineral dan air demineral.<br> Air mineral adalah air minum dalam kemasan yang mengandung mineral dalam jumlah tertentu tanpa menambahkan mineral.",
    "Aktif",
  ],
  [1401010212, "Air Embun", "-", "Aktif"],
  [
    1401010213,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen)",
    "Air yang dikemas di dalam botol atau bentuk kemasan lainnya dan ditambahkan gas oksigen.",
    "Aktif",
  ],
  [
    1401010214,
    "Air Minum pH Tinggi",
    "Air minum pH tinggi adalah air minum yang mengandung mineral dalam jumlah tertentu tanpa menambahkan mineral, dengan atau tanpa penambahan oksigen (O2) atau karbondioksida (CO2), dan memiliki pH tinggi.<br> <br> Karakteristik dasar :<br> \x{2022} pH antara 8,6 \x{2013} 9,5<br> \x{2022} memenuhi persyaratan mutu air mineral (selain pH)",
    "Aktif",
  ],
  [
    1401010215,
    "Air Mineral Berkarbonat",
    "Air mineral yang dikemas di dalam botol atau bentuk kemasan lainnya dan ditambahkan gas karbondioksida.",
    "Aktif",
  ],
  [
    1401010216,
    "Air Demineral Berkarbonat",
    "Air demineral yang dikemas di dalam botol atau bentuk kemasan lainnya dan ditambahkan gas karbondioksida.",
    "Aktif",
  ],
  [
    1401020101,
    "Sari Buah",
    "Sari buah adalah cairan yang diperoleh dari bagian buah yang dapat dimakan yang dicuci, dihancurkan, dijernihkan (jika dibutuhkan), dengan atau tanpa pasteurisasi dan dikemas untuk dapat dikonsumsi langsung.<br> <br> Karakteristik dasar :<br> \x{2022} Kadar etanol tidak lebih dari 0,5%, kecuali sari buah yang ditetapkan kadar etanolnya sendiri;<br> \x{2022} Dapat ditambahkan konsentrat ke dalam sari buah dari jenis buah yang sama;<br> \x{2022} Dapat ditambahkan gula, tidak lebih dari 50 g/kg.",
    "Aktif",
  ],
  [
    1401020102,
    "Sari Buah Campuran",
    "Sari buah campuran adalah produk buah yang diperoleh dari dua atau lebih jenis buah segar yang masak atau daging buah yang diawetkan secara fisik, tidak difermentasi tetapi dapat terfermentasi, berisi hancuran buah, keruh atau jernih, ditujukan untuk dikonsumsi langsung. Sari buah diperoleh dengan proses mekanik atau dapat diperoleh dari rekonstitusi sari buah konsentrat. Sari buah dapat dipekatkan dan direkonstitusi dengan air untuk mempertahankan komposisi esensial dan faktor mutu dari sari buah.",
    "Aktif",
  ],
  [
    1401020103,
    "Sari Jeruk Nipis (Lime Juice)",
    "Sari jeruk nipis adalah produk sari buah yang diperoleh dari jeruk<br> nipis masak spesies Citrus aurantifolia atau varietas turunannya.<br> <br> Karakteristik dasar:<br> Total padatan tidak kurang dari 8 % (b/v)<br> Total asam (sebagai asam sitrat anhidrat) tidak kurang dari 6%<br> (b/v)<br> Dengan level brix untuk sari buah rekonstitusi dan puree<br> rekonstitusi tidak kurang dari 8,0\xB0Brix (20\xB0C).",
    "Aktif",
  ],
  [
    1401020104,
    "Sari Buah Apel",
    "Sari buah apel adalah produk sari buah yang keruh atau jernih<br> yang diperoleh dari buah apel (Pyrus malus L) masak tanpa<br> fermentasi, diawetkan secara fisik. Sari buah apel juga dapat<br> diperoleh dengan rekonstitusi konsentrat sari apel. Total asam<br> (sebagai asam sitrat anhidrat) sesuai dengan ketentuan standar dan<br> atau persyaratan yang berlaku.<br> <br> Karakteristik dasar :<br> Total padatan tidak kurang dari 10% (b/v).",
    "Aktif",
  ],
  [
    1401020105,
    "Sari Buah Jeruk Bali",
    "Sari buah jeruk Bali adalah produk sari buah yang diperoleh dari jeruk Bali masak spesies Citrus grandis dan varietasnya.<br> <br> Karakteristik dasar:<br> Total padatan tidak kurang dari 9,5% (b/v)<br> Total asam (sebagai asam sitrat anhidrat) 1 g hingga 2 g<br> Total padatan terlarut tidak kurang dari 7 g untuk setiap gram asam yang dihitung sebagai asam sitrat anhidrat",
    "Aktif",
  ],
  [
    1401020106,
    "Sari Buah Jeruk Orange, Valencia",
    "Sari buah jeruk orange, Valencia adalah produk sari buah yang diperoleh dari endokarp buah jeruk (Citrus sinensis L Osbeck) yang masak tanpa fermentasi, diawetkan secara fisik. Sari jeruk juga dapat diperoleh dengan rekonstitusi konsentrat sari buah jeruk.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 10%<br> \xE2\x{20AC}\xA2 Jika sari buah diperoleh dari padatan sari buah yang diencerkan<br> dengan air, maka total padatan tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar etanol tidak lebih dari 0,3%",
    "Aktif",
  ],
  [
    1401020107,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak",
    "Sari buah jeruk siam, tangerine adalah produk sari buah yang<br> diperoleh dari endokarp buah jeruk tangerine (Citrus reticulata<br> Blanco) yang masak, tanpa fermentasi, diawetkan secara fisik. Sari<br> jeruk juga dapat diperoleh dengan rekonstitusi konsentrat sari buah<br> jeruk.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 10%<br> \xE2\x{20AC}\xA2 Jika sari buah diperoleh dari padatan sari buah yang diencerkan<br> dengan air, maka total padatan tidak kurang dari 11% \xE2\x{20AC}\xA2 Kadar etanol tidak lebih dari 0,3%<br>",
    "Aktif",
  ],
  [
    1401020108,
    "Minuman Citrus Comminutes",
    "Minuman citrus comminutes adalah minuman ringan yang diperoleh dari proses yang melibatkan kelompok buah citrus utuh.",
    "Tidak Aktif",
  ],
  [
    1401020109,
    "Sari Buah Nanas",
    "Sari buah nanas adalah produk sari buah yang diperoleh dari buah<br> nanas (Ananas comocsus L Merril, Ananas sativus L Lindii) yang<br> masak, tanpa fermentasi, diawetkan secara fisik. Sari nanas juga<br> dapat diperoleh dengan rekonstitusi konsentrat sari nanas.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Total padatan tidak kurang dari 10%<br> \xEF\x{201A}\xB7 Jika sari buah diperoleh dari padatan sari buah yang diencerkan<br> dengan air, total padatan tidak kurang dari 13,5%.",
    "Aktif",
  ],
  [
    1401020110,
    "Sari Buah Lemon",
    "Sari buah lemon adalah produk sari buah yang diperoleh dari<br> endokarp buah lemon (Lemon burf) yang masak, tanpa fermentasi,<br> diawetkan secara fisik. Sari buah lemon juga dapat diperoleh<br> dengan rekonstitusi konsentrat sari lemon.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Total padatan tidak kurang dari 6%<br> \xEF\x{201A}\xB7 Total asam tertritasi (sebagai asam sitrat anhidrat) tidak kurang<br> dari 4,5%",
    "Aktif",
  ],
  [
    1401020111,
    "Sari Buah Markisa",
    "Sari buah markisa adalah produk sari buah yang diperoleh dari<br> buah markisa masak dari spesies Passiflora sp.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Total padatan tidak kurang dari 12% (b/v)<br> \xEF\x{201A}\xB7 Total asam (sebagai asam sitrat anhidrat) 1,5% hingga 4,5% (b/v)",
    "Aktif",
  ],
  [
    1401020112,
    "Sari Buah Anggur",
    "Sari buah anggur adalah sari buah yang diperoleh dari buah anggur<br> (Vitis sp.) matang atau dari pengenceran konsentrat sari buah<br> anggur, tanpa fermentasi, dan diawetkan.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 pH tidak lebih dari 4<br> \xEF\x{201A}\xB7 Total padatan terlarut tidak kurang dari 15%",
    "Aktif",
  ],
  [
    1401020114,
    "Sari Buah Blackcurrant",
    "Sari buah blackcurrant adalah produk sari buah cair yang keruh<br> atau jernih yang diperoleh dari buah blackcurrant (Ribes nigrum L.)<br> yang masak tanpa fermentasi, diawetkan secara fisika.<br> Sari blackcurrant juga dapat diperoleh dengan rekonstitusi<br> konsentrat sari blackcurrant.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Total padatan terlarut tidak kurang dari 11% yang diukur dengan<br> refraktometer pada 20\xC2\xB0C, dibaca sebagai \xC2\xB0Brix dalam skala<br> sukrosa internasional tanpa koreksi keasaman<br> \xEF\x{201A}\xB7 Kadar etanol tidak lebih dari 0,3%",
    "Aktif",
  ],
  [
    1401020115,
    "Sari Buah Mangga",
    "Sari buah mangga adalah produk sari buah yang diperoleh dari buah mangga (Mangifera indica L.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 13,0",
    "Aktif",
  ],
  [
    1401020116,
    "Sari Buah Sirsak",
    "Sari buah sirsak adalah produk sari buah yang diperoleh dari buah sirsak (Annona muricata L.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 12,0",
    "Aktif",
  ],
  [
    1401020117,
    "Sari Buah Pisang",
    "Sari buah pisang adalah produk sari buah yang diperoleh dari buah pisang (Mangifera indica L.)",
    "Tidak Aktif",
  ],
  [
    1401020118,
    "Sari Buah Belimbing",
    "Sari buah belimbing adalah produk sari buah yang diperoleh dari buah belimbing (Averrhoa carambola L.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 7,5",
    "Aktif",
  ],
  [
    1401020120,
    "Sari Buah Plum",
    "Sari buah plum adalah produk sari buah yang diperoleh dari buah plum (Prunus domestica L. Subsp. Domestica.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 12,0",
    "Aktif",
  ],
  [
    1401020121,
    "Sari Buah Peach",
    "Sari buah peach adalah produk sari buah yang diperoleh dari buah peach (Prumus persica (L) Batch var. nucipersica)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 10,5",
    "Aktif",
  ],
  [
    1401020122,
    "Sari Buah Jambu Biji",
    "Sari buah jambu biji adalah produk sari buah yang diperoleh dari buah jambu biji (Psidium guajava L.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 7,5 untuk jambu biji merah dan 9,0 untuk jambu biji putih",
    "Aktif",
  ],
  [
    1401020123,
    "Sari Buah Delima",
    "Sari buah delima adalah produk sari buah yang diperoleh dari buah delima (Punica sp.).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 12,0",
    "Aktif",
  ],
  [
    1401020124,
    "Sari Buah Pir",
    "Sari buah pir adalah produk sari buah yang diperoleh dari buah pir (Pyrus communis.).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 12,0",
    "Aktif",
  ],
  [
    1401020125,
    "Sari Buah Redcurrant",
    "Sari buah redcurrant adalah produk sari buah yang diperoleh dari buah redcurrant (Ribes rubrum).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 10,0",
    "Aktif",
  ],
  [
    1401020126,
    "Sari Buah Blackberry",
    "Sari buah blackberry adalah produk sari buah yang diperoleh dari buah blackberry (Rubus fruitcosus L.).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 9,0",
    "Aktif",
  ],
  [
    1401020127,
    "Sari Buah Raspberry",
    "Sari buah raspberry adalah produk sari buah yang diperoleh dari buah raspberry (Rubus occidentalis L.).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 11,0",
    "Aktif",
  ],
  [
    1401020128,
    "Sari Buah Stroberi",
    "Sari buah stroberi adalah produk sari buah yang diperoleh dari buah stroberi (Fragaria rosaceae).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 7,0",
    "Aktif",
  ],
  [
    1401020129,
    "Sari Buah Manggis",
    "Sari buah manggis adalah produk sari buah yang diperoleh dari<br> buah manggis (Garcinia mangostana L).",
    "Aktif",
  ],
  [
    1401020130,
    "Sari Buah Terong Belanda",
    "Sari buah terong belanda adalah produk sari buah yang diperoleh<br> dari buah terong belanda (Solanum betaceum).",
    "Aktif",
  ],
  [
    1401020131,
    "Sari Buah (Kemasan Tetrapack)",
    "Sari buah adalah cairan yang diperoleh dari bagian buah yang dapat dimakan yang dicuci, dihancurkan, dijernihkan (jika dibutuhkan), dengan atau tanpa pasteurisasi dan dikemas untuk dapat dikonsumsi langsung",
    "Aktif",
  ],
  [
    1401020132,
    "Sari Buah dan Sari Sayur",
    "Sari buah dan sari sayur adalah produk yang terdiri dari campuran<br> sari buah dan sari sayur. Kandungan sari buah lebih banyak<br> daripada sari sayur.",
    "Aktif",
  ],
  [
    1401020133,
    "Sari Buah Jeruk Garut",
    "Sari buah jeruk Garut adalah produk sari buah yang diperoleh dari<br> endokarp buah jeruk Garut (Citrus nobilis) yang masak, tanpa<br> fermentasi, diawetkan secara fisik. Sari jeruk juga dapat diperoleh<br> dengan rekonstitusi konsentrat sari buah jeruk.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 10%<br> \xE2\x{20AC}\xA2 Jika sari buah diperoleh dari padatan sari buah yang diencerkan<br> dengan air, maka total padatan tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar etanol tidak lebih dari 0,3%",
    "Aktif",
  ],
  [
    1401020134,
    "Sari Buah Jeruk Medan",
    "Sari buah jeruk Medan adalah produk sari buah yang diperoleh dari endokarp buah jeruk Medan (Citrus sinensis (L)) yang masak, tanpa fermentasi, diawetkan secara fisik. Sari jeruk juga dapat diperoleh dengan rekonstitusi konsentrat sari buah jeruk.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Total padatan tidak kurang dari 10%<br> \xE2\x{20AC}\xA2 Jika sari buah diperoleh dari padatan sari buah yang diencerkan<br> dengan air, maka total padatan tidak kurang dari 11%<br> \xE2\x{20AC}\xA2 Kadar etanol tidak lebih dari 0,3%",
    "Aktif",
  ],
  [
    1401020135,
    "Sari Buah Prune (Prune Juice)",
    "Sari buah prune adalah produk sari buah yang diperoleh dari<br> ekstrak air buah prune (Prunus domestica L. Subsp. domestica)<br> kering. Jumlah padatan terlarut dari buah prune dapat dicapai<br> dengan pemekatan, pengenceran dari ekstrak buah atau<br> rekonstitusi konsentrat.<br> <br> Karakteristik dasar:<br> Total padatan terlarut tidak kurang dari 18,5%<br>",
    "Aktif",
  ],
  [
    1401020136,
    "Sari Buah Blueberry",
    "Sari buah blueberry adalah produk sari buah yang diperoleh dari buah blueberry (Vaccinium myrtillus L. atau Vaccinium corymbosum L. atau Vaccinium angustifolium L.).<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 10,0",
    "Aktif",
  ],
  [
    1401020137,
    "Sari Buah Leci",
    "Sari buah leci adalah produk sari buah yang diperoleh dari buah leci (Litchi chinensis Sonn.)<br> Karakteristik dasar:<br> Level brix untuk sari buah rekonstitusi dan puree rekonstitusi tidak kurang dari 11,0",
    "Aktif",
  ],
  [
    1401020138,
    "Sari Buah Kiwi",
    "Sari buah kiwi adalah produk sari buah yang diperoleh dari buah<br> kiwi (Actinidia deliciosa).",
    "Aktif",
  ],
  [
    1401020139,
    "Sari Buah Naga",
    "Sari buah naga adalah produk sari buah yang diperoleh dari buah<br> naga (Hylocereus undatus).",
    "Aktif",
  ],
  [
    1401020201,
    "Sari Sayur",
    "Sari sayur adalah cairan yang diperoleh dari bagian tanaman sayur yang dapat dimakan yang dicuci, dihancurkan, dijernihkan (jika dibutuhkan), dengan atau tanpa pasteurisasi dan dikemas untuk dapat dikonsumsi.",
    "Aktif",
  ],
  [
    1401020202,
    "Sari Tomat",
    "Sari tomat adalah produk sari sayur yang diperoleh dari bagian yang dapat dimakan dari buah tomat (Lycopersicum esculentum L.) merah atau kemerahan, yang diawetkan secara fisik (tidak termasuk iradiasi), tidak difermentasi tetapi merupakan sari sayur yang dapat difermentasi, ditujukan untuk dapat dikonsumsi langsung. Sari tomat bebas dari kulit, biji dan bagian berupa partikel besar lain dari tomat.<br> Karakteristik dasar: Total padatan terlarut tomat tidak kurang dari 4,5% yang diukur dengan refraktometer pada 20\xB0C",
    "Aktif",
  ],
  [
    1401020203,
    "Sari Wortel",
    "Sari wortel adalah produk sari sayur yang diperoleh dari bagian<br> yang dapat dimakan dari buah wortel (Daucus carota L.), yang<br> diawetkan secara fisik (tidak termasuk iradiasi), tidak difermentasi<br> tetapi merupakan sari sayur yang dapat difermentasi, ditujukan<br> untuk dapat dikonsumsi langsung.",
    "Aktif",
  ],
  [
    1401020204,
    "Sari Sayur (Kemasan Tetrapack)",
    "Sari sayur adalah cairan yang diperoleh dari bagian tanaman sayur yang dapat dimakan yang dicuci, dihancurkan, dijernihkan (jika dibutuhkan), dengan atau tanpa pasteurisasi dan dikemas untuk dapat dikonsumsi.",
    "Aktif",
  ],
  [1401020205, "Sari Lidah Buaya", "&nbsp;", "Tidak Aktif"],
  [
    1401020206,
    "Sari Sayur Campuran",
    "Sari Sayur Campuran adalah produk sayur yang diperoleh dari dua<br> atau lebih jenis sayur segar atau sayur yang diawetkan secara fisik,<br> tidak difermentasi tetapi dapat terfermentasi, berisi hancuran sayur,<br> berwarna keruh atau jernih, ditujukan untuk dikonsumsi langsung.<br> Sari sayur diperoleh dengan proses mekanik.",
    "Aktif",
  ],
  [
    1401020207,
    "Sari Sayur dan Sari Buah",
    "Sari sayur dan sari buah adalah produk yang terdiri dari campuran<br> sari sayur dan sari buah. Kandungan sari sayur lebih banyak<br> daripada sari buah.",
    "Aktif",
  ],
  [
    1401020301,
    "Konsentrat Sari Buah Jeruk Orange, Valencia",
    "Konsentrat sari buah jeruk orange, valencia adalah produk yang<br> belum difermentasi, dapat difermentasi setelah direkonstitusi,<br> diawetkan secara fisik (tidak termasuk iradiasi), diperoleh melalui<br> proses konsentrasi, yaitu penghilangan air hingga produk<br> mempunyai total padatan tidak kurang dari 20% yang diukur<br> dengan refraktometer pada suhu 20\xB0C.",
    "Aktif",
  ],
  [
    1401020302,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine",
    "Konsentrat sari buah jeruk siam, tangerine adalah produk buah<br> yang belum difermentasi, dapat difermentasi setelah direkonstitusi,<br> diawetkan secara fisik (tidak termasuk iradiasi), diperoleh melalui<br> proses konsentrasi, yaitu penghilangan air hingga produk<br> mempunyai total padatan tidak kurang dari dari 20% yang diukur<br> dengan refraktometer pada suhu 20\xB0C.",
    "Aktif",
  ],
  [
    1401020303,
    "Konsentrat Sari Buah Apel",
    "Konsentrat sari buah apel adalah produk buah yang belum<br> difermentasi, dapat difermentasi setelah direkonstitusi, diawetkan<br> secara fisik (tidak termasuk iradiasi), diperoleh melalui proses<br> konsentrasi yaitu penghilangan air hingga produk mempunyai total<br> padatan tidak kurang dari 20% yang diukur dengan refraktometer<br> pada suhu 20\xB0C.",
    "Aktif",
  ],
  [
    1401020304,
    "Konsentrat Sari Buah Anggur",
    "Konsentrat sari buah anggur adalah produk buah yang belum<br> difermentasi, dapat difermentasi setelah direkonstitusi, diawetkan<br> secara fisik (tidak termasuk iradiasi), diperoleh melalui proses<br> konsentrasi yaitu penghilangan air hingga produk mempunyai total<br> padatan tidak kurang dari 20% yang diukur dengan refraktometer<br> pada suhu 20oC.",
    "Aktif",
  ],
  [
    1401020305,
    "Konsentrat Sari Buah Anggur Manis",
    "Konsentrat sari buah anggur manis adalah produk konsentrat yang<br> belum difermentasi, dapat difermentasi setelah direkonstitusi,<br> diawetkan secara fisik (tidak termasuk iradiasi), diperoleh melalui<br> proses konsentrasi yaitu penghilangan air hingga produk<br> mempunyai total padatan tidak kurang dari 30% yang diukur<br> dengan refraktometer pada suhu 20\xB0C tanpa koreksi keasaman.",
    "Aktif",
  ],
  [
    1401020306,
    "Konsentrat Sari Buah Blackcurrant",
    "Konsentrat sari buah blackcurrant adalah produk buah yang belum<br> difermentasi, dapat difermentasi setelah direkonstitusi, diawetkan<br> secara fisik (tidak termasuk iradiasi), diperoleh melalui proses<br> konsentrasi yaitu penghilangan air hingga produk mempunyai total<br> padatan tidak kurang dari 20% yang diukur dengan refraktometer<br> pada suhu 20\xB0C.",
    "Aktif",
  ],
  [
    1401020307,
    "Konsentrat Sari Buah Nanas",
    "Konsentrat sari buah nanas adalah produk buah yang belum<br> difermentasi, dapat difermentasi setelah direkonstitusi, diawetkan<br> secara fisik (tidak termasuk radiasi ionisasi), diperoleh melalui<br> proses konsentrasi yaitu penghilangan air hingga produk<br> mempunyai total padatan tidak kurang dari 40% yang diukur<br> dengan refraktometer pada suhu 20\xB0C.",
    "Aktif",
  ],
  [
    1401020308,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan",
    "Konsentrat sari buah nanas dengan pengawet untuk keperluan industri pangan adalah produk buah tanpa fermentasi yang diperoleh dari proses konsentrasi yaitu penghilangan air hingga produk mempunyai total padatan tidak kurang dari 20% yang diukur dengan ref",
    "Tidak Aktif",
  ],
  [
    1401020309,
    "Konsentrat Minuman Sari Buah",
    "Konsentrat minuman sari buah adalah sari buah atau campuran<br> dua atau lebih sari buah yang dijadikan konsentrat dengan<br> mengurangi kadar airnya, dengan penambahan gula dan bahan<br> pangan lainnya. Konsentrat minuman sari buah dapat dikonsumsi<br> setelah diencerkan. Setelah diencerkan mengandung tidak kurang<br> dari 35% sari buah.",
    "Aktif",
  ],
  [1401020310, "Konsentrat Sari Buah ...", "&nbsp;", "Tidak Aktif"],
  [
    1401020311,
    "Konsentrat Minuman Buah",
    "Konsentrat minuman buah adalah sari buah atau campuran dua<br> atau lebih sari buah yang dijadikan konsentrat dengan mengurangi<br> kadar airnya, dengan penambahan gula dan bahan pangan lainnya.<br> Konsentrat minuman buah dapat dikonsumsi setelah diencerkan.<br> Setelah diencerkan mengandung tidak kurang dari 10% sari buah.",
    "Aktif",
  ],
  [
    1401020312,
    "Konsentrat Sari Buah dan Sari Sayur",
    "Konsentrat sari buah dan sari sayur adalah konsentrat yang berasal<br> dari campuran sari buah atau puree buah dan sari sayur.",
    "Aktif",
  ],
  [
    1401020401,
    "Konsentrat Sari Tomat",
    "Konsentrat sari tomat adalah produk yang diperoleh dari cairan<br> tomat matang (Lycopersicum esculentum P. Will). Cairan tersebut<br> dipisahkan dari kulit, biji dan bagian yang tidak diperlukan pada<br> produk akhir. Garam dan bumbu-bumbu yang sesuai lainnya dapat<br> ditambahkan, kecuali gula atau pemanis lainnya dan sari buah<br> jeruk sebagai pengatur keasaman. Produk mengandung kadar 8%<br> atau lebih buah tomat berupa padatan terlarut tetapi tidak<br> dikeringkan menjadi suatu bubuk kering atau bentuk kepingan.<br> Karakteristik dasar:<br> Kandungan tomat :<br> \xE2\x{20AC}\xA2 Pasta tomat tidak kurang dari 24%<br> \xE2\x{20AC}\xA2 Puree tomat 8% hingga 24%",
    "Aktif",
  ],
  [
    1401020402,
    "Konsentrat Sari Buah dan Sari Sayuran",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1401020403,
    "Konsentrat Sari Sayur",
    "Konsentrat sari sayur adalah produk sayur yang dibuat dari sari<br> sayur yang berasal dari satu atau lebih jenis sayur, yang dipekatkan<br> dengan menghilangkan sebagian airnya. Konsentrat sari sayur<br> terdapat dalam bentuk serbuk, cairan, sirup dan bentuk beku<br> sebagai bahan untuk tujuan persiapan dari sari sayur siap minum<br> dengan penambahan air.",
    "Aktif",
  ],
  [14010205, "Sari Buah dan Sari Sayuran", "&nbsp;", "Tidak Aktif"],
  [
    1401030101,
    "Nektar Buah Kecil",
    "Nektar buah kecil adalah hancuran buah yang dibuat dari buah<br> berries species atau turunan spesies: bilberries (Vaccinium myrtillus<br> L.); blackberries (Rubus procerus P.J. Muell., etc.); blackcurrants<br> (Ribes nigrum L.); cloudberries (Rubus chamaemorus L.); cranberries<br> (Vaccinium oxycoccus L., V. macrocarpon Ait.); redcurrants dan<br> whitecurrants (kultivar dari Ribes rubrum L., R. pallidum, Otto, and<br> Dietr., R. sylvestre (Lam.) Mert. and W.D.J. Kock, etc.); elderberries<br> (Sambucus nigra); gooseberries (Ribes uva-crispa L. dan hibridanya);<br> raspberries (Rubus idaeus L.); rose hips (Cynorrhoda of Rosa spp.);<br> rowanberries (Sorbus aucuparia L.); sea buckthorn (Hippophaea<br> rhamnoides L.); strawberi (kultivar dan hibrida dari Fragaria spp.);<br> whortleberries (Vaccinium vitis idaea L.).<br> Produk hancuran buah tersebut, dapat dipasteurisasi atau tidak,<br> dan ditujukan untuk dikonsumsi langsung, diperoleh dengan<br> mencampur hasil saringan hancuran buah yang dapat dimakan<br> atau hasil gilingan dan dihomogenisasi, produk berasal dari buah<br> berri yang bersih, masak, dipekatkan, dengan air dan gula atau<br> madu, diawetkan secara fisik.",
    "Aktif",
  ],
  [
    1401030102,
    "Nektar Buah Campuran",
    "Nektar buah campuran adalah produk buah yang dapat dipasteurisasi atau tidak, dan produk hancuran buah ditujukan untuk dikonsumsi langsung, diperoleh dengan mencampur hasil saringan hancuran buah yang dapat dimakan atau hasil gilingan dan dihomogenisasi, produk berasal dari dua atau lebih jenis buah<br> yang masak, dengan atau tanpa pemekatan atau tidak, dengan air<br> dan gula atau madu, diawetkan secara fisik. Pada buah yang<br> mengandung gula tinggi, penambahan gula dapat diabaikan.<br>",
    "Aktif",
  ],
  [
    1401030103,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear",
    "Nektar aprikot, nektar peach atau nektar pir/pear adalah produk buah yang dapat dipasteurisasi atau tidak, dan produk hancuran buah ditujukan untuk dikonsumsi langsung, diperoleh dengan mencampur hasil saringan hancuran buah yang dapat dimakan atau hasil gilingan dan dihomogenisasi, produk berasal dari buah aprikot, peach atau pir/pear yang bersih, masak, dipekatkan,<br> dengan air dan gula atau madu, diawetkan secara fisik.<br>",
    "Aktif",
  ],
  [
    1401030104,
    "Nektar Blackcurrant",
    "Nektar blackcurrant adalah produk buah yang dapat dipasteurisasi<br> atau tidak, dan produk hancuran buah ditujukan untuk dikonsumsi<br> langsung, diperoleh dengan mencampur hasil saringan hancuran<br> buah yang dapat dimakan atau hasil gilingan dan dihomogenisasi,<br> produk berasal dari buah blackcurrant yang bersih, masak,<br> dipekatkan, dengan air dan gula atau madu, diawetkan secara fisik.<br> Produk dapat keruh atau jernih.",
    "Aktif",
  ],
  [
    1401030105,
    "Nektar Buah Citrus",
    "Nektar buah citrus adalah nektar hancuran buah yang dibuat dari<br> buah spesies citrus Orange (Citrus sinensis L. Osbeck); Mandarine,<br> tangerine, (Citrus reticulata) dan Grapefruit (Citrus paradisi Mcfayden)<br> dan lain-lain. Dapat dipasteurisasi atau tidak, dan ditujukan untuk<br> dikonsumsi langsung, diperoleh dengan mencampur hasil saringan<br> hancuran endokarp buah atau hasil gilingan dan dihomogenisasi,<br> produk berasal dari buah citrus masak, dipekatkan, dengan air dan<br> gula atau madu, diawetkan secara fisik.",
    "Aktif",
  ],
  [
    1401030106,
    "Nektar Jambu Biji",
    "Nektar jambu biji adalah produk buah yang dapat dipasteurisasi<br> atau tidak, dan ditujukan untuk dikonsumsi langsung, diperoleh<br> dengan mencampur hasil saringan hancuran endokarp buah atau<br> hasil gilingan dan dihomogenisasi, produk berasal dari buah jambu<br> biji (Psidium guajava), segar dan masak, dipekatkan atau tidak,<br> dengan air dan gula atau madu, diawetkan secara fisik.",
    "Aktif",
  ],
  [
    1401030107,
    "Nektar Buah",
    "Nektar buah adalah produk buah tanpa fermentasi tetapi dapat difermentasi, mengandung hancuran buah atau tidak, ditujukan untuk dikonsumsi langsung, diperoleh dengan mencampur sari<br> buah dan atau hancuran bagian buah yang dapat dimakan dan atau hasil saringan hancuran buah dari buah masak, dengan atau<br> tanpa pemekatan, dengan air, gula atau madu, dan diawetkan secara fisik. Pada buah yang mengandung gula tinggi, penambahan gula dapat diabaikan.",
    "Aktif",
  ],
  [
    1401030108,
    "Nektar Mangga",
    "Nektar Mangga adalah bubur buah yang mengandung hancuran<br> buah (pulpy atau pur\xE9e) yang dapat dipasteurisasi atau tidak, dan<br> ditujukan untuk dikonsumsi langsung, diperoleh dengan<br> mencampur hasil saringan hancuran endokarp buah atau hasil<br> gilingan dan dihomogenisasi, produk berasal dari buah mangga<br> (Mangifera indica L), segar dan masak, dipekatkan atau tidak,<br> dengan air dan gula atau madu, diawetkan secara fisik. Dapat<br> ditambahkan bahan tambahan pangan yang diizinkan.",
    "Aktif",
  ],
  [
    1401030109,
    "Nektar Sirsak",
    "Nektar Sirsak adalah bubur buah yang mengandung hancuran buah<br> (pulpy atau pur\xE9e) yang dapat dipasteurisasi atau tidak, dan<br> ditujukan untuk dikonsumsi langsung, diperoleh dengan<br> mencampur hasil saringan hancuran endokarp buah atau hasil<br> gilingan dan dihomogenisasi, produk berasal dari buah Sirsak<br> (Annona muricata L.), masak, dipekatkan atau tidak, dengan air dan<br> gula atau madu, diawetkan secara fisik.",
    "Aktif",
  ],
  [
    1401030201,
    "Nektar Sayur",
    "Nektar sayur adalah produk bubur sayur yang berupa hancuran sayur (pulpy) homogen dapat dipasteurisasi atau tidak, dan dikemas untuk siap dijual. Dapat berasal dari satu jenis sayur atau campuran dari beberapa jenis sayur.",
    "Aktif",
  ],
  [
    14010303,
    "Konsentrat Nektar Buah",
    "Konsentrat nektar buah diperoleh dari penguapan atau pembekuan dari nektar buah atau bahan pembuatnya. Konsentrat nektar buah terdapat dalam bentuk tepung, cairan, sirup dan beku untuk tujuan persiapan dari nektar buah siap minum dengan penambahan air. Contohnya adalah konsentrat nektar pir/pear dan konsentrat nektar-persik.",
    "Aktif",
  ],
  [
    14010304,
    "Konsentrat Nektar Sayur",
    "Konsentrat nektar sayur adalah konsentrat yang diperoleh dari penguapan atau pembekuan dari nektar sayur atau bahan pembuatnya. Konsentrat nektar sayur terdapat dalam bentuk tepung, cairan, sirup dan beku untuk tujuan persiapan dari nektar sayur siap minum dengan penambahan air.",
    "Aktif",
  ],
  [
    1401040101,
    "Minuman Elektrolit Berkarbonat",
    "Minuman elektrolit berkarbonat adalah minuman formulasi berkarbonasi yang ditujukan untuk menggantikan cairan, karbohidrat, elektrolit dan mineral tubuh dengan cepat. Dapat<br> mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat,<br> magnesium laktat dan magnesium sulfat.",
    "Tidak Aktif",
  ],
  [
    1401040103,
    "Minuman Isotonik Berkarbonat",
    "Minuman isotonik berkarbonat adalah minuman ringan karbonasi yang mengandung elektrolit, gula, asam sitrat dan mineral-mineral garam.",
    "Tidak Aktif",
  ],
  [1401040106, "Serbuk Minuman Berkarbonat", "", "Tidak Aktif"],
  [
    1401040108,
    "Minuman Berkarbonat",
    "Minuman berkarbonat adalah produk minuman yang diperoleh dari proses pencampuran air minum dengan bahan perisa dengan atau tanpa penambahan gula, glukosa atau bagian yang dapat dimakan, sari buah, dan karbondioksida.",
    "Tidak Aktif",
  ],
  [
    1401040109,
    "Ginger Ale",
    "Ginger ale adalah minuman berkarbonat yang dibuat dari perisa ginger ale (konsentrat perisa dengan jahe sebagai komponen utama, dengan atau tanpa bahan pemberi aroma dan penyengat, minyak citrus, sari buah dan pewarna karamel), asam organik, air minum, dan sirup gula, dengan atau tanpa pewarna karamel.<br> <br> Karakteristik dasar :<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040110,
    "Sarsaparilla",
    "Sarsaparilla adalah minuman berkarbonat yang diperoleh dari perisa sarsaparila (konsentrat perisa yang mengandung pengganti sassafras/sassafras substitute dan metil salisilat sebagai komponen<br> utama, dengan atau tanpa bahan pemberi aroma dan penyengat, dan atau tanpa pewarna karamel); asam organik; air minum dan sirup gula dengan atau tanpa pewarna karamel.<br> <br> Karakteristik dasar :<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040111,
    "Root Beer",
    "Root beer adalah minuman berkarbonat yang diperoleh dari perisa root beer (konsentrat perisa yang mengandung pengganti sassafras/sassafras substitute dan metil salisilat sebagai komponen utama, mengandung komponen perisa lainnya dan atau tanpa pewarna karamel); asam organik; air minum dan sirup gula dengan atau tanpa pewarna karamel.<br> <br> Karakteristik dasar :<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040112,
    "Birch Beer",
    "Birch beer adalah minuman berkarbonat yang diperoleh dari perisa birch beer (konsentrat perisa seperti root beer, tetapi dengan metil salisilat sebagai komponen utama), asam organik, air minum, dan sirup gula dengan atau tanpa pewarna karamel.<br> <br> Karakteristik dasar :<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040113,
    "Soda Krim (Cream soda)",
    "Soda krim (cream soda) adalah minuman berkarbonat yang diperoleh dari perisa cream soda water (konsentrat perisa vanila atau vanilin atau kombinasi keduanya sebagai komponen utama,<br> dengan bahan pemberi aroma lain, dan atau tanpa pewarna karamel); asam organik; air minum; dan sirup gula dengan atau tanpa pewarna karamel.<br> <br> Karakteristik dasar:<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040114,
    "Minuman Citrus",
    "Minuman citrus adalah minuman yang diperoleh dari sari buah citrus (konsentrasi 10 - 15%), atau perisa buah, asam organik, sirup gula dan pewarna.<br> <br> Karakteristik dasar :<br> Kandungan tidak lebih dari 14o Brix",
    "Aktif",
  ],
  [
    1401040115,
    "Minuman Kola",
    "Minuman kola adalah minuman yang diperoleh dari bahan dasar sirup gula, kafein, ekstrak buah kola (cola nut extract), asam fosfat, dan pewarna karamel.<br> <br> Karakteristik dasar :<br> Kandungan gula tidak lebih dari 14 o Brix.",
    "Aktif",
  ],
  [
    1401040116,
    "Limun",
    "Limun adalah produk minuman ringan yang mengandung gula, karbondioksida.",
    "Aktif",
  ],
  [1401040117, "Minuman Kedelai", "-", "Tidak Aktif"],
  [1401040118, "Minuman Kedelai Steril", "-", "Tidak Aktif"],
  [
    1401040119,
    "Minuman Sari Buah Berkarbonat",
    "Minuman sari buah berkarbonat adalah minuman yang diperoleh dengan mencampur air minum; sari buah atau campuran sari buah yang tidak difermentasi, dengan bagian lain dari satu jenis buah atau lebih, yang ditambahkan karbondioksida. Total sari buah tidak kurang dari 35% (b/v).<br> <br> Karakteristik dasar:<br> Kadar CO2 tidak lebih dari 5.890 mg/L",
    "Aktif",
  ],
  [
    1401040120,
    "Minuman Rasa Susu (Cair) (Berkarbonat)",
    "Minuman rasa susu adalah produk minuman yang diperoleh dari pencampuran air minum dengan susu untuk memberikan rasa, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar lemak susu kurang dari 0.3%;<br> \xE2\x{20AC}\xA2 Kadar CO2 tidak lebih dari 5.890 mg/L.",
    "Aktif",
  ],
  [
    1401040121,
    "Minuman Berperisa Berkarbonat",
    "Minuman berperisa berkarbonat adalah produk minuman yang diperoleh dari pencampuran air minum dengan bahan perisa dan gula yang mengandung karbondioksida dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik Dasar:<br> Kadar CO2 tidak lebih dari 5.890 mg/L",
    "Aktif",
  ],
  [
    1401040122,
    "Minuman Buah Berkarbonat",
    "Minuman buah berkarbonat adalah minuman yang terdiri dari satu<br> atau lebih jenis buah, yang ditambahkan karbondioksida. Total sari<br> buah 10% sampai 35% (b/v).<br> <br> Karakteristik Dasar:<br> Kadar CO2 tidak lebih dari 5.890 mg/L",
    "Aktif",
  ],
  [
    1401040123,
    "Minuman Citrus Comminutes (Berkarbonat)",
    "Minuman citrus comminutes adalah minuman ringan yang diperoleh dari proses yang melibatkan kelompok buah citrus utuh.<br> Karakteristik dasar:<br> - Kandungan buah dalam minuman 7% hingga 10% tergantung jenisnya sebelum diencerkan, dan 1,5% hingga 2% untuk minuman yang dikonsumsi tanpa pengenceran<br> - Dapat ditambahkan gula tidak lebih dari 100 g/kg",
    "Aktif",
  ],
  [
    1401040201,
    "Punches/Ades",
    "Punches / ades adalah produk minuman yang diperoleh dari campuran sari buah dengan atau tanpa penambahan perisa.",
    "Aktif",
  ],
  [
    1401040202,
    "Crush",
    "Crush adalah minuman ringan yang mengandung sari buah, bukan untuk minuman citrus comminutes, ditujukan untuk dikonsumsi tanpa diencerkan, termasuk cordial yang dikonsumsi tanpa pengenceran.<br> <br> Karakteristik dasar:<br> Kandungan buah tidak kurang dari 3% dan tidak lebih dari 5% tergantung jenisnya",
    "Aktif",
  ],
  [
    1401040203,
    "Cordials",
    "Cordials adalah minuman yang belum mempunyai status arti yang umum, tetapi dapat diaplikasikan untuk semua jenis squash jeruk yang jernih atau crush.",
    "Tidak Aktif",
  ],
  [
    1401040204,
    "Minuman Sari Buah",
    "Minuman sari buah adalah minuman yang diperoleh dengan mencampur air minum; sari buah atau campuran sari buah yang tidak difermentasi, dengan bagian lain dari satu jenis buah atau lebih, dengan atau tanpa penambahan gula. Total sari buah tidak kurang dari 35% (b/v).",
    "Aktif",
  ],
  [
    1401040205,
    "Minuman Rasa Buah",
    "Minuman berperisa/rasa buah adalah minuman yang terdiri dari satu atau lebih jenis buah, dengan total sari buah kurang dari 10% (b/v)",
    "Aktif",
  ],
  [
    1401040206,
    "Sirup Berperisa",
    "Sirup berperisa adalah produk minuman berupa larutan 65% gula yang berperisa. Dapat ditambahkan bahan pangan lain, susu tidak lebih dari 5% dihitung sebagai susu segar.",
    "Tidak Aktif",
  ],
  [
    1401040207,
    "Sirup Buah",
    "Sirup buah adalah produk yang diperoleh dengan mencampur sirup dan sari buah dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah atau lebih.",
    "Tidak Aktif",
  ],
  [
    1401040208,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi",
    "",
    "Tidak Aktif",
  ],
  [
    1401040209,
    "Minuman Berperisa...",
    "Minuman berperisa adalah produk minuman yang diperoleh dari pencampuran air minum dengan bahan perisa dan gula dengan atau tanpa penambahan bahan pangan lain melalui proses pemanasan.",
    "Tidak Aktif",
  ],
  [
    1401040210,
    "Squash",
    "Squash adalah minuman yang diperoleh dari campuran sirup atau gula dan sari buah dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah atau lebih dan dalam penggunaannya diencerkan dengan air.",
    "Tidak Aktif",
  ],
  [
    1401040211,
    "Squash Berperisa",
    "Squash berperisa adalah produk yang diperoleh dari proses pencampuran sirup dan bahan penyedap rasa dan perisa dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah-buahan atau lebih dan dalam penggunaannya harus diencerkan terlebih dahulu.",
    "Tidak Aktif",
  ],
  [
    1401040212,
    "Lemonade dan \x{2018}Fruit-Ades\x{2019} Lainnya",
    "Lemonade dan \x{2018}fruit-ades\x{2019} lainnya adalah minuman ringan yang tidak mengikuti kandungan buah didalamnya.",
    "Tidak Aktif",
  ],
  [
    1401040213,
    "Serbuk Minuman Berperisa",
    "Serbuk minuman berperisa adalah produk serbuk minuman yang diperoleh dari campuran tepung, dengan perisa (alami, identik alami, tiruan) dengan atau tanpa pemanis.",
    "Tidak Aktif",
  ],
  [
    1401040214,
    "Serbuk Minuman Rasa Jeruk",
    "Serbuk minuman rasa jeruk adalah produk serbuk minuman yang diperoleh dari campuran tepung gula pasir dengan perisa jeruk (alami, identik alami, tiruan).",
    "Tidak Aktif",
  ],
  [
    1401040215,
    "Minuman Elektrolit Tidak Berkarbonat",
    "Minuman elektrolit tidak berkarbonat adalah minuman formulasi tidak berkarbonasi yang ditujukan untuk menggantikan cairan, karbohidrat, elektrolit dan mineral tubuh dengan cepat. Dapat mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat, magnesium laktat dan magnesium sulfat.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Kandungan natrium tidak kurang dari 10 mmol/l<br> \xEF\x{201A}\xB7 Kadar gula 50 g/l hingga 100 g/l, gula tersebut merupakan jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa, dan mengandung fruktosa tidak lebih dari 50 g/l.",
    "Tidak Aktif",
  ],
  [
    1401040216,
    "Minuman Hipotonik Tidak Berkarbonat",
    "Minuman hipotonik tidak berkarbonat adalah minuman ringan tidak berkarbonasi yang mengandung elektrolit, gula, asam sitrat dan mineral-mineral garam.",
    "Tidak Aktif",
  ],
  [
    1401040217,
    "Minuman Isotonik Tidak Berkarbonat",
    "Minuman isotonik tidak berkarbonat adalah minuman ringan tidak berkarbonasi yang mengandung elektrolit, gula, asam sitrat dan mineral-mineral garam.",
    "Tidak Aktif",
  ],
  [
    1401040218,
    "Minuman Hipertonik Tidak Berkarbonat",
    "Minuman hipertonik tidak berkarbonat adalah minuman ringan tidak berkarbonasi yang mengandung elektrolit, gula, asam sitrat dan mineral-mineral garam.",
    "Tidak Aktif",
  ],
  [
    1401040219,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat",
    "Minuman dasar elektrolit (electrolyte drinks base) tidak berkarbonat adalah minuman formulasi tidak berkarbonasi berbentuk bubuk atau cair yang dikonsumsi dengan penambahan air ditujukan untuk membuat minuman elektrolit.",
    "Tidak Aktif",
  ],
  [1401040220, "Minuman Asam Jawa", "", "Tidak Aktif"],
  [1401040225, "Nata De Coco Dalam Minuman", "", "Tidak Aktif"],
  [
    1401040226,
    "Minuman Air Kelapa",
    "Minuman Air Kelapa",
    "Tidak Aktif",
  ],
  [1401040227, "Minuman Lidah Buaya", "&nbsp;", "Tidak Aktif"],
  [1401040228, "Minuman Nata De Coco", "&nbsp;", "Aktif"],
  [
    1401040229,
    "Minuman Jeli",
    "Minuman jeli adalah minuman yang menggunakan bahan baku berupa hidrokoloid sebagai komponen utama. Produk akhir berupa<br> cairan semi liquid (gel) diperoleh dari proses pencampuran air, hidrokoloid dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Memiliki tekstur/konsistensi gel semi liquid ;<br> \xE2\x{20AC}\xA2 Kandungan hidrokoloid tidak kurang dari 0,1%.",
    "Aktif",
  ],
  [1401040230, "Minuman Madu", "&nbsp;", "Tidak Aktif"],
  [
    1401040231,
    "Minuman Sari Buah (Steril Komersial)",
    "Minuman sari buah adalah minuman yang diperoleh dengan mencampur air minum; sari buah atau campuran sari buah yang tidak difermentasi, dengan bagian lain dari satu jenis buah atau lebih, dengan atau tanpa penambahan gula, karbondioksida",
    "Aktif",
  ],
  [1401040232, "Sirup Madu", "&nbsp;", "Tidak Aktif"],
  [
    1401040233,
    "Minuman Rasa Buah (Steril Komersial)",
    "Minuman rasa buah adalah minuman yang terdiri dari satu atau lebih jenis buah, dengan total sari buah kurang dari 10% (b/v).",
    "Aktif",
  ],
  [1401040234, "Minuman Nata de Coco (Steril)", "&nbsp;", "Aktif"],
  [
    1401040235,
    "Minuman Buah",
    "Minuman buah adalah minuman yang terdiri dari satu atau lebih jenis buah, dengan total sari buah 10% sampai 35% (b/v).",
    "Aktif",
  ],
  [
    1401040236,
    "Minuman Buah (Steril Komersial)",
    "Minuman buah adalah minuman yang terdiri dari satu atau lebih jenis buah, dengan total sari buah 10% sampai 35% (b/v).",
    "Aktif",
  ],
  [
    1401040237,
    "Minuman Asam Jawa (Steril Komersil)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1401040238,
    "Minuman Kopi Dalam Kemasan",
    "Minuman kopi dalam kemasan adalah minuman yang dibuat dari kopi bubuk, gula dan air minum melalui pemanasan, kandungan kafein tidak kurang dari 20 mg/kg dengan atau tanpa penambahan bahan pangan lain, dan dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    1401040239,
    "Minuman Teh Dalam Kemasan",
    "Minuman teh adalah minuman hasil seduhan daun teh atau ekstrak teh dalam air minuman dengan penambahan gula dan dikemas secara kedap (hermetis).<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Bau dan rasa khas teh<br> \xE2\x{20AC}\xA2 Mengandung kafein dan tanin",
    "Aktif",
  ],
  [
    1401040240,
    "Minuman Teh dalam Kemasan (Steril Komersial)",
    "Minuman teh dalam kemasan (Steril Komersial)",
    "Aktif",
  ],
  [
    1401040241,
    "Squash Berperisa (Steril)",
    "Squash berperisa adalah produk yang diperoleh dari proses pencampuran sirup dan bahan penyedap rasa dan perisa dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah-buahan atau lebih dan dalam penggunaannya harus diencerkan terlebih dahulu.",
    "Tidak Aktif",
  ],
  [
    1401040242,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1401040243,
    "Minuman Kopi",
    "Minuman kopi adalah minuman yang dibuat dari kopi bubuk, kopi instan, dan/atau ekstrak kopi, air minum, dengan atau tanpa penambahan gula dan bahan pangan lain.<br> <br> Karakteristik dasar :<br> Kadar kopi tidak kurang dari 4% (dihitung dari basis berat kering).",
    "Aktif",
  ],
  [
    1401040244,
    "Minuman Teh",
    "Minuman teh adalah minuman hasil seduhan daun teh atau ekstrak teh dalam air minuman dengan penambahan gula dan dikemas secara kedap (hermetis)",
    "Tidak Aktif",
  ],
  [
    1401040245,
    "Kapucino",
    "Kapucino adalah minuman yang dibuat dari espresso dan susu, yang merupakan minuman khas Italia.",
    "Aktif",
  ],
  [
    1401040246,
    "Minuman Berperisa Tidak Berkarbonat",
    "Minuman berperisa adalah produk minuman yang diperoleh dari pencampuran air minum dengan bahan perisa dan gula dengan atau tanpa penambahan bahan pangan lain melalui proses pemanasan.<br> Minuman berperisa ini tidak ditambahkan karbondioksida (Tidak Berkarbonat)",
    "Aktif",
  ],
  [
    1401040247,
    "Minuman Kopi (Steril Komersial)",
    "Minuman kopi (steril komersial) adalah minuman yang dibuat dari kopi bubuk, gula dan air minum melalui pemanasan, kandungan kafein tidak kurang dari 250 mg/kg dengan atau tanpa penambahan bahan pangan lain, dan dikemas secara kedap (hermetis) dan steril komersial.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Warna, aroma dan rasa normal<br> \xE2\x{20AC}\xA2 Kadar kopi minimum 4% (dihitung dari basis berat kering)",
    "Aktif",
  ],
  [
    1401040248,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat)",
    "Minuman Rasa Susu (Cair) adalah minuman rasa susu berbentuk cair<br> <br> Karakteristik dasar:<br> Mengandung susu kurang dari 10% dihitung sebagai susu segar<br> Kadar lemak susu kurang dari 0.3%",
    "Aktif",
  ],
  [
    1401040249,
    "Minuman Citrus Comminutes (Tidak Berkarbonat)",
    "Minuman citrus comminutes adalah minuman ringan yang diperoleh<br> dari proses yang melibatkan kelompok buah citrus utuh.<br> Karakteristik dasar:<br> - Kandungan buah dalam minuman 7% hingga 10% tergantung<br> jenisnya sebelum diencerkan, dan 1,5% hingga 2% untuk<br> minuman yang dikonsumsi tanpa pengenceran<br> - Dapat ditambahkan gula tidak lebih dari 100 g/kg<br>",
    "Aktif",
  ],
  [
    1401040250,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat)",
    "Minuman Rasa Susu (Serbuk) adalah minuman rasa susu berbentuk serbuk.<br> <br> Karakteristik dasar:<br> Mengandung susu kurang dari 10% dihitung sebagai susu segar;<br> Kadar lemak susu kurang dari 0.3%.",
    "Tidak Aktif",
  ],
  [1401040251, "Minuman Fermentasi", "-", "Tidak Aktif"],
  [1401040252, "Minuman Ringan (Plain)", "", "Aktif"],
  [
    1401040301,
    "Konsentrat Lemonade Beku",
    "Konsentrat lemonade beku adalah produk beku disiapkan dari satu atau dua sari buah jeruk lemon dengan satu atau lebih pemanis nutritif.",
    "Aktif",
  ],
  [1401040302, "Konsentrat untuk Minuman", "&nbsp;", "Tidak Aktif"],
  [
    1401040303,
    "Minuman Konsentrat Rasa ...",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1401040304,
    "Sirup Encer Berperisa",
    "Sirup encer berperisa adalah produk minuman berupa larutan gula minimal 55% dan tidak lebih dari 65% yang berperisa. Dapat ditambahkan bahan pangan lain. Dalam penggunaanya diencerkan dengan air.",
    "Aktif",
  ],
  [
    1401040305,
    "Minuman Serbuk Berperisa (Berkarbonat)",
    "Serbuk minuman/minuman serbuk berperisa (berkarbonat) adalah produk minuman dalam bentuk bubuk yang diperoleh dari campuran bahan pangan, dengan perisa (alami, identik alami, tiruan) dengan atau tanpa pemanis, berkarbonat",
    "Aktif",
  ],
  [
    1401040306,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat)",
    "Serbuk minuman/minuman serbuk berperisa (tidak berkarbonat) adalah produk minuman dalam bentuk bubuk yang diperoleh dari campuran bahan pangan, dengan perisa (alami, identik alami, tiruan) dengan atau tanpa pemanis, tidak berkarbonat",
    "Aktif",
  ],
  [
    1401040307,
    "Squash",
    "Squash adalah minuman yang diperoleh dari campuran sirup atau gula dan sari buah dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah atau lebih dan dalam penggunaannya diencerkan dengan air.<br>",
    "Aktif",
  ],
  [
    1401040308,
    "Squash Berperisa/Rasa",
    "Squash berperisa/rasa adalah produk yang diperoleh dari proses pencampuran sirup atau gula dan perisa dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah-buahan atau lebih dan dalam penggunaannya harus diencerkan terlebih dahulu.",
    "Aktif",
  ],
  [
    1401040309,
    "Sirup Buah",
    "Sirup buah adalah produk yang diperoleh dengan mencampur sirup dan sari buah dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah atau lebih.",
    "Aktif",
  ],
  [
    1401040310,
    "Sirup Berperisa",
    "Sirup berperisa adalah produk minuman berupa larutan yang berperisa dengan kadar gula tidak kurang dari 65%. Dapat ditambahkan bahan pangan lain. Dalam penggunaannya diencerkan dengan air.",
    "Aktif",
  ],
  [
    1401040311,
    "Sirup Teh",
    "Sirup teh adalah produk minuman yang mengandung gula dan ekstrak teh (Camellia sinensis) dengan atau tanpa penambahan bahan pangan lain. Dalam penggunaannya diencerkan dengan air.",
    "Aktif",
  ],
  [
    1401040312,
    "Sirup Kopi",
    "Sirup kopi adalah produk minuman yang mengandung gula dan ekstrak kopi dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    1401040313,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk)",
    "Minuman dasar elektrolit berkarbonat (electrolyte drinks base) (serbuk) adalah minuman formulasi berbentuk serbuk yang dikonsumsi dengan penambahan air ditujukan untuk membuat minuman elektrolit berkarbonat.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Saat minuman elektrolit dibuat maka kadar natrium minuman tersebut tidak kurang dari 10 mmol/l;<br> \xE2\x{20AC}\xA2 Kadar gula 50 g/l hingga 100 g/l, dan merupakan jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa, dan kadar fruktosa tidak lebih dari 50 g/l.<br> \xE2\x{20AC}\xA2 Dapat mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat, magnesium laktat dan magnesium sulfat.",
    "Tidak Aktif",
  ],
  [
    1401040314,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair)",
    "Minuman dasar elektrolit berkarbonat (electrolyte drinks base)(cair) adalah minuman formulasi berbentuk cair yang dikonsumsi dengan penambahan air ditujukan untuk membuat minuman elektrolit berkarbonat.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Saat minuman elektrolit dibuat maka kadar natrium minuman tersebut tidak kurang dari 10 mmol/l;<br> \xE2\x{20AC}\xA2 Kadar gula 50 g/l hingga 100 g/l, dan merupakan jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa, dan kadar fruktosa tidak lebih dari 50 g/l.<br> \xE2\x{20AC}\xA2 Dapat mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat, magnesium laktat dan magnesium sulfat.",
    "Tidak Aktif",
  ],
  [
    1401040315,
    "Squash Berperisa (Steril)",
    "Squash berperisa (Steril) adalah produk steril yang diperoleh dari proses pencampuran sirup atau gula dan perisa dengan atau tanpa bagian yang dapat dimakan dari satu jenis buah-buahan atau lebih dan dalam penggunaannya harus diencerkan terlebih dahulu.",
    "Aktif",
  ],
  [
    1401040316,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar)",
    "Definisi : Produk ini dibuat dari vinegar (cuka fermentasi) yang diencerkan dengan air atau bahan pangan lain. Produk harus diencerkan sebelum dikonsumsi.<br> Karakteristik Dasar :<br> Kadar asam total dihitung sebagai asam asetat tidak lebih dari 3% (b/v).<br>",
    "Aktif",
  ],
  [
    1401040317,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk)",
    "Minuman dasar elektrolit tidak berkarbonat (electrolyte drinks base) (serbuk) adalah minuman formulasi berbentuk serbuk yang dikonsumsi dengan penambahan air ditujukan untuk membuat minuman elektrolit tidak berkarbonat.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Saat minuman elektrolit dibuat maka kadar natrium minuman tersebut tidak kurang dari 10 mmol/l;<br> \xE2\x{20AC}\xA2 Kadar gula 50 g/l hingga 100 g/l, dan merupakan jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa, dan kadar fruktosa tidak lebih dari 50 g/l.<br> \xE2\x{20AC}\xA2 Dapat mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat, magnesium laktat dan magnesium sulfat.",
    "Tidak Aktif",
  ],
  [
    1401040318,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair)",
    "Minuman dasar elektrolit tidak berkarbonat (electrolyte drinks base) (cair) adalah minuman formulasi berbentuk cair yang dikonsumsi dengan penambahan air ditujukan untuk membuat minuman elektrolit tidak berkarbonat.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Saat minuman elektrolit dibuat maka kadar natrium minuman tersebut tidak kurang dari 10 mmol/l;<br> \xE2\x{20AC}\xA2 Kadar gula 50 g/l hingga 100 g/l, dan merupakan jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa, dan kadar fruktosa tidak lebih dari 50 g/l.<br> \xE2\x{20AC}\xA2 Dapat mengandung kalsium fosfat, kalium fosfat, kalsium sitrat, kalium sitrat, kalium karbonat termasuk kalium bikarbonat, kalium klorida, kalsium klorida, natrium klorida, kalsium laktat, magnesium laktat dan magnesium sulfat.",
    "Tidak Aktif",
  ],
  [
    1401040319,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial)",
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial)",
    "Tidak Aktif",
  ],
  [
    1401040320,
    "Konsentrat Minuman Rasa/Berperisa",
    "Konsentrat Minuman Rasa/Berperisa",
    "Aktif",
  ],
  [
    "140104A1",
    "Minuman Rasa Susu (Cair)",
    "Minuman Rasa Susu (Cair) adalah minuman rasa susu berbentuk cair<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Mengandung susu kurang dari 10% dihitung sebagai susu segar;<br> \xEF\x{201A}\xB7 Kadar lemak susu kurang dari 0.3%.",
    "Tidak Aktif",
  ],
  [
    "140104A2",
    "Minuman Berperisa",
    "Minuman berperisa adalah produk minuman yang diperoleh dari pencampuran air minum dengan bahan perisa dan gula dengan atau tanpa penambahan bahan pangan lain melalui proses pemanasan.",
    "Tidak Aktif",
  ],
  [
    "140104A3",
    "Minuman Citrus Comminutes",
    "Minuman citrus comminutes adalah minuman ringan yang diperoleh dari proses yang melibatkan kelompok buah citrus utuh.",
    "Aktif",
  ],
  [
    "140104A4",
    "Minuman Rasa Susu (Serbuk)",
    "Minuman Rasa Susu (Serbuk) adalah minuman rasa susu berbentuk serbuk.<br> <br> Karakteristik dasar:<br> \xEF\x{201A}\xB7 Mengandung susu kurang dari 10% dihitung sebagai susu segar;<br> \xEF\x{201A}\xB7 Kadar lemak susu kurang dari 0.3%.",
    "Tidak Aktif",
  ],
  [
    140105,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat",
    "",
    "Aktif",
  ],
  [
    14010501,
    "Teh Hitam",
    "Teh hitam adalah teh kering hasil pengolahan pucuk dan daun muda termasuk tangkainya dari tanaman teh (Camellia sinensis L.) melalui proses fermentasi.",
    "Aktif",
  ],
  [
    14010502,
    "Teh Hijau",
    "Teh hijau adalah pucuk dan daun muda tanaman teh Camellia sinensis yang telah diolah tanpa melalui proses fermentasi.",
    "Aktif",
  ],
  [
    14010503,
    "Teh Putih",
    "Teh putih adalah produk teh yang dibuat dari daun teh yang memiliki buluh-buluh putih kecil pada daun mudanya.",
    "Aktif",
  ],
  [
    14010504,
    "Teh Wangi",
    "Teh wangi adalah teh yang telah mengalami pengolahan lebih lanjut, ditambah dengan bunga melati (Jasminum sambac), bunga melati gambir (Jasminum officinale), bunga culan (Aglaia odorata), atau bagian tanaman lain dalam bentuk bahan alaminya atau ekstraknya.<br> Kadar air tidak lebih dari 8%.",
    "Aktif",
  ],
  [
    14010505,
    "Teh Wangi Tradisional",
    "Teh wangi tradisional adalah teh hijau yang telah mengalami pengolahan lebih lanjut, pewangian dengan menggunakan melati (Jasminum sambac), bunga melati gambir (Officinale var grandiflorum), atau bunga culan (Aglaia odorata).",
    "Tidak Aktif",
  ],
  [
    14010506,
    "Teh Olong atau Teh Semi Fermentasi",
    "Teh olong atau teh semi fermentasi adalah teh yang difermentasi dengan cepat, sesudah dan sebelum penggulungan. Warna daunnya setengah coklat.",
    "Aktif",
  ],
  [
    14010507,
    "Teh Hijau Bubuk",
    "Teh hijau bubuk adalah bubuk kering dihasilkan dari pengolahan pucuk dan daun muda tanaman Camellia sinensis tanpa proses fermentasi.<br> Kadar air tidak lebih dari 8%.",
    "Aktif",
  ],
  [
    14010508,
    "Teh Kering",
    "Teh kering adalah berbagai jenis teh kering (teh hitam, teh hijau, teh olong, teh wangi melati dan teh beraroma) yang dikemas dengan berat tertentu dan siap seduh.<br> Kadar air tidak lebih dari 8%.",
    "Aktif",
  ],
  [
    14010509,
    "Teh Hitam Celup",
    "Teh hitam celup adalah teh kering hasil pengolahan pucuk daun muda dan daun muda dari tanaman teh (Camellia sinensis L.) yang telah melalui proses oksidasi enzimatis dan dikemas dalam kantong dengan atau tanpa tali maupun perekat untuk dicelup dengan atau tanpa bahan pangan lain.<br> Kadar air tidak lebih dari 10%.",
    "Aktif",
  ],
  [
    14010510,
    "Teh Wangi Celup",
    "Teh wangi celup adalah teh wangi yang dikemas dalam kantong khusus untuk dicelup.",
    "Aktif",
  ],
  [
    14010511,
    "Teh Hijau Celup",
    "Teh hijau celup adalah teh kering hasil pengolahan pucuk daun muda dan daun muda dari tanaman teh (Camellia sinensis L.) tanpa melalui proses oksidasi enzimatis dan dikemas dalam kantong dengan atau tanpa tali maupun perekat untuk dicelup dengan atau tanpa bahan pangan lain.",
    "Aktif",
  ],
  [
    14010512,
    "Minuman Teh Dalam Kemasan",
    "Minuman teh dalam kemasan adalah minuman hasil seduhan daun teh atau ekstrak teh dalam air minuman dengan penambahan gula dan dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    14010513,
    "Teh Instan",
    "Teh instan adalah teh berbentuk serbuk yang mudah larut dalam air diperoleh melalui proses ekstraksi teh (Camellia sinensis L.), penyaringan, pemekatan dan pengeringan dengan atau tanpa penambahan bahan pangan lain, dan dikemas secara kedap.",
    "Aktif",
  ],
  [
    14010514,
    "Konsentrat Minuman Teh",
    "Produk yang dibuat dari ekstrak teh pekat atau ekstrak teh yang dipekatkan dengan atau tanpa penambahan bahan pangan lain. Cara mengkonsumsinya adalah cukup ditambahkan air.",
    "Aktif",
  ],
  [
    14010515,
    "Biji Kopi yang Disangrai atau Roasting",
    "Biji kopi adalah biji dari tanaman Coffea sp dalam bentuk utuh dan sudah di sangrai.<br> Kadar air tidak lebih dari 12%",
    "Aktif",
  ],
  [
    14010516,
    "Kopi Bubuk",
    "Kopi bubuk adalah biji kopi yang disangrai kemudian digiling, kandungan kafein anhidrat tidak lebih dari 2.5%.<br> <br> Karakteristik dasar :<br> Kadar air tidak lebih dari 7%.",
    "Aktif",
  ],
  [
    14010517,
    "Kopi Instan",
    "Kopi instan adalah produk kopi berbentuk serbuk atau granula atau flake yang diperoleh dari proses pemisahan biji kopi tanpa dicamput dengan bahan lain, disangrai, digiling, diekstrak dengan air, dikeringkan dengan proses spray drying (dengan atau tanpa aglomerasi) atau freeze drying atau fluidized bed drying menjadi produk yang mudah larut dalam air.",
    "Aktif",
  ],
  [
    14010518,
    "Kopi Campur",
    "Kopi campur adalah produk kopi giling dicampur dengan gandum, jagung atau wijen, margarin atau gula. Kadar kopi tidak kurang dari 50%",
    "Aktif",
  ],
  [
    14010519,
    "Minuman Kopi Dalam Kemasan",
    "Minuman kopi dalam kemasan adalah minuman yang dibuat dari kopi bubuk, gula dan air minum melalui pemanasan, kandungan kafein tidak kurang dari 20 mg/kg dengan atau tanpa penambahan bahan pangan lain, dan dikemas secara kedap (hermetis).",
    "Tidak Aktif",
  ],
  [
    14010520,
    "Konsentrat Minuman Kopi",
    "Konsentrat minuman kopi adalah produk kopi yang diperoleh melalui proses penyeduhan kopi bubuk, kopi instan, dan/atau ekstrak kopi, dilanjutkan dengan pemekatan, dengan atau tanpa penambahan bahan pangan lain. Cara mengonsumsinya adalah diencerkan dengan penambahan air. Produk ini dapat disimpan dan didistribusikan dalam bentuk beku atau tidak beku.",
    "Aktif",
  ],
  [
    14010521,
    "Minuman Botanikal/Minuman Rempah (Cair)",
    "Minuman botanikal/minuman rempah adalah produk minuman yang dibuat dari bagian tanaman (contoh daun, bunga, biji, akar, rimpang, batang) atau ekstraknya atau cairan yang berasal dari tanaman (contoh nira, air kelapa), dengan atau tanpa penambahan bahan pangan lain. Produk dapat berbentuk padat atau cair.<br> Nama jenis produk disesuaikan dengan bahan baku yang digunakan, misalnya minuman chrysanthemum, minuman rosela, serbuk minuman jahe, serbuk bandrek, serbuk bajigur, nira kelapa.<br> <br> Karakteristik dasar :<br> Jika mengandung kinina, kadar kinina tidak lebih dari 40 mg/kg",
    "Aktif",
  ],
  [
    14010522,
    "Serbuk Minuman Tradisional",
    "Serbuk minuman tradisional adalah produk minuman berbentuk serbuk atau granula yang diperoleh dari campuran gula dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    14010523,
    "Serbuk Minuman Jahe",
    "Serbuk minuman jahe adalah produk minuman berbentuk serbuk atau granula yang diperoleh dari campuran gula dan jahe dengan atau tanpa penambahan bahan pangan lain.",
    "Tidak Aktif",
  ],
  [
    14010524,
    "Serbuk Sekoteng",
    "Serbuk sekoteng adalah produk minuman berbentuk serbuk atau granula yang diperoleh dari campuran gula dan rempah dengan penambahan bahan pangan lain (biji delima, buah kolang-kaling, kacang hijau, kacang tanah, roti tawar).",
    "Tidak Aktif",
  ],
  [
    14010525,
    "Serbuk Bandrek/Serbat/Sorbat",
    "Serbuk bandrek / serbat/ sorbat adalah minuman berbentuk serbuk atau granula yang dibuat dari campuran gula atau gula merah dan jahe dengan penambahan bahan pangan lain (sereh, merica dsb).",
    "Tidak Aktif",
  ],
  [
    14010529,
    "Minuman Sari Kacang Hijau",
    "Minuman sari kacang hijau adalah minuman yang diperoleh dari sari kacang hijau dengan penambahan air, gula dan bahan pangan lainnya, melalui pemanasan dan dikemas secara kedap (hermetis).",
    "Aktif",
  ],
  [
    14010531,
    "Serbuk Minuman",
    "Serbuk minuman adalah produk minuman yang diperoleh dari campuran satu atau lebih bahan pangan yang berbentuk serbuk.",
    "Tidak Aktif",
  ],
  [
    14010532,
    "Minuman Serbuk Kopi",
    "Minuman serbuk kopi adalah produk berbentuk bubuk yang terdiri dari campuran kopi dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar kafein tidak kurang dari 1500 mg/kg;<br> \xE2\x{20AC}\xA2 Kandungan kopi tidak kurang dari 4% (dihitung dari basis berat<br> kering).",
    "Aktif",
  ],
  [
    14010533,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian",
    "",
    "Tidak Aktif",
  ],
  [14010535, "Minuman Bandrek", "&nbsp;", "Tidak Aktif"],
  [14010536, "Minuman Sekoteng", "&nbsp;", "Tidak Aktif"],
  [
    14010537,
    "Minuman Serbuk",
    "serbuk minuman adalah produk minuman yang diperoleh dari campuran satu atau lebih bahan pangan yang berbentuk serbuk. (KP)",
    "Tidak Aktif",
  ],
  [14010538, "Minuman Jahe", "&nbsp;", "Tidak Aktif"],
  [14010539, "Minuman Rosella", "&nbsp;", "Tidak Aktif"],
  [14010540, "Minuman Cincau", "&nbsp;", "Tidak Aktif"],
  [
    14010541,
    "Minuman Cincau (Steril Komersial)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    14010542,
    "Minuman ... (Steril Komersial)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [14010543, "Minuman Krisanthemum", "&nbsp;", "Tidak Aktif"],
  [
    14010544,
    "Kopi Dekafein",
    "Kopi bubuk dekafein adalah kopi yang sebagian besar kafeinnya telah dihilangkan. Mengandung tidak lebih dari 1 g/kg kafein anhidrat dihitung terhadap bobot kering",
    "Aktif",
  ],
  [
    14010545,
    "Kopi Instan Dekafein",
    "Kopi instan dekafein adalah kopi instan yang sebagian besar telah dikurangi kandungan kafeinnya melalui proses ekstraksi tertentu.",
    "Aktif",
  ],
  [
    14010546,
    "Minuman Teh dalam Kemasan Tetrapak",
    "minuman teh dalam kemasan tetrapak adalah minuman hasil seduhan daun teh atau ekstrak teh dalam air minuman dengan penambahan gula dan didalam kemasan tetrapak<br>",
    "Tidak Aktif",
  ],
  [
    14010547,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    14010548,
    "Minuman botanikal/minuman rempah (Steril Komersial)",
    "Minuman botanikal/minuman rempah adalah produk minuman yang dibuat dari bagian tanaman (contoh daun, bunga, biji, akar, rimpang, batang) atau ekstraknya atau cairan yang berasal dari tanaman (contoh nira, air kelapa), dengan atau tanpa penambahan bahan pangan lain. Produk dapat berbentuk padat atau cair.<br> Nama jenis produk disesuaikan dengan bahan baku yang digunakan, misalnya minuman chrysanthemum, minuman rosela, serbuk minuman jahe, serbuk bandrek, serbuk bajigur, nira kelapa.<br> <br> Karakteristik dasar :<br> Jika mengandung kinina, kadar kinina tidak lebih dari 40 mg/kg",
    "Tidak Aktif",
  ],
  [
    14010549,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack)",
    "&nbsp;",
    "Aktif",
  ],
  [
    14010550,
    "Kopi Celup",
    "Kopi celup adalah kopi bubuk hasil dari biji kopi yang disangraikemudian digiling, dengan atau tanpa penambahan bahan laindalam kadar tertentu yang tidak membahayakan kesehatan, dan dikemas dalam kantong khusus untuk dicelup.<br> Karakteristik dasar:<br> Bau, rasa, dan warna normal.<br> Mutu I: mengandung sari kopi 20-36% b/b, sedangkan mutu II : mengandung sari kopi tidak lebih dari 60% b/b.",
    "Aktif",
  ],
  [
    14010551,
    "Minuman Tradisional (Cair)",
    "Minuman Tradisional (Cair) adalah produk minuman berbentuk cair yang diperoleh dari campuran gula dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain<br> Karakteristik dasar:<br> Aroma dan rasa normal khas rempah-rempah.<br>",
    "Tidak Aktif",
  ],
  [
    14010553,
    "Minuman Serbuk Kopi Susu",
    "Minuman serbuk kopi susu adalah produk berbentuk bubuk, yang terdiri dari campuran kopi bubuk dan atau kopi instan, susu, dengan atau tanpa penambahan bahan pangan lain dan dikemas secara kedap.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar kafein tidak kurang dari 1500 mg/kg<br> \xE2\x{20AC}\xA2 Kadar protein (N x 6,38) tidak kurang dari 2,0 % (b/b)",
    "Aktif",
  ],
  [
    14010554,
    "Minuman Serbuk Kopi Krimer",
    "Minuman serbuk kopi krimer adalah produk berbentuk bubuk, yang terdiri dari campuran kopi bubuk dan atau kopi instan, krimer, dengan atau tanpa penambahan bahan pangan lain dan dikemas secara kedap.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar kafein tidak kurang dari 1500 mg/kg;<br> \xE2\x{20AC}\xA2 Kadar lemak tidak kurang dari 6,0 % (b/b).",
    "Aktif",
  ],
  [
    14010555,
    "Minuman Serbuk Kopi Gula",
    "Minuman serbuk kopi gula adalah produk minuman berbentuk serbuk yang diperoleh dari campuran kopi dan gula dengan atau tanpa penambahan pangan lain.<br> \xEF\x{201A}\xB7 Kadar kafein 1500 \xE2\x{20AC}\x{201C} 6000 mg/kg<br> \xEF\x{201A}\xB7 Kandungan kopi minimum 4% (dihitung dari basis berat kering)",
    "Tidak Aktif",
  ],
  [
    14010556,
    "Teh Instan Dekafein",
    "Teh instan dekafein adalah teh instan yang sebagian besar kafeinnya telah dihilangkan. Mengandung tidak lebih dari 4 g/kg kafein anhidrat dihitung terhadap bobot kering",
    "Aktif",
  ],
  [
    14010557,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk)",
    "Minuman berkafein formulasi (formulated caffeinated beverages) adalah minuman berperisa tidak beralkohol dalam bentuk serbuk yang mengandung kafein, dapat mengandung karbohidrat, asam amino, vitamin dan zat lain, termasuk bahan pangan lain.<br> Karakteristik dasar: Kadar kafein 145 mg/l hingga 320 mg/l.",
    "Aktif",
  ],
  [
    14010558,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair)",
    "Minuman berkafein formulasi (formulated caffeinated beverages) adalah minuman berperisa tidak beralkohol berbasis air yang mengandung kafein, dapat mengandung karbohidrat, asam amino, vitamin dan zat lain, termasuk bahan pangan lain.<br> Karakteristik dasar: Kadar kafein 145 mg/l hingga 320 mg/l.",
    "Aktif",
  ],
  [
    14010559,
    "Minuman botanikal/minuman rempah (Serbuk)",
    "Minuman botanikal/minuman rempah adalah produk minuman yang dibuat dari bagian tanaman (contoh daun, bunga, biji, akar, rimpang, batang) atau ekstraknya atau cairan yang berasal dari tanaman (contoh nira, air kelapa), dengan atau tanpa penambahan bahan pangan lain. Produk dapat berbentuk padat atau cair.<br> Nama jenis produk disesuaikan dengan bahan baku yang digunakan, misalnya minuman chrysanthemum, minuman rosela, serbuk minuman jahe, serbuk bandrek, serbuk bajigur, nira kelapa.<br> <br> Karakteristik dasar :<br> Jika mengandung kinina, kadar kinina tidak lebih dari 40 mg/kg",
    "Aktif",
  ],
  [
    14010560,
    "Minuman botanikal/minuman rempah (Seduhan)",
    "Minuman botanikal/minuman rempah adalah produk minuman yang dibuat dari bagian tanaman (contoh daun, bunga, biji, akar, rimpang, batang) atau ekstraknya atau cairan yang berasal dari tanaman (contoh nira, air kelapa), dengan atau tanpa penambahan bahan pangan lain. Produk dapat berbentuk padat atau cair.<br> Nama jenis produk disesuaikan dengan bahan baku yang digunakan, misalnya minuman chrysanthemum, minuman rosela, serbuk minuman jahe, serbuk bandrek, serbuk bajigur, nira kelapa.<br> <br> Karakteristik dasar :<br> Jika mengandung kinina, kadar kinina tidak lebih dari 40 mg/kg",
    "Aktif",
  ],
  [
    14010561,
    "Minuman Tradisional (Serbuk)",
    "Minuman Tradisional (Serbuk) adalah produk minuman berbentuk serbuk atau granula yang diperoleh dari campuran gula dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain<br> Karakteristik dasar:<br> Aroma dan rasa normal khas rempah-rempah.",
    "Tidak Aktif",
  ],
  [
    14010562,
    "Minuman Tradisional (Seduhan)",
    "Minuman Tradisional (Seduhan) adalah produk minuman berbentuk seduhan yang diperoleh dari campuran gula dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain<br> Karakteristik dasar:<br> Aroma dan rasa normal khas rempah-rempah.",
    "Tidak Aktif",
  ],
  [
    14010563,
    "Minuman Tradisional (Steril Komersial)",
    "Minuman Tradisional (Steril Komersial) adalah produk minuman berbentuk cair yang diproses secara steril komersial, yang diperoleh dari campuran gula dan rempah-rempah dengan atau tanpa penambahan bahan pangan lain<br> Karakteristik dasar:<br> Aroma dan rasa normal khas rempah-rempah.",
    "Tidak Aktif",
  ],
  [14010564, "Serealia Celup", "-", "Aktif"],
  [14010565, "Minuman Serealia", "-", "Aktif"],
  [
    14010566,
    "Minuman Asam Jawa",
    "Pindahan kategori pangan 1401040220",
    "Aktif",
  ],
  [
    14010567,
    "Minuman Serbuk Teh",
    "Minuman serbuk teh adalah produk minuman berbentuk serbuk yang dibuat dari teh bubuk, teh instan, dan/atau ekstrak teh, dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    14010569,
    "Serbuk Sekoteng",
    "Serbuk sekoteng adalah produk minuman berbentuk serbuk atau granula yang diperoleh dari campuran gula dan rempah dengan penambahan bahan pangan lain (biji delima, buah kolang-kaling, kacang hijau, kacang tanah, roti tawar).",
    "Aktif",
  ],
  [
    14010571,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond",
    "-",
    "Aktif",
  ],
  [
    14010572,
    "Minuman Serbuk Biji Salak",
    "Minuman Serbuk Biji Salak adalah produk berupa serbuk yang diperoleh dari biji salak melalui proses pengeringan, pemanasan dan/atau penyangraian, dan penggilingan. Dapat ditambahkan bahan pangan lain.",
    "Aktif",
  ],
  [
    14020101,
    "Bir",
    "Bir adalah minuman mengandung etanol sebagai hasil proses fermentasi khamir (yeast) terhadap bahan baku utama malt, hops (humulus lupulus) dan air yang memberikan aroma, rasa, dan sifat khas bir dapat ditambahkan bahan pangan lain seperti: beras, jagung, gula, tapioka, barley, barley yang disangrai. Malt adalah barley (Hordeum vulgare), gandum (Triticum sp. ), atau rye (Secale cereale) yang telah melalui proses pengecambahan/germinasi.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 0,5% hingga 8%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020102,
    "Bir Hitam (Stout)",
    "Bir hitam (stout) adalah minuman hasil fermentasi kamir yang mengapung darimalt dan biji barley (Hordeum vulgare) yang disangrai dan ditambahkan hops (Lupuli glandulae) dengan aroma hops yang kuat,berwarna hitam kecoklatan, dengan atau tanpa bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 2% hingga 8%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020103,
    "Ale",
    "Ale adalah minuman hasil fermentasi kamir dari gilingan malt atau kecambah barley dan hops, aromanya lebih kuat dan rasanya lebih pahit daripada bir.",
    "Aktif",
  ],
  [
    14020104,
    "Malt Liqueur",
    "Malt liqueur adalah bir dengan kadar etanol 5% hingga 9%.",
    "Tidak Aktif",
  ],
  [
    14020201,
    "Cider atau Anggur Apel",
    "Cider atau anggur apel adalah minuman hasil fermentasi lumatan buah apel dan atau produk yang berasal dari buah apel (sari buah apel, konsentrat apel), dengan kadar etanol tidak lebih dari 8,5%.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak lebih dari 8,5%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020202,
    "Perry",
    "Perry adalah minuman yang dibuat melalui fermentasi sari buah pir/pear atau campuran sari buah pir/pear dan apel dimana jumlah sari buah apel tidak lebih dari 25% v/v dari total jumlah sari buah, dengan kadar etanol tidak kurang dari 8,5%.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 8,5%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    140203,
    "Anggur (Grape Wine)",
    "Anggur (Grape Wine) Anggur (Grape wine) adalah minuman beralkohol hasil peragian sari buah anggur Vitis sp.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7%-24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020301,
    "Still Grape Wine",
    "Still Grape Wine<br> Still grape wine (putih/white, merah/red, merah jambu/ros\xC3\xA9 atau blush, dry atau sweet) adalah anggur dengan kandungan karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C.<br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7%-24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C<br> <br> catatan :<br> Kategori pangan ini sudah digantikan (sesuai jenisnya) :<br> - 1402030101 Still Grape Wine Merah / Anggur Merah (Red Wine)<br> - 1402030102 Still Grape Wine Putih / Anggur Putih (White Wine)<br> - 1402030104 Still Grape Wine Merah Jambu / Anggur Merah Jambu (Rose Wine atau Blush Wine)<br> - 1402030104 Still Grape Wine Dry atau Sweet (Dry Wine atau Sweet Wine)<br>",
    "Tidak Aktif",
  ],
  [
    1402030101,
    "Still Grape Wine Merah / Anggur Merah (Red Wine)",
    "Still Grape Wine Merah / Anggur Merah (Red Wine) adalah anggur dengan kandungan karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7%-24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C<br>",
    "Aktif",
  ],
  [
    1402030102,
    "Still Grape Wine Putih / Anggur Putih (White Wine)",
    "Still Grape Wine Putih / Anggur Putih (White Wine) adalah anggur dengan kandungan karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7%-24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar karbondioksida tidak lebih dari 0,4 g/100 ml pada suhu 20\xC2\xB0C<br>",
    "Aktif",
  ],
  [
    1402030103,
    "Stillwine",
    "Stillwine adalah anggur dengan kandungan karbondioksida tidak<br> lebih dari 0,4 g/ml pada suhu 20\xB0C.<br> <br> catatan :<br> Kategori pangan ini sudah digantikan (sesuai jenisnya) :<br> - 1402030101 Still Grape Wine Merah / Anggur Merah (Red Wine)<br> - 1402030102 Still Grape Wine Putih / Anggur Putih (White Wine)<br> - 1402030104 Still Grape Wine Merah Jambu / Anggur Merah Jambu (Rose Wine atau Blush Wine)<br> - 1402030104 Still Grape Wine Dry atau Sweet (Dry Wine atau Sweet Wine)<br>",
    "Tidak Aktif",
  ],
  [
    1402030201,
    "Anggur Sparkling dan Semi Sparkling",
    "Anggur sparkling dan semi sparkling adalah anggur yang menghasilkan karbondioksida selama fermentasinya, baik fermentasi dalam botol atau tangki tertutup. Termasuk di dalamnya anggur berkarbonasi dimana karbondioksidanya sebagian atau seluruhnya ditambahkan dari luar. Contohnya termasuk spumante dan anggur \"cold duck\".<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7%-24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar karbondioksida tidak kurang dari 0,3 g/100 ml pada suhu 20\xC2\xB0C<br>",
    "Aktif",
  ],
  [
    1402030301,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis",
    "Anggur fortifikasi, anggur liqueur dan anggur manis adalah anggur buah yang dihasilkan dari fermentasi sari buah anggur yang tinggi kandungan gulanya, atau dengan mencampurkan konsentrat sari buah anggur dengan anggur buah atau campuran dari sari buah anggur yang difermentasi dan alkohol. Contohnya termasuk grape dessert wine.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020401,
    "Anggur Buah",
    "Anggur buah adalah minuman hasil fermentasi buah-buahan (selain buah anggur, apel, pir) dan hasil pertanian lainnya dengan atau tanpa bahan pangan lain. Buah-buahan dan hasil pertanian lainnya dapat dicampur dengan anggur dan atau apel dan atau pir.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020402,
    "Anggur Beras",
    "Anggur beras adalah minuman beralkohol hasil fermentasi beras yang telah dimasak, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> <br> <br>",
    "Aktif",
  ],
  [
    14020403,
    "Anggur Beras Ketan",
    "Anggur beras ketan adalah minuman beralkohol hasil fermentasi beras ketan yang telah dimasak, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020404,
    "Anggur Brem Bali",
    "Anggur brem bali adalah minuman hasil fermentasi beras ketan. Merupakan produk khas daerah Bali.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020405,
    "Anggur Sayur (Vegetable Wine)",
    "Anggur sayur (vegetable wine) adalah minuman beralkohol yang diperoleh dari fermentasi sari sayur dan bagian lain dari sayur.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020406,
    "Tuak",
    "Tuak adalah minuman beralkohol yang diperoleh dari hasil fermentasi nira kelapa atau aren.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020407,
    "Anggur Tonikum Kinina",
    "Anggur tonikum kinina adalah minuman beralkohol yang terbuat dari anggur yang ditambah dengan kinina atau senyawa dari kinina.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar kinina (sebagai kinina hidroklorida) 0,6 g/l hingga 2,5 g/l<br>",
    "Aktif",
  ],
  [
    14020408,
    "Sake",
    "Sake adalah minuman beralkohol khas Jepang yang terbuat dari hasil fermentasi beras, dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v",
    "Aktif",
  ],
  [
    140205,
    "Mead, Anggur Madu",
    "Mead, anggur madu adalah minuman beralkohol yang diperoleh dari fermentasi campuran madu dengan air, atau dengan sari buah atau campuran madu, air dan sari buah dengan atau tanpa penambahan herbal atau rempah.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 7% dan tidak lebih dari 24% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020601,
    "Minuman Spirit",
    "Minuman spirit adalah minuman beralkohol dari penyulingan cairan beralkohol hasil fermentasi biji-bijian, buah atau gula tebu.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol lebih dari 15% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020602,
    "Brandy",
    "Brandy adalah hasil penyulingan dari fermentasi buah anggur yang dimatangkan dalam tong kayu selama tidak kurang dari 1 tahun dengan ukuran tong kayu tidak lebih dari 1000 L.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 36% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Dapat mengandung gula, glukosa, fruktosa, jus anggur maupun anggur<br>",
    "Aktif",
  ],
  [
    14020603,
    "Brandy Buah",
    "Brandy buah adalah spirit yang diperoleh dari penyulingan cairan beralkohol (liqueur) hasil fermentasi buah selain buah anggur.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 36% v/v;<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0,01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020604,
    "Cognac",
    "Cognac adalah brandy yang dibuat dari penyulingan hasil fermentasi buah anggur yang tumbuh di daerah tertentu di Perancis.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kandungan etanol tidak kurang dari 40% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020605,
    "Rum",
    "Rum merupakan minuman beralkohol hasil destilasi dari fermentasi sari tebu, sirup tebu, molase tebu atau produk tebu lainnya.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 37.5% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020606,
    "Whisky",
    "Whisky adalah minuman beralkohol dari spirit hasil peragian lumatan serealia atau biji-bijian atau hasil olahannya, dan dimatangkan dalam tong kayu selama tidak kurang dari 2 tahun.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 40% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020607,
    "Gin",
    "Gin adalah hasil penyulingan fermentasi dari biji-bijian, kentang, molases, atau bahan pertanian lainnya, penyulingan ulang dari spirit hasil penyulingan atau pencampuran beberapa spirit asli dan penambahan aroma Juniper berries (Juniperus communis L. dan atau Juniperus oxicedrus L.) dengan atau tanpa penambahan gula.<br> Umumnya gin tidak berwarna meskipun kadang-kadang berwarna emas atau coklat muda.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 37.5%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020608,
    "Vodka",
    "Vodka adalah hasil penyulingan produk fermentasi biji-bijian, kentang, molases, atau bahan pertanian lainnya dan setelah penyulingan ditambahkan arang atau karbon aktif atau absorben lainnya.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 37.5%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020609,
    "Tequila",
    "Tequila adalah hasil penyulingan produk fermentasi getah pohon century atau hasil destilasi produk fermentasi jus tanaman blue agave. Disebut juga cactus whiskey.<br> Catatan : Kategori Pangan ini sudah tidak aktif, digantikan dengan Tequila (14020613) dan Tequila \"100%\" Agave (14020614).",
    "Tidak Aktif",
  ],
  [
    14020610,
    "Arak",
    "Arak adalah minuman beralkohol yang diperoleh dari penyulingan cairan beralkohol hasil fermentasi bahan pangan misalnya beras, shorgum, molases, nira, dan atau buah-buahan.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Bau dan rasa normal dan khas<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 30% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020611,
    "Genever",
    "Genever adalah hasil penyulingan fermentasi dari biji-bijian, kentang, molases, atau bahan pertanian lainnya, penyulingan ulang dari spirit hasil penyulingan atau pencampuran beberapa spirit asli dan penambahan aroma Juniper berries (Juniperus communis L. dan atau Juniperus oxicedrus L.) dengan atau tanpa penambahan gula.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 30% v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020612,
    "Liqueur",
    "Liqueur adalah minuman beralkohol yang diperoleh dengan mencampur atau menyuling spirit dengan atau bersama buah, bunga, daun atau sayur lain atau sarinya, tunggal atau campuran atau dengan ekstrak yang berasal dari penyulingan, seduhan, perkolasi atau maserasi bahan tersebut di atas dengan atau tanpa penambahan gula.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol tidak kurang dari 15 % v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)<br> \xE2\x{20AC}\xA2 Kadar gula tidak kurang dari 2.5 % b/b dihitung terhadap berat produk akhir<br>",
    "Aktif",
  ],
  [
    14020613,
    "Tequila",
    "Tequila adalah minuman beralkohol yang berasal dari Meksiko, yang dihasilkan dari varietas tanaman agave tequilana Weber blue, yang hanya ditanam di wilayah yang telah ditentukan dalamthe Declaration for the Protection of the Appellation of Origin of Tequila dan memenuhi spesifikasi bahan baku, proses produksi, sifat fisiko kimia serta telah memenuhi persyaratan Regulasi Teknis Meksiko (Mexican Technical Regulation). Dapat ditambahkan gula dari sumber lain, sebelum fermentasi hingga kadar gula pereduksi tidak lebih dari 49%<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 35% - 55%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020614,
    "Tequila 100% Agave",
    "Tequila adalah minuman beralkohol yang berasal dari Meksiko, yang dihasilkan dari varietas tanaman agave tequilana Weber blue, yang hanya ditanam di wilayah yang telah ditentukan oleh The Declaration for the Protection of Appellation of Origin of Tequila dan memenuhi spesifikasi meliputi bahan baku, proses produksi, sifat fisika kimia dan telah memenuhi persyaratan Regulasi Teknis Meksiko (Mexican Technical Regulation), tidak boleh ditambahkan gula dari sumber lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 35% - 55%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020615,
    "Soju",
    "Soju adalah minuman beralkohol hasil destilasi dari fermentasi beras, gandum, barley, kentang, ubi, tapioka, atau pati lainnya.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 20-35 % v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020701,
    "Minuman Ringan Beralkohol",
    "Minuman ringan beralkohol adalah minuman ringan berkarbonasi yang diberi aroma dan mengandung etanol kurang dari 1%.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol kurang dari 1%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020702,
    "Anggur Rendah Alkohol",
    "Anggur rendah alkohol adalah anggur yang dikurangi kadar etanolnya dengan cara selain pengenceran dengan air.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol : reduced alcohol wine 1,2% hingga 6,5% v/v dan low alcohol wine tidak lebih dari 1.2 % v/v<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020703,
    "Koktail Anggur (Wine Cocktail)",
    "Koktail anggur (wine cocktail) adalah anggur atau anggur fortifikasi yang ditambah dengan salah satu atau campuran dari \"vegetable bitters\", bahan aroma, buah, sari buah atau bahan aroma buah, herbal kering dan atau aromanya.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7% hingga 24%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020704,
    "Shandy",
    "Shandy adalah produk minuman yang mengandung etanol tidak lebih dari 1% dibuat dari konsentrat shandy, dengan atau tanpa dicampur bir, ditambah gula, air berkarbondioksida. Umumnya shandy diperoleh dari campuran bir dan minuman tidak beralkohol.<br> <br> Karakteristik dasar:<br> Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020705,
    "Meat Wine",
    "Meat wine adalah anggur yang ditambah dengan sari daging sapi.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar protein tidak kurang dari 20 g/l<br> \xE2\x{20AC}\xA2 Kadar etanol 7% hingga 24%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)",
    "Aktif",
  ],
  [
    14020706,
    "Anggur Mengandung Temulawak",
    "Anggur mengandung temulawak adalah anggur ditambah dengan sari temulawak.",
    "Tidak Aktif",
  ],
  [
    14020707,
    "Arak Anggur Mengandung Ginseng",
    "Arak anggur mengandung ginseng adalah anggur ditambah dengan sari ginseng.",
    "Tidak Aktif",
  ],
  [
    14020708,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak)",
    "Anggur mengandung bahan pangan lain adalah anggur ditambah dengan sari atau bahan pangan lain.<br> <br> Karakteristik dasar:<br> \xE2\x{20AC}\xA2 Kadar etanol 7% hingga 24%<br> \xE2\x{20AC}\xA2 Kadar metanol tidak lebih dari 0.01% v/v (dihitung terhadap volume produk)<br>",
    "Aktif",
  ],
  [
    14020709,
    "Minuman Beralkohol Golongan A",
    "Kadar alkohol 1% sampai dengan 5%",
    "Aktif",
  ],
  [
    14020710,
    "Minuman Beralkohol Golongan B",
    "Kadar alkohol lebih dari 5% sampai dengan 20%",
    "Aktif",
  ],
  [
    14020711,
    "Minuman Beralkohol Golongan C",
    "Kadar alkohol lebih dari 20% sampai dengan 55%",
    "Aktif",
  ],
  [140208, "Minuman Beralkohol Golongan A", "-", "Tidak Aktif"],
  [140209, "Minuman Beralkohol Golongan B", "-", "Tidak Aktif"],
  [140210, "Minuman Beralkohol Golongan C", "-", "Tidak Aktif"],
  [
    "1402A1",
    "Minuman Beralkohol Golongan A",
    "Kadar alkohol 1% sampai dengan 5%",
    "Tidak Aktif",
  ],
  [
    "1402B1",
    "Minuman Beralkohol Golongan B",
    "Kadar alkohol lebih dari 5% sampai dengan 20%",
    "Tidak Aktif",
  ],
  [
    "1402C1",
    "Minuman Beralkohol Golongan C",
    "Kadar alkohol lebih dari 20% sampai dengan 55%",
    "Tidak Aktif",
  ],
  [
    150101,
    "Keripik Kentang",
    "Keripik3 kentang adalah makanan ringan yang dibuat dari umbi kentang (Solanum tuberosum) berbentuk irisan tipis dari kentang utuh atau irisan dari kentang yang sudah dipotong dan diolah dengan proses penggorengan atau pemanggangan atau proses lain yang sesuai sehingga diperoleh produk bertekstur renyah siap konsumsi dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Tekstur renyah;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 3%. (dusty), tidak lebih dari 7% (salut).",
    "Aktif",
  ],
  [
    150102,
    "Keripik Gadung",
    "Keripik2 gadung adalah makanan kering yang dibuat dari gadung (Dioscorea hispida) berbentuk irisan tipis yang digoreng dengan atau tanpa penambahan bahan lainnya.",
    "Aktif",
  ],
  [
    150103,
    "Krekers Beras (Senbei)",
    "Kreker beras (senbei) adalah makanan ringan yang terbuat dari beras atau tepung beras dengan campuran bahan atau pati lain dan bahan lainnya.",
    "Aktif",
  ],
  [
    150104,
    "Keripik Singkong",
    "Keripik3 singkong adalah makanan ringan yang dibuat dari umbi singkong (Manihot sp.) berbentuk irisan tipis dari singkong utuh atau<br> irisan singkong yang sudah dipotong dan diolah dengan proses penggorengan atau pemanggangan atau proses lain yang sesuai, sehingga diperoleh produk bertekstur renyah siap konsumsi dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Tekstur renyah;<br> \xE2\x{20AC}\xA2 Kadar air maksimal 6% (dusty), 7% (salut)",
    "Aktif",
  ],
  [150106, "Keripik Sanjai", "", "Aktif"],
  [
    150108,
    "Keripik Ubi Jalar",
    "Keripik ubi jalar adalah makanan kering yang dibuat dari ubi jalar (Manihot esculenta) berbentuk irisan tipis yang digoreng dengan atau tanpa penambahan bahan lainnya.",
    "Aktif",
  ],
  [
    150109,
    "Keripik Tempe",
    "Keripik3 tempe adalah makanan ringan yang dibuat dari tempe kedelai (Glycine max) berbentuk lempengan/irisan tipis dengan proses penggorengan atau pengeringan sehingga diperoleh produk bertekstur renyah dengan atau tanpa penambahan bahan pangan lain.<br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Tekstur renyah;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 4%.",
    "Aktif",
  ],
  [
    150110,
    "Keripik Oncom",
    "Keripik oncom adalah makanan khas dari Bandung yang umumnya terbuat dari oncom merah, yang merupakan hasil fermentasi bungkil kacang kedelai. Keripik oncom terbuat dari oncom yang diiris tipis-tipis, kemudian dilapisi dengan campuran tepung dan bahan lain",
    "Aktif",
  ],
  [
    150111,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu",
    "Keripik3 tahu/keripik3 produk tahu/keripik3 kembang tahu adalah makanan kering yang dibuat dari tahu atau produk olahan tahu dengan proses penggorengan atau pengeringan sehingga diperoleh produk bertekstur renyah dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> Kadar air tidak lebih dari 10%.",
    "Aktif",
  ],
  [
    150112,
    "Keripik Talas",
    "Keripik3 talas adalah makanan ringan yang dibuat dari umbi talas (Colocasia esculenta L) berbentuk irisan tipis yang digoreng dengan atau tanpa penambahan bahan pangan lain.<br> <br> Karakteristik dasar :<br> \xE2\x{20AC}\xA2 Tekstur renyah;<br> \xE2\x{20AC}\xA2 Kadar air tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    150113,
    "Makanan Ringan Simulasi",
    "Makanan ringan simulasi adalah makanan ringan yang terbuat dari<br> tepung dan/atau pati (serealia, umbi, kacang-kacangan) dengan<br> pencampuran bahan lain, dibentuk atau dipotong,<br> dijemur/dikeringkan atau langsung digoreng/dioven.<br> Produk ini tidak termasuk keripik3 kentang, keripik3 singkong atau<br> keripik3 umbi-umbian lainnya.",
    "Aktif",
  ],
  [
    150114,
    "Kecimpring",
    "Kecimpring adalah makanan ringan yang terbuat dari singkong (ubi<br> kayu), bumbu. Pembuatan meliputi pemarutan singkong untuk<br> dicampur dengan bumbu. Kemudian adonan dipres hingga tipis,<br> dilanjutkan dengan pengukusan dan penjemuran. Setelah kering,<br> cetakan (pelat pres) dilepas, dipotong dan digoreng.",
    "Aktif",
  ],
  [
    150115,
    "Opak",
    "Opak adalah makanan ringan yang terbuat dari tepung beras atau singkong atau umbi-umbi lainnya yang diparut dengan penambahan bahan lain, dibentuk dan dipanggang.",
    "Aktif",
  ],
  [
    150116,
    "Simping",
    "Simping adalah makanan ringan khas Jawa Barat dengan rasa asin<br> dan citarasa khas. Simping terbuat dari bahan tapioka, garam dan<br> kencur halus yang dicampur menjadi adonan, kemudian dimasak<br> pada cetakan khusus (dipres diantara dua pelat tebal) dan proses<br> pemasakan melibatkan pembakaran kedua pelat tersebut pada api<br> secara langsung.",
    "Aktif",
  ],
  [
    150117,
    "Slondok",
    "Slondok adalah makanan ringan terbuat dari tepung singkong atau tapioka dengan campuran bahan dan pati lain.",
    "Aktif",
  ],
  [
    150118,
    "Pilus",
    "Pilus adalah makanan ringan terbuat dari tepung singkong/tapioka<br> dengan campuran bahan atau pati lain dan bumbu rempah; yang<br> diproses dengan atau tanpa menggunakan mesin ekstrusi kemudian<br> dipotong menjadi ukuran kecil dan digoreng atau dipanggang.",
    "Aktif",
  ],
  [
    150119,
    "Jagung Berondong",
    "Jagung berondong adalah makanan ringan terbuat dari jagung (Zea<br> mays) varietas popping corn, diolah dengan pemanasan hingga<br> menyebabkan peletupan dan pengembangan dengan atau tanpa<br> penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    150120,
    "Jagung Marning",
    "Jagung marning adalah makanan ringan yang dibuat dari biji jagung<br> (Zea mays) tua, direbus, dikeringkan dan digoreng dengan atau tanpa<br> penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    150121,
    "Jipang Jagung",
    "Jipang jagung adalah makanan ringan dibuat dari jagung (Zea mays)<br> yang diolah sampai mengembang dengan proses penggorengan atau<br> pemanggangan atau puffing/ekstrusi atau terlebih dahulu dikukus,<br> dikeringkan dan digoreng sampai mengembang, dicampur dengan<br> gula, kemudian dicetak, dengan atau tanpa penambahan bahan<br> pangan lain.",
    "Aktif",
  ],
  [
    150122,
    "Jipang Beras",
    "Jipang beras adalah produk makanan ringan yang dibuat dari beras<br> (Oryza sativa L.) dan/atau beras ketan (Oryza sativa var. glutinosa)<br> yang diolah dengan proses penggorengan atau pemanggangan atau<br> puffing/ekstrusi atau terlebih dahulu dikukus, dikeringkan dan<br> digoreng sampai mengembang, dicampur dengan gula, kemudian<br> dicetak, dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    150123,
    "Kerupuk Beras",
    "Kerupuk4 beras adalah makanan ringan terbuat dari bahan tepung<br> beras atau tepung beras ketan yang dengan atau tanpa penambahan<br> bahan pangan lain, dibentuk, direbus/dikukus, dicetak lempengan<br> tipis, dikeringkan dan digoreng.",
    "Aktif",
  ],
  [
    150124,
    "Kerupuk Puli",
    "Kerupuk puli adalah makanan ringan terbuat dari tepung beras yang dicampur dengan bahan lain, dibentuk, direbus/dikukus, dicetak lempengan tipis, dikeringkan dan digoreng. Umumnya ditambahkan udang.",
    "Aktif",
  ],
  [
    150125,
    "Kerupuk Karak",
    "Kerupuk4 karak adalah makanan ringan terbuat dari hasil<br> pemasakan nasi, ditumbuk yang kemudian dikeringkan kembali<br> untuk digoreng.",
    "Aktif",
  ],
  [
    150126,
    "Kerupuk Intip",
    "Kerupuk4 intip adalah makanan ringan terbuat dari bagian/lapisan<br> yang diperoleh dari hasil pemasakan nasi yang menempel pada<br> bagian dasar wadah, dikeringkan kembali untuk digoreng dengan<br> atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [
    150127,
    "Rengginang/ Batiah",
    "Rengginang/batiah adalah makanan ringan terbuat dari beras ketan<br> yang telah dimasak menjadi nasi ketan terlebih dahulu, dengan atau<br> tanpa penambahan bahan pangan lain, dibentuk, dijemur hingga<br> kering dan digoreng.",
    "Aktif",
  ],
  [
    150128,
    "Rempeyek",
    "Rempeyek adalah makanan ringan berbentuk tipis dan renyah,<br> terbuat dari tepung beras dengan atau tanpa campuran tepung lain,<br> dicampur dengan bahan pangan lain seperti kacang tanah, kacang<br> kedelai, kacang hijau, ikan atau bahan pangan lain kemudian<br> digoreng. Nama jenis untuk produk ini misalnya rempeyek kacang,<br> rempeyek kacang kedelai.",
    "Aktif",
  ],
  [
    150129,
    "Makanan Ringan Ekstrudat",
    "Makanan ringan siap makan yang dibuat dari bahan pangan sumber<br> karbohidrat dan/atau protein melalui proses ekstrusi dengan atau<br> tanpa penambahan bahan pangan lain, dengan atau tanpa melalui<br> proses lainnya seperti penggorengan/ pemanggangan.",
    "Aktif",
  ],
  [
    150130,
    "Emping Melinjo Goreng",
    "Emping melinjo goreng adalah produk keripik yang diperoleh dari emping melinjo yang digoreng dengan atau tanpa penambahan bahan lain.",
    "Aktif",
  ],
  [150131, "Keripik Lainnya", "&nbsp;", "Aktif"],
  [150132, "Kerupuk Lainnya", "&nbsp;", "Aktif"],
  [150133, "Makanan Ringan Lain", "&nbsp;", "Aktif"],
  [
    150134,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati",
    "-",
    "Aktif",
  ],
  [
    150135,
    "Krekers Rasa",
    "Krekers rasa adalah jenis krekers dari terigu dan/atau non terigu yang dalam pembuatannya memerlukan proses fermentasi atau tidak, serta melalui proses laminasi sehingga menghasilkan bentuk pipih dan bila dipatahkan penampangnya tampak berlapis-lapis, diberi bahan sebagai sumber rasa misalnya gula, keju, abon, cokelat. Nama jenis untuk kategori ini disesuaikan dengan bahan sumber rasanya, misalnya krekers abon, krekers cokelat, krekers manis, krekers gurih.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 5%",
    "Aktif",
  ],
  [
    150136,
    "Krekers Sandwich",
    "Krekers sandwich adalah jenis krekers dari terigu dan/atau non terigu dengan menggunakan krim filling (rasa keju, rasa coklat, rasa buah, dan lain-lain) sedikitnya terdiri dari 2 (dua) keping krekers.",
    "Aktif",
  ],
  [
    150137,
    "Malkist",
    "Malkist adalah jenis krekers dari terigu dan/atau non terigu fermentasi yang pada proses laminasinya menggunakan cracker dust di antara lapisan-lapisannya yang permukaannya disalut atau ditaburi gula.<br> Karakteristik dasar :<br> Kadar air tidak lebih dari 5%.",
    "Aktif",
  ],
  [
    150138,
    "Jipang Melinjo",
    "Jipang melinjo adalah makanan ringan dibuat dari melinjo (Gnetum gnemon) yang diolah dengan proses penggorengan atau pemanggangan atau puffing/ekstrusi atau terlebih dahulu dikukus, dikeringkan dan digoreng sampai mengembang, dicampur dengan gula, kemudian dicetak, dengan atau tanpa penambahan bahan pangan lain. Karakteristik dasar: Kadar air tidak lebih dari 8%.",
    "Aktif",
  ],
  [
    150139,
    "Patilo / Rengginang Singkong",
    "Patilo/rengginang singkong adalah makanan ringan sejenis rengginang yang terbuat dari singkong, dengan atau tanpa penambahan bahan pangan lain, dibentuk, dijemur hingga kering dan digoreng.",
    "Aktif",
  ],
  [
    150140,
    "Makanan Ringan Berbentuk Batang/Bar",
    "Makanan ringan terbuat dari campuran bahan sumber karbohidrat dan/atau protein, dengan atau tanpa penambahan gula, lemak, dan bahan pangan lain seperti cokelat, buah kering, serealia, dan dibentuk batang (bar).",
    "Aktif",
  ],
  [
    150201,
    "Kacang Garing/Kacang Kulit",
    "Kacang garing/kacang kulit adalah kacang tanah atau kacang lainnya yang masih dalam kulitnya, direndam, direbus dengan atau tanpa penambahan bahan pangan lain, ditiriskan kemudian dipanggang/dioven.",
    "Aktif",
  ],
  [
    150204,
    "Kacang Panggang",
    "Kacang panggang adalah kacang tanah yang telah dihilangkan kulit<br> arinya, kemudian dipanggang/dioven. Dengan atau tanpa pelapisan<br> bumbu. Nama jenis untuk produk ini misalnya kacang Bali.",
    "Aktif",
  ],
  [
    150205,
    "Kacang Mede",
    "Kacang mede adalah biji dari buah tanaman jambu mete (Anacardium occidentale) yang telah dikupas kulitnya, dikeringkan dan dapat dipanggang atau digoreng.",
    "Tidak Aktif",
  ],
  [150206, "Kipang Kacang Mete", "", "Aktif"],
  [
    150207,
    "Kacang Atom/Sukro",
    "Kacang atom/sukro adalah makanan ringan yang terbuat dari kacang tanah dan disalut dengan adonan tepung dan/atau pati, dan digoreng atau dipanggang. Dapat ditambahkan bumbu atau bahan pangan lain.",
    "Aktif",
  ],
  [
    150208,
    "Kacang Telur",
    "Kacang telur adalah makanan ringan yang terbuat dari kacang tanah (Arachis hypogea L) dan disalut dengan adonan tepung dan/atau pati dan telur yang telah dibumbui dan digoreng.",
    "Aktif",
  ],
  [
    150209,
    "Kacang Goyang",
    "Kacang goyang adalah kacang tanah (Arachis hypogea L) yang telah dihilangkan kulit arinya, disalut dengan adonan bergula, kemudian diproses dengan penggoyangan secara panas.",
    "Aktif",
  ],
  [
    150210,
    "Jipang/Kipang Kacang",
    "Jipang/kipang kacang adalah makanan ringan, dibuat dari kacang tanah (Arachis hypogea L) atau kacang lainnya, disangrai, dihilangkan kulit arinya, dicampur dengan gula, dengan atau tanpa penambahan bahan pangan lain.",
    "Aktif",
  ],
  [150211, "Kacang Kapri", "", "Tidak Aktif"],
  [150212, "Kacang Koro", "", "Tidak Aktif"],
  [150213, "Kacang Bogor", "", "Tidak Aktif"],
  [150214, "Kacang Pistacio", "-", "Tidak Aktif"],
  [150215, "Makanan Ringan Berbahan Dasar Kacang", "-", "Aktif"],
  [
    150216,
    "Kacang Atom Lainnya",
    "PERATURAN BADAN PENGAWAS OBAT DAN MAKANAN NOMOR 34 TAHUN 2019 TENTANG KATEGORI PANGAN<br> <br> Kacang atom lainnya adalah makanan ringan yang terbuat dari kacang selain kacang tanah dan disalut dengan adonan tepung<br> dan/atau pati, dan digoreng atau dipanggang. Dapat ditambahkan bumbu atau bahan pangan lain. Nama jenis untuk produk ini misalnya kacang atom kedelai.",
    "Aktif",
  ],
  [
    150217,
    "Kacang Sangrai",
    "Kacang sangrai adalah kacang tanah yang masih dalam kulitnya dan disangrai.<br> <br> Karakteristik dasar:<br> Kadar air tidak lebih dari 3%",
    "Aktif",
  ],
  [
    150218,
    "Kacang Goreng Lainnya",
    "Kacang goreng lainnya adalah kacang selain kacang tanah dengan atau tanpa kulit ari, yang telah digoreng, dengan atau tanpa penambahan bahan pangan lain. Nama jenis untuk produk ini misalnya kacang kedelai goreng, kacang koro goreng, kacang kapri goreng, kacang bogor goreng.",
    "Aktif",
  ],
  [
    150219,
    "Kacang Panggang Lainnya",
    "Kacang panggang lainnya adalah kacang selain kacang tanah yang telah dihilangkan kulit arinya, kemudian dipanggang/dioven. Dengan atau tanpa pelapisan bumbu. Nama jenis untuk produk ini misalnya kacang mede panggang, kacang koro panggang.",
    "Aktif",
  ],
  [
    150220,
    "Kacang Bersalut",
    "Kacang bersalut adalah makanan ringan, dibuat dari kacang yang<br> dilapisi dengan tepung/pati, gula atau bahan lainnya. Kacang<br> bersalut termasuk di dalamnya kacang atom/sukro, kacang telur,<br> kacang goyang, dan lain-lain.",
    "Aktif",
  ],
  [
    150221,
    "Kacang Goreng",
    "Kacang goreng adalah kacang tanah dengan atau tanpa kulit ari, yang telah digoreng, dengan atau tanpa penambahan bahan pangan lain",
    "Aktif",
  ],
  [150222, "Kacang Alas (Biji Sengon)", "&nbsp;", "Aktif"],
  [
    150301,
    "Kerupuk Ikan",
    "Kerupuk ikan adalah makanan ringan, dibuat dari campuran ikan laut atau ikan air tawar, beku atau segar dengan tepung tapioka, sagu atau tepung pati dan atau bahan lainnya. Dapat mengandung gula dan rempah. Digoreng, dikemas dalam kemasan kedap.",
    "Aktif",
  ],
  [
    150302,
    "Kerupuk Udang Matang",
    "Kerupuk udang adalah makanan ringan dibuat dari campuran udang beku atau segar dengan tepung tapioka, sagu atau tepung pati lainnya. Dapat mengandung gula dan rempah. Digoreng, dikemas dalam kemasan kedap.",
    "Aktif",
  ],
  [
    150303,
    "Kerupuk Cumi",
    "Kerupuk cumi adalah makanan ringan dibuat dari cumi-cumi beku atau segar dengan tepung tapioka, sagu atau tepung pati lainnya. Dapat ditambahkan rempah atau bahan lainnya. Digoreng, dikemas dalam kemasan kedap.",
    "Aktif",
  ],
  [
    150304,
    "Kemplang",
    "Kemplang adalah makanan ringan dibuat dari campuran produk perikanan beku atau segar dengan tepung tapioka, sagu atau tepung pati lainnya. Dapat mengandung gula dan rempah. Dipanggang, dikemas dalam kemasan kedap.",
    "Aktif",
  ],
  [
    150305,
    "Rempeyek Ikan",
    "Rempeyek ikan adalah makanan ringan dibuat dari tepung beras dengan atau tanpa campuran pati lain, dicampur dengan bahan lain seperti teri, udang atau bahan lainnya kemudian digoreng.",
    "Aktif",
  ],
  [
    150306,
    "Sumpia Udang",
    "Sumpia udang adalah makanan ringan yang berbentuk seperti lumpia dengan ukuran kecil yang dibuat dari adonan tepung terigu dan/atau tepung lainnya, diisi udang dengan atau tanpa bahan pangan lain dan digoreng.",
    "Aktif",
  ],
  [150307, "Getas", "", "Aktif"],
  [150308, "Makanan Ringan Berbasis Ikan, dll", "&nbsp;", "Aktif"],
  [1606, "Nasi Goreng Instan", "", "Tidak Aktif"],
  [1609, "Nasi Kuning Instan", "", "Tidak Aktif"],
  [1611, "Nasi Kunyit Instan", "", "Tidak Aktif"],
  [1613, "Nasi Liwet Instan", "", "Tidak Aktif"],
  [1615, "Nasi Uduk Instan", "", "Tidak Aktif"],
  [
    1657,
    "Pengembang Roti/Kue (Bread Improver)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [1658, "Pangsit Isi Sayuran", "&nbsp;", "Tidak Aktif"],
  [1659, "Sup Jamur", "&nbsp;", "Tidak Aktif"],
  [1660, "Sup Sayuran", "&nbsp;", "Tidak Aktif"],
  [1661, "Lumpia Isi", "-", "Tidak Aktif"],
  [1662, "Kroket Isi", "-", "Tidak Aktif"],
  [
    1663,
    "Nasi Campur Lauk (daging, ikan, dll)",
    "-",
    "Tidak Aktif",
  ],
  [
    1664,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1665,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1666,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril)",
    "",
    "Tidak Aktif",
  ],
  [
    1667,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur)",
    "&nbsp;",
    "Tidak Aktif",
  ],
  [
    1668,
    "Nasi Instan Dengan ....",
    "Nasi instan dengan \xE2\x{20AC}\xA6 adalah produk nasi instan yang mengandung bumbu, kacang, daging, sayur dan atau bahan pangan lainnya.",
    "Tidak Aktif",
  ],
  [
    1669,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging",
    "",
    "Tidak Aktif",
  ],
  [
    1670,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....)",
    "-",
    "Tidak Aktif",
  ],
  [
    1671,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk)",
    "Kategori pangan ini mengakomodir pendaftaran dari produk kombinasi, di mana dalam satu kemasan terdiri dari 2 macam produk. Untuk kategori pangan ini produk terdiri dari produk bakeri istimewa (wafer, biskuit, kukis dll) dan minuman serbuk.",
    "Tidak Aktif",
  ],
  [
    1672,
    "Olahan Gluten (Diolah dengan Perlakuan Panas)",
    "-",
    "Tidak Aktif",
  ],
  [1673, "Nasi Instan Dengan .... (Steril)", "-", "Tidak Aktif"],
  [1674, "Kolak", "-", "Tidak Aktif"],
  [1675, "Bakso Campur dan Batagor", "-", "Tidak Aktif"],
  [
    1676,
    "Makanan Siap Saji Berbasis Nasi (Terkemas)",
    "Makanan cepat saji berbasis nasi, misalnya nasi goreng, nasi uduk, nasi kuning, nasi opor ayam, nasi rendang ayam, ketupat sayur, pecel lele, lontong sate ayam, bubur ayam.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1677,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas)",
    "Makanan cepat saji berbasis mi/bihun, kecuali mi instan dengan<br> bahan pelengkap/garnish yang kering. Misalnya mi/bihun goreng<br> dengan ayam, mi/bihun ayam jamur, mi rendang, ramen ayam.<br> <br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1678,
    "Makanan Siap Saji Berbasis Kentang (Terkemas)",
    "Makanan cepat saji berbasis kentang, misalnya steak.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1679,
    "Makanan Siap Saji Berbasis Pasta (Terkemas)",
    "Makanan cepat saji berbasis pasta, misalnya makaroni dan keju, lasagna, spaghetti marinara.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1680,
    "Makanan Siap Saji Berbasis Umbi (Terkemas)",
    "Makanan cepat saji berbasis umbi, seperti tiwul dengan lauk.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1681,
    "Makanan Siap Saji Berbasis Roti (Terkemas)",
    "Makanan cepat saji berbasis roti, seperti burger, pizza, hotdog, kebab, panini, tortilla, roti canai dan kare.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1682,
    "Makanan Siap Saji Berbasis Kuah (Terkemas)",
    "Makanan cepat saji berkuah, misalnya soto bersantan, soto tanpa<br> santan, sop, rawon, sambal tumpang, dan brongkos.<br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [
    1683,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas)",
    "Makanan cepat saji berbasis sayuran, misalnya pecel, lotek, cap cay,<br> gado-gado, karedok, rujak cingur, sayur nangka, dan gudeg.<br> <br> Pangan siap saji, tidak termasuk Kategori Pangan 01 - 15. Terdiri dari campuran produk pangan dari Kategori Pangan 01 \xE2\x{20AC}\x{201C} 15, minimal 2 Kategori Pangan yang berbeda. Masing-masing produk pangan penyusun dapat diidentifikasi (terlihat jelas) sesuai jenis pangan. Apabila dilakukan pemanasan hanya untuk tujuan menghangatkan.",
    "Aktif",
  ],
  [99, "Bahan Tambahan Pangan", "", "Aktif"],
];
# END FRAGMENT id=data-idn_bpom_kategori_pangan

our $meta_reg_code_prefixes = {
  summary => "Known alphabetical prefixes in BPOM registered product codes",
  "fields" => {
    code => {
      pos => 0,
      schema => ["str*"],
      sortable => 1,
      summary => "code",
    },
    division => {
      pos      => 1,
      schema   => ["str*"],
      sortable => 1,
      summary  => "Division (food, supplement [including herbal], medicine)",
      unique   => 0,
    },
    summary_eng => {
      pos      => 2,
      schema   => ["str*"],
      sortable => 1,
      summary  => "Summary (in English)",
      unique   => 0,
    },
    summary_ind => {
      pos      => 3,
      schema   => ["str*"],
      sortable => 1,
      summary  => "Summary (in Indonesian)",
      unique   => 0,
    },
  },
  "pk" => "code",
  "summary" => "BPOM registered product code prefixes",
  "summary.alt.lang.id_ID" => "Awalan huruf di kode produk terdaftar BPOM",
};

our $data_reg_code_prefixes = [
    ["MD", "food", "Food (local)", "Makanan (dalam negeri)"],
    ["ML", "food", "Food (imported)", "Makanan (impor)"],


    # ?N? and ?P? codes currently are not listed here

    ["DBL", "medicine", "Local (L) OTC (B) patented (D) medicine", "Obat paten (D) bebas (B) lokal (L)"],
    ["DBI", "medicine", "Imported (L) OTC (B) patented (D) medicine", "Obat paten (D) bebas (B) impor (I)"],
    ["DBE", "medicine", "Exported (L) OTC (B) patented (D) medicine", "Obat paten (D) bebas (B) ekspor (E)"],
    ["DBX", "medicine", "Special-purpose (X) OTC (B) patented (D) medicine", "Obat paten (D) bebas (B) keperluan khusus (X)"],

    ["DTL", "medicine", "Local (L) limited-OTC (T) patented (D) medicine", "Obat paten (D) bebas terbatas (T) lokal (L)"],
    ["DTI", "medicine", "Imported (L) limited-OTC (T) patented (D) medicine", "Obat paten (D) bebas terbatas (T) impor (I)"],
    ["DTE", "medicine", "Exported (L) limited-OTC (T) patented (D) medicine", "Obat paten (D) bebas terbatas (T) ekspor (E)"],
    ["DTX", "medicine", "Special-purpose (X) limited-OTC (T) patented (D) medicine", "Obat paten (D) bebas terbatas (T) keperluan khusus (X)"],

    ["DKL", "medicine", "Local (L) hard (K) patented (D) medicine", "Obat paten (D) keras (K) lokal (L)"],
    ["DKI", "medicine", "Imported (L) hard (K) patented (D) medicine", "Obat paten (D) keras (K) impor (I)"],
    ["DKE", "medicine", "Exported (L) hard (K) patented (D) medicine", "Obat paten (D) keras (K) ekspor (E)"],
    ["DKX", "medicine", "Special-purpose (X) hard (K) patented (D) medicine", "Obat paten (D) keras (K) keperluan khusus (X)"],

    ["GBL", "medicine", "Local (L) OTC (B) generic (G) medicine", "Obat generik (G) bebas (B) lokal (L)"],
    ["GBI", "medicine", "Imported (L) OTC (B) generic (G) medicine", "Obat generik (G) bebas (B) impor (I)"],
    ["GBE", "medicine", "Exported (L) OTC (B) generic (G) medicine", "Obat generik (G) bebas (B) ekspor (E)"],
    ["GBX", "medicine", "Special-purpose (X) OTC (B) generic (G) medicine", "Obat generik (G) bebas (B) keperluan khusus (X)"],

    ["GTL", "medicine", "Local (L) limited-OTC (T) generic (G) medicine", "Obat generik (G) bebas terbatas (T) lokal (L)"],
    ["GTI", "medicine", "Imported (L) limited-OTC (T) generic (G) medicine", "Obat generik (G) bebas terbatas (T) impor (I)"],
    ["GTE", "medicine", "Exported (L) limited-OTC (T) generic (G) medicine", "Obat generik (G) bebas terbatas (T) ekspor (E)"],
    ["GTX", "medicine", "Special-purpose (X) limited-OTC (T) generic (G) medicine", "Obat generik (G) bebas terbatas (T) keperluan khusus (X)"],

    ["GKL", "medicine", "Local (L) hard (K) generic (G) medicine", "Obat generik (G) keras (K) lokal (L)"],
    ["GKI", "medicine", "Imported (L) hard (K) generic (G) medicine", "Obat generik (G) keras (K) impor (I)"],
    ["GKE", "medicine", "Exported (L) hard (K) generic (G) medicine", "Obat generik (G) keras (K) ekspor (E)"],
    ["GKX", "medicine", "Special-purpose (X) hard (K) generic (G) medicine", "Obat generik (G) keras (K) keperluan khusus (X)"],


    ["SD", "supplement+cosmetic", "Local supplement", "Suplemen dalam negeri"],
    ["SI", "supplement+cosmetic", "Imported supplement", "Suplemen impor"],
    ["SL", "supplement+cosmetic", "Licensed Supplement", "Suplemen dalam negeri dengan lisensi"],

    ["BTR", "supplement+cosmetic", "Local traditional medicine/production medicine", "Obat tradisional berbatasan dengan obat produksi, dalam negeri"],
    ["BTI", "supplement+cosmetic", "Imported traditional medicine/production medicine", "Obat tradisional berbatasan dengan obat produksi, impor"],
    ["BTL", "supplement+cosmetic", "Licensed traditional medicine/production medicine", "Obat tradisional berbatasan dengan obat produksi, dalam negeri dengan lisensi"],

    ["NA", "supplement+cosmetic", "Cosmetics from Asia including local", "Kosmetik dari Asia termasuk lokal"],
    ["NB", "supplement+cosmetic", "Cosmetics from Australia", "Kosmetik dari Australia"],
    ["NC", "supplement+cosmetic", "Cosmetics from Europe", "Kosmetik dari Eropa"],
    ["ND", "supplement+cosmetic", "Cosmetics from Africa", "Kosmetik dari Afrika"],
    ["NE", "supplement+cosmetic", "Cosmetics from America", "Kosmetik dari Amerika"],
];

# BEGIN FRAGMENT id=meta-idn_bpom_bahan_baku_pangan varname=meta_idn_bpom_bahan_baku_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_bahan_baku_pangan/meta.yaml
# src-revision: ee31160a5cacaff81583d27f8c688d7a6ea681c0 (Mon Oct 31 18:06:17 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_bahan_baku_pangan = {
  "fields" => {
    country_of_origin => {
      "filterable_regex" => "Yes",
      "pos" => 4,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Country of origin",
      "summary.alt.lang.id" => "Negara asal",
      "unique" => "No",
    },
    id => {
      "pos" => 0,
      "schema" => "uint*",
      "sortable" => "Yes",
      "summary" => "ID",
      "summary.alt.lang.id" => "ID",
      "unique" => "Yes",
    },
    is_herbal => {
      "filterable_regex" => "No",
      "pos" => 5,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Herbal?",
      "summary.alt.lang.id" => "Herbal?",
      "unique" => "No",
    },
    name => {
      "filterable_regex" => "Yes",
      "pos" => 1,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Name of ingredient",
      "summary.alt.lang.id" => "Nama bahan",
      "unique" => "No",
    },
    origin => {
      "filterable_regex" => "Yes",
      "pos" => 3,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Origin",
      "summary.alt.lang.id" => "Asal bahan",
      "unique" => "No",
    },
    status => {
      "filterable_regex" => "No",
      "pos" => 6,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Status",
      "summary.alt.lang.id" => "Status",
      "unique" => "No",
    },
    type => {
      "filterable_regex" => "Yes",
      "pos" => 2,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Type of ingredient",
      "summary.alt.lang.id" => "Jenis bahan",
      "unique" => "No",
    },
  },
  "pk" => "id",
  "summary" => "Ingredients in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Bahan baku di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_bahan_baku_pangan

# BEGIN FRAGMENT id=data-idn_bpom_bahan_baku_pangan varname=data_idn_bpom_bahan_baku_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_bahan_baku_pangan/data.csv
# src-revision: ee31160a5cacaff81583d27f8c688d7a6ea681c0 (Mon Oct 31 18:06:17 2022 +0700)
# generate-date: Mon Oct 31 15:23:01 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_bahan_baku_pangan = [
  [
    1,
    "Bubuk Sayuran (tomat, wortel, sawi, kentang, paprika hijau, bawang putih, seledri)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2, "Bubuk Teh Hijau", "", "NO", "NO", "NO", "NO"],
  [
    3,
    "Bubuk Ayam (maltodextrin, garam, bubuk kaldu ayam)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [4, "Bubuk Buih", "", "NO", "NO", "NO", "NO"],
  [
    5,
    "Bubuk Custard (Susu Bubuk, Gula, Lemak Nabati, Pati Tapioka, Maltodekstrin)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [6, "Bubuk Ekstrak Pizza ", "", "NO", "NO", "NO", "NO"],
  [
    7,
    "Bubuk Ekstrak Tulang Sapi (Ekstrack tulang sapi, Garam)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [8, "Bubuk jahe", "", "NO", "NO", "NO", "NO"],
  [
    9,
    "Bubuk kecap (kedelai, garam, tepung)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [10, "Bubuk Kelapa", "", "NO", "NO", "NO", "NO"],
  [11, "Bubuk lada putih ", "", "NO", "NO", "NO", "NO"],
  [12, "Bumbu Rasa Kacang Polong", "", "NO", "NO", "NO", "NO"],
  [13, "Bumbu Rasa Salmon Teriyaki", "", "NO", "NO", "NO", "NO"],
  [14, "Cabe Merah ", "", "NO", "NO", "NO", "NO"],
  [15, "CO2", "", "NO", "NO", "NO", "NO"],
  [
    16,
    "Dinatrium 5 Inosinat (disodium 5 Inosinate)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    17,
    "Dinatrium 5 ribonukleotida (Disodium 5 ribonucleotides)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [18, "Ekstrak Cumi-cumi", "", "NO", "NO", "NO", "NO"],
  [19, "Iodium ( Kalium Iodat- Kio3 )", "", "NO", "NO", "NO", "NO"],
  [20, "ekstrak vanillin", "", "NO", "NO", "NO", "NO"],
  [21, "bunga jagung", "", "NO", "NO", "NO", "NO"],
  [22, "Butiran Coklat", "", "NO", "NO", "NO", "NO"],
  [23, "Cabe Chilli Hijau ", "", "NO", "NO", "NO", "NO"],
  [24, "Cabe Hijau ", "", "NO", "NO", "NO", "NO"],
  [25, "Cabe Jalapeno ", "", "NO", "NO", "NO", "NO"],
  [26, "Dextrosa", "", "NO", "NO", "NO", "NO"],
  [27, "Kalium Fosfat ", "", "NO", "NO", "NO", "NO"],
  [
    28,
    "Ekstrak Bumbu (bawang bombay,bawang putih, paprika dan annato)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [29, "Dekstrosa monohidrat", "", "NO", "NO", "NO", "NO"],
  [30, "Karagenan", "", "NO", "NO", "NO", "NO"],
  [31, "Karamel ", "", "NO", "NO", "NO", "NO"],
  [
    32,
    "Keju Ricotta (susu sapi, susu domba)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [33, "Konsentrat Jus Apel", "", "NO", "NO", "NO", "NO"],
  [34, "Kayu Manis Bubuk", "", "NO", "NO", "NO", "NO"],
  [35, "Keju Bubuk ", "", "NO", "NO", "NO", "NO"],
  [36, "Konsentrat Buah Apel", "", "NO", "NO", "NO", "NO"],
  [37, "KARBONDIOKSIDA (CARBONDIOXIDE)", "", "NO", "NO", "NO", "NO"],
  [38, "Konyaku Bubuk", "", "NO", "NO", "NO", "NO"],
  [39, "Kopi Putih Bubuk", "", "NO", "NO", "NO", "NO"],
  [40, "Krim Nabati Bubuk", "", "NO", "NO", "NO", "NO"],
  [41, "Krimer", "", "NO", "NO", "NO", "NO"],
  [42, "Krimer Nabati", "", "NO", "NO", "NO", "NO"],
  [43, "Kubis ", "", "NO", "NO", "NO", "NO"],
  [
    44,
    "Lemak Nabati tidak hidrogenasi (Unhydrogenated Vegetable Fat)",
    "",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [45, "Mentega ", "", "NO", "NO", "NO", "NO"],
  [46, "Krispi ", "", "NO", "NO", "NO", "NO"],
  [47, "Keju ", "", "NO", "NO", "NO", "NO"],
  [48, "Lada Hitam", "", "NO", "NO", "NO", "NO"],
  [49, "Laktosa", "", "NO", "NO", "NO", "NO"],
  [50, "Maltodekstrin", "", "NO", "NO", "NO", "NO"],
  [51, "Lada Jalapeno", "", "NO", "NO", "NO", "NO"],
  [52, "Lemak Kakao ", "", "NO", "NO", "NO", "NO"],
  [
    53,
    "LEMAK NABATI (MARGARIN DAN LEMAK REROTI)",
    "",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [54, "Massa Kakao", "", "NO", "NO", "NO", "NO"],
  [55, "Minyak Nabati ", "", "NO", "NO", "NO", "NO"],
  [56, "Minyak Kedelai", "", "NO", "NO", "NO", "NO"],
  [57, "Minyak Sawit Olein", "", "NO", "NO", "NO", "NO"],
  [
    58,
    "Mono Dan Digliserida (mono- And Di-glycerides)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [59, "Monogliserida (monoglycerides)", "", "NO", "NO", "NO", "NO"],
  [
    60,
    "NATRIUM TRIPOLIFOSFAT (SODIUM TRIPOLYPHOSPHATE)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [61, "minyak vanila", "", "NO", "NO", "NO", "NO"],
  [
    62,
    "NATRIUM KARBOKSIMETIL SELULOSA (SODIUM CARBOXYMETHYL CELLULOSE)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    63,
    "NATRIUM KARBONAT (SODIUM CARBONATE)",
    "",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [64, "Parutan Kelapa Kering", "", "NO", "NO", "NO", "NO"],
  [65, "Pasta Kopi", "", "NO", "NO", "NO", "NO"],
  [66, "pektin", "", "NO", "NO", "NO", "NO"],
  [67, "Pizza Bubuk Ekstrak", "", "NO", "NO", "NO", "NO"],
  [68, "Protein Nabati Terhidrolisa", "", "NO", "NO", "NO", "NO"],
  [69, "protein nabati terhirolisa", "", "NO", "NO", "NO", "NO"],
  [70, "Protein nabati tertekstur", "", "NO", "NO", "NO", "NO"],
  [71, "Riboflavin (vitamin B2)", "", "NO", "NO", "NO", "NO"],
  [
    72,
    "Sayuran kering (Kubis, protein nabati tertekstur, bawang putih goreng, wortel)",
    "",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [73, "Ragi Roti", "", "NO", "NO", "NO", "NO"],
  [74, "minyak mentega", "", "NO", "NO", "NO", "NO"],
  [75, "Pati terModifikasi", "", "NO", "NO", "NO", "NO"],
  [76, "Seng", "", "NO", "NO", "NO", "NO"],
  [77, "PATI TAPIOKA ", "", "NO", "NO", "NO", "YES"],
  [78, "Serat Pangan", "", "NO", "NO", "NO", "NO"],
  [79, "Sirup Glukosa", "", "NO", "NO", "NO", "NO"],
  [80, "Serbu Sari Buah Raspberi", "", "NO", "NO", "NO", "NO"],
  [81, "Teh Bubuk", "", "NO", "NO", "NO", "NO"],
  [82, "Telur", "", "NO", "NO", "NO", "NO"],
  [83, "Tepung Beras", "", "NO", "NO", "NO", "NO"],
  [84, "Tepung Gandum Semolina ", "", "NO", "NO", "NO", "NO"],
  [85, "Thixogums", "", "NO", "NO", "NO", "NO"],
  [86, "Tartazine (cl.19140)", "", "NO", "NO", "NO", "NO"],
  [87, "tapioka ", "", "NO", "NO", "NO", "NO"],
  [88, "Tepung Maizena", "", "NO", "NO", "NO", "NO"],
  [89, "Tepung mazena", "", "NO", "NO", "NO", "NO"],
  [90, "Tepung Rumput laut", "", "NO", "NO", "NO", "NO"],
  [
    91,
    "Tepung Rye (Rye Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    92,
    "Tepung Sagu (Sago Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    93,
    "Tepung Semolina (Semolina Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    94,
    "Tepung Singkong (Cassava Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    95,
    "Tepung Sorgum (Sorghum Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    96,
    "Tepung Spelt (Spelt flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    97,
    "Tepung Talas (Taro Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [98, "TEPUNG TAPIOKA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [99, "TEPUNG TELUR", "Bahan Baku", "NO", "YES", "NO", "YES"],
  [
    100,
    "Tepung Tempura (Tempura Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    101,
    "TEPUNG TERIGU (WHEAT FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    102,
    "Tepung Terigu Diperkaya (Enriched Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    103,
    "Tepung Terigu Protein Rendah (Low Protein Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    104,
    "Tepung Terigu Protein Sedang (Cake Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    105,
    "Tepung Terigu Protein Tinggi (High Protein Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    106,
    "TEPUNG TERIGU SEMOLINA (SEMOLINA FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    107,
    "Tepung Terigu Terfermentasi (Fermented Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    108,
    "TEPUNG UBI (CASSAVA FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    109,
    "Tepung Ubi Jalar (Sweet Potato Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    110,
    "Tepung Ubi Jalar Ungu (Violet Sweet Potato Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [111, "Tequila (Tequilla)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    112,
    "Terasi - Belacan (Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    113,
    "Terasi - Belacan Udang (Shrimp Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    114,
    "Terasi Bubuk (Shrimp Paste Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    115,
    "TERIPANG LAUT (SEA CUCUMBERS - HOLOTHUROIDEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [116, "Terong (Eggplant)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    117,
    "TETES TEBU (MOLASES, TREACLE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [118, "THIAMIN MONONITRAT", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    119,
    "Tepung Muffin (Muffin Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    120,
    "Tepung Olahan / Pati Olahan / Protein Olahan",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    121,
    "Tepung Panir (Panir Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    122,
    "Tepung Premiks (Premix Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    123,
    "Tepung Premiks Es Krim (Ice Cream Base)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    124,
    "Tepung Quinoa (Quinoa Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    125,
    "Tepung Roti (Bread Crumb)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    126,
    "Tepung Roti (Bread Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    127,
    "Tepung Malt (Malt Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    128,
    "Tarako Bubuk (Tarako Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [129, "TAUCO (TAUCO)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [130, "TAURIN (TAURINE)", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [131, "Tebu", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [132, "Tebu (Cane)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [133, "TEH (TEA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    134,
    "TIAMIN MONONITRAT (VIT B1)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    135,
    "TIMI (THYME - THYMUS VULGARIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    136,
    "TIMI BUBUK (THYME - THYMUS VULGARIS POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    137,
    "Tinta Cumi (Squid Ink)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [138, "Tiram (Oyster)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [139, "Tiramisu (Tiramisu)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [140, "Tirosin (Thyrosin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [141, "TOFFEE", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [142, "Tomat (Tomato)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    143,
    "Tomat Bubuk (Tomato Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    144,
    "Tomat Cincang (Chopped Tomato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    145,
    "Tomat Hijau (Green Tomato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    146,
    "Tomat Kering (Dried Tomato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    147,
    "Tomat Kupas (Peeled Tomato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    148,
    "TONGKAT ALI BUBUK (EURYCOMA LONGIFOLIA POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [149, "TOPPING", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    150,
    "Torbangun (Mexican mint)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    151,
    "TREHALOSA (TREHALOSE DIHYDRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [152, "TREONIN (THREONINE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [153, "TRIBULUS", "Bahan Baku", "NO", "NO", "YES", "NO"],
  [
    154,
    "Trikalium fosfat (Tripotassium orthophosphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    155,
    "trikalium sitrat (tripotassium citrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    156,
    "Trikalium Sitrat Monohidrat (Tripotassium Citrate Monohydrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    157,
    "Trikalsium Fosfat (Tricalcium Phosphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    158,
    "trikalsium sitrat (Tricalcium citrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    159,
    "Trimagnesium sitrat anhidrat (Trimagnesium Citrate Anhydrous)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    160,
    "TRINATRIUM FOSFAT (TRISODIUM ORTHOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    161,
    "TRINATRIUM FOSFAT (TRISODIUM OTRHOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    162,
    "TRINATRIUM SITRAT (TRISODIUM CITRATE) (KECUALI MP ASI)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    163,
    "Triptofan (Triptophan)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [164, "Triticale", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [165, "Truffle (Truffle)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    166,
    "Tulang Ayam (Chicken Bone)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    167,
    "Tulang Babi (Pig Bone)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    168,
    "Tulang Ikan Salmon (Salmon Bone)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    169,
    "Tulang Muda Ikan Hiu Bubuk (Cartilage Shark Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    170,
    "Tulang Sapi (Cow's Bone)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    171,
    "Tuna Bubuk (Tuna Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    172,
    "TVP (Texturized Vegetable Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    173,
    "UBI JALAR (SWEET POTATO)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    174,
    "Ubi Jepang (Japanese Yam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [175, "UBI KAYU (CASSAVA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    176,
    "UBI MADU (SWEET HONEY POTATO)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [177, "Ubi Merah ", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [178, "UBI RAMBAT (YAM)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    179,
    "UBI UNGU (PURPLE SWEET POTATO)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    180,
    "Ubur-Ubur (Jellyfish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    181,
    "Udang Bubuk (Shrimp Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [182, "UDANG (FRESH PRAWN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [183, "Udang (Shrimp)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    184,
    "Udang Kering - Ebi (Dried Shrimp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    185,
    "Udang Rebon (Shrimp Rebon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    186,
    "UMBI KONNYAKU (KONJAC)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [187, "Usus Ayam", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [188, "Usus Babi", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [189, "Usus Kambing", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    190,
    "Usus Sapi (Cow Intestines)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    191,
    "UVA URSI POWDER (ARCTISTAPHYLOS UVA URSI)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [192, "Valin", "Bahan Baku", "YES", "YES", "NO", "YES"],
  [193, "VANILA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [194, "VANILIN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [195, "Vitamin A (Retinal)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [196, "VITAMIN A ASETAT", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [197, "Vitamin A Palmitat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [198, "VITAMIN B", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    199,
    "Vitamin B1 (Thiamine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [200, "VITAMIN B10", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    201,
    "Vitamin B12 (Cyanocobalamin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    202,
    "Vitamin B2 (Riboflavin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    203,
    "VITAMIN B3 (NIACINAMIDE)(NICOTINAMIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    204,
    "Vitamin B5 (Pantothenic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    205,
    "Vitamin B6 (Pyridoxine Hydrochloride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [206, "Vitamin B7 (Biotin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    207,
    "VITAMIN B8 (INOSITOL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    208,
    "Vitamin B9 (Folic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    209,
    "Vitamin C (Ascorbic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [210, "VITAMIN D ", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [211, "VITAMIN D1", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    212,
    "Vitamin D2 (Ergocalciferol)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    213,
    "Vitamin D3 (Cholecalciferol)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    214,
    "Vitamin E (Tocopherol)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [215, "VITAMIN E ASETAT", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [216, "VITAMIN H (BIOTIN)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [217, "VITAMIN K", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    218,
    "Vitamin K1 (Phytomenadione)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    219,
    "VITAMIN K2 (MENAQUINONE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [220, "Vodka (Vodka)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [221, "WAFER", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [222, "WAFER CONE", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [223, "Wakame (Wakame)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [224, "WALNUT (WALNUT)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [225, "Wasabi (Wasabi)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    226,
    "Wasabi Bubuk (Wasabi Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [227, "WATER CHESNUT", "Bahan Baku", "YES", "YES", "NO", "YES"],
  [228, "WAX (WAX)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [229, "Waxberry (Waxberry)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    230,
    "Wheat grass (Triticum aestirum)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [231, "Whey (Whey)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    232,
    "Whey Bubuk (Whey Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    233,
    "Whey Demineralisasi (Whey Demineralization)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    234,
    "Whey Protein (Whey Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    235,
    "Whey Protein Demineralisasi (Whey Protein Demineralization)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    236,
    "Whey Protein Konsentrat (Whey Protein Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    237,
    "Whipping Cream (Whipping Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [238, "Wijen (Sesame)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    239,
    "Wijen Bubuk (Sesame Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    240,
    "Wijen Hitam (Black Sesame)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    241,
    "Wijen Putih (White Sesame)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [242, "WISKI (WHISKY)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [243, "Wortel (Carrot)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    244,
    "Wortel Bubuk (Carrot Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    245,
    "Wortel Kering (Dried Carrot)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    246,
    "Yerbamate Ekstrak (Ilex paraguariensis)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [247, "Yoghurt (Yoghurt)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    248,
    "Yoghurt Bubuk (Yoghurt Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [249, "ZAT BESI (IRON)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [250, "ZEASANTIN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    251,
    "Zink Glukonat (Zinc Gluconate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    252,
    "Zink Laktat Dihidrat (Zink Lactate Dihydrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    253,
    "Zink Oksida (Zinc Oxide)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    254,
    "Zink Pikolinat (Zinc Picolinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    255,
    "zink Sitrat Dihidrat (Zink Citrate Dihydrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    256,
    "Zink Sulfat (Zinc Sulphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    257,
    "Tepung Gandum Semolina (Semolina Wheat Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    258,
    "Tepung Gandum Utuh (Whole Wheat Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    259,
    "Tepung Gaplek (Cassava Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    260,
    "Tepung Gluten (Gluten Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [261, "Tepung Iles-Iles", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    262,
    "Tepung Jagung (Corn Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    263,
    "Tepung Jagung Modifikasi (Modified Corn Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    264,
    "Tepung Jagung Ungu (Purple Corn Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    265,
    "Tepung Jamur (Mushroom Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    266,
    "Tepung Kacang (Peanut Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    267,
    "TEPUNG KACANG ARAB - TEPUNG GARBANZO (CHICKPEA - GARBANZO FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    268,
    "Tepung Kacang Chena (Chena Bean Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    269,
    "Tepung Kacang Hijau (Mungbean Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    270,
    "Tepung Kacang Kedelai (Soybean Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    271,
    "Tepung Kacang Koro (Broad Bean Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    272,
    "Tepung Kacang Merah (Red Bean Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    273,
    "Tepung Kacang Mete (Cashew Nut Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    274,
    "Tepung Kacang Polong (Pea Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [275, "TEPUNG KAMUT", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    276,
    "Tepung Kanji (Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    277,
    "TEPUNG KEDELAI (SOY FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    278,
    "Tepung Kelapa (Coconut Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    279,
    "Tepung Kencur (Kaempferia galanga Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    280,
    "Tepung Kentang (Potato Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    281,
    "Tepung Kerang (Shell Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    282,
    "TEPUNG KETAN (GLUTINOUS RICE FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    283,
    "Tepung Ketan Hitam (Black Glutinous Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    284,
    "Tepung Ketan Putih (White Glutinous Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [285, "TEPUNG KONJAC", "Bahan Baku", "YES", "NO", "NO", "NO"],
  [
    286,
    "TEPUNG KONNYAKU (KONJAC FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    287,
    "TEPUNG KONYAKU (KONYAKU FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    288,
    "Tepung Kue (Cake Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    289,
    "Tepung Lobak (Rapeseed Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    290,
    "Tepung Beras (Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    291,
    "Tepung Beras Cokelat (Brown Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [292, "Tepung Beras Hitam", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    293,
    "Tepung Beras Ketan (Glutinous Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    294,
    "Tepung Beras Merah (Brown Rice Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    295,
    "Tepung Biji Rami (Flaxseed Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    296,
    "Tepung Bran Gandum (Wheat Bran Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [297, "Tepung Breader", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    298,
    "Tepung Buckwheat (Buckwheat Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    299,
    "Tepung Bumbu (Seasoning Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    300,
    "Tepung Bumbu Ayam Goreng (Fried Chicken Seasoning Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    301,
    "TEPUNG DHAL (HUSKED DEW GRAM FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [302, "TEPUNG DURUM ", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    303,
    "Tepung Gandum (Wheat Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    304,
    "Tepung Gandum Hitam (Rye Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    305,
    "Tepung Gandum Hitam Terfermentasi (Fermented Rye Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [306, "TELUR (EGG)", "Bahan Baku", "NO", "YES", "NO", "YES"],
  [
    307,
    "TELUR ASIN (SALTED EGG)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    308,
    "TELUR AYAM (CHICKEN EGG)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    309,
    "TELUR AYAM NEGERI UTUH",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    310,
    "TELUR BEBEK (DUCK EGG)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    311,
    "Telur Bubuk (Whole Egg Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    312,
    "Telur Ikan (Fish Egg)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    313,
    "Telur Puyuh (Quail Egg)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    314,
    "TEMBAGA GLUKONAT (COPPER GLUCONAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    315,
    "Tembaga Sulfat (Copper Sulfate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [316, "Tempe", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    317,
    "Tempe Goreng (Fried Tempe)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [318, "TEMPE MATANG", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [319, "Tempura (Tempura)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    320,
    "TEMU KUNCI (CURCUMA ROTUNDA, BOESENBERGIA ROTUNDA (L) MANSF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    321,
    "TEMULAWAK (CURCUMA XANTHORRHIZA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    322,
    "TEPUNG AGAR-AGAR (AGAR-AGAR POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [323, "Tepung Amaranth", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    324,
    "TEPUNG ARARUT/TEPUNG GARUT (ARROWROOT FLOUR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    325,
    "Tepung Aren (Sugar Palm Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    326,
    "Tepung Barley (Barley Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    327,
    "Tepung Barley Malt (Barley Malt Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [328, "TEPUNG BATTER", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    329,
    "Teh Bubuk (Tea Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    330,
    "Teh Earl Grey (Earl Grey Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    331,
    "Teh Hijau (Green Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    332,
    "Teh Hijau Bubuk (Green Tea Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    333,
    "Teh Hijau Melati (Green Tea Jasmine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    334,
    "Teh Hijau Panggang (Roasted Green Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    335,
    "Teh Hitam (Black Tea Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    336,
    "Teh Hitam Ceylon (Black Tea Ceylon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    337,
    "Teh Hitam Melati (Jasmine Black Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    338,
    "Teh Instan (Instant Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    339,
    "TEH JAWA (ORTHOSIPHON STAMINEUS; ORTHOSIPHON ARISTATUS; ORTHOSIPHON SPICATUS; ORTHOSIPHONBLAETTER; JAVATEE, INDISCHER NIERENTEE, FEUILLES DE BARBIFLORE; DE JAVA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [
    340,
    "TEH KERING (DRIED TEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    341,
    "Teh Melati (Jasmine Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    342,
    "Teh Oolong (Oolong Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    343,
    "Teh Putih (White Tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    344,
    "TEH ROOIBOSA (ASPHALATUS LINEARIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    345,
    "Serbuk Kale (Brassica Oleracea L.var. acephala)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [346, "Serbuk Minuman", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [347, "Serbuk Sari (Pollen)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [348, "Sereal (Cereal)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    349,
    "Sereal Beras (Rice Cereal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    350,
    "Sereal Gandum (Wheat Cereal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    351,
    "Sereal Gandum Utuh (Whole Wheat Cereal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    352,
    "Sereal Jagung (Corn Cereal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [353, "Serealia (Cerealia)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    354,
    "SEREH (LEMON GRASS-CYMBOPOGON NARDUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    355,
    "Sereh Bubuk (Lemongrass Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    356,
    "SERPIHAN KENTANG (POTATO FLAKES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    357,
    "Serundeng Ikan (Fish Serundeng)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    358,
    "Silver Needle-yingzhen (white tea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    359,
    "SINGKONG - UBI KAYU (CASSAVA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    360,
    "Singkong Bubuk (Cassava Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [361, "SIOMAY", "Bahan Baku", "YES", "NO", "NO", "NO"],
  [362, "SIRIH (BETEL)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    363,
    "SIRIH EKSTRAK (PIPER BETLE L.)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    364,
    "Sirip Ikan Hiu (Shark Fins)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [365, "Sirsak (Soursop)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [366, "Sirup (Syrup)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    367,
    "Sirup Agave (Agave Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    368,
    "Sirup Anggur (Grape Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    369,
    "Sirup Barley Malt (Barley Malt Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    370,
    "Sirup Beras (Rice Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    371,
    "Sirup Beras Merah (Brown Rice Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    372,
    "Sirup Cokelat Malt (Chocolate Malt Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    373,
    "Sirup Fruktosa (Fructose Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    374,
    "SIRUP FRUKTOSA JAGUNG (FRUCTOSE CORN SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    375,
    "Streptococcus cremoris",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [376, "Streptococcus lactis", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    377,
    "Streptococcus thermophilus",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [378, "SUCCUS LIQUIRITIAE", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [379, "succus liquirities", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    380,
    "SUJI (DRACAENA ANGUSTIFOLIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [381, "Sukade (Sukade)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    382,
    "Sukade Pepaya (Papaya Sukade)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    383,
    "Sukromalt (Sucromalt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [384, "Sukrosa (Sucrose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [385, "Sultana (Sultana)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [386, "Sup (Soup)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    387,
    "Sup Apel (Apple Soup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    388,
    "Sup Daging (Meat Soup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [389, "Surimi (Surimi)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [390, "SUSU (MILK)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    391,
    "SUSU BUBUK (MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    392,
    "SUSU BUBUK FULL CREAM (FULL CREAM MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    393,
    "Susu Bubuk Lemak/Minyak Nabati",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    394,
    "SUSU BUBUK RENDAH LEMAK (LOW FAT MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    395,
    "SUSU BUBUK TANPA LEMAK ATAU SUSU SKIM BUBUK (SKIMMED MILK POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    396,
    "SUSU CAIR (LIQUID MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    397,
    "SUSU COKLAT (CHOCOLATE MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    398,
    "SUSU COKLAT BUBUK (CHOCOLATE MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    399,
    "SUSU EVAPORASI (EVAPORATED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    400,
    "SUSU FERMENTASI (FERMENTED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    401,
    "Susu Full Cream (Full Cream Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    402,
    "Susu Kambing (Goat's Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    403,
    "Susu Kambing Bubuk (Goat's Milk Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    404,
    "SUSU KAMBING FULL CREAM BUBUK (FULL CREAM GOAT'S MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    405,
    "SUSU KAMBING SKIM BUBUK (SKIM GOAT'S MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    406,
    "SUSU KENTAL (CONDENSED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    407,
    "SUSU KENTAL MANIS (SWEETENED CONDENSED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    408,
    "SUSU KENTAL TIDAK MANIS (UNSWEETENED CONDENSED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    409,
    "SUSU KERBAU (BUFFALO MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    410,
    "SUSU KUDA (HORSE MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    411,
    "Susu Lemak Nabati-Susu Minyak Nabati (Filled Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    412,
    "SUSU PASTEURISASI (PASTEURIZED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    413,
    "SUSU RENDAH LEMAK (LOW FAT MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    414,
    "Susu Sapi (Cow's Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    415,
    "SUSU SEGAR (FRESH MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    416,
    "SUSU SKIM (SKIM MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    417,
    "SUSU SKIM BUBUK (SKIMMED MILK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "NO",
  ],
  [
    418,
    "SUSU SKIM COKLAT (SKIM MILK CHOCOLATE)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    419,
    "SUSU SKIM KENTAL MANIS (SWEETENED CONDENSED SKIMMED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    420,
    "SUSU TANPA LEMAK ATAU SUSU SKIM (SKIMMED MILK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [421, "SUSU UHT (UHT MILK)", "Bahan Baku", "NO", "YES", "NO", "YES"],
  [422, "Tahini (Tahini)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [423, "Tahu (Tofu)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    424,
    "Tahu Goreng (Fried Tofu)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    425,
    "TAHU KERING (DRIED TOFU)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [426, "TAHU MATANG", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [427, "TALAS (TARO)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    428,
    "TANGKAI TERATAI (LOTUS STEM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [429, "TAOGE (BEAN SPROUTS)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    430,
    "TAPAI BERAS (FERMENTED RICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    431,
    "TAPAI KETAN (FERMENTED STILKY RICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    432,
    "SIRUP GLUKOSA - FRUKTOSA (GLUCOSE - FRUCTOSE SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    433,
    "Sirup Glukosa (Glucose Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    434,
    "SIRUP GLUKOSA BUBUK (GLUCOSE POWDER SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    435,
    "Sirup Grenadine (Grenadine Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    436,
    "Sirup Gula (Sugar Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    437,
    "Sirup Gula Invert (Invert Sugar Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    438,
    "SIRUP GULA JAGUNG (CORN SUGAR SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    439,
    "Sirup Gula Merah (Brown Sugar Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    440,
    "SIRUP GULA TERKARAMELISASI (CARAMELIZED SUGAR SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    441,
    "Sirup Jagung (Corn Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    442,
    "Sirup Jagung Fruktosa (Fructose Corn Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    443,
    "Sirup Jagung Padat (Corn Syrup Solid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    444,
    "Sirup Jagung Tinggi Fruktosa (High Fructose Corn Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    445,
    "Sirup Jagung Tinggi Maltosa (High Maltose Corn Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    446,
    "Sirup Jahe (Ginger Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    447,
    "Sirup Karamel (Caramel Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    448,
    "Sirup Kelengkeng (Longan Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    449,
    "Sirup Kiwi (Kiwi Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    450,
    "Sirup Kurma (Dates Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    451,
    "Sirup Malt (Malt Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    452,
    "SIRUP MAPEL (MAPLE SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    453,
    "Sirup Melon (Melon Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    454,
    "Sirup Semangka (Watermelon Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    455,
    "Sirup Stroberi (Strawberry Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    456,
    "Sirup Sukrosa (Sucrose Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    457,
    "SIRUP TAPIOKA (TAPIOCA SYRUP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    458,
    "Sirup Tinggi Fruktosa (High Fructose Syrup)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [459, "Sistein (Cysteine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [460, "Sistin (Cystine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    461,
    "SITIDIN 5'-MONOFOSFAT (CYTIDINE 5'-MONOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [462, "Sitrulin Malat", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [463, "SIWALAN (SIWALAN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [464, "SOBA (BUCKWHEAT)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [465, "Soda (Soda)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    466,
    "SODA BUBUK (SODA POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    467,
    "Soda Krim (Cream Soda)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    468,
    "Sohun-Soun (Vermicelli)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [469, "Sorgum (Sorghum)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    470,
    "Sosis Ayam (Chicken Sausage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    471,
    "Sosis Babi (Pork Sausage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    472,
    "Sosis Ikan (Fish Sausage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    473,
    "Sosis Sapi (Beef Sausage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [474, "Sotong (Cuttlefish)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    475,
    "Sotong Bubuk (Cuttlefish Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [476, "Spagheti (Spaghetti)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    477,
    "Spearmint (Spearmint)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    478,
    "Spelt (Triticum spelta)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    479,
    "SPINGOMIELIN (SPHINGOMYELIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [480, "Spirit (Spirit)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    481,
    "Spirit Air Nira (Sap Water Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    482,
    "Spirit Anggur (Grape Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    483,
    "Spirit Beras (Rice Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    484,
    "Spirit Beras Ketan (Glutinous Rice Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    485,
    "Spirit Buah Nanas (Pineapple Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    486,
    "Spirit Buah Pepaya (Papaya Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    487,
    "Spirit Buah Tomat (Tomato Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    488,
    "Spirit Gula (Sugar Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    489,
    "Spirit Gula Merah (Brown Sugar Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    490,
    "SPIRIT HASIL FERMENTASI MOLASES (FERMENTED MOLASES SPIRIT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    491,
    "Spirit Jeruk (Orange Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    492,
    "Spirit Lontar (Palmyra Spirit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    493,
    "Spirulina (Spirulina)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    494,
    "Spirulina Bubuk (Spirulina Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    495,
    "SQUASH BERPERISA ANGGUR (GRAPE FLAVOUR SQUASH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    496,
    "SQUASH BERPERISA JERUK (ORANGE FLAVOUR SQUASH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    497,
    "Squash Berperisa Kelapa ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    498,
    "SQUASH BERPERISA LECI (LYCHEE FLAVOUR SQUASH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    499,
    "SQUASH BERPERISA STROBERI (STRAWBERRY FLAVOUR SQUASH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    500,
    "SRIKAYA (ANNONA SQUAMOSA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    501,
    "STARTER YOGHURT (YOGHURT STARTER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [502, "Stearin (Stearine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    503,
    "Stearin Inti Buah Rafinasi (Refined Kernel Stearine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    504,
    "Stearin Inti Kelapa Sawit Hidrogenasi (Hydrogenated Palm Kernel Stearine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    505,
    "Serat Pangan (Dietary Fiber)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    506,
    "Serat Sayuran (Vegetable Fiber)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    507,
    "PATI TAPIOKA TERMODIFIKASI (MODIFIED TAPIOCA STARCH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    508,
    "Seng Laktat (Zinc Lactate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    509,
    "Seng Oksida (Zinc Oxide)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    510,
    "Seng Sulfat (Zinc Sulphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    511,
    "SERAT GANDUM (WHEAT FIBER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    512,
    "SERAT LARUT (SOLUBLE FIBER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    513,
    "Serat Larut dari Jagung (Soluble Corn Fiber atau Gluco Fibre)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    514,
    "Pati Ubi (Cassava Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    515,
    "PATI UBI JALAR (SWEET POTATO STARCH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    516,
    "PECAHAN JAGUNG (CORN GRITS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    517,
    "Pedada (Sonneratia caseolaris)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    518,
    "Pekak (Bunga Lawang-Kembang Lawang-Star Anise) (Star Anise)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    519,
    "Pekak Bubuk (Star Anise Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    520,
    "Minyak Mentega (Butter Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [521, "MINYAK MUSTARD", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    522,
    "NATRIUM SELENAT (SODIUM SELENATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    523,
    "NATRIUM SELENIT (SODIUM SELENITE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    524,
    "RAGI ROTI (BAKER YEAST)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [525, "Ragi Tape", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [526, "Rajungan", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [527, "Rambutan (Rambutan)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    528,
    "REBUNG (BAMBOO SPROUTS-BAMBOO SHOOTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    529,
    "Rebung Kelapa Sawit (Palm Heart)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    530,
    "red currant leaves (ribes rubrum)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    531,
    "REHMANNIA GLUTINOSA (REHMANNIA GLUTINOSE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [532, "REMAHAN BAWANG HIJAU", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    533,
    "REMAHAN BISKUIT (BISCUIT CRUMB)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    534,
    "REMAHAN HOKEY POKEY (HOKEY POKEY CRUMB)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [535, "REMAHAN TELUR", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [536, "Remahan wafer", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    537,
    "Remis Bubuk (Mussel Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    538,
    "Remis Kering (Dried Mussel)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [539, "Rempah (Spices)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [540, "Rennet (Rennet)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    541,
    "Resin Gum (Gum Resin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    542,
    "Retinil Asetat (Retinyl Acetate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    543,
    "Retinil Palmitat (Retinyl Palmitate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    544,
    "Rhodopseudomonas palustris",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    545,
    "rhubarb batang (rheum rhabarbarum)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [
    546,
    "Sayuran Okra (Abelmoschus esculentus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    547,
    "SCUTELLARIA BAICALENSIS (ASIAN SKULLCAP, BAIKAL SKULLCAP, GOLDEN ROOT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    548,
    "Seabuckthorn (Hippophae Rhamnoides L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    549,
    "SEAFOOD KERING (DRY SEAFOOD)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [550, "Selada (Lettuce)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    551,
    "SELADA AIR (WATERCRESS) (FOLIUM NOSTURTIUM OFFICINALE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [552, "SELAI (JAM)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    553,
    "Selai Anggur (Grape Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    554,
    "Selai Apel (Apple Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    555,
    "Selai Aprikot (Apricot Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    556,
    "Selai Belimbing (Starfruit Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    557,
    "SELAI BLUBERI (BLUEBERRY JAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    558,
    "Selai Buah-Buahan (Fruits Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    559,
    "Selai Ceri (Cherry Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    560,
    "SELAI COKELAT (CHOCOLATE JAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    561,
    "Selai Durian (Durian Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    562,
    "Selai Jeruk (Orange Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    563,
    "Selai Kacang (Peanut Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    564,
    "Selai Kelapa (Coconut Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    565,
    "Selai Kiwi (Kiwi Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    566,
    "Selai Kurma (Dates Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    567,
    "Selai Nanas (Pineapple Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    568,
    "Selai Nangka (Jackfruit Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    569,
    "Selai Pisang (Banana Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    570,
    "Selai Rasberi (Raspberry Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    571,
    "SELAI SRIKAYA (SWEETSOP JAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    572,
    "Selai Stroberi (Strawberry Jam)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [573, "Selasih (Basil)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [574, "Seledri (Celery)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    575,
    "Seledri Bubuk (Celery Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [576, "Selenium (Selenium)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    577,
    "SELONGSONG SOSIS (SAUSAGE SLEEVE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [578, "Selulosa (Cellulose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    579,
    "Semangka Merah (Red Watermelon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [580, "SEMOLINA", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    581,
    "RIMPANG TERATAI (LOTUS ROOT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [582, "Rolled Oats", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    583,
    "rooibos-rooibush-rooibosh (asphalatus linearis)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    584,
    "Roombutter (Roombutter)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [585, "ROOT BEER BASE", "Bahan Baku", "YES", "YES", "NO", "YES"],
  [
    586,
    "ROSEHIP PEELS (ROSA CANINA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    587,
    "ROSELA (HIBISCUS SABDARIFFA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [588, "ROSEMARI (ROSEMARY)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [589, "Roti (Bread)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    590,
    "Roti Kering (Crusty Bread)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    591,
    "ROYAL JELLY (KHUSUS MADU)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [592, "Rum (Rum)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    593,
    "Rumput Laut (Seaweed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    594,
    "Rumput Laut Bubuk (Seaweed Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    595,
    "Rumput Laut Kering (Dried Seaweed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [596, "SAFRON (SAFFRON)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    597,
    "SAGE (SALVIA OFFICINALIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [598, "Sagu (Sago)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [599, "Sake (Sake)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [600, "Salak", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    601,
    "Salicornia herbacea L (Salicornia europaea L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [602, "SAMBAL (SAUCE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    603,
    "Sambal Seafood (Seafood Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    604,
    "SAMBILOTO (ANDROGRAPHIS PANICULATA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [605, "SAMBUCUS NIGRA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    606,
    "Santan Kelapa (Coconut Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    607,
    "Santan Kelapa Bubuk (Coconut Milk Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    608,
    "SANTAN KELAPA MURNI (PURE COCONUT MILK)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    609,
    "Sarang Burung Walet (Swallow's Nest)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    610,
    "Sari Asam (Tamarind Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    611,
    "Sari Asam Jawa (Tamarind Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    612,
    "SARI AYAM (CHICKEN ESSENCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    613,
    "Sari Bawang Bombay (Onion Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    614,
    "Sari Beras (Grains of Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    615,
    "SARI BERAS MERAH (BROWN RICE JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    616,
    "Sari Buah ...... Rekonstitusi",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    617,
    "Sari Buah Anggur (Grape Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    618,
    "SARI BUAH ANGGUR BUBUK",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    619,
    "Sari Buah Anggur Hijau (Green Grape Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    620,
    "Sari Buah Anggur Merah (Red Grape Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    621,
    "Sari Buah Anggur Muscat (Muscat Grape Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    622,
    "Sari Buah Anggur Putih (White Grape Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    623,
    "SARI BUAH ANGGUR REKONSTITUSI (GRAPE JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    624,
    "Sari Buah Apel (Apple Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    625,
    "SARI BUAH APEL REKONSTITUSI (APPLE JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    626,
    "Sari Buah Apricot (Apricot Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    627,
    "SARI BUAH ARBEI (ARBEI JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [628, "Sari Buah Aren", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    629,
    "Sari Buah Aronia (Aronia Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    630,
    "SARI BUAH ASAM JAWA (TAMARIND JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    631,
    "Sari Buah Belimbing (Starfruit Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    632,
    "Sari Buah Bilberry (Bilberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    633,
    "Sari Buah Blackberry (Blackberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    634,
    "Sari Buah Blackcurant (Blackcurrant Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    635,
    "Sari Buah Blackcurrant Bubuk (blackcurrant juice powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    636,
    "Sari Buah Blewah (Cantaloupe Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    637,
    "Sari Buah Blueberry (Blueberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    638,
    "Sari Buah Ceri (Cherry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    639,
    "Sari Buah Chokeberry (Chokeberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    640,
    "Sari Buah Cranberry (Cranberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    641,
    "SARI BUAH CRANBERRY REKONSTITUSI (CRANBERRY JUICE RECONSTITUTION) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    642,
    "Sari Buah Delima (Pomegranate Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    643,
    "SARI BUAH FRAMBOZEN (FRAMBOZEN JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    644,
    "SARI BUAH GOJIBERRY (GOJIBERRY JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    645,
    "Sari Buah Gooseberry (Gooseberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [646, "Sari Buah Jambu", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    647,
    "Sari Buah Jambu Biji (Guava Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [648, "SARI BUAH JAMBU MERAH", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    649,
    "Sari Buah Jeruk (Orange Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    650,
    "SARI BUAH JERUK BUBUK (ORANGE JUICE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    651,
    "Sari Buah Jeruk Florida-Jeruk .....",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    652,
    "Sari Buah Jeruk Kalamansi",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    653,
    "Sari Buah Jeruk Lemon (Lemon Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    654,
    "SARI BUAH JERUK LIMAU (LIMAU JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    655,
    "Sari Buah Jeruk Mandarin",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    656,
    "Sari Buah Jeruk Nipis",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    657,
    "SARI BUAH JERUK REKONSTITUSI (ORANGE JUICE RECONSTITUTION) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    658,
    "SARI BUAH KELAPA (COCONUT JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    659,
    "Sari Buah Kiwi (Kiwi Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    660,
    "Sari Buah Kranberi (Cranberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    661,
    "SARI BUAH KUNDUR (BENINCASA HISPIDA JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    662,
    "SARI BUAH KURMA (DATES JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    663,
    "Sari Buah Labu (Pumpkin Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    664,
    "Sari Buah Leci (Lychee Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    665,
    "Sari Buah Mangga (Mango Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    666,
    "SARI BUAH MANGGA BUBUK (MANGO JUICE POWDER)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    667,
    "Sari Buah Manggis (Mangosteen Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    668,
    "Sari Buah Markisa (Passion Fruit Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    669,
    "SARI BUAH MARKISA REKONSTITUSI (PASSION FRUIT JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    670,
    "SARI BUAH MELON (MELON JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    671,
    "Sari Buah Nanas (Pineapple Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    672,
    "SARI BUAH NANAS REKONSTITUSI (PINEAPPLE JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    673,
    "Sari Buah Nangka (Jackfruit Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    674,
    "Sari Buah Pala (Nutmeg Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    675,
    "SARI BUAH PEAR REKONSTITUSI (PEAR JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    676,
    "Sari Buah Pepaya (Papaya Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    677,
    "Sari Buah Persik (Peach Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    678,
    "Sari Buah Pir (Pear Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    679,
    "Sari Buah Pisang (Banana Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    680,
    "Sari Buah Plum (Plum Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    681,
    "Sari Buah Prune (Prune Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    682,
    "Sari Buah Raspberi (Raspberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    683,
    "SARI BUAH RASPBERI REKONSTITUSI (RASPBERRY JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    684,
    "Sari Buah Redcurrant (Redcurrant Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    685,
    "Sari Buah Semangka (Watermelon Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    686,
    "Sari Buah Sirsak (Soursop Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    687,
    "SARI BUAH SIWALAN (PALMYRA FRUIT JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    688,
    "Sari Buah Stroberi (Strawberry Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    689,
    "SARI BUAH STROBERI REKONSTITUSI (STRAWBERRY JUICE RECONSTITUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    690,
    "Sari Buah Terong (Eggplant Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    691,
    "SARI BUAH TERONG BELANDA (TAMARILLO JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    692,
    "Sari Buah Tomat (Tomato Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    693,
    "SARI BUNGA MAWAR (ROSE JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [694, "SARI DAGING AYAM", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [695, "SARI DAGING SAPI", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    696,
    "SARI DAUN CINCAU (GRASS JELLY JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    697,
    "SARI DAUN KATUK (KATUK JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    698,
    "SARI DAUN PANDAN (PANDAN JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    699,
    "Sari Jagung (Corn Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    700,
    "Sari Jahe (Ginger Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    701,
    "SARI JAHE MERAH (RED GINGER JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    702,
    "Sari Kacang Almond (Almond Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    703,
    "Sari Kacang Kedelai (Soy Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    704,
    "SARI KACANG KEDELAI BUBUK (SOY JUICE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    705,
    "SARI KACANG KEDELAI HITAM (BLACK SOYBEAN JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    706,
    "Sari Kelapa (Coconut Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    707,
    "SARI KERANG ABALONE (ABALONE JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    708,
    "Sari Kopi (Coffee Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    709,
    "Sari Kunyit (Turmeric Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    710,
    "Sari Lidah Buaya (Aloe Vera Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    711,
    "Sari Malt (Malt Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    712,
    "Sari Rosella (Rosella Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    713,
    "Sari Rumput Laut (Seaweed Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    714,
    "Sari Sayuran (Vegetable Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    715,
    "Sari Seledri (Celery Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    716,
    "SARI TAPE (TAPAI JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    717,
    "Sari Tebu (Sugar Cane Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    718,
    "Sari Tiram (Oyster Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    719,
    "Sari Wortel (Carrot Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [720, "SAUS (SAUCE)", "Bahan Baku", "YES", "NO", "NO", "YES"],
  [
    721,
    "SAUS BARBEKUE (BARBEQUE SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    722,
    "SAUS BUAH (FRUIT SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    723,
    "Saus Buah Blueberry (Blueberry Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    724,
    "Saus Buah Jambu (Guava Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    725,
    "Saus Buah Markisa (Passion Fruit Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    726,
    "Saus Buah Pepaya (Papaya Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    727,
    "Saus Buah Pisang (Banana Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    728,
    "SAUS BUAH STROBERI (STRAWBERRY SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    729,
    "Saus Buffalo Style (Buffalo Style Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    730,
    "Saus Cabe (Chili Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    731,
    "Saus Coklat (Chocolate Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    732,
    "Saus Durian (Durian Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    733,
    "Saus Ikan (Fish Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    734,
    "Saus Ikan Teri (Anchovy Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    735,
    "Saus Kacang (Peanut Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    736,
    "SAUS KACANG KEDELAI (SOYBEAN SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    737,
    "SAUS KAPUCINO (CAPPUCINNO SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    738,
    "SAUS KEJU (CHEESE SAUCE)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    739,
    "SAUS KOPI (COFFEE SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    740,
    "SAUS TAR TAR (TAR TAR SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    741,
    "Saus Teriyaki (Teriyaki Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    742,
    "Saus Tiram (Oyster Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    743,
    "Saus Tomat (Tomato Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    744,
    "Saus/ Topping/ Olesan/ Pasta Manis",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    745,
    "Sawi (Mustard Greens)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    746,
    "SAWI PUTIH (CHINESE CABBAGE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [747, "Sawo (Sapodilla)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    748,
    "Sayap Ayam (Chicken Wing)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    749,
    "SAYUR BUBUK (VEGETABLE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    750,
    "Sayuran Beku (Frozen Vegetable)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    751,
    "SAYURAN KERING (DRY VEGETABLE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    752,
    "Protein Susu (Milk Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    753,
    "Protein Susu Fermentasi (Fermented Milk Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [754, "PRUNELLA VULGARIS", "Bahan Baku", "NO", "NO", "YES", "NO"],
  [755, "PSYLLIUM HUSK", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    756,
    "Puff Gandum (Wheat Puffed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    757,
    "Puree Apel (Apple Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    758,
    "PUREE BAWANG PUTIH (GARLIC PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    759,
    "PUREE BLACKBERRY (BLACKBERRY PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    760,
    "Puree Blackcurrant (Blackcurrant Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    761,
    "PUREE BLUBERI (BLUEBERRY PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    762,
    "PUREE BUAH LAINNYA (FRUIT PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    763,
    "Puree Ceri (Cherry Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    764,
    "Puree Jambu Biji (Guava Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [765, "PUREE JAMBU MERAH", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [766, "Puree Kurma", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    767,
    "Puree Leci (Lyche Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    768,
    "Puree Mangga (Mango Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    769,
    "PUREE MIX BERRY (MIX BERRY PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    770,
    "Puree Persik (Peach Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    771,
    "PUREE PIR (PEAR PUREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    772,
    "Puree Sirsak (Soursop Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    773,
    "Puree Stroberi (Strawberry Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    774,
    "Puree Tomat (Tomato Puree)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    775,
    "PUTIH TELUR (EGG WHITE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    776,
    "PUTIH TELUR BUBUK (EGG WHITE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    777,
    "PUTIH TELUR PADAT (EGG WHITE SOLID)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    778,
    "QUERCETIN (BERUPA ISOLAT DARI BANYAK TANAMAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [779, "Rafinosa (Raffinose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [780, "Ragi (Yeast)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    781,
    "Ragi Bubuk (Yeast Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    782,
    "Ragi Instan (Instant Yeast)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    783,
    "Ragi Kering (Dried Yeast)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    784,
    "Ragi Padat (Solid Yeast)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    785,
    "PLANT STANOL ESTER-FITOSTANOL (PHYTOSTANOL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    786,
    "Polidekstrosa (Polydextrose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    787,
    "Polifruktosa (Polyfructose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    788,
    "Polisakarida (Polysaccharides)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    789,
    "POTONGAN BUAH APEL (APPLE SLICES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    790,
    "POTONGAN KENTANG (POTATO SLICES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [791, "Pottasium Aspartate", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [792, "Praline (Praline)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [793, "PREM (PLUM)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    794,
    "PREM ASIN (SALTED PLUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    795,
    "PREMIKS MINERAL (MINERAL PREMIX)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    796,
    "Premiks Vitamin (Vitamin Premix)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    797,
    "PREMIKS VITAMIN DAN MINERAL (VITAMIN AND MINERAL PREMIX)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    798,
    "Preparat Perisa (Flavoring Preparation)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [799, "PROPOLIS (PROPOLLIS)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    800,
    "Protein Gandum (Wheat Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    801,
    "Protein Jagung Terhidrolisa (Hydrolized Corn Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    802,
    "Protein Kedelai (Soy Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    803,
    "PROTEIN KEDELAI TERHIDROLISA (HYDROLIZED SOY PROTEIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    804,
    "PROTEIN NABATI (VEGETABLE PROTEIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [805, "Pektin (Pectin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    806,
    "Pelapis Gula (Sugar Coating)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [807, "Pelet (Pellet)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    808,
    "Pengganti Lemak Kakao (Cacao Butter Substitute)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [809, "PENGGANTI MENTEGA", "Bahan Baku", "YES", "NO", "NO", "NO"],
  [
    810,
    "PENGGANTI MINYAK MENTEGA (BUTTER OIL SUBSTITUTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    811,
    "Penicillium camemberti",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [812, "Penicillium candidum", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    813,
    "PENICILLIUM CASEICOLUM",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    814,
    "Penicillium roqueforti",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    815,
    "penyangga bunga teratai",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [816, "Pepaya Gunung/Karika", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    817,
    "Pepermint (Peppermint)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    818,
    "Pepermint Bubuk (Peppermint Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    819,
    "Peptida Kolagen (Collagen Peptide)",
    "Bahan Baku",
    "YES",
    "NO",
    "NO",
    "YES",
  ],
  [
    820,
    "Perasan Air Jeruk (Lemon Juice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [821, "PETAI (BITTER BEAN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    822,
    "PETAI CINA (WHITE LEADTREE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [823, "Peterseli (Parsley)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    824,
    "Peterseli Bubuk (Parsley Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [825, "Pimenta (Pimenta)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [826, "Pimento (Allspice)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    827,
    "Pimento Bubuk (Allspice Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [828, "PINANG (ARECA NUT)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    829,
    "Pinto Beans (Kacang Pinto)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [830, "PIR (PEAR)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    831,
    "PIRIDOKSIN HIDROKLORIDA (VITAMIN B6)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [832, "Pisang (Banana)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    833,
    "Pisang Bubuk (Banana Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    834,
    "Pasta Kurma (Datess Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    835,
    "PASTA LADA MERAH (RED PEPPER PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    836,
    "Pasta Leci (Lychee Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    837,
    "Pasta Mangga (Mango Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    838,
    "Pasta Nanas (Pineapple Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    839,
    "Pasta Pear (Pear Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    840,
    "Pasta Pepaya (Papaya Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    841,
    "Pasta Persik (Peach Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    842,
    "Pasta Pisang (Banana Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    843,
    "Pasta Plum (Plum Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    844,
    "PASTA RASPBERI (RASPBERRY PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    845,
    "PASTA SARIKAYA (SARIKAYA PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    846,
    "Pasta Srikaya (Soursop Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    847,
    "Pasta Stroberi (Strawberry Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    848,
    "Pasta Tomat (Tomato Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    849,
    "Pasta Udang (Shrimp Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    850,
    "Pasta Wijen (Sesame Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    851,
    "Pastri Samosa (Samosa Pastry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [852, "Pati (Starch)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    853,
    "Pati Beras (Rice Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    854,
    "Pati Gandum (Wheat Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    855,
    "Pati Jagung (Corn Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    856,
    "Pati Jagung Terhidrolisa (Hydrolized Corn Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    857,
    "PATI JAGUNG TERMODIFIKASI (MODIFIED CORN STARCH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    858,
    "Pati Kacang Hijau (Mungbean Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    859,
    "PATI KACANG POLONG (PEAS STARCH)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    860,
    "Pati Kedelai Terhidrolisa ((Hydrolized Soy Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    861,
    "Pati Kentang (Potato Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    862,
    "PATI KENTANG TERMODIFIKASI (MODIFIED POTATO STARCH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    863,
    "PATI MODIFIKASI (MODIFIED STARCH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    864,
    "Pati Sagu (Sago Starch)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    865,
    "PATI SINGKONG (TAPIOCA STARCH) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    866,
    "PASAK BUMI (EURYCOMA LONGIFOLIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    867,
    "Pasta (Fettucini, Lasagna, Macaroni, Spaghetti, dll)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    868,
    "Pasta Almond (Almond Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    869,
    "Pasta Apel (Apple Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    870,
    "Pasta Ayam (Chicken Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    871,
    "Pasta Bawang Bombay (Onion Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    872,
    "Pasta Bawang Putih (Garlic Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    873,
    "Pasta Biji Wijen (Sesame Seed Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    874,
    "Pasta Bluberi (Blueberry Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    875,
    "PASTA BUAH, DLL (FRUITS PASTE, ETC)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    876,
    "Pasta Bumbu Kari (Curry Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    877,
    "Pasta Cabe (Chili Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    878,
    "Pasta Cokelat Malt (Chocolate Malt Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    879,
    "Pasta Coklat (Chocolate Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    880,
    "Pasta Durian (Durian Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    881,
    "Pasta Ikan (Fish Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    882,
    "Pasta Ikan Anchovy (Anchovy Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    883,
    "Pasta Jagung Manis (Sweet Corn Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    884,
    "Pasta Jeruk (Orange Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    885,
    "Pasta Jeruk Lemon (Lemon Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    886,
    "Pasta Kacang (Nut Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    887,
    "Pasta Kacang Hazel (Hazelnut Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    888,
    "Pasta Kacang Hijau (Mungbean Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    889,
    "Pasta Kacang Kedelai (Soybean Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    890,
    "PASTA KACANG MERAH (RED BEAN PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    891,
    "Pasta Keju (Cheese Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    892,
    "Pasta Kelapa (Coconut Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    893,
    "PASTA KETAN HITAM (BLACK STICKY RICE PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    894,
    "Pasta Kismis (Raisin Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    895,
    "Natrium Kaseinat (Sodium Caseinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    896,
    "natrium klorida (sodium chloride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    897,
    "NATRIUM MOLIBDAT (SODIUM MOLYBDATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    898,
    "Natrium dihidrogen fosfat (Sodium dihydrogen phosphate) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    899,
    "Natrium fluorida (Sodium fluoride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    900,
    "NATRIUM HIDROGEN KARBONAT (SODIUM BICARBONATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    901,
    "Natrium Hidroksida (Sodium Hydroxide) (Kecuali MP ASI)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    902,
    "NATRIUM IODIDA (SODIUM IODIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    903,
    "Minyak Wijen (Sesame Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    904,
    "MINYAK ZAITUN (REFINED BLEACHED DEODORIZED OLIVE OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    905,
    "MINYAK ZAITUN EXTRA VIRGIN (EXTRA VIRGIN OLIVE OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    906,
    "Minyak Zaitun Pomace (Pomace Olive Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    907,
    "Minyak Zaitun Virgin (Virgin Olive Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [908, "Mirin", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [909, "Miso", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    910,
    "MISO BUBUK (MISO POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    911,
    "Mocaf (Tepung Singkong Fermentasi)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [912, "Molibdenum", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [
    913,
    "Nektar Agave (Agave Nectar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [914, "Nektar Lontar", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    915,
    "NETTLE LEAF POWDER (URTICA DIOCA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [916, "NIASIN (NIACIN)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    917,
    "NIKOTINAMIDA (NICOTINAMIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    918,
    "NIRA KELAPA (COCONUT SAP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    919,
    "Nira Lontar (Siwalan)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    920,
    "Non-Dairy Toppings, Fillings, Frostings",
    "Bahan Baku",
    "YES",
    "NO",
    "NO",
    "YES",
  ],
  [
    921,
    "Nori Goreng (Fried Seawed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [922, "Nougat (Nougat)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    923,
    "Nukleotida (Nucleotide)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    924,
    "NUKLEOTIDA PREMIKS (PREMIX NUCLEOTIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [925, "Oat (Oat)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    926,
    "OAT BUBUK (OAT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    927,
    "OAT SERPIHAN (OAT FLAKES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [928, "OATMEAL (OATMEAL)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [929, "OKSIGEN (OXYGEN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    930,
    "OLIGOFRUKTOSA (OLIGOFRUCTOSE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    931,
    "OLIGOSAKARIDA (OLIGOSACCHARIDES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [932, "Omega 3 (Omega 3)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [933, "Oregano (Oregano)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    934,
    "Oregano Bubuk (Oregano Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    935,
    "PADATAN SUSU (MILK SOLIDS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    936,
    "PADATAN SUSU TANPA LEMAK (NON FAT MILK SOLIDS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    937,
    "PAHA AYAM (CHICKEN THIGHS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    938,
    "Pakcoy atau Pokcoy (Brassica Rapa L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [939, "Pala (Nutmeg)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    940,
    "Pala Bubuk (Nutmeg Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [941, "Pandan (Pandan)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [942, "PANGSIT (DUMPLINGS)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [943, "PAPRIKA (PAPRIKA)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    944,
    "PAPRIKA BUBUK (PAPRIKA POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    945,
    "PAPRIKA HIJAU (GREEN PAPRIKA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    946,
    "PAPRIKA HIJAU MANIS (SWEET GREEN PAPRIKA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    947,
    "PAPRIKA KUNING (YELLOW PAPRIKA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    948,
    "PAPRIKA MERAH (RED PAPRIKA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    949,
    "PAPRIKA MERAH MANIS (SWEET RED PAPRIKA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    950,
    "PAPRIKA OLEORESIN (PAPRIKA OLEORESIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [951, "PARE (PARE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    952,
    "PARE KERING (DRY PARE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [953, "PARSLEY", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    954,
    "PARSNIP (PASTINACA SATIVA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    955,
    "PARU SAPI (PULMONARY COW)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    956,
    "PARUTAN KELAPA (GRATED COCONUT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    957,
    "Monokalium fosfat (Potassium phosphate, monobasic) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [958, "MULUKHIYAH", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    959,
    "MUNG DHAL (MOONG DAL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [960, "Muscat (Muscat)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [961, "Mustard (Mustard)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    962,
    "Mustard Bubuk (Mustard Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    963,
    "Mustard Kuning (Yellow Mustard)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    964,
    "Mustard Pasta (Mustard Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [965, "Myo-Inositol", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [966, "Naget (Nugget)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [967, "Nanas (Pineapple)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    968,
    "NANAS BUBUK (PINEAPPLE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [969, "Nangka (Jackfruit)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [970, "Nasi (Rice)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    971,
    "Nata De Coco (Nata De Coco)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    972,
    "NATRIUM ASKORBAT (SODIUM ASCORBATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    973,
    "MINYAK SAYUR (COOKING OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    974,
    "MINYAK SAYUR PADAT (COOKING FAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    975,
    "Minyak Sekam Oat (Oat Bran Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    976,
    "Minyak Spearmint (Spearmint Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    977,
    "Minyak Spinkenard (Spinkenard Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    978,
    "Minyak Stearin Inti Kelapa Sawit Terhidrogenasi (Hydrogenated Palm Kernel Stearin Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    979,
    "MINYAK STEARIN KELAPA SAWIT (REFINED BLEACHED DEODORIZED PALM STEARIN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    980,
    "MINYAK TRIGLISERIDA RANTAI SEDANG (MCT) (MEDIUM CHAIN TRIGLYCERIDES OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [981, "Minyak Truffle", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    982,
    "MINYAK KEDELAI (REFINED BLEACHED DEODORIZED SOYBEAN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    983,
    "Minyak Kedelai Terhidrogenasi Parsial (Partially Hydrogenated Soybean Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    984,
    "MINYAK KELAPA (REFINED BLEACHED DEODORIZED COCONUT OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    985,
    "Minyak Kelapa Bubuk (Coconut Oil Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    986,
    "Minyak Kelapa Mentah (Unrefined Coconut Oil-Crude Coconut Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    987,
    "Minyak Kelapa Murni (Virgin Coconut Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    988,
    "MINYAK KELAPA SAWIT (REFINED BLEACHED DEODORIZED PALM OIL-RBDPO) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    989,
    "Minyak Kelapa Sawit Terhidrogenasi (Refined Hydrogenated Palm Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    990,
    "Minyak Kelapa Terhidrogenasi (Hydogenated Coconut Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    991,
    "Minyak Kulit Ari Beras (Rice Husk Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    992,
    "Minyak LC-PUFA (Oil Mix LC-PUFA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    993,
    "Minyak Melon (Melon Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    994,
    "Minyak Nabati (Vegetable Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    995,
    "Minyak Nabati Terhidrogenasi (Hydrogenated Vegetable Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    996,
    "Minyak Nanas (Pineapple Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    997,
    "Minyak Nangka (Jackfruit Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    998,
    "MINYAK OLEIN KELAPA SAWIT (REFINED BLEACHED DEODORIZED PALM OLEIN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    999,
    "Minyak Pandan (Pandan Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1000,
    "Minyak Peppermint (Peppermint Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1001,
    "MINYAK PERILLA (PERILLA OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1002,
    "Minyak Primrose (Evening Primrose Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1003,
    "MINYAK RAPESEED (RAPESEED OIL-TURNIP RAPE OIL-COLZA OIL-RAVISON OIL-SARSON OIL-TORIA OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1004,
    "Minyak Raspberry (Raspberry Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1005,
    "Minyak Reroti (Shortening Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1006,
    "MINYAK ROS ESENSIAL (ROSE ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1007,
    "Minyak Sacha Inchi (Plukenetiva Volubilis L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1008,
    "MINYAK SAFFLOWER (REFINED BLEACHED DEODORIZED SAFFLOWER OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1009,
    "Minyak Salad (Salad Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1010,
    "MINYAK SAMIN ATAU VANASPATI (VEGETABLE GHEE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1011,
    "Minyak Sapi (Beef Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1012,
    "Minyak Sarsaparila (Sarsaparilla Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1013,
    "mate green (illex paraguarienis)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1014,
    "Mate Green (Illex Paraguariensis)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1015,
    "MAXIMOWICZIA (SCHISANDRA CHINENSIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1016,
    "Mayonais (Mayonnaise)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1017, "Melati (Jasmine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1018,
    "MELINJO (GNETUM GNEMON L.)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1019,
    "MELISASA OFFICINALIS (HERBA LEMON BALM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1020, "Melon (Melon)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1021,
    "Melon Bubuk ( Melon Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1022,
    "Mengkudu (Morinda citrifolia)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1023,
    "Lemak Nabati (Vegetable Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1024,
    "Lemak Nabati Terhidrogenasi (Hydrogenated Vegetable Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1025,
    "Lemak Kakao (Cocoa Butter)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1026,
    "LEMAK MENTEGA (BUTTER FAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1027,
    "LADA MERAH (RED PEPPER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1028,
    "Lada Putih (White Pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1029,
    "LADA PUTIH BUBUK (WHITE PEPPER POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1030,
    "LAKTOFERIN (LACTOFERRIN)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1031,
    "Maltodekstrin (Maltodextrine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1032,
    "Maltodekstrin Resisten",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1033, "Maltosa (Maltose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1034,
    "Maltotriose (Maltotriose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1035,
    "MANGAN (II) GLUKONAT (MANGANESE (II) GLUCONATE) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1036,
    "Mangan (II) Klorida (Manganese (II) Chloride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1037,
    "MANGAN SITRAT (MANGANESE CITRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1038,
    "Mangan Sulfat (Manganese Sulphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1039, "Mangga (Manggo)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1040,
    "Mangga Bubuk (Mango Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1041,
    "Mangga Kering (Dried Mango)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1042,
    "Manggis (Mangosteen)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1043,
    "MANISAN CRANBERRY (CANDIED CRANBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1044,
    "Manisan Jeruk (Candied Orange)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1045,
    "Manisan Kulit Jeruk (Candied Orange Peel)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1046,
    "Manisan Mangga (Candied Mango)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1047,
    "Manisan Nanas (Candied Pineapple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1048,
    "Manisan Pepaya (Candied Papaya)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1049,
    "MAQUI BERRY (ARISTOTELIA CHILENSIS) ",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [
    1050,
    "Margarin (Margarine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1051,
    "MARGARIN OLES (MARGARINE SPREAD)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1052, "Marjoram", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1053,
    "Markisa (Passion Fruit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1054,
    "Marmalad (Marmalade)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1055,
    "MARSHMALLOW (MARSHMALLOW)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1056, "MARSMALLOW", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1057, "MARZIPAN (MARZIPAN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1058, "LAKTOSA (LACTOSE)", "Bahan Baku", "NO", "YES", "NO", "YES"],
  [
    1059,
    "LAKTOSA BUBUK (LACTOSE POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1060,
    "LAKTULOSA (LACTULOSE)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1061,
    "LAPACHO (TABEBULA IMPETIGINOSA ATAU HANDROANTHUS IMPETIGINOSUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1062,
    "LARUTAN GULA (SUGAR SOLUTION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1063,
    "lavender (lavandula angustifolia)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1064,
    "Lemak Ayam (Chicken Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1065, "Lemak Babi (Lard)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1066,
    "LEMAK COKLAT (CHOCOLATE FAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1067,
    "Lemak Hewani (Tallow)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1068,
    "Lemak Inti Sawit Terhidrogenasi (Refined Hydrogenated Palm Kernel Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1069,
    "Lada Hitam (Black Pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1070,
    "Lada Hitam Bubuk (Black Pepper Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1071, "Keju (Cheese)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1072,
    "Keju Biru (Blue Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1073,
    "Krispi Beras (Rice Crispy)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1074,
    "Krispi Kedelai (Soy Crispy)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1075,
    "KROMIUM KLORIDA (CHROMIUM CHLORIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1076,
    "Kromium Pikolinat (Chromium Picolinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1077,
    "KROMIUM POLINIKOTINAT (CHROMIUM POLYNICOTINATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1078,
    "Kuaci (Sunflower Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1079, "Mentega (Butter)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1080,
    "MENTEGA ASIN (SALTED BUTTER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1081,
    "Mentega Bubuk (Butter Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1082,
    "Mentega Kacang (Peanut Butter)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1083,
    "Mentega Tawar (Unsalted Butter)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1084,
    "Mentimun - Ketimun (Cucumber)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1085,
    "Mentimun Hijau (Green Cucumber)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1086, "MENTOL (MENTHOL)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1087,
    "Merica Sichuan (Zanthoxylum peperitum - Szechuan pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1088,
    "MESES (CHOCOLATE SPRINKLES-CHOCOLATE VERMICELLI-STREUSEL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1089, "MESHIMAKOBU", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1090, "Mesoyi", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1091,
    "Metionin (Methionine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1092, "Mi (Noodle)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1093,
    "Mi Telur (Egg Noodles)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1094, "MICROCOS PANICULATA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1095,
    "MIKOPROTEIN (MYCOPROTEIN) DARI FUSARIUM VENENATUM",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1096, "Millet (Millet)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1097,
    "Millet Serpih (Millet Flakes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1098, "MINUMAN BERALKOHOL", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1099,
    "Minuman Sari Buah ....",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1100,
    "Minyak Almond (Almond Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1101,
    "Minyak Adas Manis (Anise Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1102,
    "Minyak Alpukat (Avocado Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1103,
    "MINYAK ANGGUR (GRAPE OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1104,
    "MINYAK ANIS (ANISE OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1105,
    "Minyak Atsiri Adas Manis (Anise Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1106,
    "MINYAK ATSIRI BAWANG BOMBAY (ONION ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1107,
    "Minyak Atsiri Bunga Matahari (Sunflower Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1108,
    "Minyak Atsiri Cabai (Chili Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1109,
    "Minyak Atsiri Cengkeh (Clove Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1110,
    "Minyak Atsiri Chamomile (Chammomile Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1111,
    "Minyak Atsiri Durian (Durian Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1112,
    "MINYAK ATSIRI JAHE (GINGER OLEORESIN-GINGER ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1113,
    "Minyak Atsiri Jeruk (Orange Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1114,
    "MINYAK ATSIRI JERUK BALI (GRAPEFRUIT ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1115,
    "Minyak Atsiri Jeruk Bergamot (Bergamot Orange Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1116,
    "Minyak Atsiri Jeruk Lemon (Lemon Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1117,
    "Minyak Atsiri Jeruk Nipis (Lime Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1118,
    "MINYAK ATSIRI JERUK PURUT (KAFFIR LIME ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1119,
    "Minyak Atsiri Jintan Hitam (Black Cumin Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1120,
    "MINYAK ATSIRI JUNIPER BERRY (JUNIPER BERRY ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1121,
    "Minyak Atsiri Kayu Manis (Cinnamon Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1122,
    "Minyak Atsiri Kemukus (Cubeb Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1123,
    "Minyak Atsiri Kunyit (Turmeric Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1124,
    "Minyak Atsiri Lada (Pepper Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1125,
    "Minyak Atsiri Leci (Lychee Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1126,
    "MINYAK ATSIRI LEMON (LEMON ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1127,
    "MINYAK ATSIRI LOBAK (RADISH ESSENTIAL OIL-TURNIP ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1128,
    "Minyak Atsiri Mangga (Mango Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1129,
    "Minyak Atsiri Mint (Mint Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1130,
    "MINYAK ATSIRI MUSTARD (MUSTARDSEED ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1131,
    "MINYAK ATSIRI NANAS (PINEAPPLE ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1132,
    "Minyak Atsiri Nangka (Jackfruit Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1133,
    "Minyak Atsiri Pala (Nutmeg Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1134,
    "Minyak Atsiri Pandan (Pandan Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1135,
    "MINYAK ATSIRI PAPRIKA (PAPRIKA OLEORESIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1136,
    "Minyak Atsiri Peppermint (Peppermint Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1137,
    "MINYAK ATSIRI PERILLA (PERILLA ESSENTIAL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1138,
    "Minyak Atsiri Pisang (Banana Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1139,
    "MINYAK ATSIRI ROSEMARY (ROSEMARY OLEORESIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1140,
    "Minyak Atsiri Sereh (Lemongrass Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1141,
    "Minyak Atsiri Spearmint (Spearmint Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1142,
    "Minyak Atsiri Stroberi (Strawberry Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1143,
    "Minyak Atsiri Tarragon (Tarragon Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1144,
    "Minyak Atsiri Wortel (Carrot Essential Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1145,
    "Minyak Ayam (Chicken Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1146,
    "Minyak Babi (Pork Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1147,
    "Minyak Barley (Barley Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1148,
    "Minyak Bawang Merah (Shallot Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1149,
    "MINYAK BAWANG PUTIH (GARLIC OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1150,
    "MINYAK BERAS (RICE BRAN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1151,
    "Minyak Biji Anggur (Grapeseed Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1152,
    "MINYAK BIJI APRIKOT (APRICOT KERNEL OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1153,
    "MINYAK BIJI BUNGA MATAHARI (REFINED BLEACHED DEODORIZED SUNFLOWER OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1154,
    "MINYAK BIJI KAPAS (REFINED BLEACHED DEODORIZED COTTONSEED OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1155,
    "Minyak Biji Rami (Flaxseed Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1156,
    "MINYAK BIJI SAWI (MUSTARDSEED OIL - REFINED BLEACHED DEODORIZED MUSTARDSEED OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1157,
    "MINYAK BUNGA MATAHARI (SUNFLOWER OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1158,
    "MINYAK CABAI (CAPSICUM OLEORESIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1159,
    "MINYAK DAUN JERUK PURUT (KAFFIR LIME LEAF OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1160,
    "Minyak Durian (Durian Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1161,
    "MINYAK FRAMBOZEN (FRAMBOZEN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1162,
    "MINYAK GORENG (FRYING OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1163,
    "MINYAK GORENG KEDELAI (SOYBEAN FRYING OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1164,
    "Minyak Goreng Kelapa Sawit (Palm Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1165,
    "MINYAK IKAN (FISH OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1166,
    "Minyak Inti Kelapa Sawit Terhidrogenasi (Refined Hydrogenated Palm Kernel Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1167,
    "MINYAK JAGUNG (REFINED BLEACHED DEODORIZED CORN OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1168,
    "MINYAK JERUK (CITRUS OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1169,
    "MINYAK KACANG (PEANUT OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1170,
    "Minyak Kacang Macadamia (Macadamia Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1171,
    "MINYAK KACANG TANAH (REFINED BLEACHED DEODORIZED PEANUT OIL - REFINED BLEACHED DEODORIZED GROUNDNUT OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1172,
    "MINYAK KACANG WALNUT (WALNUT OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1173,
    "Minyak Kanola (Canola Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1174,
    "Minyak Kari (Curry Oil)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1175,
    "MINYAK KAYU MANIS (CINNAMON OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1176,
    "MINYAK KAYU PUTIH (EUCALYPTUS OIL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1177,
    "Lemak Reroti (Shortening)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1178,
    "Lemak Sapi (Beef Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1179,
    "Lemak Susu (Fat Milk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1180,
    "Lemak Susu Anhidrat (Anhydrous Milk Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1181,
    "Lemak Susu Sapi (Cow's Milk Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1182,
    "Lemak Trigliserida Rantai Sedang (MCT) (Medium Chain Triglyceride Fat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1183,
    "Lembaga Gandum (Wheat Germ)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1184,
    "Lemon Verbena (Lippia citriodora)",
    "Bahan Baku",
    "YES",
    "NO",
    "NO",
    "YES",
  ],
  [1185, "Lempuyang", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1186, "Lempuyang Wangi ", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1187,
    "Lengkuas - Laos (Galangal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1188,
    "Lengkuas Bubuk (Galangal Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1189,
    "Lentil (Lens Culinaris)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1190,
    "LEPTOSPERPUM CITRATEM",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1191, "Leuconostoc citreum", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1192,
    "Leuconostoc cremoris",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1193, "Leusin (Leusin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1194,
    "L-Glutamin (L-Glutamine)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    1195,
    "LICORICE - LIQUORICE (GLYCYRRHIZA GLABRA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1196,
    "Licorice Root-Akar Licorice (Glycyrrhiza Uralensis)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1197,
    "Lidah Buaya (Aloe Vera)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1198,
    "Lidah Buaya Bubuk (Aloe Vera Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1199,
    "Lidah Buaya Gel (Aloe Vera Gel)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1200,
    "LIDAH SAPI (BEEF ATAU COW ATAU OX TONGUE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1201, "Likopen (Lycopene)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1202,
    "LINGZHI (GANODERMA LUCIDUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1203, "LIQUEUR", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1204, "LIQUIORICE", "Bahan Baku", "NO", "NO", "YES", "NO"],
  [1205, "Lisin (Lysine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1206,
    "Lisin Monohidrat (Lysine Monohydrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1207,
    "L-KARNITIN (L-CARNITINE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1208,
    "LO HAN GUO (LO HAN GUO)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1209, "Lobak (Radish)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1210,
    "Lobak Bubuk (Radish Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1211,
    "Lobak Hijau (Turnip Greens)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1212,
    "Lobak Hijau Kering (Dried Turnip Greens)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1213,
    "Lobak Merah (Red Radish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1214,
    "LOBI - LOBI (BATOKO PLUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1215, "Lobster", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1216,
    "LOKIO KERING (DRIED CHIVES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1217,
    "LOKIO-BAWANG BATAK (CHIVES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1218, "LONICERA JAPONICA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1219,
    "LONTAR (LONTAR PALM ATAU BORASSUS FLABELLIFER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1220,
    "L-ORNITIN (L-ORNITHINE) (KATEGORI PANGAN 13)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1221, "L-Prolin", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1222, "L-Serin", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1223, "L-Theanine", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [
    1224,
    "Lucuma (Pouteria lucuma)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1225, "LUTEIN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1226, "Madu (Honey)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1227,
    "Madu Agave (Agave Honey)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1228,
    "Madu Akasia (Acacia Honey)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1229,
    "Madu Bubuk (Honey Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1230,
    "MADU HUTAN (FOREST HONEY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1231,
    "Madu Kelengkeng (Longan Honey)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1232,
    "MADU RANDU (KAPOK HONEY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1233,
    "Madu Sarang (Comb Honey) (Khusus Madu)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1234,
    "MAGNESIUM ASETAT (MAGNESIUM ACETATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1235,
    "Magnesium hidrogen fosfat (Magnesium hydrogen phosphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1236,
    "Magnesium hidroksida (Magnesium hydroxide)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1237,
    "MAGNESIUM KARBONAT (MAGNESIUM CARBONATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1238, "Magnesium Kaseinat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1239,
    "magnesium klorida (magnesium chloride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1240,
    "Magnesium laktat (Magnesium lactate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1241,
    "Magnesium L-Aspartat (Magnesium L-Aspartate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1242,
    "MAGNESIUM OKSIDA (MAGNESIUM OXIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1243, "Magnesium Sulfat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1244, "MAIZENA (CORNSTARCH)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1245, "Makaroni (Macaroni)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1246, "MALT (BARLEY MALT)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1247, "Malt (Malt)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1248,
    "Malt Barley (Barley Malt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1249,
    "Malt Bubuk (Malt Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1250,
    "Malto Oligosakarida (Malto Oligosaccharide)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1251,
    "Kubis Brussel (Brussels Sprouts)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1252,
    "KUCAI (GARLIC CHIVES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1253,
    "KUCAI KERING (DRIED GARLIC CHIVES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1254,
    "KUE BROWNIES (BROWNIE CAKE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1255, "KUE BUSA (MERINGUE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1256,
    "Kue Ikan (Fish Cake)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1257, "KUKIS (COOKIES)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1258,
    "Kulit Ayam (Chicken Skin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1259,
    "Kulit Babi (Pork Rind)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1260,
    "Kulit Bergamot (Bergamot Peels)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1261,
    "KULIT BIJI PALA (NUTMEG MACE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1262, "Kulit Buah Manggis", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1263,
    "Kulit Domba (Sheepskin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1264,
    "Kulit Gandum (Wheat Bran)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1265,
    "KULIT IKAN PATIN (PANGASIUS SKIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1266,
    "Kulit Ikan Salmon (Salmon Skin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1267,
    "Kulit Ikan Tenggiri (Mackerel Skin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1268,
    "Kulit Jagung (Corn Bran)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1269,
    "Kulit Jeruk (Orange Peel)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1270, "KULIT JERUK ........", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1271,
    "Kulit Jeruk Bubuk (Orange Peel Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1272,
    "Kulit Jeruk Lemon (Orange Peels)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1273,
    "KULIT JERUK MANDARIN (MANDARIN ORANGE PEELS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1274,
    "KULIT JERUK NIPIS (LIME PEELS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1275,
    "Kulit Kebab/Tortilla",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1276,
    "Kulit Lumpia (Spring Roll Skin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1277,
    "Kulit Oats Bubuk (Oats Bran Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1278,
    "Kulit Pangsit (Dumpling Skin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1279,
    "KULIT POHON PINUS EKSTRAK (PINE BARK EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1280, "Kulit Sapi", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1281,
    "KULIT SIOMAY (DUMPLING WRAPPER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1282,
    "KULIT TAHU (GOHYONG, BEAN CURD SHEET, BEAN CURD ROBES, BEAN CURD SKIN, TOFU SKIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1283,
    "KULIT TELUR (EGGSHELL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1284,
    "KULTUR BAKTERI (BACTERIAL CULTURE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1285,
    "KULTUR BAKTERI ASAM LAKTAT (LACTIC ACID BACTERIAL CULTURE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1286,
    "KULTUR STARTER (STARTER CULTURE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1287,
    "KUNING TELUR (EGG YOLK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1288,
    "KUNING TELUR ASIN (SALTED EGG YOLK)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1289,
    "KUNING TELUR BUBUK (EGG YOLK POWDER)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [1290, "KUNYIT (TURMERIC)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1291,
    "KUNYIT (TURMERIC-CURCUMA LONGA RHIZOME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1292,
    "KUNYIT ASAM (TURMERIC AND TAMARIND)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1293,
    "Kunyit Bubuk (Turmeric Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1294,
    "KUPANG KERING (DRY GREENSHELL MUSSELS",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1295, "Kurma (Dates)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1296,
    "Kurma Bubuk (Dates Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1297,
    "Kurma Merah (Red Dates)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1298,
    "L - GLUTATION (L - GLUTATHIONE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [1299, "Labu (Pumpkin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1300,
    "Labu Bubuk (Pumpkin Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1301, "LABU KUNING", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1302, "LABU SIAM (CHAYOTE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1303,
    "LACTOBACILLUS ACIDOPHILUS",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1304,
    "Lactobacillus bulgaricus",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1305, "Lactobacillus casei", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1306,
    "Lactobacillus Fermentum",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1307,
    "Lactobacillus helveticus ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1308,
    "Lactobacillus kefiri ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1309,
    "Lactobacillus lactis subsp. cremoris",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1310,
    "LACTOBACILLUS LACTIS SUBSP. LACTIS",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1311,
    "LACTOBACILLUS PARACASEI",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    1312,
    "Lactobacillus Plantarum",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1313,
    "Lactobacillus Reuteri",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1314,
    "LACTOBACILLUS RHAMNOSUS LGG (L+)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1315,
    "Lactobacillus rhamnosus NCC 4007",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1316, "Lactococcus lactis", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1317, "LADA (PEPPER)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1318,
    "LADA HIJAU (GREEN PEPPERCORN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1319,
    "KRIMER NABATI (NON DAIRY CREAMER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1320,
    "KRISANTEMUM (CHRYSANTHEMUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [
    1321,
    "KRISANTEMUM BUBUK (CHRYSANTEMUM POWDER) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1322, "KRIMER (CREAMER)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1323,
    "Krimer Kental Manis (Sweetened Condensed Creamer)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1324,
    "KRIMER MINUMAN (NON DAIRY CREAMER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1325,
    "Krim Nabati Bubuk (Vegetable Cream Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1326,
    "Krim Pasteurisasi (Pasteurized Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1327,
    "KRIM RASA VANILA (VANILLA CREAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1328,
    "KRIM SAYUR (VEGETABLE CREAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1329,
    "Krim Stroberi (Strawberry Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1330,
    "KRIM SUSU (MILK CREAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1331,
    "Krim Susu Bubuk (Milk Cream Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1332,
    "Krim Tiramisu (Tiramisu Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1333,
    "Kopi Robusta (Robusta Coffee)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1334, "Kopra (Copra)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1335,
    "KORIANDER BUBUK (CORIANDER POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1336,
    "Koro Pedang (Jack Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1337,
    "Kranberi (Cranberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1338,
    "Kranberi Kering (Dried Cranberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1339,
    "Kratom (Mitragyna speciosa)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1340,
    "KREATIN MONOHIDRAT (CREATINE MONOHYDRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [1341, "KRECEK (KRECHEK)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1342,
    "Krekers Beras (Rice Crackers)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1343,
    "Krill Oil (Eupausia Superba)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1344, "Krim (Cream)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1345,
    "Krim Asam (Sour Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1346,
    "Krim Bubuk (Cream Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1347,
    "Krim Kacang Hazel (Hazelnut Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1348,
    "KRIM KAPUCINO (CAPPUCCINO CREAM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1349,
    "Krim Karamel (Caramel Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1350,
    "Krim Kelapa (Coconut Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1351,
    "Krim Kopi (Coffee Cream)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1352,
    "Krim Nabati (Vegetable Cream) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1353, "Kopi (Coffee)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1354,
    "KOPI ARABIKA (ARABICA COFFEE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1355,
    "Kopi Bubuk (Coffee Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1356,
    "Kopi Bubuk Instan (Instant Coffee Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1357,
    "Kopi Pasta (Coffee Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1358,
    "Kari Bubuk (Curry Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1359, "Kasein (Casein)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1360,
    "Kayu Manis (Cinnamon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1361,
    "Konsentrat Buah Blueberry (Blueberry Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1362,
    "KONSENTRAT BUAH ELDERBERRY (ELDERBERRY CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1363,
    "KONSENTRAT BUNGA ELDERBERI (ELDERFLOWER CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1364,
    "KONSENTRAT CAMPURAN SARI BUAH (MIXTURE OF FRUIT JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1365,
    "KONSENTRAT COCOPANDAN (COCOPANDAN CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1366,
    "KONSENTRAT COKELAT SUSU (MILK CHOCOLATE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1367,
    "KONSENTRAT COLA (COLA CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1368,
    "KONSENTRAT DAUN ASAM MUDA (TAMARIND LEAVES CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1369,
    "Konsentrat Daun Mint (Mint Leaves Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1370,
    "KONSENTRAT DAUN PANDAN (PANDAN LEAVES CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1371,
    "KONSENTRAT DAUN TEH (TEA LEAVES CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1372,
    "Konsentrat Gula Tebu (Sugar Cane Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1373,
    "Konsentrat Jahe (Ginger Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1374,
    "Konsentrat Jeruk (Orange Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1375,
    "Keju Bubuk (Cheese Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1376,
    "Keju Cheddar (Cheddar Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1377,
    "Keju Edam (Edam Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1378,
    "Keju Feta (Feta Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1379,
    "Keju Gouda (Gouda Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1380,
    "Keju Grana Padano (Grana Padano Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1381,
    "Keju Krim (Cream Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1382,
    "Keju Mascarpone (Mascarpone Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1383,
    "Keju Mozzarella (Mozzarella Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1384,
    "Keju Myzithra (Mizithra Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1385,
    "Keju Parmesan (Parmesan Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1386,
    "Keju Pecorino (Pecorino Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1387,
    "Keju Pecorino Romano (Pecorino Romano Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1388,
    "Keju Ricota (Richotta Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1389,
    "KAYU SECANG (SAPPAN WOOD - CAESALPINIAE SAPPANIS LIGNUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1390,
    "Kayumanis-Keningar Bubuk (Cinnamon Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1391, "Kecap (Soy Sauce)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1392,
    "KECAP ASIN (SALTY SOY SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1393,
    "Kecap Bubuk (Soy Sauce Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1394,
    "Kecap Ikan (Fish Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1395,
    "Kecap Inggris (Worcestershire Sauce)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1396,
    "KECAP KEDELAI MANIS (SWEET SOY SAUCE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1397, "Kedelai", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1398,
    "KEDONDONG (AMBARELLA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1399, "Kefir (Keffir)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1400,
    "Konsentrat Kacang Kedelai (Soybean Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1401,
    "Konsentrat Kacang Merah (Red Beans Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1402,
    "KONSENTRAT KELAPA KOPYOR (KOPYOR CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1403,
    "Konsentrat Kepiting (Crab Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1404,
    "Konsentrat Kopi (Coffee Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1405,
    "KONSENTRAT LECI (LYCHEES CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1406,
    "Konsentrat Lemon (Lemon Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1407,
    "Konsentrat Lidah Buaya (Aloe Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1408,
    "Konsentrat Lobak Merah (Red Radish Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1409,
    "Konsentrat Loofah (Loofah Concentrate) (Kecuali Pangan Untuk Keperluan Gizi Khusus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1410,
    "Konsentrat Madu (Honey Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1411,
    "Konsentrat Mangga (Mango Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1412,
    "Konsentrat Mentimun (Cucumber Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1413,
    "Konsentrat Nanas (Pineapple Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1414,
    "Konsentrat Peppermint (Peppermint Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1415,
    "Konsentrat Pir (Pears Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1416,
    "Konsentrat Protein Kedelai (Soy Protein Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1417,
    "Konsentrat Protein Susu (Milk Protein Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1418,
    "KONSENTRAT PROTEIN WHEY (WHEY PROTEIN CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1419,
    "Konsentrat Santan (Coconut Milk Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1420,
    "Konsentrat Sari Buah Acai Berry (Acai Berry Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1421,
    "Konsentrat Sari Buah Anggur (Grape Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1422,
    "Konsentrat Sari Buah Anggur Merah (Red Grape Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1423,
    "Konsentrat Sari Buah Apel (Apple Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1424,
    "Konsentrat Sari Buah Aprikot (Apricots Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1425,
    "KONSENTRAT SARI BUAH ARONIA BERRY (ARONIABERRY JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1426,
    "Konsentrat Sari Buah Bit (Bit Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1427,
    "Konsentrat Sari Buah Bit Merah (Red Bit Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1428,
    "Konsentrat Sari Buah Blackberry (Blackberry Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1429,
    "Konsentrat Sari Buah Blackcurrant (Blackcurrant Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1430,
    "Konsentrat Sari Buah Blueberry (Blueberry Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1431,
    "KONSENTRAT SARI BUAH CAMPURAN (MIXED FRUIT JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1432,
    "Konsentrat Sari Buah Ceri (Cherry Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1433,
    "Konsentrat Sari Buah Delima (Pomegranate Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1434,
    "Konsentrat Sari Buah Durian (Durian Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1435,
    "KONSENTRAT SARI BUAH ELDERBERRY (ELDERBERRY JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1436,
    "KONSENTRAT SARI BUAH GOJI BERRY (GOJI BERRY JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1437,
    "KONSENTRAT SARI BUAH JAMBU MERAH (GUAVA JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1438,
    "KONSENTRAT SARI BUAH JERUK (ORANGE JUICE CONCENTRATE)",
    "Bahan Baku",
    "YES",
    "NO",
    "NO",
    "YES",
  ],
  [
    1439,
    "Konsentrat Sari Buah Jeruk Bali Merah (grapefruit juice concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1440,
    "Konsentrat Sari Buah Jeruk Florida (Florida Orange Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1441,
    "KONSENTRAT SARI BUAH JERUK NIPIS (LIME JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1442,
    "Konsentrat Sari Buah Kawista (Kawista Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1443,
    "Konsentrat Sari Buah Kiwi (Kiwi Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1444,
    "KONSENTRAT SARI BUAH KRANBERI (CRANBERRY JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1445,
    "KONSENTRAT SARI BUAH KURMA (DATES JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1446,
    "KONSENTRAT SARI BUAH LABU AIR (CALABASH JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1447,
    "KONSENTRAT SARI BUAH LECI (LYCHEE JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1448,
    "Konsentrat Sari Buah Leci (Lychees Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1449,
    "Konsentrat Sari Buah Lemon (Lemon Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1450,
    "Konsentrat Sari Buah Mangga (Mango Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1451,
    "Konsentrat Sari Buah Markisa (Passion Fruit Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1452,
    "Konsentrat Sari Buah Melon (Honeydew Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1453,
    "Konsentrat Sari Buah Merah (Red Fruit Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1454,
    "Konsentrat Sari Buah Nanas (Pineapple Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1455,
    "Konsentrat Sari Buah Nangka (Jackfruit Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1456,
    "Konsentrat Sari Buah Pepaya (Papaya Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1457,
    "KONSENTRAT SARI BUAH PERSIK (PEACH JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1458,
    "KONSENTRAT SARI BUAH PIR (PEAR JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1459,
    "Konsentrat Sari Buah Pisang (Banana Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1460,
    "Konsentrat Sari Buah Plum (Plum Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1461,
    "Konsentrat Sari Buah Prune (Prune Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1462,
    "Konsentrat Sari Buah Quince (Quince Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1463,
    "Konsentrat Sari Buah Raspberry (Raspberry Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1464,
    "Konsentrat Sari Buah Redcurrant (Redcurrant Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1465,
    "KONSENTRAT SARI BUAH SALAK (SNAKE FRUIT JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1466,
    "Konsentrat Sari Buah Semangka (Watermelon Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1467,
    "Konsentrat Sari Buah Sirsak (Soursop Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1468,
    "KONSENTRAT SARI BUAH STROBERI (STRAWBERRY JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1469,
    "KONSENTRAT SARI BUAH TOMAT (TOMATO JUICE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1470,
    "Konsentrat Sari Kelapa (Coconut Juice Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1471,
    "konsentrat sayur .....",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1472,
    "Konsentrat Spirulina (Spirulina Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1473,
    "KONSENTRAT SUSU (MILK CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1474,
    "Konsentrat Talas (Taro Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1475,
    "KONSENTRAT VANILA (VANILLA CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1476,
    "KONSENTRAT WHEY PROTEIN (WHEY PROTEIN CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1477,
    "Konsentrat Wortel (Carrot Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1478,
    "KONSENTRAT WORTEL UNGU/WORTEL HITAM (PURPLE/BLACK CARROT CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1479,
    "Keju Romano (Romano Cheese)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1480, "KEJU WHEY", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1481,
    "KELABAT (FENUGREEK)(HALBA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1482,
    "Kelabat Bubuk (Fenugreek Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1483,
    "Keladi - Talas (Taro-Caladium)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1484, "Kelapa (Coconut)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1485,
    "Kelapa Bubuk (Coconut Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1486,
    "Kelapa Kering (Dried Coconut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1487,
    "Kelapa Muda (Young Coconut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1488,
    "Kelapa Parut (Desiccated Coconut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1489,
    "Kelapa Parut Kering (Dried Desiccated Coconut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1490, "Kelapa Sawit (Palm)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1491, "Kelengkeng (Longan)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1492,
    "Kelp Bubuk (Kelp Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1493, "Kemangi (Basil)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1494,
    "Kembang Kol (Cauliflower)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1495,
    "KEMBANG PALA (MYRISTICA FRAGRAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1496,
    "KEMBANG SEPATU (HIBISCUS ROSA SINENSIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1497,
    "Kembang Tahu (Beancurd)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1498, "KEMIRI (CANDLENUT)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1499,
    "KEMIRI BUBUK (CANDLENUT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1500,
    "KENCUR ( KAEMPFERIA GALANGA )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1501, "Kenikir (Marigolds)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1502, "KENTANG", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1503, "Kentang (Potato)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1504,
    "Kentang Bubuk (Potato Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1505,
    "Kentang Kering (Dried Potatoes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1506,
    "Kentang Merah (Red Potato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1507,
    "Kentang Panggang Bubuk (Roasted Potato Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1508, "Keong (Snail)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1509, "Kepah (Mussel)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1510, "Kepiting (Crab)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1511, "Kerang (Scallops)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1512,
    "Kerang Bubuk (Scallops Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1513,
    "Keripik Pisang (Banana Chips)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1514,
    "Keripik Singkong (Cassava Chips)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1515, "KERTAS BERAS", "Bahan Baku", "YES", "YES", "NO", "YES"],
  [1516, "Kerupuk", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1517,
    "Kerupuk Beras (Rice Crackers)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1518, "Kerupuk Ikan", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1519,
    "KERUPUK KEPITING ( CRAB CHIPS )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1520,
    "Kerupuk Udang (Prawn Crackers)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1521, "Ketam (Crab)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1522,
    "Ketan Hitam (Black Sticky Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1523,
    "KETUMBAR (CORIANDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1524,
    "Ketumbar Bubuk (Coriander Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1525, "Kimchi (Kimchi)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1526,
    "Kimchi Kering (Kimchi Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1527, "KININ (KININE)", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [1528, "Kismis (Raisin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1529,
    "Kismis Merah (Red Raisin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1530, "Kitosan (Chitosan)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1531, "Kiwi (Kiwi)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1532,
    "KLEMBAK (RHEUM OFFICINALE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1533,
    "KLOROFIL (CHLOROPHYL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1534, "Kluwek-Keluwek", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1535, "KOJI", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1536,
    "KOJI (SWEET POTATO KOJI)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "NO",
  ],
  [
    1537,
    "KOJI BERAS (RICE KOJI)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "NO",
  ],
  [
    1538,
    "Kol - Kubis (Cabbage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1539,
    "Kol - Kubis Kering (Dried Cabbage)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1540, "Kolagen (Collagen)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1541,
    "KOLANG KALING ( BUAH ATAP, SUGAR PALM FRUIT )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1542,
    "KOLEKALSIFEROL (VIT D3)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1543, "Kolin (Choline)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1544,
    "Kolin Bitartrat (Choline Bitartrat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1545,
    "Kolin Klorida (Choline Chloride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1546,
    "Kolostrum Bubuk (Colostrum Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1547,
    "KONDROITIN (CHONDROITIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1548,
    "KONDROITIN SULFAT (CHONDROITIN SULFATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [1549, "Konsentrat acerola", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1550,
    "Konsentrat Agave (Agave Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1551,
    "Konsentrat Air Kelapa (Coconut Water Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1552,
    "Konsentrat Akar Bunga Balon (Balloon Flower Root Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1553,
    "KONSENTRAT ANGGUR MERAH (RED GRAPE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1554,
    "KONSENTRAT APEL (APPLE CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1555,
    "KONSENTRAT ARONIA BERRY (CHOKEBERRY CONCENTRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1556,
    "Konsentrat Asam Jawa (Tamarind Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1557,
    "Konsentrat Bawang Putih (Garlic Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1558,
    "Konsentrat Blewah (Cantaloupe Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1559,
    "KONSENTRAT BUAH ......",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1560,
    "Konsentrat Buah Anggur (Grape Concentrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1561, "Karamel (Caramel)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1562,
    "Karamel Bubuk (Caramel Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1563,
    "KARAMEL CAIR (LIQUID CARAMEL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1564,
    "Karagenan (Caragenan)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1565,
    "DEKSTROSA MONOHIDRAT (DEXTROSE MONOHYDRATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1566,
    "EKSTRAK BUNGA CHAMOMILE (CHAMOMILE FLOS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1567,
    "EKSTRAK BUNGA ELDER (ELDER FLOS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1568,
    "Ekstrak Bunga Jeruk (Orange Flos Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1569,
    "EKSTRAK BUNGA KRISAN (CHRYSANTHEMUM EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1570,
    "EKSTRAK BUNGA MAWAR (ROSE FLOS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1571,
    "EKSTRAK BUNGA SAFFLOWER (CARTHAMUS TINCTORIUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1572,
    "Ekstrak Cabe (Chili Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1573,
    "Ekstrak Campuran Buah Beri (Mixberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1574,
    "Ekstrak Chicory (Chicory Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1575,
    "Ekstrak Cincau (Grass Jelly Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1576, "EKSTRAK COCOPANDAN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1577, "Kalium Hidroksida", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1578,
    "KALIUM IODIDA (POTASSIUM IODIDA-KIO3)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1579,
    "Kalium Karbonat (Potassium carbonate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1580,
    "Kalium Kaseinat (Potassium Caseinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1581,
    "KALIUM KLORIDA (POTASSIUM CHLORIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1582, "Kalium Sitrat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1583,
    "KALSIUM DARI GANGGANG LAUT (CALCAREOUS MARINE ALGAE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1584,
    "Kalsium Gliserofosfat (Calcium Glycerophosphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1585,
    "Kalsium Hidrogen Fosfat Anhidrat (Calsium Hydrogen Phosphate Anhydrous)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1586, "Kalsium hidroksida", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1587, "KALSIUM KARBONAT", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1588,
    "Kalsium Kaseinat (Calcium caseinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1589, "Kalsium Klorida", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1590,
    "Kalsium L-5-metil tetrahidrofolat (Calcium L-5- methyl tetrahydrofolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1591,
    "Kalsium Laktat (Calcium Laktate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1592,
    "Kalsium Natrium Kaseinat (Calcium Sodium Caseinate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1593,
    "KALSIUM PANTOTENAT (CALCIUM PANTOTHENATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1594,
    "KALSIUM PANTOTENAT (VIT B5)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1595,
    "Kalsium Pidolat (Calcium Pidolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1596,
    "Kalsium Susu (Milk Calcium)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1597, "Kalsium Tulang Ikan", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1598,
    "KALSIUM-D-PANTOTENAT (CALCIUM-D-PANTOTHENATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1599, "Kamaboko", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1600, "Kangkung", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1601, "Kapulaga (Cardamon)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1602,
    "Kapulaga Bubuk (Cardamon Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1603,
    "DHA (dari Minyak Ikan)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1604,
    "DHA (dari Minyak Sel Tunggal)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1605,
    "DHA (DOCOSAHEXAENOIC ACID )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1606,
    "DIKALIUM FOSFAT (DIPOTASSIUM PHOSPHATE-DIPOTASSIUM ORTHOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1607,
    "DI-KALIUM HIDROGEN FOSFAT (DI-POTASSIUM HYDOGEN PHOSPAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1608,
    "DIKALSIUM FOSFAT (KALSIUM HIDROGEN FOSFAT, KALSIUM MONOHIDROGEN FOSFAT, KALSIUM HIDROGEN ORTOFOSFAT))",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1609,
    "Cabe Jalapeno (Jalapeno Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1610,
    "CABE JALAPENO BUBUK (JALAPENO POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1611,
    "CABE JAWA (JAVANESE LONG PEPPER, PIPER RETROFRACTUM VAHL.)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1612,
    "Cabe Kering (Dried Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1613,
    "Cabe Kuning (Yellow Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1614,
    "Cabe Hijau (Green Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1615,
    "Cabe Hijau Bubuk (Green Chili Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1616,
    "Cabe Habanero (Habanero Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1617,
    "Buttermilk (Buttermilk)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1618,
    "Buttermilk Bubuk (Buttermilk Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1619, "Cabe (Chili)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1620,
    "Cabe Bubuk (Chili Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1621,
    "BUNGA JAGUNG (CORN FLOWER - CENTAURA CYANUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1622,
    "BUNGA JERUK CITRUS AURANTIUM (FLOWERS ORANGE CITRUS AURANTIUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1623,
    "BUNGA JERUK CITRUS AURANTIUM-JERUK NIPIS (ORANGE BLOSSOMS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1624,
    "Bunga Lavender (Lavandula angustifolia)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1625, "BUNGA MATAHARI", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1626,
    "Bunga Matahari (Sunflower)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1627,
    "BUNGA MAWAR ROSA CHINENSIS (ROSE BLOSSOMS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1628,
    "BUNGA MAWAR-ROSE BLOSSOM (ROSA CHINENSIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1629,
    "Bunga Osmanthus Kering (Dried Osmanthus Flower) (Kecuali Pangan Untuk Keperluan Gizi Khusus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1630, "Bunga Pala", "Bahan Baku", "NO", "YES", "NO", "YES"],
  [1631, "BUNGA SAFFLOWER", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1632, "BUNGA SAKURA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1633,
    "Bunga Scarlet Bee Balm (Monarda didyma L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1634,
    "Bunga Sedap Malam (Lily Flower)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1635,
    "Bunga Telang (Clitoria Ternatea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1636, "bunga teratai", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1637,
    "Buntut Sapi (Oxtail)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1638, "BURDOCK ROOT", "Bahan Baku", "NO", "NO", "YES", "NO"],
  [
    1639,
    "Ekstrak Wasabi (Wasabi Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1640,
    "Ekstrak Wildberry (Wildberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1641,
    "EKSTRAK WOLFBERRY (WOLFBERRY EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1642,
    "Ekstrak Wortel (Carrot Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1643,
    "EKSTRAK WORTEL UNGU/WORTEL HITAM (PURPLE/BLACK CARROTS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1644,
    "Ekstrak Zizania latifolia (Kecuali Pangan Untuk Keperluan Gizi Khusus)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1645,
    "ELDERBERRY (SAMBUCUS EBULUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1646,
    "ELDERBERRY (SAMBUCUS NIGRA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1647, "EMPING BARLEY ", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1648,
    "EMPING JAGUNG (CORN FLAKES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1649,
    "EMPING MELINJO - GNETUM GNEMON ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1650,
    "ENZIM AMILASE (AMILASE ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1651,
    "Enzim Beta - Fruktofuranosidase ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1652,
    "ENZIM BROMELAIN (BROMELAINE ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1653,
    "Enzim Glucoamylase dari Aspergillus niger (Glucoamylase from Aspergillus niger)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1654,
    "ENZIM LAKTASE (LACTASE ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1655,
    "Enzim Laktoperoksidase (Lactoperoxidase Enzyme)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1656,
    "ENZIM LIPASE (LIPASE ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1657,
    "ENZIM PAPAIN (PAPAIN ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1658,
    "ENZIM PROTEASE (PROTEASE ENZYME)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1659,
    "Enzim Transglutaminase",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1660,
    "EPA (EICOSAPENTAENOIC ACID)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1661, "Es (Ice)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1662, "Es Batu (Ice Cube)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1663, "Es Susu (Milk Ice)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1664, "Ester Sterol", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1665, "EUCOMMIA ULMOIDES", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1666,
    "Feijoa / Pineapple Guava (Acca sellowiana)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1667,
    "Fenilalanin (Phenilalanin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1668,
    "FITOMENADION (VIT K1)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1669,
    "FITOSTANOL (PHYTOSTANOL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1670,
    "Fitosterol (Phytosterol)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1671, "FONDAN (FONDANT)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1672,
    "Fosfolipid (Phospholipids)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1673,
    "FRUKTO OLIGOSAKARIDA (FOS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1674, "Fruktosa (Fructose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1675,
    "GABAH PADI (RICE GRAIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1676,
    "Galakto Oligosakarida (GOS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1677, "GAMA KAROTEN", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1678,
    "Gambir (Uncaria gambir)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1679,
    "Gamma Aminobutyric Acid (GABA) (Untuk Minuman Teh)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [1680, "Gandum (Wheat)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1681,
    "GANDUM DURUM SEMOLINA (DURUM SEMOLINA WHEAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1682, "GANDUM HITAM (RYE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1683,
    "GANDUM MALT (WHEAT MALT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1684,
    "Gandum Merah (Red Wheat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1685,
    "Gandum Panggang (Roasted Wheat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1686,
    "Gandum Semolina (Semolina Wheat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1687,
    "Gandum Serpihan (Wheat Flakes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1688,
    "Gandum Utuh (Whole Wheat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1689,
    "Ganggang Laut (Sea Algae)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1690,
    "GANGLIOSIDA (GANGLIOSIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1691, "Garam (Salt)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1692,
    "GARAM BERIODIUM (IODIZED SALT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1693,
    "Garam Halus (Refined Salt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1694,
    "Garam Hitam (Black Salt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1695,
    "Garam Inggris (Epsom Salt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1696,
    "Garam Laut (Sea Salt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1697,
    "GARAM RAFINASI (REFINED SALT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1698, "GARCINIA CAMBOGIA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1699, "GARDENIA BLUE", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1700, "GELATIN (GELATINE)", "Bahan Baku", "YES", "NO", "NO", "YES"],
  [1701, "Gembili", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1702,
    "GENMAICHA (ROASTED RICE TEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1703, "GIN (GIN)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1704, "GINKGO BILOBA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1705, "GLISERIN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1706,
    "Iodium (Kalium Iodat - KIO3)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1707,
    "Isian berbasis susu",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    1708,
    "Isolat Protein Kedelai (Soy Protein Isolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1709,
    "ISOLAT PROTEIN NABATI (VEGETABLE PROTEIN ISOLATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1710, "Isolat Protein Pea", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [
    1711,
    "Isolat Protein Pea (Pea Protein Isolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1712,
    "ISOLAT PROTEIN SUSU (MILK PROTEIN ISOLATE)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1713,
    "ISOLAT PROTEIN WHEY (WHEY PROTEIN ISOLATE)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    1714,
    "Isoleusin (Isoleucine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1715,
    "ISOMALTO OLIGOSAKARIDA (ISOMALTOOLIGOSACCHARIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1716,
    "Isomaltodekstrin (IMD)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1717,
    "Isomaltulosa (Isomaltulose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1718, "Jagung", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [1719, "Jagung (Corn)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1720,
    "JAGUNG BAKAR (ROASTED CORN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1721,
    "Jagung Bakar Bubuk (Roasted Corn Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1722,
    "Jagung Berondong (Pop Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1723,
    "Jagung Butiran (Corn Grain)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1724,
    "Jagung Kering (Dried Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1725,
    "Jagung Kernel Utuh (Whole Kernel Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1726,
    "Jagung Manis (Sweet Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1727,
    "Jagung Manis Bubuk (Sweet Corn Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1728,
    "Jagung Muda (Baby Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1729,
    "JAGUNG SEMOLINA (MAIZE SEMOLINA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1730,
    "Jagung Serpihan (Corn Flakes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1731, "Jahe (Ginger)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1732,
    "Jahe Bubuk (Ginger Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1733,
    "Jahe Giling (Milled Ginger)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1734,
    "Jahe Kering (Dried Ginger)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1735,
    "JAHE MERAH- ZINGIBER OFFICINALE VAR RUBRU (RED GINGER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1736,
    "JALI (COIX LACRYMA-JOBI)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1737,
    "JAMBU AIR (ROSE APPLE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1738, "Jambu Biji (Guava)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1739,
    "Jambu Biji Bubuk (Guava Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1740, "Jambu Mete (Cashew)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1741, "Jamur (Mushroom)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1742,
    "Jamur Boletes Kuning",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1743,
    "Jamur Bubuk (Mushroom Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1744,
    "Jamur Geotrichum candidum",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1745,
    "Jamur Kancing (Champignon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1746,
    "Jamur Kering (Dried Mushroom)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1747,
    "Jamur Kuping (Auricularia auricula)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1748,
    "JAMUR KUPING HITAM (AURICULARIA POLYTRICHA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1749,
    "JAMUR MADU (ARMILLARIA OSTOYAE, HONEY MUSHROOM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1750,
    "JAMUR MERAH BUBUK (RED MUSHROOM POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1751,
    "Jamur Merang (Volvariella volvacea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1752,
    "JAMUR MESHAMA- JAMUR SANGHWANG, MESHIMAKOBU; SONG GEN (PHELLINUS LINTEUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1753,
    "JAMUR SALJU - ENOKITAKE (FLAMMULINA VELUTIPES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1754,
    "JAMUR SANGHWANG (PHELLINUS LINTEUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1755,
    "JAMUR SHIITAKE (LENTINULA EDODES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1756,
    "Jamur Shiitake Bubuk (Shiitake Mushroom Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1757, "Jamur Tempe", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1758,
    "JAMUR TEROMPET - JAMUR SARANG BURUNG",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1759,
    "Jamur Tiram (Pleurotus ostreatus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1760,
    "Jantung Pisang (Banana Heart)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1761,
    "Jantung Sapi (Beef Heart)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1762, "Jeli (Jelly)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1763,
    "Jeli Bubuk (Jelly Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1764, "JENGKOL (DJENKOL)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1765, "Jeruk (Orange)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1766,
    "Jeruk Asam-Pahit (Seville Orange)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1767,
    "Jeruk Bali (Grapefruit- Pomelo)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1768,
    "JERUK BALI MERAH (GRAPEFRUIT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1769,
    "JERUK BERGAMOT (CITRUS BERGAMIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1770,
    "Jeruk Besar (Grapefruit- Pomelo)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1771,
    "Jeruk Bubuk (orange powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1772,
    "Jeruk Citron-Jeruk Sukade (Citrus medica)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1773,
    "JERUK KEPROK (CITRUS RETICULATA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1774,
    "Jeruk Kunci (Key Lime)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1775,
    "JERUK LEMON (CITRUS LIMON)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1776,
    "Jeruk Lemon Bubuk (Lemon Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1777,
    "JERUK LIMAU (CITRUS AMBLYCARPA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1778,
    "Jeruk Mandarin (Mandarin Orange)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1779,
    "JERUK NIPIS (CITRUS AURANTIFOLIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1780,
    "Jeruk Nipis Bubuk (Lime Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1781,
    "JERUK PURUT (KAFFIR LIME - CITRUS HYSTRIX)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1782,
    "JERUK TANGERINE (CITRUS TANGERINA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1783,
    "JINTAN HITAM (NIGELLA SATIVA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1784,
    "JINTAN-JINTEN (CARAWAY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1785,
    "JINTAN-JINTEN BUBUK (CARAWAY POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1786,
    "JINTAN-JINTEN HITAM (HABBATUSSAUDA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1787,
    "JINTAN-JINTEN MANIS (ANISE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1788,
    "JINTAN-JINTEN PUTIH-CUNICUM CYMINUM (CUMIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1789, "JUNIPER BERRIES", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1790,
    "Kacang Alas/ Biji Sengon",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1791,
    "KACANG ALMOND (ALMOND)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1792,
    "KACANG ARAB - GARBANZO (CHICKPEA - CICER ARIETINUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1793, "Kacang Atom ", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1794,
    "KACANG AZUKI - KACANG MERAH KECIL - KACANG TOLO MERAH (AZUKI BEANS) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1795,
    "Kacang Blackeye (Blackeye Beans)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1796,
    "KACANG BOGOR (BAMBARA GROUNDNUTS - VIGNA SUBTERRANEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1797,
    "Kacang Brazil (Brazil Nut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1798,
    "KACANG BUNCIS (COMMON BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1799,
    "KACANG DAL (DHAL PEANUTS) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1800,
    "KACANG DAL URAD (DHAL URAD PEANUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1801,
    "Kacang Flageolet (Flageolet Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1802,
    "KACANG GARBANZO (GARBANZO BEANS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1803,
    "KACANG GINKGO (GINKGO NUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1804,
    "Kacang Gude (Pigeon Pea)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1805,
    "Kacang Hazel (Hazelnut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1806,
    "Kacang Hazel Panggang (Roasted Hazelnut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1807,
    "KACANG HIJAU (MUNG BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1808,
    "KACANG HIJAU BUBUK (MUNG BEAN POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1809,
    "KACANG HIJAU TANPA KULIT (SPLIT MUNG BEANS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1810, "KACANG HITAM", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1811, "KACANG KAPRI (PEAS)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1812,
    "KACANG KASTANYE (CHESTNUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1813,
    "Kacang Kedelai (Soybean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1814,
    "Kacang Kedelai Bubuk (Soybean Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1815,
    "KACANG KEDELAI HITAM (BLACK SOYBEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1816,
    "Kacang Kedelai Hitam Bubuk (Black Soybean Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1817,
    "Kacang Kedelai Muda (Edamame)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1818,
    "KACANG KENARI (WALNUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1819,
    "Kacang Koro (Broad Bean) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1820,
    "KACANG KRANBERI (BORLOTTI BEANS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1821,
    "Kacang Kuning (Yellow Beans)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1822,
    "KACANG LENTIL (LENTILS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1823,
    "KACANG LENTIL COKLAT (BROWN LENTILS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1824,
    "KACANG LENTIL MERAH (RED LENTILS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1825,
    "KACANG LIMA (LIMA BEANS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1826,
    "Kacang Macadamia (Macadamia Nut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1827,
    "Kacang Mede (Cashewnut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1828,
    "Kacang Merah (Red Bean-Kidney Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1829,
    "KACANG NAVY - KACANG PUTIH (NAVY BEANS - WHITE PEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1830,
    "KACANG PANJANG (YARDLONG BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1831,
    "KACANG PARANG (JACK BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1832,
    "KACANG PIKAN (PECAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1833,
    "KACANG PINUS (PINE NUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1834,
    "KACANG PISTACHIO (PISTACHIO NUTS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1835,
    "KACANG PISTACHIO PANGGANG (ROASTED PISTACHIO)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1836,
    "KACANG POLONG HIJAU (GREEN SPLIT PEAS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1837,
    "Kacang Polong Kering (Dried Greenpeas)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1838,
    "KACANG POLONG KUNING (YELLOW GREENPEAS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1839,
    "Kacang Polong-Ercis (Greenpeas)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1840, "KACANG PUTIH ", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1841,
    "Kacang Tanah (Peanut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1842,
    "Kacang Tanah Kupas (Shelled Peanuts)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1843,
    "Kacang Tanah Panggang (Roasted Peanut)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1844,
    "KACANG TOLO-KACANG TUNGGAK-KACANG DADAP",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1845,
    "KACANG WALNUT (WALNUT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1846, "KAFEIN (CAFFEIN)", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [
    1847,
    "Kailan (Kai-lan-Chinese Broccoli)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1848, "KAKAO (COCOA)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1849,
    "KAKAO BUBUK (COCOA POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1850, "KAKAO LIQUOR", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1851,
    "KAKAO MASSA (COCOA MASS - COCOA LIQUOR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1852,
    "KAKAO PASTA (COCOA PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1853,
    "Kaki Babi (Pigs Feet)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1854,
    "Kalamansi (Calamansi)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1855,
    "Kaldu Ayam (Chicken Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1856,
    "Kaldu Babi (Pork Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1857,
    "Kaldu Ikan (Fish Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1858,
    "Kaldu Kalkun (Turkey Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1859,
    "Kaldu Kerang (Scallop Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1860,
    "Kaldu Sapi (Beef Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1861,
    "Kaldu Sayuran (Vegetable Broth)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1862, "Kaldu Udang", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [1863, "Kalium Bikarbonat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1864,
    "KALIUM DIHIDROGEN FOSFAT (POTASSIUM DIHYDROGEN PHOSPHATE) KEC. MPASI",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1865,
    "Kalium fluorida (Potassium fluoride)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1866,
    "Ekstrak Daging Ayam (Chicken Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1867,
    "Ekstrak Daging Babi (Pork Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1868,
    "Ekstrak Daging Sapi (Beef Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1869,
    "Ekstrak Daun Katuk (Sauropus androgynus Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1870,
    "EKSTRAK DAUN MESONA (MESONA LEAF EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1871,
    "EKSTRAK DAUN PANDAN (PANDANUS LEAF EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1872,
    "Ekstrak Daun Salam (Bay Leaf Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1873,
    "EKSTRAK DAUN SIRIH (PIPER BETLE EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1874,
    "Ekstrak Daun Wasabi (Wasabi Leaf Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1875,
    "EKSTRAK DEDAK (RICE BRAN EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1876,
    "EKSTRAK FRAMBOZEN (FRAMBOZEN EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1877,
    "Ekstrak Gandum (Wheat Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1878,
    "Ekstrak Ginseng (Panax Ginseng C.A Meyer)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1879,
    "Ekstrak Ginseng (Panax Quinquefolius-American Ginseng)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1880,
    "EKSTRAK GUARANA - PAULLINIA CUPANA(GUARANA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1881,
    "EKSTRAK GUARANA BUBUK (GUARANA POWDER EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1882,
    "Ekstrak Gula Tebu (Cane Sugar Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1883,
    "Ekstrak Gurita Bubuk (Octopus Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1884,
    "EKSTRAK HOP (HOP EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1885,
    "Ekstrak Ikan (Fish Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1886,
    "Ekstrak Ikan Bonito (Bonito Fish Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1887,
    "Ekstrak Ikan Sardin (Sardines Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1888,
    "Ekstrak Ikan Teri (Anchovy Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1889,
    "Ekstrak Jagung (Corn Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1890,
    "Ekstrak Jahe (Ginger Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1891,
    "Ekstrak Jambu Biji (Guava Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1892,
    "Ekstrak Jamur (Mushroom Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1893,
    "EKSTRAK JAMUR BUBUK (MUSHROOM EXTRACT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1894,
    "Ekstrak Jamur Shitake (Shitake Mushroom Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1895,
    "Ekstrak Jeruk (Orange Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1896,
    "EKSTRAK JERUK ........",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1897,
    "Ekstrak Jeruk Lemon (Lemon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1898,
    "Ekstrak Jeruk Limau (Citrus Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1899,
    "EKSTRAK JERUK LIMAU BUBUK (LIME EXTRACT POWDER)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    1900,
    "Ekstrak Jeruk Nipis (Lime Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1901,
    "Ekstrak Kacang Hazel (Hazelnut Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1902,
    "Ekstrak Kacang Hijau (Mungben Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1903,
    "Ekstrak Kacang Kedelai (Soybean Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1904,
    "EKSTRAK KACANG TANAH (PEANUT EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1905,
    "Ekstrak Kawis (Kawis Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1906,
    "Ekstrak Kayu Manis (Cinnamon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1907,
    "Ekstrak Kecambah (Sprouts Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1908,
    "EKSTRAK KEDELAI (SOY EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1909,
    "Ekstrak Kelapa (Coconut Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1910,
    "EKSTRAK KELAPA MUDA (YOUNG COCONUT EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1911,
    "Ekstrak Kelp (Kelp Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1912,
    "EKSTRAK KENCUR (GALANGAL EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1913,
    "Ekstrak Kepiting (Crab Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1914,
    "Ekstrak Kerang (Clam Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1915,
    "Ekstrak Kimchi (Kimchi Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1916,
    "Ekstrak Kola (Coke Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1917,
    "Ekstrak Kolesom (Kolesom Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1918,
    "Ekstrak Kopi (Coffee Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1919,
    "Ekstrak Kopi Hijau (Green Coffee Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1920,
    "Ekstrak Krisantemum (Chrysantemum Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1921,
    "Ekstrak Kubis Merah (Red Cabbage Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1922,
    "EKSTRAK KUNING TELUR (YOLK EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1923,
    "Ekstrak Kunyit (Turmeric Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1924,
    "Ekstrak Lada (Pepper Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1925,
    "EKSTRAK LICORICE-LIQUORICE- SUCCUS LIQUIRITIAE (GLYCYRRHIZA GLABRA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1926,
    "Ekstrak Lidah Buaya (Aloe Vera Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1927,
    "Ekstrak Lobak (Radish Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1928,
    "Ekstrak Madu (Honey Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1929,
    "Ekstrak Malt (Malt Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1930,
    "Ekstrak Mangga (Mango Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1931,
    "Ekstrak Manggis (Mangosteen Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1932,
    "Ekstrak Melati (Jasmine Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1933,
    "Ekstrak Melon (Melon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1934,
    "Ekstrak Mint (Mint Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1935,
    "Ekstrak Minyak Ikan (Fish Oil Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1936,
    "Ekstrak Muscat (Muscat Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1937,
    "Ekstrak Mustard (Mustard Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1938,
    "Ekstrak Nanas (Pineapple Extact)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1939,
    "Ekstrak Nangka (Jackfruit Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1940,
    "Ekstrak Pala (Nutmeg Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1941, "EKSTRAK PANDAN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1942,
    "Ekstrak Paprika (Paprika Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1943,
    "EKSTRAK PEGAGAN (PENNYWORTH EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1944,
    "EKSTRAK PEPAYA (PAPAYA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1945, "ekstrak perilla seed", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    1946,
    "Ekstrak Pir (Pear Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1947,
    "Ekstrak Protein.... (Asal Bahan...)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1948, "EKSTRAK QUILLAILA", "Bahan Baku", "NO", "NO", "YES", "NO"],
  [
    1949,
    "Ekstrak Ragi (Yeast Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1950,
    "Ekstrak Remis (Mussels Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1951,
    "Ekstrak Ricola (Ricola Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1952,
    "EKSTRAK ROSELLA (HIBISCUS SABDARIFFA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1953,
    "EKSTRAK ROSEMARY (ROSMARINUS OFFICINALIS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1954,
    "Ekstrak Rum (Rhum Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1955,
    "Ekstrak Rumput Laut (Seaweed Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1956,
    "EKSTRAK SARSAPARILA - SARSI (SARSAPARILLA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1957,
    "Ekstrak Sayuran (Vegetable Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1958,
    "Ekstrak Seafood (Seafood Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1959,
    "EKSTRAK SEREALIA (CEREALS EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1960,
    "Ekstrak Sereh (Lemongrass Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1961,
    "EKSTRAK STEVIA (STEVIA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1962,
    "Ekstrak Tebu (Cane Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1963,
    "Ekstrak Teh (Tea Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1964,
    "Ekstrak Teh Hijau (Green Tea Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1965,
    "Ekstrak Teh Hitam (Black Tea Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1966,
    "EKSTRAK TEMU HITAM (CURCUMA AERUGINOSA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1967,
    "Ekstrak Temulawak (Curcuma xanthorrhiza Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1968,
    "Ekstrak Tiram (Oyster Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1969,
    "Ekstrak Tulang Babi (Pig Bone Extract)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    1970,
    "Ekstrak Tulang Sapi (Beef Bone Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1971,
    "Ekstrak Udang (Shrimp Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1972,
    "DInatrium 5-Monofosfat",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1973,
    "Dinatrium fosfat (Disodium Orthophosphate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1974,
    "Dinatrium Fosfat Anhidrat (Disodium Phosphate Anhydrous)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1975,
    "Dinatrium Guanosin 5-Monofosfat",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1976,
    "DINATRIUM SUKSINAT (DISODIUM SUCCINATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1977,
    "Dinatrium Uridin 5-Monofosfat",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1978,
    "Duckweed / water lentils (Lemna gibba / Lemna minor complex dan Wolffia globosa)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    1979,
    "Dulse (Palmaria palmata)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1980,
    "DURIAN BUBUK (DURIAN POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [1981, "D-XILOSA (D-XYLOSE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1982,
    "ECHINACEAE; CONEFLOWERS; PURPLE CONEFLOWER",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1983,
    "EGCG (EPIGALLOCATECHIN GALLATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1984,
    "EKSTRA VIRGIN OLIVE OIL (VIRGIN OLIVE OIL EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [1985, "EKSTRAK .....", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    1986,
    "EKSTRAK AIR KELAPA (COCONUT WATER EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1987,
    "Ekstrak Akar Kolesom (Talinum triangulare Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1988,
    "EKSTRAK ANGGUR (GRAPE EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    1989,
    "EKSTRAK ASAM JAWA (TAMARIND EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1990,
    "Ekstrak Ayam (Chicken Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1991,
    "Ekstrak Barley (Barley Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1992,
    "Ekstrak Barley Malt (Barley Malt Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1993,
    "Ekstrak Basil (Basil Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1994,
    "EKSTRAK BAWANG BOMBAY (ONION EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1995,
    "Ekstrak Bawang Goreng (Dried Onion Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1996,
    "Ekstrak Bawang Putih (Garlic Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1997,
    "Ekstrak Bengkuang (Yambean Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1998,
    "Ekstrak Beras (Rice Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    1999,
    "EKSTRAK BERAS KENCUR (BERAS KENCUR EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2000,
    "EKSTRAK BERAS MERAH (BROWN RICE EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2001,
    "EKSTRAK BIJI ANGGUR (GRAPE SEED EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2002,
    "EKSTRAK BIJI BUNGA MATAHARI (SUNFLOWER SEED EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2003,
    "EKSTRAK BILBERRY (BILBERY EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2004,
    "Ekstrak Blewah (Cantaloupe Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2005,
    "Ekstrak Bonito (Bonito Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2006,
    "EKSTRAK BROKOLI (BROCCOLI EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2007,
    "EKSTRAK BUAH ACAI BERRY (ACAI BERRY EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2008,
    "EKSTRAK BUAH ALPUKAT (AVOCADO EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2009,
    "Ekstrak Buah Anggur (Grape Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2010,
    "EKSTRAK BUAH APEL (APPLE EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2011,
    "EKSTRAK BUAH APEL HIJAU (GREEN APPLE EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2012,
    "Ekstrak Buah Belimbing (Starfruit Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2013,
    "EKSTRAK BUAH BIT (BEETROOT EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2014,
    "Ekstrak Buah Blackberry (Blackberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2015,
    "Ekstrak Buah Blackcurrant (Blackcurrant Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2016,
    "Ekstrak Buah Blueberry (Blueberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2017,
    "Ekstrak Buah Ceri (Cherry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2018,
    "Ekstrak Buah Delima (Pomegranate Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2019,
    "Ekstrak Buah Durian (Durian Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2020,
    "EKSTRAK BUAH KELENGKENG (LONGAN EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2021,
    "Ekstrak Buah Kesemek (Persimmon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2022,
    "EKSTRAK BUAH KIWI (KIWI EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2023,
    "Ekstrak Buah Kundur (Benincasa hispida Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2024,
    "Ekstrak Buah Leci (Lychee Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2025,
    "Ekstrak Buah Lemon (Lemon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2026,
    "Ekstrak Buah Mangga (Mango Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2027,
    "Ekstrak Buah Mangga Manalagi (Manalagi Mango Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2028,
    "Ekstrak Buah Markisa (Passionfruit Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2029,
    "Ekstrak Buah Melon (Melon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2030,
    "EKSTRAK BUAH MURBEI (MULBERRY EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2031,
    "Ekstrak Buah Nangka (Jackfruit Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2032,
    "Ekstrak Buah Persik (Peach Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2033,
    "Ekstrak Buah Pisang (Banana Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2034,
    "Ekstrak Buah Plum (Plum Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2035,
    "Ekstrak Buah Prune (Prune Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2036,
    "Ekstrak Buah Raspberry (Raspberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2037,
    "Ekstrak Buah Semangka (Watermelon Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2038,
    "Ekstrak Buah Sirsak (Soursop Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2039,
    "Ekstrak Buah Stroberi (Strawberry Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2040,
    "Ekstrak Buah Tangkwa (Tangkwa Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2041,
    "EKSTRAK BUAH TIN ATAU BUAH ARA (FIG EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2042,
    "Ekstrak Buah Ume (Japanesse Plum Extract)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2043, "GLISIN (GLYCINE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2044, "Glukosa (Glucose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2045,
    "Glukosa Anhidrat (Glucose Anhydrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2046,
    "Glukosa Bubuk (Glucose Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2047,
    "GLUKOSAMIN (GLUCOSAMINE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2048,
    "GLUKOSAMIN HIDROKLORIDA (GLUCOSAMINE HYDROCHLORIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2049,
    "GLUKOSAMIN SULFAT (GLUCOSAMINE SULPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [2050, "GLUTEN (GLUTEN)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2051,
    "GLYCYRRHIZA GLABRA (LICORICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [2052, "GOBO", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2053,
    "GOBO BUBUK (GOBO POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2054,
    "GOJI (LYCIUM BARBARUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2055,
    "GOJI BERRY - WOLBERRY",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2056,
    "GOJI BERRY (LYCIUM BARBARUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2057,
    "Great Northern Beans",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2058,
    "GUARANA (PAULLINIA CUPANA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2059,
    "GULA AREN (PALM SUGAR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2060,
    "Gula Batu (Rock Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2061,
    "Gula Bit (Sugar Beet)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2062,
    "Gula Cair (Liquid Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2063,
    "Gula Cokelat (Brown Sugar-Demerara)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2064,
    "Gula Halus (Refined Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2065,
    "Gula Hitam (Raw Cane Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2066,
    "Gula Icing (Icing Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2067,
    "Gula Invert (Invert Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2068,
    "Gula Jawa (Palm Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2069,
    "GULA KASTOR (CASTOR SUGAR ATAU CASTER SUGAR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2070,
    "GULA KELAPA (COCONUT SUGAR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2071,
    "Gula Kristal (Sugar Crystals)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2072,
    "Gula Merah (Brown Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2073,
    "Gula Palem (Palm Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2074,
    "Gula Pasir (Granulated Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2075,
    "GULA SIWALAN (PALM SUGAR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2076,
    "Gula Sorgum (Shorgum Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2077,
    "Gula Tebu (Cane Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2078,
    "Gula Terfermentasi (Fermented Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2079, "GUM BASE", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2080, "Gurita (Octopus)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2081, "HALBA (HALBA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2082, "Halia (Halia)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2083,
    "Hancuran Permen/ Butiran Permen (Crushed candy)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2084,
    "Hasil Destilasi Minyak Peppermint (Peppermint Oil Distillation)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2085,
    "HASIL DISTILASI FERMENTASI ANGGUR (DISTILLED FERMENTED GRAPE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2086,
    "HASIL DISTILASI FERMENTASI ANGGUR HIJAU (DISTILLED FERMENTED GREEN GRAPE) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2087,
    "Hasil Distilasi Fermentasi Beras (Distilled Fermented Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2088,
    "Hasil Distilasi Fermentasi Jambu Mente (Distilled Fermented Cashew)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2089,
    "Hasil Distilasi Fermentasi Malt-Gandum-....... (Distilled Fermented Malt-Wheat-.....)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2090,
    "HASIL FERMENTASI .....(SEREALIA, BUAH, ....)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2091,
    "Hasil Fermentasi Apel (Fermented Apple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2092,
    "Hasil Fermentasi Arbei (Fermented Berries)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2093,
    "Hasil Fermentasi Beras (Fermented Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2094,
    "Hasil Fermentasi Beras Ketan Hitam (Fermented Black Glutinous Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2095,
    "Hasil Fermentasi Beras Ketan Putih (Fermented White Glutinous Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2096,
    "Hasil Fermentasi Buah Agave (Fermented Agave)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2097,
    "Hasil Fermentasi Buah Anggur Hijau (Fermented Green Grape)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2098,
    "Hasil Fermentasi Buah Anggur Merah (Fermented Red Grape)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2099,
    "Hasil Fermentasi Buah Lontar (Fermented Palmyra) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2100,
    "Hasil Fermentasi Gandum (Fermented Wheat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2101,
    "Hasil Fermentasi Gula Merah (Fermented Brown Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2102,
    "Hasil Fermentasi Jagung (Fermented Corn)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2103,
    "Hasil Fermentasi Jeruk (Fermented Orange)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2104,
    "HASIL FERMENTASI KEDELAI (FERMENTED SOYBEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2105,
    "Hasil Fermentasi Kedelai Hitam (Fermented Black Soybeans)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2106,
    "HASIL FERMENTASI KETAN HITAM (FERMENTED BLACK GLUTINOUS RICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2107,
    "Hasil Fermentasi Malt (Fermented Malt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2108,
    "Hasil Fermentasi Markisa (Fermented Passion Fruit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2109,
    "Hasil Fermentasi Molases (Fermented Molases)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2110,
    "Hasil Fermentasi Nanas (Fermented Pineapple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2111,
    "Hasil Fermentasi Nira (Fermented Sap)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2112,
    "Hasil Fermentasi Pepaya (Fermented Papaya)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2113,
    "Hasil Fermentasi Salak (Fermented Salak)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2114,
    "Hasil Fermentasi Sawo (Fermented Sapodilla)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2115,
    "Hasil Fermentasi Singkong (Fermented Cassava)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2116,
    "Hasil Fermentasi Tepung Rye (Fermented Rye Flour)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2117,
    "Hasil Fermentasi Tomat (Fermented Tomato)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2118,
    "Hati Ayam (Chicken Liver)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2119,
    "Hati Ayam Bubuk (Chicken Liver Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2120,
    "Hati Babi (Pig Liver)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2121,
    "Hati Sapi (Cow Liver)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2122,
    "HEATHER (ERICA VULGARIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2123,
    "Hemiselulase (Hemicellulase)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2124,
    "Hidrolisat Kasein Protein (Hydrolysed Casein Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2125,
    "Hidrolisat Protein (Hydrolyzed Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2126,
    "Hidrolisat Protein Ikan (Hydrolyzed Fish Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2127,
    "Hidrolisat Protein Kedelai (Hydrolyzed Soy Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2128,
    "Hidrolisat Protein Nabati (Hydrolyzed Vegetable Protein)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2129,
    "HIDROLISAT PROTEIN WHEY (HYDROLIZED WHEY PROTEIN)",
    "Bahan Baku",
    "NO",
    "YES",
    "NO",
    "YES",
  ],
  [
    2130,
    "Histidin (Histidine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2131,
    "Hojicha Bubuk (Hojicha Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2132,
    "honeybush (cyclopia maculate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2133,
    "Honeybush (Cyclopia maculate, Cyclopia genistoides, Cyclopia sessiliflora (\"Heidelbergtee\")",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [2134, "HONEYSUCKLE", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2135, "HOPS", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2136,
    "HUPERSZINE (HUPERZINE SERRATA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2137, "HYDRATED DEXTRATES", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2138,
    "ICE STRUCTURING PROTEIN",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2139,
    "Iga Babi (Pork Ribs)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2140,
    "IGA SAPI (BEEF RIBS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2141, "Ikan (Fish)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2142,
    "Ikan Asap Bubuk (Smoked Fish Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2143,
    "Ikan Asin (Salted Fish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2144,
    "Ikan Bandeng (Milkfish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2145,
    "IKAN BELIDA (BELIDA FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2146, "IKAN BILIS", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2147,
    "IKAN BONITO (BONITO FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2148,
    "IKAN BONITO BUBUK (BONITO FISH POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2149,
    "Ikan Bubuk (Fish Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2150,
    "IKAN CAKALANG (SKIPJACK TUNA FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2151,
    "IKAN DACE (DACE FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2152,
    "Ikan Fillet (FISH FILLET)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2153, "Ikan Gindara", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2154,
    "IKAN HARING (HERRING FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2155,
    "IKAN HARING FILLET (HERRING FISH FILLET)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2156,
    "IKAN KAKAP (SNAPPER FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2157,
    "IKAN KISU (KISU FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2158, "Ikan Kod (Cod Fish)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2159,
    "Ikan Kod Bubuk (Cod Fish Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2160,
    "IKAN KORVINA KUNING (YELLOW CORVINA FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2161,
    "Ikan Layar (Sailfish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2162,
    "IKAN LAYUR (LAYUR FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2163, "Ikan Lele (Catfish)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2164,
    "Ikan Lemuru (Sardine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2165,
    "IKAN MAKAREL (MACKEREL FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2166,
    "IKAN MARLIN (MARLIN FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2167,
    "Ikan Nila (Tilapia Fish)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2168, "Ikan Patin", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2169,
    "IKAN POLLOCK (POLLOCK FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2170,
    "IKAN SALMON (SALMON FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2171,
    "IKAN SARDIN (SARDINES FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2172,
    "IKAN SARDIN BUBUK (SARDINES FISH POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2173,
    "IKAN SLENGSENG (MACKEREL FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2174,
    "IKAN TEMBANG (SARDINELLA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2175,
    "Ikan Tenggiri (Mackerel)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2176, "Ikan Teri (Anchovy)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2177,
    "IKAN TUNA (TUNA FISH)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2178, "INOSITOL (INOSITOL)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2179, "Inulin (Inulin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2180,
    "COCOA BUTTER EQUIVALENT (CBE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2181,
    "Cocoa Butter Replacer (CBR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2182,
    "Cocoa Butter Substitute (CBS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2183, "Cognac (Cognac)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2184, "Cokelat (Chocolate)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2185,
    "Cokelat Batang (Chocolate Bar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2186,
    "COKELAT BUBUK (CHOCOLATE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2187,
    "Cokelat Butir (Chocolate Granules)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2188,
    "COKELAT CAIR (MELTED CHOCOLATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2189,
    "Cokelat Chip (Chocolate Chip)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2190,
    "COKELAT COMPOUND BUTIR (CHOCOLATE COMPOUND GRANULE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2191,
    "COKELAT COMPOUND PUTIH (WHITE CHOCOLATE COMPOUND)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2192,
    "Cokelat Compound Susu (Milk Chocolate Compound)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2193,
    "COKELAT HITAM (DARK CHOCOLATE, BITTERSWEET CHOCOLATE))",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2194,
    "COKELAT HITAM CHIP (DARK CHOCOLATE CHIP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2195,
    "COKELAT HITAM COMPOUND (DARK CHOCOLATE COMPOUND)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2196,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2197,
    "Cokelat Imitasi/Hasil Olah Gula (Imitation Chocolate/Processed Sugar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2198,
    "COKELAT LIQUOR (COCOA LIQUOR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2199,
    "COKELAT MASSA (CHOCOLATE MASS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2200,
    "Cokelat Paduan (Compound Chocolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2201,
    "COKELAT PADUAN-COMPOUND",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2202,
    "COKELAT PAHIT (BITTER CHOCOLATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2203,
    "Cokelat Pasta (Chocolate Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2204,
    "Cokelat Pelapis (Chocolate Coating)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2205,
    "Cokelat Putih (White Chocolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2206,
    "COKELAT RENDAH LEMAK (LOW FAT COCOA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2207,
    "Cokelat Susu (Milk Chocolate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2208,
    "COKELAT SUSU KOVERTUR (MILK CHOCOLATE COUVERTURE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2209, "COKLAT MASSA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2210,
    "Combrang - Kecombrang (Etlingera elatior)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2211,
    "COMPOUND PUTIH (WHITE COMPOUND)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2212,
    "CORNFLOWER (CENTAURA CYANUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2213,
    "CORNFLOWER (CENTAUREA CYANUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [2214, "Couscous", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2215,
    "CRANBERRY BUBUK (CRANBERRY POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2216,
    "Cuka Anggur (Grape Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2217,
    "Cuka Anggur Putih (White Wine Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2218,
    "Cuka Apel (Apple Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2219,
    "Cuka Balsamic (Balsamic Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2220,
    "Cuka Beras (Rice Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2221,
    "Cuka Bubuk (Vinegar Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2222,
    "CUKA FERMENTASI (VINEGAR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2223,
    "Cuka Lemon (Lemon Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2224,
    "Cuka Makan (Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2225,
    "Cuka Plum (Plum Vinegar)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2226, "Cumi-Cumi (Squid)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2227,
    "CUMI-CUMI BUBUK (SQUID POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2228,
    "cupuacu (theobroma grandiflorum)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2229, "Custard (Custard)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2230,
    "Custard Bubuk (Custard Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2231,
    "Dada Ayam (Chicken Breast)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2232, "Dadih", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2233,
    "Dadih Bubuk (Buttermilk Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2234,
    "DAGING AYAM (CHICKEN MEAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2235,
    "DAGING AYAM ASAP (SMOKE CHICKEN MEAT)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2236,
    "Daging Ayam Bubuk (Chicken Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2237,
    "Daging Ayam Cincang (Minced Chiken)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2238,
    "Daging Ayam Fillet (Chicken Fillet)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2239,
    "Daging Ayam Irisan (Chicken Strips)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2240,
    "DAGING AYAM SERPIHAN (CHICKEN FLAKES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2241, "Daging Babi (Pork)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2242,
    "DAGING BABI ASAP (SMOKE PORK)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2243,
    "Daging Babi Bubuk (Pork Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2244,
    "Daging Bebek (Duck Meat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2245,
    "Daging Burung Puyuh/Dara/.....",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2246, "Daging Domba (Lamb)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2247,
    "Daging Kalkun (Turkey Meat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2248,
    "Daging Kambing (Mutton)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2249,
    "Daging Kelinci (Rabbit Meat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2250,
    "DAGING KERBAU (BUFFALO MEAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2251,
    "Daging Paha Babi (Ham)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2252,
    "Daging Rusa (Deer Meat)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2253, "Daging Sapi (Beef)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2254,
    "DAGING SAPI ASAP (SMOKE BEEF)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2255,
    "Daging Sapi Bubuk (Beef Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2256,
    "Daging Sapi Cincang (Minced Beef)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2257,
    "Dandelion Root Powder (Taraxacum officinale)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2258,
    "DAUN ANGGUR (GRAPE LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2259,
    "Daun Apple Mint (Mentha suaveolens Ehrh)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2260,
    "Daun Asam Jawa (Tamarindus indica)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2261,
    "Daun Basil (Basil Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2262,
    "Daun Basil Bubuk (Basil Leaf Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2263,
    "Daun Basil Kering (Dried Basil Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2264,
    "DAUN BAWANG (SCALLION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2265,
    "DAUN BAWANG BUBUK (LEEK POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2266,
    "DAUN BAWANG KERING (DRIED SCALLION)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2267,
    "Daun Beluntas (Pluchea Folium)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2268,
    "Daun Bergamot (Monarda didyma)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2269,
    "Daun Blackberry (Blackberry Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2270, "Daun Blackcurrant", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2271,
    "Daun Cengkeh (Clove Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2272,
    "Daun Citrus Thyme (Thymus citriodorus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2273,
    "DAUN GANDUM (WHEATGRASS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2274,
    "Daun Gedi (Abelmoschus manihot (L.) Medik)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2275,
    "DAUN JAMBU BIJI (GUAVA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2276,
    "DAUN JATI BELANDA (GUAZUMA ULMIFOLIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "NO",
  ],
  [
    2277,
    "DAUN JERUK (CITRUS LEAF ATAU LIME LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2278,
    "Daun Jeruk Purut (Kaffir Lime Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2279,
    "Daun Kari (Curry Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2280, "Daun Katuk", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2281,
    "Daun Kelor (Moringa oleifera L.)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2282,
    "DAUN KEMANGI (LEMON BASIL LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2283,
    "DAUN KETUMBAR (CILANTRO- CORIANDER LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2284,
    "DAUN KOPI (COFFEE LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2285,
    "DAUN KUCAI (GARLIC LEAF CHIVES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2286,
    "Daun Kunyit (Turmeric Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2287,
    "DAUN LAKSA (LAKSA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2288,
    "Daun Lobak (Radish Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2289,
    "Daun Marjoram (Marjoram Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2290,
    "DAUN MELINJO (MELINJO LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2291,
    "Daun Mint (Mint Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2292,
    "DAUN MOLOKHIA (MOLOKHIA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2293,
    "DAUN MULBERRY (MULBERRY LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2294,
    "Daun Oregano (Oregano Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2295,
    "Daun Oregano Kering (Dried Oregano Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2296,
    "Daun Pakis / Paku Sayur (Vegetable Fern)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2297,
    "Daun Pandan (Pandan Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2298,
    "Daun Pepaya (Papaya Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2299,
    "Daun Peppermint (Peppermint Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2300,
    "DAUN PERILLA (PERILLA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2301,
    "DAUN PERILLA BUBUK (PERILLA LEAF POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2302,
    "DAUN PETERSELI (PETROSELINUM CRISPUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2303,
    "Daun Raspberry (Raspberry Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2304,
    "DAUN RHUBARB (RHEUM RHABARBARUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2305,
    "Daun Rosemarry (Rosemarry Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2306,
    "DAUN SAGA (JEQUIRITY LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2307,
    "Daun Salam (Bay Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2308,
    "Daun Salam Bubuk (Bay Leaf Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2309,
    "Daun Seledri (Celery Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2310,
    "Daun Seledri Kering (Dried Celery Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2311,
    "DAUN SEMBUNG (SAMBONG LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2312,
    "DAUN SERUNI (CHRYSANTHEMUM LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2313,
    "DAUN SINGKONG (CASSAVA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2314,
    "DAUN SIRIH (BETEL LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2315,
    "DAUN SIRSAK (SOURSOP LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2316,
    "DAUN STEVIA (STEVIA LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2317,
    "Daun Stroberi (Strawberry Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2318,
    "DAUN SWISS CHARD (FOLIUM BETA VULGARIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2319,
    "DAUN TARRAGON (TARRAGON LEAF)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2320, "daun teratai ", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2321,
    "Daun Teratai (Lotus Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2322,
    "Daun Ubi Merah (Red Sweet Potato Leaf)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2323, "Dekstrin (Dextrin)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2324,
    "Dekstrosa (Dextrose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2325,
    "Dekstrosa Anhidrat (Anhydrous Dextrose)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2326,
    "Dekstrosa Bubuk (Dextrose Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2327,
    "Cabe Merah (Red Chili)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2328, "CABE MERAH BESAR", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2329,
    "Cabe Merah Bubuk (Red Chili Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2330,
    "Cabe Rawit (Cayenne Pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2331,
    "Cabe Rawit Bubuk (Cayenne Pepper Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2332,
    "Cabe Rawit Hijau (Green Cayenne Pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2333,
    "Cabe Rawit Merah (Red Cayenne Pepper)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2334,
    "Calcium Beta Hydroxy Beta Methylbutyrate (CaHMB)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2335,
    "Campuran Buah Tropical Bubuk (Mixed Tropical Fruit Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2336,
    "Campuran Citrus Bubuk (Mixed Citrus Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2337,
    "Campuran Margarin dan Mentega (Blends of butter and margarine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2338,
    "camu-camu (Myrciaria dubia)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2339,
    "Cangkang Rajungan (Crab Shells)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2340, "Capers (Capers)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2341, "CARAWAY (CARAWAY)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2342, "Carob (Carob)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2343, "CASSIA OBTUSIFOLIA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2344, "CASSIA TORA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2345, "Ceker Ayam", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2346,
    "Cempedak (Artocarpus integer)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2347, "Cendol", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2348, "Cengkeh (Clove)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2349,
    "CENGKEH BUBUK (CLOVE POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2350,
    "CEPOKAK (COKOWANA, TERONG PIPIT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2351,
    "Ceremai (Phyllanthus acidus (L.) Skeells)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2352,
    "Ceri Bubuk (Cherry Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2353, "CHAMOMILE", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2354,
    "Chicory (Cichorium intybus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2355,
    "Chlorella (Chlorella)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2356, "Chutney (Chutney)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2357, "CILANTRO", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2358,
    "CINCAU (JELLY GRASS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2359,
    "CINCAU HITAM (BLACK JELLY GRASS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2360, "CITRUS BIOFLAVONOID", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2361, "Citrus Fiber", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2362,
    "BUMBU RASA SAPI (SEASONING BEEF FLAVOR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2363,
    "BUMBU RASA SAPI PANGGANG ( ROASTED BEEF FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2364,
    "Bumbu Rasa Stroberi (Strawberry Flavored Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2365,
    "Bumbu Rasa Tomat (Tomato Flavored Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2366,
    "BUMBU RASA UDANG (SHRIMP FLAVORED SEASONING)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2367,
    "BUMBU RAWON (RAWON SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2368,
    "BUMBU RENDANG (RENDANG SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2369,
    "BUMBU RICA- RICA (RICA-RICA SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2370,
    "Bumbu Rumput Laut (Seaweed Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2371,
    "BUMBU SAMBAL LIMAU (SAMBAL LIMAU SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2372,
    "BUMBU SAPI PANGGANG (ROAST BEEF MARINADE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2373,
    "Bumbu Sate (Satay Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2374,
    "Bumbu Sate Pedas (Spicy Satay Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2375,
    "Bumbu Sayuran (Vegetable Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2376,
    "Bumbu Seafood (Seafood Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2377,
    "Bumbu Sosis (Sausage Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2378,
    "Bumbu Soto (Soto Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2379,
    "Bumbu Sup (Soup Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2380,
    "BUMBU TOM YAM (TOM YAM SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2381,
    "Bumbu Tomat (Tomato Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2382,
    "Bumbu Tomat Pedas (Spicy Tomato Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2383,
    "BUMBU... (SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2384,
    "BUNCIS BUBUK (GREEN BEAN POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2385,
    "BUNCIS HIJAU (GREEN BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2386,
    "BUNGA CAMOMILE (CHAMOMILE FLOWER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2387,
    "BUNGA CORNFLOWER (CENTAUREA CYANUS LYNN)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2388,
    "Bunga Elder (Sambucus nigra)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2389,
    "BUMBU RASA KALDU AYAM (CHICKEN BROTH FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2390,
    "BUMBU RASA KARAMEL (CARAMEL FLAVOURED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2391,
    "BUMBU RASA KARAMEL BAWANG (CARAMELIZED ONION FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2392,
    "BUMBU RASA KARI AYAM (CHICKEN CURRY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2393,
    "BUMBU RASA KEJU (CHEESE FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2394,
    "BUMBU RASA KENTANG GORENG (FRENCH FRIES FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2395,
    "BUMBU RASA LEMON (LEMON FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2396,
    "BUMBU RASA MANIS PEDAS (SWEET AND SPICY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2397,
    "BUMBU RASA MUSTARD (MUSTARD FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2398,
    "BUMBU RASA PEDAS (SPICY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2399,
    "BUMBU RASA PEDAS MANIS ASIN (SWEET, SPICY AND SALTY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2400,
    "BUMBU RASA PEPPERONI PIZZA (PEPPERONI PIZZA FLAVOR)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2401,
    "BUMBU RASA PIZZA (PIZZA FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2402,
    "BUMBU RASA RUMPUT LAUT (SEAWEED FLAVORED SEASONING )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2403, "BUBUK LECI ", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2404,
    "Bubuk Mutiara (Pearl Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2405,
    "Bubuk Salmon (Salmon Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2406,
    "Bubur Beras (Rice Porridge)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2407,
    "Bubur Beras Merah (Brown Rice Porridge)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2408,
    "Bubur Buah Apel (Apple Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2409,
    "Bubur Buah Aprikot (Apricot Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2410,
    "Bubur Buah Arbei (Arbei Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2411,
    "Bubur Buah Jambu (Guava Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2412,
    "Bubur Buah Jambu Merah",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2413,
    "Bubur Buah Jeruk (Orange Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2414,
    "Bubur Buah Lemon (Lemon Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2415,
    "Bubur Buah Mangga (Mango Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2416,
    "Bubur Buah Mulberry (Mulberry Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2417,
    "Bubur Buah Nanas (Pineapple Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2418,
    "Bubur Buah Persik (Peach Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2419,
    "Bubur Buah Sirsak (Soursop Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2420,
    "Bubur Buah Stroberi (Strawberry Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2421,
    "Bubur Buah Tomat (Tomato Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2422,
    "BUBUR GANDUM (WHEAT PORRIDGE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2423,
    "BUBUR KACANG (PEANUT PORRIDGE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2424,
    "BUBUR KACANG HIJAU (MUNGBEAN PORRIDGE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2425,
    "Bubur Kacang Merah (Red Bean Porridge)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2426,
    "Bubur Kentang (Potato Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2427,
    "BUBUR KULIT JERUK (ORANGE PEEL PULP)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2428,
    "Bubur Labu Kuning (Pumpkin Porridge)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2429,
    "Bubur Susu (Milk Porridge)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2430,
    "BUCKWHEAT (BUCKWHEAT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2431,
    "BUCKWHEAT (BUCKWHEAT-FAGOPYRUM ESCULENTUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2432,
    "Bulir Jeruk (Orange Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2433,
    "Bulir Jeruk Valencia (Valencia Orange Pulp)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2434,
    "BUMBU RASA KEJU (CHEESE FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2435,
    "BUMBU ABON AYAM (CHICKEN FLOSS SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2436,
    "Bumbu Abon Sapi (Beef Floss Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2437,
    "BUMBU ASAM MANIS (SWEET AND SOUR SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2438,
    "Bumbu Ayam (Chicken Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2439,
    "Bumbu Ayam Bawang (Garlic Chicken Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2440,
    "Bumbu Ayam Goreng (Fried Chicken Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2441,
    "Bumbu Ayam Pedas (Spicy Chicken Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2442,
    "Bumbu Balado (Balado Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2443,
    "Bumbu Barbekiu (Barbeque Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2444,
    "BUMBU BAWANG PEDAS (SPICY GARLIC SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2445,
    "BUMBU CUMI BAKAR (GRILLED SQUID SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2446,
    "Bumbu Daging Sapi (Beef Flavor)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2447,
    "Bumbu Ekstrak Daging Ayam (Chicken Extract Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2448,
    "Bumbu Frankfurter (Frankfurter Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2449,
    "BUMBU GULAI (GULAI SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2450,
    "BUMBU IGA SAPI (SPICES OR SEASONING FOR BEEF RIBS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2451,
    "BUMBU IKAN TERI (ANCHOVY SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2452,
    "BUMBU JAGUNG (CORN SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2453,
    "BUMBU JAGUNG BAKAR (ROASTED CORN SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2454,
    "BUMBU KACANG MERAH (RED BEAN SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2455,
    "BUMBU KARI (CURRY SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2456,
    "BUMBU KARI DAGING (MEAT CURRY SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2457,
    "BUMBU KARI IKAN (FISH CURRY SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2458,
    "BUMBU KEJU BURGER (CHEESEBURGER SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2459,
    "Bumbu Kentang Barbekiu (Barbeque Potato Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2460,
    "BUMBU KIMCHI (KIMCHI SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2461,
    "BUMBU KRIM ASAM (SOUR CREAM SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2462,
    "BUMBU KRIM MENTEGA (BUTTERCREAM SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2463,
    "BUMBU MI GORENG (FRIED NOODLE SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2464,
    "BUMBU MINYAK UDANG (OIL SEASONING SHRIMP)",
    "Bahan Baku",
    "YES",
    "YES",
    "NO",
    "YES",
  ],
  [
    2465,
    "BUMBU NGOHIONG (NGOHIONG SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2466,
    "BUMBU OPOR (OPOR SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2467,
    "BUMBU OTAK-OTAK (OTAK-OTAK SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2468,
    "Bumbu Pasta (Paste Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2469,
    "Bumbu Pedas (Spicy Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2470,
    "BUMBU PERENDAM (MARINADE SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2471, "Bumbu Petis Bubuk", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2472,
    "Bumbu Pizza (Pizza Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2473,
    "BUMBU RASA (FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2474,
    "BUMBU RASA ASAM PEDAS (SOUR SPICY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2475,
    "Bumbu Rasa Ayam (Chicken Flavored Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2476,
    "Bumbu Rasa Ayam Bakar (Grilled Chicken Flavor Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2477,
    "Bumbu Rasa Ayam Panggang (Roasted Chicken Flavor Seasoning)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2478,
    "BUMBU RASA BABI (PORK OR BACON FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2479,
    "BUMBU RASA BALADO (BALADO FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2480,
    "BUMBU RASA BAWANG (ONION FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2481,
    "BUMBU RASA BAWANG PUTIH (GARLIC FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2482,
    "BUMBU RASA COKELAT (CHOCOLATE FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2483,
    "BUMBU RASA DAGING SAPI (BEEF FLAVORED SEASONING )",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2484,
    "BUMBU RASA DENDENG (JERKY FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2485,
    "BUMBU RASA IKAN (FISH FLAVORED SEASONING)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2486,
    "ADAS PEDAS BUBUK-ADAS BUBUK-FENNEL POWDER (FOENICULUM VULGARE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2487, "Abalon (Abalone)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2488,
    "Abon Ayam (Chicken Floss)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2489,
    "Abon Babi (Pork Floss)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2490,
    "ABON CAKALANG (SKIPJACK TUNA FLOSS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2491,
    "Abon Sapi (Beef Floss)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2492,
    "Abon Sapi Pedas (Hot Beef Floss)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2493, "Acar (Pickles)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2494,
    "Acar Bawang Putih (Garlic Pickles)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2495,
    "Acar Cabe (Chili Pickles)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2496,
    "Acar Jahe (Ginger Pickles)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2497,
    "Acar Mentimun-Ketimun (Cucumber Pickles)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2498, "ACEROLA (ACEROLA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2499,
    "ACEROLA (MALPIGHIA GLABRA)- BARBADOS CHERRY-WEST INDIAN CHERRY-CEREZA-CERESIER-SEMERUCO-WILD CRAPEMYRTLE",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2500,
    "ACEROLA BUBUK (ACEROLA POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2501,
    "ACEROLA EKSTRAK (ACEROLA EXTRACT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2502, "ADAS (FENNEL)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2503,
    "ADAS MANIS BUBUK-ANIS POWDER (PIMPINELLA ANISUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2504,
    "Adas Manis-Anis (Pimpinella anisum)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2505,
    "ADAS PEDAS - ADAS - FENNEL (FOENICULUM VULGARE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2506,
    "ADAS SOWA-DILL (ANETHUM GRAVEOLENS L.)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2507,
    "ADENOSIN 5-MONOFOSFAT (ADENOSINE 5-MONOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2508, "Adonan (Dough)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2509, "AGAR-AGAR (AGAR)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2510,
    "AGAR-AGAR BUBUK (AGAR POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2511, "Air (Water)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2512,
    "Air Berkarbonat (Carbonated Water)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2513, "Air Dadih (Whey)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2514,
    "Air Deionisasi (Deionized Water)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2515,
    "AIR DEMINERALISASI (DEMINERALIZED WATER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2516, "Air Es (Cold Water)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2517, "Air Kaldu (Broth)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2518,
    "AIR KELAPA (COCONUT WATER-COCONUT JUICE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2519,
    "Air Mineral (Mineral Water)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2520,
    "Air Soda (Soda Water)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2521,
    "Air Suling (Distilled Water)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2522,
    "AKAR BUNGA TERATAI (LOTUS ROOT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2523,
    "Akar Chicory (Chicory Root)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2524,
    "Akar Ginseng (Panax Ginseng C.A Meyer)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2525,
    "Akar Ginseng (Panax Quinquefolius-American Ginseng)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2526,
    "Akar Ketumbar (Coriander Root)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2527,
    "AKAR TERATAI BUBUK -LOTUS ROOT POWDER(NELUMBIUM NELUMBO DRUCE; NELUMBIUM NUCIFERUM) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2528, "Alanin (Alanine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2529, "Albumin (Albumine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2530, "ALFA KAROTEN", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2531,
    "Alfa Laktalbumin (Alpha-Lactalbumin)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2532,
    "Alfa Tokoferol (Alpha-Tocopherol)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2533,
    "ALFA-AMILASE (ALPHA-AMYLASE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2534, "ALFALFA (ALFALFA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2535,
    "Alga Merah (Red Algae)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2536,
    "Alga Merah Lithothamnion (Lithothamnion Red Algae) (Kecuali Pangan Untuk Keperluan Gizi Khusus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2537, "ALGINAT (ALGINATE)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2538, "Alkohol (Alcohol)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2539, "Allulosa (Allulose)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2540,
    "Almond Bubuk (Almond Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2541,
    "Almond Butiran (Almond Granules)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2542,
    "Almond Panggang (Roasted Almond)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2543, "Alpukat (Avocado)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2544,
    "Alpukat Bubuk (Avocado Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2545,
    "Alpukat Pasta (Avocado Paste)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2546, "AMONIAK (AMMONIA)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2547,
    "AMONIAK CAIR (LIQUID AMMONIA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2548, "Ampela (Gizzard)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2549,
    "ANDALIMAN (ZANTHOXYLUM ACANTHOPODIUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2550,
    "ANDALIMAN BUBUK - ANDALIMAN POWDER (ZANTHOXYLUM ACANTHOPODIUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2551,
    "ANEKA BUAH BERI (MIX BERRIES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2552, "Anggur (Wine)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2553,
    "Anggur Beras (Rice Wine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2554,
    "Anggur Merah (Red Wine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2555,
    "Anggur Putih (White Wine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2556, "ANGGUR PUTIH BUBUK", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2557,
    "Apel Bubuk (Apple Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2558,
    "Apel Kering (Dried Apple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2559, "Aprikot (Apricot)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2560, "AQUAMIN F", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2561,
    "Arak Beras (Rice Wine)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2562,
    "ARAK BERAS KETAN (GLUTINOUS RICE WINE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2563,
    "ARANG AKTIF (ACTIVATED CARBON)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2564, "ARGININ (ARGININE)", "Bahan Baku", "NO", "NO", "YES", "YES"],
  [
    2565,
    "Artichoke (Artichoke)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2566,
    "Arugula (Eruca Sativa)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2567, "Asafoetida", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2568,
    "Asam Amino Premiks (Amino Acid Premix)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2569,
    "ASAM ARAKHIDONAT -ARA-AA (DARI MINYAK LAIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2570,
    "ASAM ARAKHIDONAT-ARA-AA (DARI MINYAK SEL TUNGGAL)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2571,
    "ASAM ASETAT GLASIAL (GLACIAL ACETIC ACID)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2572,
    "Asam Folat (Folic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2573,
    "Asam Fosfat (Acid Phosphoric)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2574,
    "ASAM GELUGUR (GARCINIA ATROVIRIDIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2575,
    "ASAM JAWA BUBUK-TAMARIND POWDER (TAMARINDUS INDICA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2576,
    "ASAM JAWA-TAMARIND (TAMARINDUS INDICA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2577,
    "ASAM KANDIS (GARCINIA XANTHOCHYMUS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2578,
    "Asam Linoleat (Linoleic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2579,
    "Asam Linoleat Terkonjugasi (Conjugated Linoleic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2580,
    "Asam Nukleat (Nucleic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2581,
    "Asam Oktanoat (Octanoate Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2582,
    "ASAM OLEAT (OLEIC ACID)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2583,
    "Asam Palmitat (Palmitic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2584,
    "Asam Stearat (Stearic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2585,
    "Asam Sulfat (Sulfic Acid)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2586,
    "ASKORBIL PALMITAT (ASCORBYL PALMITATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2587,
    "ASPARAGUS (ASPARAGUS OFFICINALIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2588,
    "Asparagus Laut (Sea Asparagus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2589,
    "Asparagus Putih (White Asparagus)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2590, "ASPERGILLUS ORYZAE", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2591, "ASTRAGALI", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2592, "ASTRAGALUS", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2593,
    "Ayam Bubuk (Chicken Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2594, "Ayam Suwir", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2595, "Babat Sapi", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2596,
    "BACILLUS COAGULANS GBI-30 6086 (GANEDEN BC30)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2597,
    "BACILLUS COAGULANS MTCC 5856",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [2598, "BAHAN HERBAL LAINNYA", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2599,
    "Bahan Perisa (Flavoring Substances)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2600,
    "Bakso Ayam (Chicken Meatball)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2601,
    "Bakso Ikan (Fish Meatball)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2602,
    "Bakso Sapi (Beef Meatball)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2603,
    "BALM (MELISSA OFFICINALIS L)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [2604, "Barley (Barley)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2605, "BARLEY (KOJI)", "Bahan Baku", "NO", "YES", "NO", "NO"],
  [
    2606,
    "Barley grass ( Hordeum vulgare L)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2607,
    "Barley Malt (Barley Malt)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2608,
    "Barley Panggang (Roasted Barley)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2609,
    "Barley Serpihan (Barley Flakes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2610, "BASIL (BASIL)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2611,
    "BASIL BUBUK-BASIL POWDER (OCIMUM BASILICUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2612,
    "Bawang Bombay (Onion)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2613,
    "Bawang Bombay Bubuk (Onion Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2614,
    "Bawang Bombay Kering (Dried Onion)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2615, "BAWANG DAUN (CHIVES)", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2616,
    "BAWANG MERAH (RED ONION-SHALLOT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2617,
    "BAWANG MERAH BUBUK (RED ONION POWDER - SHALLOT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2618,
    "BAWANG MERAH GORENG (FRIED RED ONION - FRIED SHALLOT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2619,
    "Bawang Putih (Garlic)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2620,
    "Bawang Putih Bubuk (Garlic Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2621,
    "BAWANG PUTIH GILING (GRINDED GARLIC)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2622,
    "Bawang Putih Goreng (Fried Garlic)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2623,
    "Bawang Putih Kering (Dried Garlic)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2624,
    "Bawang Putih Serpihan (Garlic Flakes)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2625, "Bayam (Spinach)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2626,
    "Bayam Bubuk (Spinach Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2627,
    "BEE POLLEN (KHUSUS MADU)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2628,
    "Bekatul Beras (Rice Bran)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2629, "BEKICOT (SNAIL)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2630,
    "BELIMBING WULUH (AVERRHOA BILIMBI)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2631, "Belut (Eel)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2632, "benang sari teratai", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2633,
    "Bengkuang - Sengkuang (Yam Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2634,
    "BERANGAN (MALAYAN CHESTNUT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2635, "Beras (Rice)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2636,
    "Beras Butiran (Rice Grains)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2637,
    "Beras Cokelat (Brown Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2638,
    "Beras Hitam (Black Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2639,
    "Beras Instan (Instant Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2640, "BERAS KEPALA", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2641,
    "Beras Ketan (Glutinous Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2642,
    "Beras Ketan Hitam (Black Glutinous Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2643,
    "Beras Ketan Putih (White Glutinous Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2644,
    "Beras Merah (Brown Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2645,
    "Beras Merah Krispi (Brown Rice Crispy)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2646,
    "Beras Merah Utuh (Whole Brown Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2647, "Beras Pandan Wangi", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2648,
    "Beras Panggang (Roasted Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2649,
    "Beras Utuh (Whole Rice)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2650,
    "Besi Bisglisinat (Ferrous bisglycinate) ",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2651,
    "BESI FOSFAT (FERROUS PHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2652,
    "BESI FUMARAT (FERROUS FUMARATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2653, "Besi Glukonat", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2654,
    "BESI LAKTAT (FERROUS LACTATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2655,
    "BESI ORTOFOSFAT (FERROUS ORTHOPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2656,
    "BESI PIROFOSFAT (FERROUS PYROPHOSPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2657,
    "Besi Sitrat (Ferrous Citrate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2658,
    "BESI SULFAT (FERROUS SULPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2659,
    "BESI SULFATE (FERROUS SULPHATE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2660,
    "BESI TRIOKSIDA (FERROUS TRIOXIDE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2661,
    "BETA GLUKAN DARI SACCHAROMYCES CEREVISIAE",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2662,
    "BETA KAROTEN (BETA-CAROTENE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2663,
    "Bifidobacterium Animalis",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2664,
    "Bifidobacterium longum NCC 3001",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2665,
    "Bifidobakterium Breve",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2666,
    "Bifidobakterium Laktis",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2667,
    "Bifidobakterium Longum",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2668, "Bihun (Vermicelli)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2669,
    "Bihun Kentang (Potato Vermicelli)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2670,
    "Biji Amaranthus hypochondriacus",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2671,
    "BIJI ANGGUR (GRAPE SEED)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2672,
    "Biji Aprikot (Apricot Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2673,
    "Biji Blond Grain Husk (Semen Triticum aestivum)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2674,
    "BIJI BUNCIS (BAKED BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2675,
    "Biji Bunga Matahari (Sunflower Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2676,
    "BIJI BUNGA TERATAI-LOTUS SEED (NELUMBIUM NELUMBO DRUCE; NELUMBIUM NUCIFERUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2677,
    "Biji Cabe (Chili Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2678,
    "BIJI CARAWAY (CARAWAY SEED)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2679,
    "BIJI CHIA (SALVIA HISPANICA)",
    "Bahan Baku",
    "NO",
    "NO",
    "YES",
    "YES",
  ],
  [
    2680,
    "BIJI COKELAT-BIJI KAKAO (COCOA BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2681,
    "Biji Delima (Pomegranate Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2682,
    "Biji Kopi (Coffee Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2683,
    "Biji Kopi Arabika (Arabica Coffee Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2684,
    "Biji Kopi Hijau (Green Coffee Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2685,
    "Biji Kopi Panggang (Roasted Coffee Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2686,
    "Biji Kopi Robusta (Robusta Coffee Bean)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2687,
    "Biji Labu (Pumpkin Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2688, "Biji Labu Putih", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2689,
    "Biji Leci (Lychee Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2690, "Biji Lin (Lin Seed)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2691,
    "BIJI LUPIN (LUPIN BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2692,
    "Biji Melinjo - Belinjo (Gnetum gnemon)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2693,
    "Biji Melon (Melon Seeds)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2694,
    "Biji Mustard (Mustard Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2695, "Biji Pala (Nutmeg)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2696,
    "BIJI PERILLA - PERILLA SEED",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2697,
    "Biji Pinus (Pinecone)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2698, "BIJI PLANTAGO", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2699,
    "BIJI POPPY (PAPAVER SOMNIFERUM)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2700,
    "BIJI QUINOA (CHENOPODIUM QUINOA WILLDENOW)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2701,
    "Biji Rami (Flaxseed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2702,
    "Biji Rami Bubuk (Flaxseed Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2703, "BIJI SAFFLOWER", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2704,
    "Biji Salak Bubuk (Salak Seed Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2705,
    "Biji Sawi (Mustard Green Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2706,
    "Biji Selasih (Basil Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2707,
    "Biji Seledri (Celery Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2708,
    "Biji Semangka (Watermelon Seed)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2709,
    "Biji Teff (Teff Grain)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2710,
    "BIJI VANILA (VANILA BEAN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2711, "BIOTIN", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2712, "Bir (Beer)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2713, "BISKUIT (BISCUIT)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2714, "Bit (Beetroot)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2715,
    "Bit Bubuk (Beetroot Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2716,
    "Bit Merah (Red Beetroot)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2717,
    "Bit Merah Bubuk (Red Beetroot Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2718,
    "BLACKCURRANT BUBUK (BLACKCURRANT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2719, "Blondo / Galendo", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2720,
    "BLUEBERRY KERING (DRIED BLUEBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2721,
    "BLUEBERRY PASTA (BLUEBERRY PASTE)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2722, "Bonggol Pisang", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2723, "Brandy (Brandy)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2724, "Brem", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2725, "Brokoli (Brocoli)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2726,
    "BROKOLI BUBUK (BROCCOLI POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2727,
    "BUAH ACAI BERRY (EUTERPE OLERACEA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2728, "Buah Anggur (Grape)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2729,
    "Buah Anggur Bubuk (Grape Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2730,
    "BUAH ANGGUR KERING (DRIED GRAPES)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2731,
    "Buah Anggur Merah Bubuk (Red Grape Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2732, "Buah Apel (Apple)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2733,
    "Buah Apel Hijau (Green Apple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2734,
    "Buah Apel Merah (Red Apple)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2735,
    "BUAH ARA (BUAH FIG, BUAH TIN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2736,
    "BUAH ARONIA BUBUK - ARONIA BERRY POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2737, "BUAH ATAP", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [2738, "BUAH BAKU", "Bahan Baku", "NO", "NO", "NO", "NO"],
  [
    2739,
    "Buah Belimbing (Starfruit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2740, "Buah Beri (Berry)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2741,
    "Buah Beri Hitam (Blackberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2742,
    "Buah Beri Merah (Redberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2743,
    "BUAH BILBERRY (BILBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2744,
    "Buah Blackcurrant (Blackcurrant)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2745,
    "BUAH BLUEBERRY (BLUEBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2746,
    "Buah Boysenberry (Boysenberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2747,
    "BUAH BUBUK (FRUIT POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2748, "Buah Ceri (Cherry)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2749,
    "Buah Ceri Hitam (Black Cherry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2750,
    "Buah Ceri Merah (Red Cherry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2751,
    "BUAH CRANBERRY (CRANBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2752,
    "Buah Delima (Pomegranate)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2753,
    "BUAH DHAL BUBUK (DHAL POWDER)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2754,
    "Buah Durian (Durian)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2755,
    "BUAH DURIAN MONTHONG (DURIAN MONTHONG)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2756,
    "BUAH ELDERBERRY (ELDERBERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2757,
    "BUAH FRAMBOZEN (FRAMBOZEN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2758,
    "BUAH GAC (MOMORDICA COCHINCHINENSIS)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2759,
    "BUAH GOJI BERRY - BARBARY WOLFBERRY",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2760,
    "BUAH HAW (HAWTHORN BERRY)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2761,
    "BUAH KERING (DRIED FRUIT)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2762, "Buah Kesemek", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2763, "Buah Kundur", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2764, "Buah Leci (Lychee)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2765,
    "Buah Leci Bubuk (Lychee Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2766,
    "Buah Mulberry (Mulberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2767,
    "Buah Naga (Dragonfruit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2768,
    "Buah Pala (Myristica Fragran)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2769,
    "BUAH PAW PAW (ASIMINA TRILOBA)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2770,
    "Buah Pepaya (Papaya)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2771,
    "Buah Pepaya Kuning (Golden Papaya)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2772,
    "Buah Pepaya Merah (Red Papaya)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2773, "Buah Persik (Peach)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [2774, "Buah Prune (Prune)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2775,
    "Buah Prune Kering (Dried Prune)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2776,
    "BUAH RASPBERRY (FRAMBOZEN)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2777,
    "Buah Redcurrant (Redcurrant)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2778,
    "Buah Stroberi (Strawberry)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2779,
    "Buah Stroberi Bubuk (Strawberry Powder)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2780,
    "Buah Sukun (Breadfruit)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [2781, "Buah Zaitun (Olive)", "Bahan Baku", "NO", "NO", "NO", "YES"],
  [
    2782,
    "Buah Zaitun Hijau (Green Olive)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2783,
    "Buah Zaitun Hijau Tanpa Biji (Seedless Green Olive)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2784,
    "Buah Zaitun Hitam (Black Olive)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2785,
    "Buah Zaitun Hitam Tanpa Biji (Seedless Black Olive)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2786,
    "Buah Zaitun Kalamata (Kalamata Olive)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2787,
    "Buah Zukini (Zucchini atau Courgette)",
    "Bahan Baku",
    "NO",
    "NO",
    "NO",
    "YES",
  ],
  [
    2788,
    "GLISEROL (GLYCEROL)",
    "Bahan Tambahan Pangan",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2789,
    "NATRIUM BENZOAT (SODIUM BENZOATE)",
    "Bahan Tambahan Pangan",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2790,
    "NATRIUM POLIFOSFAT (SODIUM POLYPHOSPHATE)",
    "Bahan Tambahan Pangan",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
  [
    2791,
    "STEVIA (STEVIA)",
    "Bahan Tambahan Pangan",
    "NO",
    "NO",
    "NO",
    "NO",
  ],
];
# END FRAGMENT id=data-idn_bpom_bahan_baku_pangan


# BEGIN FRAGMENT id=meta-idn_bpom_bahan_tambahan_pangan varname=meta_idn_bpom_bahan_tambahan_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_bahan_tambahan_pangan/meta.yaml
# src-revision: eec157d25120d323d500af0345f6343ae9cd1a00 (Mon Oct 31 21:22:53 2022 +0700)
# generate-date: Mon Oct 31 15:23:02 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_bahan_tambahan_pangan = {
  "fields" => {
    id => {
      "filterable_regex" => "Yes",
      "pos" => 0,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Name",
      "summary.alt.lang.id" => "Nama",
      "unique" => "Yes",
    },
    name => {
      "filterable_regex" => "Yes",
      "pos" => 1,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Name",
      "summary.alt.lang.id" => "Nama",
      "unique" => "Yes",
    },
  },
  "pk" => "id",
  "summary" => "Additives in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Bahan tambahan pangan di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_bahan_tambahan_pangan

# BEGIN FRAGMENT id=data-idn_bpom_bahan_tambahan_pangan varname=data_idn_bpom_bahan_tambahan_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_bahan_tambahan_pangan/data.csv
# src-revision: eec157d25120d323d500af0345f6343ae9cd1a00 (Mon Oct 31 21:22:53 2022 +0700)
# generate-date: Mon Oct 31 15:23:02 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_bahan_tambahan_pangan = [
  [
    1,
    "a -Amilase dari Aspergillus oryzae, Var (alpha-Amylase from Aspergillus oryzae, var.)",
    "",
  ],
  [2, "Agar-agar (Agar)", ""],
  [3, "Agar-agar (Agar)", ""],
  [4, "Agar-agar (Agar)", ""],
  [5, "Agar-agar (Agar)", ""],
  [6, "Agar-agar (Agar)", ""],
  [7, "Alfa-Siklodekstrin (alpha-Cyclodextrin)", ""],
  [8, "Alfa-Siklodekstrin (alpha-Cyclodextrin)", ""],
  [9, "Amonium Fosfatidat (Ammonium Phosphatide)", ""],
  [
    10,
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate)",
    "",
  ],
  [
    11,
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate) ",
    "",
  ],
  [
    12,
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate)",
    "",
  ],
  [13, "Amonium karbonat (Ammonium carbonate)", ""],
  [14, "Amonium karbonat (Ammonium carbonate)", ""],
  [15, "Amonium karbonat (Ammonium carbonate)", ""],
  [16, "Amonium klorida (Ammonium chloride)", ""],
  [17, "Antosianin (Anthocyanins)", ""],
  [18, "Asam 5- inosinat (5-Inosinic acid)", ""],
  [19, "Asam 5-guanilat (5-Guanylic acid)", ""],
  [20, "Asam adipat (Adipic acid) ", ""],
  [21, "Asam adipat (Adipic acid)", ""],
  [22, "Asam alginat (Alginic acid)", ""],
  [23, "Asam alginat (Alginic acid)", ""],
  [24, "Asam alginat (Alginic acid)", ""],
  [25, "Asam alginat (Alginic acid)", ""],
  [26, "Asam alginat (Alginic acid)", ""],
  [27, "Asam asetat (Acetic acid)", ""],
  [28, "Asam askorbat (Ascorbic acid)", ""],
  [29, "Asam benzoate (Benzoic acid)", ""],
  [30, "Asam eritorbat (Erythorbic acid)", ""],
  [31, "Asam fosfat (Orthophosphoric acid)", ""],
  [32, "Asam fumarat (Fumaric acid)", ""],
  [33, "Asam fumarat (Fumaric acid)", ""],
  [34, "Asam hidroklorida (Hydrochloric acid)", ""],
  [35, "Asam laktat (Lactic acid)", ""],
  [36, "Asam L-glutamat (L-Glutamic acid)", ""],
  [37, "Asam malat (Malic acid)", ""],
  [38, "Asam propionat (Propionic acid)", ""],
  [39, "Asam siklamat (Cyclamic acid)", ""],
  [40, "Asam sitrat (Citric acid)", ""],
  [41, "Asam sorbat (Sorbic acid) ", ""],
  [42, "Asam tartrat (Tartaric acid)", ""],
  [43, "Asesulfam-K (Acesulfame potassium)", ""],
  [44, "Asetil pati oksidasi (Acetylated oxidized starch)", ""],
  [45, "Asetil pati oksidasi (Acetylated oxidized starch)", ""],
  [46, "Asetil pati oksidasi (Acetylated oxidized starch)", ""],
  [47, "Askorbil palmitat (Ascorbyl palmitate)", ""],
  [48, "Askorbil stearat (Ascorbyl stearate)", ""],
  [49, "Aspartam (Aspartame)", ""],
  [50, "Belerang dioksida (Sulphur dioxide)", ""],
  [51, "Besi (II) Glukonat", ""],
  [
    52,
    "Beta-apo-8-karotenal CI. No. 40820 (beta-Apo-8-Carotenal)",
    "",
  ],
  [
    53,
    "Beta-karoten (sayuran) CI. No. 75130 (Carotenes, beta(vegetable))",
    "",
  ],
  [
    54,
    "Beta-karoten (sintetik) CI. No. 40800 (beta-Carotenes, synthetic)",
    "",
  ],
  [
    55,
    "Beta-karoten dari Blakeslea trispora (beta-Carotenes (Blakeslea trispora))",
    "",
  ],
  [56, "Biru berlian FCF CI No. 42090 (Brilliant blue FCF)", ""],
  [57, "Bromelain (Bromelain)", ""],
  [58, "Bromelain (Bromelain)", ""],
  [59, "Bromelain (Bromelain)", ""],
  [
    60,
    "Butil hidrokinon tersier/TBHQ (Tertiary butylhydroquinone)",
    "",
  ],
  [61, "Butil hidroksi anisol/BHA (Butylated hydroxyanisole)", ""],
  [62, "Butil hidroksi toluen/BHT (Butylated hydroxytoluene)", ""],
  [63, "Coklat HT CI. No. 20285 (Brown HT)", ""],
  [64, "d-alfa tokoferol (d-alpha-Tocopherol )", ""],
  [65, "Dekstrin (Dextrins) ", ""],
  [66, "Dekstrin (Dextrins)", ""],
  [67, "Dekstrin (Dextrins) ", ""],
  [68, "Dikalium 5-guanilat (Dipotassium 5- guanylate) ", ""],
  [69, "Dikalium 5-inosinat (Dipotassium 5- inosinate)", ""],
  [70, "Dikalium fosfat (Dipotassium orthophosphate)", ""],
  [71, "Dikalium fosfat (Dipotassium orthophosphate)", ""],
  [72, "Dikalium fosfat (Dipotassium orthophosphate)", ""],
  [73, "Dikalsium difosfat (Dicalcium diphosphate)", ""],
  [74, "Dikalsium difosfat (Dicalcium diphosphate)", ""],
  [75, "Dikalsium difosfat (Dicalcium diphosphate)", ""],
  [76, "Dikalsium fosfat (Dicalcium orthophosphate) ", ""],
  [77, "Dinatrium 5- inosinat (Disodium 5- inosinate)", ""],
  [
    78,
    "Dinatrium 5- ribonukleotida (Disodium 5- ribonucleotides)",
    "",
  ],
  [79, "Dinatrium 5-guanilat (Disodium 5- guanylate)", ""],
  [80, "Dinatrium difosfat (Disodium diphosphate)", ""],
  [81, "Dinatrium difosfat (Disodium diphosphate)", ""],
  [82, "Dinatrium difosfat (Disodium diphosphate)", ""],
  [83, "Dinatrium fosfat (Disodium orthophosphate)", ""],
  [84, "Dinatrium fosfat (Disodium orthophosphate)", ""],
  [85, "Dinatrium fosfat (Disodium orthophosphate)", ""],
  [
    86,
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
    "",
  ],
  [
    87,
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
    "",
  ],
  [
    88,
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
    "",
  ],
  [
    89,
    "Dipati adipat terasetilasi (Acetylated distarch adipate) ",
    "",
  ],
  [
    90,
    "Dipati adipat terasetilasi (Acetylated distarch adipate) ",
    "",
  ],
  [
    91,
    "Dipati adipat terasetilasi (Acetylated distarch adipate) ",
    "",
  ],
  [
    92,
    "Dipati adipat terasetilasi (Acetylated distarch adipate) ",
    "",
  ],
  [93, "Dipati fosfat (Distarch phosphate)", ""],
  [94, "Dipati fosfat (Distarch phosphate)", ""],
  [95, "Dipati fosfat (Distarch phosphate)", ""],
  [96, "Dipati fosfat (Distarch phosphate)", ""],
  [
    97,
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
    "",
  ],
  [
    98,
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
    "",
  ],
  [
    99,
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
    "",
  ],
  [
    100,
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
    "",
  ],
  [101, "dl-alfa tokoferol (dl-alpha Tocopherol)", ""],
  [
    102,
    "Ekstrak anato CI. No. 75120 (berbasis bixin) (Annatto extracts, bixin based)",
    "",
  ],
  [103, "Ekstrak cochineal No. 75470 (Cochineal extract)", ""],
  [
    104,
    "Ekstrak Luo Han Guo (berasal dari buah Siraitia grosvenorii) atau Monk Fruit Extract",
    "Pemanis",
  ],
  [105, "Ekstrak Quillaila", ""],
  [106, "Ekstrak Ragi (Yeast Extract)", ""],
  [107, "Ekstrak Rosemari (Rosemary Extract)", "Antioksidan"],
  [108, "Eritritol (Erythritol)", ""],
  [109, "Eritrosin CI. No. 45430 (Erythrosine)", ""],
  [
    110,
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
    "",
  ],
  [
    111,
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
    "",
  ],
  [
    112,
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
    "",
  ],
  [
    113,
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltaric and fatty acid esters of glycerol)",
    "",
  ],
  [
    114,
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltaric and fattya acid esters of glycerol)",
    "",
  ],
  [
    115,
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltartaric and fatty acid esters of glycerol)",
    "",
  ],
  [
    116,
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
    "",
  ],
  [
    117,
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
    "",
  ],
  [
    118,
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
    "",
  ],
  [
    119,
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
    "",
  ],
  [
    120,
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
    "",
  ],
  [
    121,
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
    "",
  ],
  [
    122,
    "Ester gliserol resin kayu (Glycerol ester of wood Rosin)",
    "",
  ],
  [
    123,
    "Ester gliserol resin kayu (Glycerol ester of wood rosin)",
    "",
  ],
  [
    124,
    "Ester gliserol resin kayu (Glycerol ester of wood rosin)",
    "",
  ],
  [
    125,
    "Ester gliserol resin kayu (Glycerol ester of wood Rosin)",
    "",
  ],
  [
    126,
    "Ester poligliserol asam lemak (Polyglycerol esters of fatty acids)",
    "",
  ],
  [
    127,
    "Ester poligliserol asam risinoleat terinteresterifikasi (Polyglycerol esters of interesterified ricinoleic acid)",
    "",
  ],
  [
    128,
    "Ester poligliserol asam risinoleat terinteresterifikasi (Polyglycerol esters of interesterified ricinoleic acid)",
    "",
  ],
  [
    129,
    "Ester propilen glikol asam lemak (Propylene glycol esters of fatty acids)",
    "",
  ],
  [
    130,
    "Ester sukrosa asam lemak (Sucrose esters of fatty acids)",
    "",
  ],
  [
    131,
    "Etil ester dari beta-apo-8asam karotenoat CI. No. 40825 (beta-apo-8-Carotenoic acid ethyl ester)",
    "",
  ],
  [132, "Etil metil selulosa (Methyl ethyl cellulose)", ""],
  [133, "Etil metil selulosa (Methyl ethyl cellulose)", ""],
  [134, "Etil metil selulosa (Methyl ethyl cellulose)", ""],
  [135, "Etil metil selulosa (Methyl ethyl cellulose)", ""],
  [
    136,
    "Etil para-hidroksibenzoat (Ethyl para- hydroxybenzoate)",
    "",
  ],
  [137, "Etil selulosa (Ethyl cellulose)", ""],
  [138, "Etil selulosa (Ethyl cellulose)", ""],
  [
    139,
    "Fosfat dipati fosfat (Phosphate distarch phosphates)",
    "",
  ],
  [
    140,
    "Fosfat dipati fosfat (Phosphated distarch phosphate)",
    "",
  ],
  [
    141,
    "Fosfat dipati fosfat (Phosphated distarch phosphates)",
    "",
  ],
  [
    142,
    "Fosfat dipati fosfat (Phosphated distarch phosphates)",
    "",
  ],
  [143, "Gama tokoferol (Gamma Tocopherol)", ""],
  [144, "Gama-Siklodekstrin (gamma-Cyclodextrin)", ""],
  [145, "Gama-Siklodekstrin (gamma-Cyclodextrin)", ""],
  [146, "Gelatin (Edible gelatin)", ""],
  [147, "Gelatin (Edible gelatin)", ""],
  [148, "Gelatin (Edible gelatin)", ""],
  [149, "Gelatin (Edible gelatin)", ""],
  [150, "Gelatin (Edible gelatin)", ""],
  [151, "Glikosida steviol (Steviol glycosides)", ""],
  [152, "Gliserol (Glycerol)", ""],
  [153, "Gliserol (Glycerol)", ""],
  [154, "Gliserol (Glycerol)", ""],
  [155, "Gliserol (Glycerol)", ""],
  [156, "Glukono delta lakton (Glucono delta lactone)", ""],
  [157, "Glukono delta lakton (Glucono delta lactone)", ""],
  [158, "Glukosa oksidase dari Aspergillus niger", ""],
  [159, "Gom arab (Arabic gum)", ""],
  [160, "Gom arab (Arabic gum)", ""],
  [161, "Gom arab (Arabic gum)", ""],
  [162, "Gom arab (Arabic gum)", ""],
  [163, "Gom gatti (Gum ghatti)", ""],
  [164, "Gom gatti (Gum ghatti)", ""],
  [165, "Gom gelan (Gellan gum)", ""],
  [166, "Gom gelan (Gellan gum)", ""],
  [167, "Gom gelan (Gellan gum)", ""],
  [168, "Gom guar (Guar gum)", ""],
  [169, "Gom guar (Guar gum)", ""],
  [170, "Gom guar (Guar gum)", ""],
  [171, "Gom guar (Guar gum)", ""],
  [172, "Gom kacang lokus (Locust bean gum)", ""],
  [173, "Gom kacang lokus (Locust bean gum)", ""],
  [174, "Gom kacang lokus (Locust bean gum)", ""],
  [175, "Gom karaya (Karaya gum)", ""],
  [176, "Gom karaya (Karaya gum)", ""],
  [177, "Gom karaya (Karaya gum)", ""],
  [178, "Gom karaya (Karaya gum)", ""],
  [179, "Gom tara (Tara gum)", ""],
  [180, "Gom tara (Tara gum)", ""],
  [181, "Gom tragakan (Tragacanth gum)", ""],
  [182, "Gom tragakan (Tragacanth gum)", ""],
  [183, "Gom tragakan (Tragacanth gum)", ""],
  [184, "Gom tragakan (Tragacanth gum)", ""],
  [185, "Gom xanthan (Xanthan gum)", ""],
  [186, "Gom xanthan (Xanthan gum)", ""],
  [187, "Gom xanthan (Xanthan gum)", ""],
  [188, "Hemiselulase dari Aspergillus niger", ""],
  [
    189,
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
    "",
  ],
  [
    190,
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
    "",
  ],
  [
    191,
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
    "",
  ],
  [
    192,
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
    "",
  ],
  [
    193,
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
    "",
  ],
  [
    194,
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
    "",
  ],
  [
    195,
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
    "",
  ],
  [
    196,
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
    "",
  ],
  [197, "Hidroksipropil pati (Hydroxypropyl starch)", ""],
  [198, "Hidroksipropil pati (Hydroxypropyl starch)", ""],
  [199, "Hidroksipropil pati (Hydroxypropyl starch)", ""],
  [200, "Hidroksipropil pati (Hydroxypropyl starch)", ""],
  [201, "Hidroksipropil selulosa (Hydroxypropyl cellulose)", ""],
  [202, "Hidroksipropil selulosa (Hydroxypropyl cellulose)", ""],
  [203, "Hidroksipropil selulosa (Hydroxypropyl cellulose)", ""],
  [204, "Hijau FCF CI. No. 42053 (Fast green FCF)", ""],
  [205, "Indigotin CI. No. 73015 (Indigotine)", ""],
  [206, "Isopropil sitrat (Isopropyl citrates)", ""],
  [207, "Kalium adipat (Potassium adipate)", ""],
  [208, "Kalium alginat (Potassium alginate)", ""],
  [209, "Kalium alginat (Potassium alginate) ", ""],
  [210, "Kalium alginat (Potassium alginate) ", ""],
  [211, "Kalium alginat (Potassium alginate) ", ""],
  [212, "Kalium askorbat (Potassium ascorbate)", ""],
  [213, "Kalium benzoat (Potassium benzoate)", ""],
  [214, "Kalium besi (II) sianida (Potassium ferrocyanide)", ""],
  [215, "Kalium bisulfit (Potassium bisulphite)", ""],
  [
    216,
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
    "",
  ],
  [
    217,
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
    "",
  ],
  [
    218,
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
    "",
  ],
  [
    219,
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
    "",
  ],
  [220, "Kalium glukonat (Potassium gluconate)", ""],
  [
    221,
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate)",
    "",
  ],
  [
    222,
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate) ",
    "",
  ],
  [
    223,
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate) ",
    "",
  ],
  [
    224,
    "Kalium hidrogen tartrat (Potassium hydrogen tartrate)",
    "",
  ],
  [225, "Kalium hidroksida (Potassium hydroxide)", ""],
  [226, "Kalium hidroksida (Potassium hydroxide)", ""],
  [227, "Kalium hidroksida (Potassium hydroxide)", ""],
  [228, "Kalium karbonat (Potassium carbonate)", ""],
  [229, "Kalium karbonat (Potassium carbonates)", ""],
  [230, "Kalium klorida (Potassium chloride)", ""],
  [231, "Kalium klorida (Potassium chloride)", ""],
  [232, "Kalium klorida (Potassium chloride)", ""],
  [233, "Kalium laktat (Potassium lactate)", ""],
  [234, "Kalium laktat (Potassium lactate)", ""],
  [235, "Kalium metabisulfit (Potassium metabisulphite)", ""],
  [236, "Kalium nitrat (Potassium nitrate)", ""],
  [237, "Kalium nitrit (Potassium nitrite) ", ""],
  [238, "Kalium polifosfat (Potassium polyphosphate)", ""],
  [239, "Kalium polifosfat (Potassium polyphosphate)", ""],
  [240, "Kalium polifosfat (Potassium polyphosphate)", ""],
  [241, "Kalium propionat (Potassium propionate) ", ""],
  [242, "Kalium sakarin (Potassium saccharin)", ""],
  [243, "Kalium sorbat (Potassium sorbate)", ""],
  [244, "Kalium sulfat (Potassium sulphate)", ""],
  [245, "Kalium sulfit (Potassium sulphite)", ""],
  [246, "Kalium tripolifosfat (Potassium tripolyphosphate)", ""],
  [247, "Kalium tripolifosfat (Potassium tripolyphosphate)", ""],
  [248, "Kalsium 5- inosinat (Calcium 5- inosinate)", ""],
  [
    249,
    "Kalsium 5- ribonukleotida (Calcium 5- ribonucleotides)",
    "",
  ],
  [250, "Kalsium 5-guanilat (Calcium 5- guanylate) ", ""],
  [251, "Kalsium alginat (Calcium alginate)", ""],
  [252, "Kalsium alginat (Calcium alginate)", ""],
  [253, "Kalsium alginat (Calcium alginate)", ""],
  [254, "Kalsium alginat (Calcium alginate)", ""],
  [255, "Kalsium alginat (Calcium alginate)", ""],
  [256, "Kalsium asetat (Calcium acetate)", ""],
  [257, "Kalsium asetat (Calcium acetate)", ""],
  [258, "Kalsium asetat (Calcium acetate)", ""],
  [259, "Kalsium askorbat (Calcium ascorbate)", ""],
  [260, "Kalsium benzoat (Calcium benzoate )", ""],
  [261, "Kalsium besi (II) sianida (Calcium ferrocyanide)", ""],
  [262, "Kalsium bisulfit (Calcium bisulphite)", ""],
  [263, "Kalsium difosfat (Calcium Dihydrogen Diphosphate)", ""],
  [264, "Kalsium di-L-glutamat (Calsium di-L-glutamate)", ""],
  [
    265,
    "Kalsium dinatrium etilen diamin tetra asetat (Calcium disodium ethylene diamine tetra acetate)",
    "",
  ],
  [266, "Kalsium DL-malat (Calcium DL-malate)", ""],
  [267, "Kalsium fosfat (Calcium phosphates)", ""],
  [268, "Kalsium glukonat (Calcium gluconate)", ""],
  [269, "Kalsium glukonat (Calcium gluconate)", ""],
  [270, "Kalsium hidroksida (Calcium hydroxide)", ""],
  [271, "Kalsium hidroksida (Calcium hydroxide)", ""],
  [272, "Kalsium karbonat (Calcium carbonate)", ""],
  [273, "Kalsium karbonat (Calcium carbonate)", ""],
  [274, "Kalsium karbonat (Calcium carbonate)", ""],
  [275, "Kalsium karbonat (Calcium carbonate)", ""],
  [276, "Kalsium klorida (Calcium chloride)", ""],
  [277, "Kalsium klorida (Calcium chloride)", ""],
  [278, "Kalsium klorida (Calcium chloride)", ""],
  [279, "Kalsium laktat (Calcium lactate)", ""],
  [280, "Kalsium laktat (Calcium lactate)", ""],
  [281, "Kalsium laktat (Calcium lactate)", ""],
  [282, "Kalsium laktat (Calcium lactate)", ""],
  [283, "Kalsium laktat (Calcium lactate)", ""],
  [284, "Kalsium oksida (Calcium oxide)", ""],
  [285, "Kalsium oksida (Calcium oxide)", ""],
  [286, "Kalsium polifosfat (Calcium polyphosphate)", ""],
  [287, "Kalsium polifosfat (Calcium polyphosphates)", ""],
  [288, "Kalsium polifosfat (Calcium polyphosphates)", ""],
  [289, "Kalsium propionat (Calcium propionate) ", ""],
  [290, "Kalsium sakarin (Calcium saccharin)", ""],
  [291, "Kalsium siklamat (Calcium cyclamate)", ""],
  [292, "Kalsium silikat (Calcium silicate)", ""],
  [293, "Kalsium sorbat (Calcium sorbate)", ""],
  [294, "Kalsium sulfat (Calcium sulphate)", ""],
  [295, "Kalsium sulfat (Calcium sulphate)", ""],
  [296, "Kalsium sulfat (Calcium sulphate)", ""],
  [297, "Kalsium sulfat (Calcium sulphate)", ""],
  [298, "Kalsium sulfat (Calcium sulphate)", ""],
  [299, "Kalsium sulfat (Calcium sulphate)", ""],
  [300, "Karagen (Carrageenan)", ""],
  [301, "Karagen (Carrageenan)", ""],
  [302, "Karagen (Carrageenan)", ""],
  [303, "Karagen (Carrageenan)", ""],
  [304, "Karagen (Carrageenan)", ""],
  [305, "Karamel I (Caramel I - plain)", ""],
  [306, "Karamel II", ""],
  [
    307,
    "Karamel III amonia proses (Caramel III - ammonia process)",
    "",
  ],
  [
    308,
    "Karamel IV amonia sulfit proses (Caramel IV - sulphite ammonia process)",
    "",
  ],
  [309, "Karbon dioksida (Carbon dioxide)", ""],
  [310, "Karbon dioksida (Carbon dioxide)", ""],
  [311, "Karbon tanaman CI. 77266 (Vegetable carbon)", ""],
  [312, "Karmin CI. No. 75470 (Carmines) ", ""],
  [313, "Karmoisin CI. No. 14720 (Azorubine (carmoisine))", ""],
  [314, "Karmoisin CI. No. 14720 (carmoisine)", ""],
  [315, "Klorofil CI. No. 75810 (Chlorophyll)", ""],
  [
    316,
    "Klorofil dan klorofilin tembaga kompleks CI. No. 75810 (Chlorophylls and chlorophyllins, copper complexes)",
    "",
  ],
  [
    317,
    "Klorofil tembaga kompleks CI. No. 75810 (Chlorophylls, Copper Complexes)",
    "",
  ],
  [318, "Kuning FCF CI. No. 15985 Sunset yellow FCF", ""],
  [319, "Kuning kuinolin CI. No. 47005 Quinoline yellow", ""],
  [320, "Kurkumin CI. No. 75300 (Curcumin)", ""],
  [321, "Laktitol (Lactitol)", ""],
  [322, "L-amonium laktat (L-ammonium lactate)", ""],
  [323, "L-Amonium laktat (L-Ammonium lactate)", ""],
  [324, "Lesitin (Lecithins)", ""],
  [325, "Lesitin (Lecithins)", ""],
  [326, "Lilin kandelila (Candelilla wax)", ""],
  [327, "Lilin kandelila (Candelilla wax)", ""],
  [328, "Lilin karnauba (Carnauba wax)", ""],
  [329, "Lilin mikrokristalin (Microcrystalline wax)", ""],
  [330, "Lisozim hidroklorida (Lysozyme hydrochloride)", ""],
  [331, "Lutein", ""],
  [332, "Magnesium hidroksida (Magnesium hydroxide)", ""],
  [333, "Magnesium hidroksida (Magnesium hydroxide)", ""],
  [334, "Magnesium hidroksida (Magnesium hydroxide)", ""],
  [335, "Magnesium karbonat (Magnesium carbonate)", ""],
  [336, "Magnesium karbonat (Magnesium carbonate)", ""],
  [337, "Magnesium karbonat (Magnesium carbonate)", ""],
  [338, "Magnesium oksida (Magnesium oxide)", ""],
  [339, "Magnesium silikat (Magnesium silicate)", ""],
  [340, "Malam (Beeswax)", ""],
  [341, "Malam (Beeswax)", ""],
  [342, "Malam (Beeswax)", ""],
  [343, "Manitol (Mannitol)", ""],
  [344, "Merah allura CI. No. 16035 (Allura red)", ""],
  [345, "Merah bit (Beet red)", ""],
  [
    346,
    "Metil para-hidroksibenzoat (Methyl para hydroxybenzoate)",
    "",
  ],
  [347, "Metil selulosa (Methyl cellulosa)", ""],
  [348, "Metil selulosa (Methyl cellulosa)", ""],
  [349, "Metil selulosa (Methyl cellulose)", ""],
  [350, "Metil selulosa (Methyl cellulose)", ""],
  [351, "Minyak Atsiri Paprika (Paprika Oleoresin)", ""],
  [
    352,
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
    "",
  ],
  [
    353,
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
    "",
  ],
  [
    354,
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
    "",
  ],
  [
    355,
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
    "",
  ],
  [
    356,
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
    "",
  ],
  [357, "Monokalium fosfat (Monopotassium orthophosphate)", ""],
  [358, "Monokalium fosfat (Monopotassium orthophosphate)", ""],
  [359, "Monokalium fosfat (Monopotassium orthophosphate)", ""],
  [360, "Monokalium L-glutamate (Monopotassium L-glutamate)", ""],
  [361, "Monokalsium fosfat (Monocalcium orthophosphate) ", ""],
  [362, "Mononatrium fosfat (Monosodium orthophosphate)", ""],
  [363, "Mononatrium fosfat (Monosodium orthophosphate)", ""],
  [364, "Mononatrium fosfat (Monosodium orthophosphate)", ""],
  [365, "Mononatrium L-glutamate (Monosodium L-glutamate)", ""],
  [366, "Monopati fosfat (Monostarch phosphate)", ""],
  [367, "Monopati fosfat (Monostarch phosphate)", ""],
  [368, "Monopati fosfat (Monostarch phosphate)", ""],
  [369, "Monopati fosfat Mono (starch phosphate)", ""],
  [370, "Natrium malat (Sodium malate)", ""],
  [371, "Natrium adipat (Sodium adipates)", ""],
  [372, "Natrium alginat (Sodium alginate)", ""],
  [373, "Natrium alginat (Sodium alginate)", ""],
  [374, "Natrium alginat (Sodium alginate)", ""],
  [375, "Natrium alginat (Sodium alginate)", ""],
  [376, "Natrium alginat (Sodium alginate)", ""],
  [
    377,
    "Natrium aluminium fosfat (Sodium aluminium phosphates)",
    "",
  ],
  [378, "Natrium aluminosilikat (Sodium aluminosilicate)", ""],
  [379, "Natrium asetat (Sodium acetate)", ""],
  [380, "Natrium askorbat (Sodium ascorbate)", ""],
  [381, "Natrium benzoat (Sodium benzoate)", ""],
  [382, "Natrium besi (II) sianida (Sodium ferrocyanide)", ""],
  [383, "Natrium bisulfit (Sodium bisulphate)", ""],
  [
    384,
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
    "",
  ],
  [
    385,
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
    "",
  ],
  [
    386,
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
    "",
  ],
  [
    387,
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
    "",
  ],
  [388, "Natrium eritorbat (Sodium erythorbate)", ""],
  [389, "Natrium glukonat (Sodium gluconate)", ""],
  [390, "Natrium glukonat (Sodium gluconate)", ""],
  [
    391,
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate)",
    "",
  ],
  [
    392,
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate) ",
    "",
  ],
  [
    393,
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate) ",
    "",
  ],
  [394, "Natrium hidrogen malat (Sodium hydrogen malate)", ""],
  [395, "Natrium hidrogen malat (Sodium hydrogen malate)", ""],
  [396, "Natrium Hidrogen Sulfat (Sodium Hydrogen Sulphate)", ""],
  [397, "Natrium hidroksida (Sodium hydroxide)", ""],
  [
    398,
    "Natrium kalsium polifosfat (Sodium calcium polyphosphate)",
    "",
  ],
  [
    399,
    "Natrium kalsium polifosfat (Sodium calcium polyphosphate)",
    "",
  ],
  [
    400,
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
    "",
  ],
  [
    401,
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
    "",
  ],
  [
    402,
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
    "",
  ],
  [
    403,
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
    "",
  ],
  [
    404,
    "Natrium karboksimetil selulosa hidrolisa enzim (Sodium carboxymethyl cellulose, enzymatically hydrolysed)",
    "",
  ],
  [
    405,
    "Natrium karboksimetil selulosa hidrolisa enzim (Sodium carboxymethyl cellulose, enzymatically hydrolysed)",
    "",
  ],
  [406, "Natrium karbonat (Sodium carbonate)", ""],
  [407, "Natrium karbonat (Sodium carbonate)", ""],
  [408, "Natrium karbonat (Sodium carbonate)", ""],
  [409, "Natrium karbonat (Sodium carbonate)", ""],
  [410, "Natrium kaseinat (Sodium caseinate)", ""],
  [411, "Natrium kaseinat (Sodium caseinate)", ""],
  [412, "Natrium kaseinat (Sodium caseinate)", ""],
  [413, "Natrium kroskarmelos (Croscarmellose sodium)", ""],
  [414, "Natrium laktat (Sodium lactate)", ""],
  [415, "Natrium laktat (Sodium lactate)", ""],
  [416, "Natrium laktat (Sodium lactate)", ""],
  [417, "Natrium laktat (Sodium lactate)", ""],
  [418, "Natrium laktat (Sodium lactate)", ""],
  [419, "Natrium laktat (Sodium lactate)", ""],
  [420, "Natrium malat (Sodium malate)", ""],
  [421, "Natrium metabisulfit (Sodium metabisulphite)", ""],
  [422, "Natrium nitrat (Sodium nitrate)", ""],
  [423, "Natrium nitrit (Sodium nitrite)", ""],
  [424, "Natrium polifosfat (Sodium polyphosphate)", ""],
  [425, "Natrium polifosfat (Sodium polyphosphate)", ""],
  [426, "Natrium polifosfat (Sodium polyphosphate)", ""],
  [427, "Natrium propionat (Sodium propionate)", ""],
  [428, "Natrium sakarin (Sodium saccharin)", ""],
  [429, "Natrium siklamat (Sodium cyclamate)", ""],
  [430, "Natrium sorbat (Sodium sorbate)", ""],
  [
    431,
    "Natrium stearoil-2-laktilat (Sodium stearoyl-2-lactylate)",
    "",
  ],
  [
    432,
    "Natrium stearoil-2-laktilat (Sodium stearoyl-2-lactylate)",
    "",
  ],
  [433, "Natrium sulfat (Sodium sulphate)", ""],
  [434, "Natrium sulfit (Sodium sulphite )", ""],
  [435, "Natrium tripolifosfat (Sodium Tripolyphosphate)", ""],
  [436, "Natrium tripolifosfat (Sodium Tripolyphosphate)", ""],
  [437, "Neotam (Neotame)", ""],
  [438, "Nisin (Nisin)", ""],
  [439, "Nitrogen (Nitrogen)", ""],
  [440, "Papain (Papain)", ""],
  [441, "Papain (Papain)", ""],
  [442, "Pati asetat (Starch acetate)", ""],
  [443, "Pati asetat (Starch acetate)", ""],
  [444, "Pati asetat (Starch acetate)", ""],
  [445, "Pati asetat (Starch acetate)", ""],
  [446, "Pati modifikasi asam (Acid treated starch)", ""],
  [447, "Pati modifikasi asam (Acid treated starch)", ""],
  [448, "Pati modifikasi asam (Acid treated starch)", ""],
  [449, "Pati modifikasi asam (Acid treated starch)", ""],
  [450, "Pati modifikasi basa (Alkaline treated starch)", ""],
  [451, "Pati modifikasi basa (Alkaline treated starch)", ""],
  [452, "Pati modifikasi basa (Alkaline treated starch)", ""],
  [453, "Pati modifikasi enzim (Enzymed treated starch)", ""],
  [454, "Pati modifikasi enzim (Enzymed treated starch)", ""],
  [455, "Pati modifikasi enzim (Enzymed treated starch)", ""],
  [456, "Pati modifikasi enzim (Enzymed treated starch)", ""],
  [
    457,
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
    "",
  ],
  [
    458,
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
    "",
  ],
  [
    459,
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
    "",
  ],
  [460, "Pati oksidasi (Oxidized starch)", ""],
  [461, "Pati oksidasi (Oxidized starch)", ""],
  [462, "Pati oksidasi (Oxidized starch)", ""],
  [463, "Pati oksidasi (Oxidized starch)", ""],
  [464, "Pati pucat (Bleached starch)", ""],
  [465, "Pati pucat (Bleached starch)", ""],
  [466, "Pati pucat (Bleached starch)", ""],
  [467, "Pati pucat (Bleached starch)", ""],
  [468, "Pektin (Pectins)", ""],
  [469, "Pektin (Pectins)", ""],
  [470, "Pektin (Pectins)", ""],
  [471, "Pektin (Pectins)", ""],
  [472, "Perisa Alami (Natural Flavour)", ""],
  [473, "Perisa Artifisial (Artificial flavour)", ""],
  [474, "Perisa hasil proses panas (Process flavouring)", ""],
  [475, "Perisa Identik Alami (Natural Identical Flavour)", ""],
  [476, "Polidekstrosa (Polydextroses)", ""],
  [477, "Polidekstrosa (Polydextroses)", ""],
  [478, "Polidekstrosa (Polydextroses)", ""],
  [479, "Polidekstrosa (Polydextroses)", ""],
  [480, "Polidekstrosa (Polydextroses)", ""],
  [481, "Polietilen glikol (Polyethylene glycol)", ""],
  [
    482,
    "Polisorbat 20 (Polyoxyethylene (20) sorbitan monolaurate)",
    "",
  ],
  [
    483,
    "Polisorbat 40 (Polyoxyethylene (20) Sorbitan Monopalmitate)",
    "",
  ],
  [
    484,
    "Polisorbat 60 (Polyoxyethylene (20) sorbitan monostearate)",
    "",
  ],
  [
    485,
    "Polisorbat 65 (Polyoxyethylene (20) ssorbitan tristearate)",
    "",
  ],
  [
    486,
    "Polisorbat 80 (Polyoxyethylene (20) sorbitan monooleate)",
    "",
  ],
  [487, "Ponceau 4R CI. No. 16255 (Ponceau 4R)", ""],
  [488, "Propil galat (Propyl gallate)", ""],
  [489, "Propilen glikol (Propylene glycol)", ""],
  [490, "Propilen glikol (Propylene glycole)", ""],
  [491, "Propilen glikol alginat (Propylene glycol alginate)", ""],
  [492, "Propilen glikol alginat (Propylene glycol alginate)", ""],
  [493, "Propilen glikol alginat (Propylene glycol alginate)", ""],
  [494, "Propilen glikol alginat (Propylene glycol alginate)", ""],
  [
    495,
    "Protease dari Aspergillus oryzae, Var. (Protease from Aspergillus oryzae, var)",
    "",
  ],
  [496, "Riboflavin (sintetik) (Riboflavin, synthetic)", ""],
  [
    497,
    "Riboflavin 5- natrium fosfat (Riboflavin 5-phosphate sodium)",
    "",
  ],
  [
    498,
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
    "",
  ],
  [
    499,
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
    "",
  ],
  [
    500,
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
    "",
  ],
  [501, "Sakarin (Saccharin)", ""],
  [502, "Selulosa bubuk (Powdered cellulose)", ""],
  [503, "Selulosa bubuk (Powdered cellulose)", ""],
  [504, "Selulosa bubuk (Powdered cellulose)", ""],
  [505, "Selulosa bubuk (Powdered cellulose)", ""],
  [506, "Selulosa bubuk (Powdered cellulose)", ""],
  [
    507,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [
    508,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [
    509,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [
    510,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [
    511,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [
    512,
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
    "",
  ],
  [513, "Silikon dioksida halus (Silicon dioxide, amorphous)", ""],
  [514, "Silitol (Xylitol)", ""],
  [515, "Sorbitan monostearat (Sorbitan monostearat) ", ""],
  [516, "Sorbitan tristearat (Sorbitan tristearat)", ""],
  [517, "Sorbitol (Sorbitol)", ""],
  [518, "Sorbitol Sirup (Sorbitol syrup)", ""],
  [519, "Sukralosa (Sucralose/Trichlorogalactosucrose)", ""],
  [
    520,
    "Sukrosa asetat isobutirat (Sucrose acetate isobutyrate)",
    "",
  ],
  [521, "Syelak (Shellac)", ""],
  [522, "Tartrazin CI. No. 19140 (Tartrazine)", ""],
  [523, "Tetrakalium difosfat (Tetrapotassium diphosphate)", ""],
  [524, "Tetrakalium difosfat (Tetrapotassium diphosphate)", ""],
  [525, "Tetrakalium difosfat (Tetrapotassium diphosphate)", ""],
  [526, "Tetranatrium difosfat (Tetrasodium diphosphate)", ""],
  [527, "Tetranatrium difosfat (Tetrasodium diphosphate)", ""],
  [528, "Tetranatrium difosfat (Tetrasodium diphosphate)", ""],
  [529, "Titanium dioksida CI. No. 77891 (Titanium dioxide)", ""],
  [
    530,
    "Tokoferol campuran pekat (Mixed tocopherol concentrate)",
    "",
  ],
  [531, "Triasetin (Triacetin)", ""],
  [532, "Trietil sitrat (Triethyl citrate)", ""],
  [533, "Trietil sitrat (Triethyl citrate)", "Pembawa"],
  [534, "Trikalium fosfat (Tripotassium orthophosphate)", ""],
  [535, "Trikalium fosfat (Tripotassium orthophosphate)", ""],
  [536, "Trikalium fosfat (Tripotassium orthophosphate)", ""],
  [537, "Trikalium sitrat (Tripotassium citrate)", ""],
  [538, "Trikalium sitrat (Tripotassium citrate)", ""],
  [539, "Trikalium sitrat (Tripotassium citrate)", ""],
  [540, "Trikalium sitrat (Tripotassium citrate)", ""],
  [541, "Trikalsium fosfat (Tricalcium orthophosphate) ", ""],
  [542, "Trikalsium fosfat (Tricalcium orthophosphate)", ""],
  [543, "Trikalsium sitrat (Tricalcium citrate)", ""],
  [544, "Trikalsium sitrat (Tricalcium citrate)", ""],
  [545, "Trikalsium sitrat (Tricalcium citrate)", ""],
  [546, "Trinatrium difosfat (Trisodium diphosphate)", ""],
  [547, "Trinatrium difosfat (Trisodium diphosphate)", ""],
  [548, "Trinatrium fosfat (Trisodium orthophosphate)", ""],
  [549, "Trinatrium fosfat (Trisodium orthophosphate)", ""],
  [550, "Trinatrium fosfat (Trisodium orthophosphate)", ""],
  [551, "Trinatrium sitrat (Trisodium citrate)", ""],
  [552, "Trinatrium sitrat (Trisodium citrate)", ""],
  [553, "Trinatrium sitrat (Trisodium citrate)", ""],
  [554, "Trinatrium sitrat (Trisodium citrate)", ""],
  [555, "Xylanase dari Aspergillus niger", "Perlakuan Tepung"],
  [556, "Xylanase dari Aspergillus niger", ""],
];
# END FRAGMENT id=data-idn_bpom_bahan_tambahan_pangan


# BEGIN FRAGMENT id=meta-idn_bpom_cemaran_mikroba_pangan varname=meta_idn_bpom_cemaran_mikroba_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_cemaran_mikroba_pangan/meta.yaml
# src-revision: c422671fcd2b83d86e4f559c3f2cf4d1f0646f50 (Mon Oct 31 22:07:23 2022 +0700)
# generate-date: Mon Oct 31 15:23:02 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_cemaran_mikroba_pangan = {
  "fields" => {
    category => {
      "filterable_regex" => "Yes",
      "pos" => 1,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Category",
      "summary.alt.lang.id" => "Kategori",
      "unique" => "Yes",
    },
    characteristic => {
      "filterable_regex" => "Yes",
      "pos" => 2,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Characteristic",
      "summary.alt.lang.id" => "Karakteristik",
      "unique" => "Yes",
    },
    id => {
      "filterable_regex" => "Yes",
      "pos" => 0,
      "schema" => "uint*",
      "sortable" => "Yes",
      "summary" => "ID",
      "summary.alt.lang.id" => "ID",
      "unique" => "Yes",
    },
    lower_limit => {
      "filterable_regex" => "Yes",
      "pos" => 4,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Lower limit",
      "summary.alt.lang.id" => "Batas bawah",
      "unique" => "Yes",
    },
    upper_limit => {
      "filterable_regex" => "Yes",
      "pos" => 3,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Upper limit",
      "summary.alt.lang.id" => "Batas atas",
      "unique" => "Yes",
    },
  },
  "pk" => "id",
  "summary" => "Microbe specification in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Cemaran mikroba di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_cemaran_mikroba_pangan

# BEGIN FRAGMENT id=data-idn_bpom_cemaran_mikroba_pangan varname=data_idn_bpom_cemaran_mikroba_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_cemaran_mikroba_pangan/data.csv
# src-revision: c422671fcd2b83d86e4f559c3f2cf4d1f0646f50 (Mon Oct 31 22:07:23 2022 +0700)
# generate-date: Mon Oct 31 15:23:02 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_cemaran_mikroba_pangan = [
  [
    1,
    "",
    "Escherichia coli (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2,
    "",
    "Escherichia coli (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    3,
    "",
    "Escherichia coli (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4,
    "",
    "Escherichia coli (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5,
    "",
    "Escherichia coli (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [6, "", "Salmonella (/25 g)"],
  [7, "", "Jumlah Sampel - Salmonella", "\x{2265}"],
  [8, "", "Salmonella (/25 g)"],
  [9, "", "Jumlah Sampel - Salmonella", "\x{2265}"],
  [
    10,
    "",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    11,
    "",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    12,
    "",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [13, "", "Salmonella (/25 g)"],
  [14, "", "Jumlah Sampel - Salmonella"],
  [15, "", "Salmonella (/25 g)"],
  [16, "", "Jumlah Sampel - Salmonella"],
  [17, "", "Salmonella (/25 g)"],
  [18, "", "Jumlah Sampel - Salmonella"],
  [19, "", "Salmonella (/25 g)"],
  [20, "", "Jumlah Sampel - Salmonella"],
  [21, "", "Salmonella (/25 g)"],
  [22, "", "Jumlah Sampel - Salmonella"],
  [
    23,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Salmonella (/25 g)",
  ],
  [
    24,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    25,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Vibrio parahaemolyticus (APM/g)",
  ],
  [
    26,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Vibrio parahaemolyticus (APM/g)",
  ],
  [
    27,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Vibrio parahaemolyticus (APM/g)",
  ],
  [
    28,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Vibrio parahaemolyticus (APM/g)",
  ],
  [
    29,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Vibrio parahaemolyticus (APM/g)",
  ],
  [
    30,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Salmonella (/25 g)",
  ],
  [
    31,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    32,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    33,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    34,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    35,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    36,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    37,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    38,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    39,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    40,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    41,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    42,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    43,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    44,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    45,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    46,
    "Abon Daging (08020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [47, "Abon Daging (08020213)", "Salmonella (/25 g)"],
  [48, "Abon Daging (08020213)", "Salmonella (/25 g)"],
  [49, "Abon Daging (08020213)", "Salmonella (/25 g)"],
  [50, "Abon Daging (08020213)", "Jumlah Sampel - Salmonella"],
  [51, "Abon Daging (08020213)", "Jumlah Sampel - Salmonella"],
  [52, "Abon Daging (08020213)", "Jumlah Sampel - Salmonella"],
  [
    53,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    54,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    55,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    56,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    57,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    58,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    59,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    60,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    61,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    62,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    63,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    64,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    65,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    66,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    67,
    "Abon Daging (08020213)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    68,
    "Abon Ikan (0902040304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    69,
    "Abon Ikan (0902040304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    70,
    "Abon Ikan (0902040304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    71,
    "Abon Ikan (0902040304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    72,
    "Abon Ikan (0902040304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    73,
    "Abon Udang (0902040307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    74,
    "Abon Udang (0902040307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    75,
    "Abon Udang (0902040307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    76,
    "Abon Udang (0902040307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    77,
    "Abon Udang (0902040307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [78, "Acar (Sweet Pickle) (0402020322)", "Salmonella (/25ml)"],
  [
    79,
    "Acar (Sweet Pickle) (0402020322)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [80, "Acar Bawang Putih (0402020306)", "Salmonella (/25 g)"],
  [
    81,
    "Acar Bawang Putih (0402020306)",
    "Jumlah Sampel - Salmonella",
  ],
  [82, "Acar Cabe (0402020308)", "Salmonella (/25 g)"],
  [83, "Acar Cabe (0402020308)", "Jumlah Sampel - Salmonella"],
  [84, "Acar Jahe (0402020307)", "Salmonella (/25 g)"],
  [85, "Acar Jahe (0402020307)", "Jumlah Sampel - Salmonella"],
  [86, "Acar Jamur (0402020304)", "Salmonella (/25 g)"],
  [87, "Acar Jamur (0402020304)", "Jumlah Sampel - Salmonella"],
  [88, "Acar Lobak (0402020309)", "Salmonella (/25 g)"],
  [89, "Acar Lobak (0402020309)", "Jumlah Sampel - Salmonella"],
  [90, "Acar Sayur (0402020320)", "Salmonella (/25 g)"],
  [91, "Acar Sayur (0402020320)", "Jumlah Sampel - Salmonella"],
  [92, "Acar Timun Mentah (0402020305)", "Salmonella (/25 g)"],
  [
    93,
    "Acar Timun Mentah (0402020305)",
    "Jumlah Sampel - Salmonella",
  ],
  [94, "Adas Bubuk (12020105)", "Salmonella (/25 g)"],
  [95, "Adas Bubuk (12020105)", "Jumlah Sampel - Salmonella"],
  [
    96,
    "Adas Bubuk (12020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    97,
    "Adas Bubuk (12020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    98,
    "Adas Bubuk (12020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    99,
    "Adas Bubuk (12020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    100,
    "Adas Bubuk (12020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    101,
    "Adas Bubuk (12020105)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    102,
    "Adas Bubuk (12020105)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    103,
    "Adas Bubuk (12020105)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    104,
    "Adas Bubuk (12020105)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    105,
    "Adas Bubuk (12020105)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    106,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Salmonella (/25 g)",
  ],
  [
    107,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    108,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    109,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    110,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    111,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    112,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    113,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    114,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    115,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    116,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    117,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [118, "Adonan Shortened Bread (07010406)", "Salmonella (/25 g)"],
  [
    119,
    "Adonan Shortened Bread (07010406)",
    "Jumlah Sampel - Salmonells",
    "",
    "\x{2265}5",
  ],
  [
    120,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    121,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    122,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    123,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    124,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    125,
    "Air Mineral Alami (1401010105)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [126, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [127, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [128, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [129, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [130, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [131, "Air Mineral Alami (1401010105)", "Enterococci (/250 ml)"],
  [
    132,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    133,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    134,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    135,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    136,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    137,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    138,
    "Air Mineral Alami (1401010105)",
    "Jumlah Sampel - Bakteri anaerob pereduksi sulfit pembentuk spora",
  ],
  [
    139,
    "Air Mineral Alami (1401010105)",
    "Jumlah Sampel - Enteococci",
  ],
  [
    140,
    "Air Mineral Alami (1401010105)",
    "Jumlah Sampel - Pseudomonas aeruginosa",
  ],
  [
    141,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    142,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    143,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    144,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    145,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    146,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    147,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    148,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    149,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    150,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    151,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    152,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Enterococci (/250 ml)",
  ],
  [
    153,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    154,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    155,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    156,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    157,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    158,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    159,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Jumlah Sampel - Bakteri anaerob pereduksi sulfit pembentuk spora",
  ],
  [
    160,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Jumlah Sampel - Enteococci",
  ],
  [
    161,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Jumlah Sampel - Pseudomonas aeruginosa",
  ],
  [
    162,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    163,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    164,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    165,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    166,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    167,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    168,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    169,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    170,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    171,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    172,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    173,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Enterococci (/250 ml)",
  ],
  [
    174,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    175,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    176,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    177,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    178,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    179,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    180,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Jumlah Sampel - Bakteri anaerob pereduksi sulfit pembentuk spora",
  ],
  [
    181,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Jumlah Sampel - Enteococci",
  ],
  [
    182,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Jumlah Sampel - Pseudomonas aeruginosa",
  ],
  [
    183,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    184,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    185,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    186,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    187,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    188,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri anaerob pereduksi sulfit pembentuk spora (/50 ml)",
  ],
  [
    189,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    190,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    191,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    192,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    193,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    194,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Enterococci (/250 ml)",
  ],
  [
    195,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    196,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    197,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    198,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    199,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    200,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    201,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Jumlah Sampel - Bakteri anaerob pereduksi sulfit pembentuk spora",
  ],
  [
    202,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Jumlah Sampel - Enteococci",
  ],
  [
    203,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Jumlah Sampel - Pseudomonas aeruginosa",
  ],
  [
    204,
    "Akar Chicory (12020198)",
    "Jumlah Sampel - Salmonella - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [205, ""],
  [
    206,
    "Akar Chicory (12020198)",
    "Jumlah Sampel - Salmonella - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [207, "Akar Chicory (12020198)", "Jumlah Sampel - Salmonella"],
  [208, "Akar Chicory (12020198)", "Salmonella (/25 g)"],
  [209, "Akar Chicory (12020198)", "Salmonella (/25 g)"],
  [210, "Akar Chicory (12020198)", "Salmonella (/25 g)"],
  [211, "Akar Chicory (12020198)", "Salmonella (/25 g)"],
  [212, "Akar Chicory (12020198)", "Salmonella (/25 g)"],
  [
    213,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    214,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    215,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    216,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    217,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    218,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    219,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    220,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    221,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    222,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    223,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    224,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    225,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    226,
    "Akar Chicory (12020198)",
    "Bacillus cereus (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    227,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    228,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    229,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    230,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    231,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    232,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    233,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [234, ""],
  [
    235,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [236, ""],
  [
    237,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [238, ""],
  [
    239,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [240, ""],
  [
    241,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [242, ""],
  [
    243,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    244,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    245,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    246,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    247,
    "Akar Chicory (12020198)",
    "Salmonella (/25 g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    248,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    249,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    250,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    251,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    252,
    "Akar Chicory (12020198)",
    "Clostridium pefringens (koloni/g) - Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [253, "Allspice (12020109)", "Salmonella (/25 g)"],
  [254, "Allspice (12020109)", "Jumlah Sampel - Salmonella"],
  [
    255,
    "Allspice (12020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    256,
    "Allspice (12020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    257,
    "Allspice (12020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    258,
    "Allspice (12020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    259,
    "Allspice (12020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    260,
    "Allspice (12020109)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    261,
    "Allspice (12020109)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    262,
    "Allspice (12020109)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    263,
    "Allspice (12020109)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    264,
    "Allspice (12020109)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    265,
    "Amparan Tatak Pisang (060715)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    266,
    "Amparan Tatak Pisang (060715)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    267,
    "Amparan Tatak Pisang (060715)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    268,
    "Amparan Tatak Pisang (060715)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    269,
    "Amparan Tatak Pisang (060715)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [270, "Amparan Tatak Pisang (060715)", "Salmonella (/25 g)"],
  [
    271,
    "Amparan Tatak Pisang (060715)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    272,
    "Amparan Tatak Pisang (060715)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    273,
    "Amparan Tatak Pisang (060715)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    274,
    "Amparan Tatak Pisang (060715)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    275,
    "Amparan Tatak Pisang (060715)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    276,
    "Amparan Tatak Pisang (060715)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    277,
    "Analog keju (010605)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    278,
    "Analog keju (010605)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    279,
    "Analog keju (010605)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    280,
    "Analog keju (010605)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    281,
    "Analog keju (010605)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [282, "Andaliman (12020173)", "Salmonella (/25 g)"],
  [283, "Andaliman (12020173)", "Jumlah Sampel - Salmonella"],
  [
    284,
    "Andaliman (12020173)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    285,
    "Andaliman (12020173)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    286,
    "Andaliman (12020173)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    287,
    "Andaliman (12020173)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    288,
    "Andaliman (12020173)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    289,
    "Andaliman (12020173)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    290,
    "Andaliman (12020173)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    291,
    "Andaliman (12020173)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    292,
    "Andaliman (12020173)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    293,
    "Andaliman (12020173)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [294, "Apem (07010503)", "Salmonella (/25 g)"],
  [295, "Apem (07010503)", "Jumlah Sampel - Salmonella"],
  [296, "Asam Glugur (12020106)", "Salmonella (/25 g)"],
  [297, "Asam Glugur (12020106)", "Jumlah Sampel - Salmonella"],
  [
    298,
    "Asam Glugur (12020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    299,
    "Asam Glugur (12020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    300,
    "Asam Glugur (12020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    301,
    "Asam Glugur (12020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    302,
    "Asam Glugur (12020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    303,
    "Asam Glugur (12020106)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    304,
    "Asam Glugur (12020106)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    305,
    "Asam Glugur (12020106)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    306,
    "Asam Glugur (12020106)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    307,
    "Asam Glugur (12020106)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [308, "Asam Jawa (12020107)", "Salmonella (/25 g)"],
  [309, "Asam Jawa (12020107)", "Jumlah Sampel - Salmonella"],
  [
    310,
    "Asam Jawa (12020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    311,
    "Asam Jawa (12020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    312,
    "Asam Jawa (12020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    313,
    "Asam Jawa (12020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    314,
    "Asam Jawa (12020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    315,
    "Asam Jawa (12020107)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    316,
    "Asam Jawa (12020107)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    317,
    "Asam Jawa (12020107)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    318,
    "Asam Jawa (12020107)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    319,
    "Asam Jawa (12020107)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [320, "Asam Kandis (12020108)", "Salmonella (/25 g)"],
  [321, "Asam Kandis (12020108)", "Jumlah Sampel - Salmonella"],
  [
    322,
    "Asam Kandis (12020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    323,
    "Asam Kandis (12020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    324,
    "Asam Kandis (12020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    325,
    "Asam Kandis (12020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    326,
    "Asam Kandis (12020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    327,
    "Asam Kandis (12020108)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    328,
    "Asam Kandis (12020108)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    329,
    "Asam Kandis (12020108)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    330,
    "Asam Kandis (12020108)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    331,
    "Asam Kandis (12020108)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [332, "Asam Sunti (12020199)", "Salmonella (/25 g)"],
  [333, "Asam Sunti (12020199)", "Jumlah Sampel - Salmonella"],
  [
    334,
    "Asam Sunti (12020199)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    335,
    "Asam Sunti (12020199)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    336,
    "Asam Sunti (12020199)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    337,
    "Asam Sunti (12020199)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    338,
    "Asam Sunti (12020199)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    339,
    "Asam Sunti (12020199)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    340,
    "Asam Sunti (12020199)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    341,
    "Asam Sunti (12020199)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    342,
    "Asam Sunti (12020199)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    343,
    "Asam Sunti (12020199)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [344, "Asinan Buah (0401020302)", "Jumlah Sampel - Salmonella"],
  [345, "Asinan Buah (0401020302)", "Salmonella (/25 g)"],
  [346, "Asinan Jahe (0402020323)", "Salmonella (/25ml)"],
  [
    347,
    "Asinan Jahe (0402020323)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [348, "Aspic Ikan (09030103)", "Salmonella (/25 g)"],
  [349, "Aspic Ikan (09030103)", "Jumlah Sampel - Salmonella"],
  [
    350,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Salmonella (/25 g)",
  ],
  [
    351,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    352,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    353,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    354,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    355,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    356,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    357,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    358,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    359,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Salmonella (/25 g)",
  ],
  [
    360,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    361,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    362,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    363,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    364,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    365,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    366,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    367,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    368,
    "Ayam Karage (Chicken karage) (08020309)",
    "Salmonella (/25 g)",
  ],
  [
    369,
    "Ayam Karage (Chicken karage) (08020309)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    370,
    "Ayam Karage (Chicken karage) (08020309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    371,
    "Ayam Karage (Chicken karage) (08020309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    372,
    "Ayam Karage (Chicken karage) (08020309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    373,
    "Ayam Karage (Chicken karage) (08020309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    374,
    "Ayam Karage (Chicken karage) (08020309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    375,
    "Ayam Karage (Chicken karage) (08020309)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    376,
    "Ayam Karage (Chicken karage) (08020309)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    377,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Salmonella (/25 g)",
  ],
  [
    378,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    379,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    380,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    381,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    382,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    383,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    384,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    385,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    386,
    "Bacon (0802010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    387,
    "Bacon (0802010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    388,
    "Bacon (0802010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    389,
    "Bacon (0802010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    390,
    "Bacon (0802010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [391, "Bacon (0802010101)", "Salmonella (/25 g)"],
  [392, "Bacon (0802010101)", "Jumlah Sampel - Salmonella"],
  [
    393,
    "Bacon Sapi (0802010102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    394,
    "Bacon Sapi (0802010102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    395,
    "Bacon Sapi (0802010102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    396,
    "Bacon Sapi (0802010102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    397,
    "Bacon Sapi (0802010102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [398, "Bacon Sapi (0802010102)", "Salmonella (/25 g)"],
  [399, "Bacon Sapi (0802010102)", "Jumlah Sampel - Salmonella"],
  [400, "Bagel (07010302)", "Salmonella (/25 g)"],
  [401, "Bagel (07010302)", "Jumlah Sampel - Salmonella"],
  [
    402,
    "Bahu Sapi Curing Matang (08020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    403,
    "Bahu Sapi Curing Matang (08020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    404,
    "Bahu Sapi Curing Matang (08020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    405,
    "Bahu Sapi Curing Matang (08020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    406,
    "Bahu Sapi Curing Matang (08020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    407,
    "Bahu Sapi Curing Matang (08020205)",
    "Salmonella (/25 g)",
  ],
  [
    408,
    "Bahu Sapi Curing Matang (08020205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    409,
    "Bahu Sapi Curing Matang (08020205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    410,
    "Bahu Sapi Curing Matang (08020205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    411,
    "Bahu Sapi Curing Matang (08020205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    412,
    "Bahu Sapi Curing Matang (08020205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    413,
    "Bahu Sapi Curing Matang (08020205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [414, "Bakpao/Pao (07010502)", "Salmonella (/25 g)"],
  [415, "Bakpao/Pao (07010502)", "Jumlah Sampel - Salmonella"],
  [416, "Bakpia (07020210)", "Salmonella (/25 g)"],
  [417, "Bakpia (07020210)", "Jumlah Sampel - Salmonella"],
  [
    418,
    "Bakpia (07020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    419,
    "Bakpia (07020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    420,
    "Bakpia (07020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    421,
    "Bakpia (07020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    422,
    "Bakpia (07020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [423, "Bakso Campur dan Batagor (1675)", "Salmonella (/25 g)"],
  [
    424,
    "Bakso Campur dan Batagor (1675)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    425,
    "Bakso Campur dan Batagor (1675)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    426,
    "Bakso Campur dan Batagor (1675)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    427,
    "Bakso Campur dan Batagor (1675)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    428,
    "Bakso Campur dan Batagor (1675)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    429,
    "Bakso Campur dan Batagor (1675)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    430,
    "Bakso Campur dan Batagor (1675)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    431,
    "Bakso Campur dan Batagor (1675)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [432, "Bakso Daging (08030244)", "Salmonella (koloni/25 g)"],
  [433, "Bakso Daging (08030244)", "Jumlah Sampel - Salmonella"],
  [
    434,
    "Bakso Daging (08030244)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    435,
    "Bakso Daging (08030244)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    436,
    "Bakso Daging (08030244)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    437,
    "Bakso Daging (08030244)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    438,
    "Bakso Daging (08030244)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    439,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    440,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    441,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    442,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    443,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    444,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    445,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    446,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    447,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    448,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    449,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    450,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    451,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    452,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    453,
    "Bakso Daging Kombinasi (08030230)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    454,
    "Bakso Daging Kombinasi (08030230)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    455,
    "Bakso Daging Kombinasi (08030230)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    456,
    "Bakso Daging Kombinasi (08030230)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    457,
    "Bakso Daging Kombinasi (08030230)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    458,
    "Bakso Daging Kombinasi (08030230)",
    "Jumlah Sampel - Salmonella",
  ],
  [459, "Bakso Goreng (08030318)", "Salmonella (koloni/25 ml)"],
  [460, "Bakso Goreng (08030318)", "Salmonella (koloni/25 ml)"],
  [461, "Bakso Goreng (08030318)", "Jumlah Sampel - Salmonella"],
  [462, "Bakso Goreng (08030318)", "Jumlah Sampel - Salmonella"],
  [
    463,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    464,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    465,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    466,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    467,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    468,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    469,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    470,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    471,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    472,
    "Bakso Goreng (08030318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    473,
    "Bakso Goreng (08030318)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    474,
    "Bakso Goreng (08030318)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    475,
    "Bakso Goreng (08030318)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    476,
    "Bakso Goreng (08030318)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    477,
    "Bakso Goreng Kombinasi (08030319)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    478,
    "Bakso Goreng Kombinasi (08030319)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    479,
    "Bakso Goreng Kombinasi (08030319)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    480,
    "Bakso Goreng Kombinasi (08030319)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    481,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    482,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    483,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    484,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    485,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    486,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    487,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    488,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    489,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    490,
    "Bakso Goreng Kombinasi (08030319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    491,
    "Bakso Goreng Kombinasi (08030319)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    492,
    "Bakso Goreng Kombinasi (08030319)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    493,
    "Bakso Goreng Kombinasi (08030319)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    494,
    "Bakso Goreng Kombinasi (08030319)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    495,
    "Bakso Ikan (0902040107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    496,
    "Bakso Ikan (0902040107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    497,
    "Bakso Ikan (0902040107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    498,
    "Bakso Ikan (0902040107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    499,
    "Bakso Ikan (0902040107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [500, "Bakso Ikan Beku (09020133)", "Salmonella (/25 g)"],
  [
    501,
    "Bakso Ikan Beku (09020133)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    502,
    "Bakso Ikan Kering (0902040108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    503,
    "Bakso Ikan Kering (0902040108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    504,
    "Bakso Ikan Kering (0902040108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    505,
    "Bakso Ikan Kering (0902040108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    506,
    "Bakso Ikan Kering (0902040108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    507,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    508,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    509,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    510,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    511,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    512,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Salmonella (/25 g)",
  ],
  [
    513,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    514,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    515,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    516,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    517,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    518,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    519,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    520,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    521,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    522,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    523,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    524,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    525,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    526,
    "Bandeng Isi (0902040125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    527,
    "Bandeng Isi (0902040125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    528,
    "Bandeng Isi (0902040125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    529,
    "Bandeng Isi (0902040125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    530,
    "Bandeng Isi (0902040125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    531,
    "Bandeng Presto (0902040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    532,
    "Bandeng Presto (0902040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    533,
    "Bandeng Presto (0902040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    534,
    "Bandeng Presto (0902040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    535,
    "Bandeng Presto (0902040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [536, "Baozi atau Bao (07010506)", "Salmonella (/25 g)"],
  [537, "Baozi atau Bao (07010506)", "Jumlah Sampel - Salmonella"],
  [538, "Bars Buah (0401020815)", "Jumlah Sampel - Salmonella"],
  [539, "Bars Buah (0401020815)", "Salmonella (/25 g)"],
  [
    540,
    "Basil Kering, Ruku-Ruku, Kemangi Hutan (12020111)",
    "Salmonella (/25 g)",
  ],
  [
    541,
    "Basil Kering, Ruku-Ruku, Kemangi Hutan (12020111)",
    "Jumlah Sampel - Salmonella",
  ],
  [542, "Basilla (12020112)", "Salmonella (/25 g)"],
  [543, "Basilla (12020112)", "Jumlah Sampel - Salmonella"],
  [544, "Bawang Batak/Lokio (12020116)", "Salmonella (/25 g)"],
  [
    545,
    "Bawang Batak/Lokio (12020116)",
    "Jumlah Sampel - Salmonella",
  ],
  [546, "Bawang Daun (12020117)", "Salmonella (/25 g)"],
  [547, "Bawang Daun (12020117)", "Jumlah Sampel - Salmonella"],
  [548, "Bawang Goreng (12020195)", "Salmonella (/25 g)"],
  [549, "Bawang Goreng (12020195)", "Jumlah Sampel - Salmonella"],
  [
    550,
    "Bawang Goreng (12020195)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    551,
    "Bawang Goreng (12020195)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    552,
    "Bawang Goreng (12020195)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    553,
    "Bawang Goreng (12020195)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    554,
    "Bawang Goreng (12020195)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    555,
    "Bawang Goreng (12020195)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    556,
    "Bawang Goreng (12020195)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    557,
    "Bawang Goreng (12020195)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    558,
    "Bawang Goreng (12020195)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    559,
    "Bawang Goreng (12020195)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [560, "Bawang Hitam (12020211)", "Salmonella (/25 g)-kering"],
  [
    561,
    "Bawang Hitam (12020211)",
    "Jumlah Sampel - Salmonella-bumbu kering",
  ],
  [
    562,
    "Bawang Hitam (12020211)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    563,
    "Bawang Hitam (12020211)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    564,
    "Bawang Hitam (12020211)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    565,
    "Bawang Hitam (12020211)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    566,
    "Bawang Hitam (12020211)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    567,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    568,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    569,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    570,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    571,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [572, "Bawang Hitam (12020211)", "Salmonella (/25 g)-basah"],
  [
    573,
    "Bawang Hitam (12020211)",
    "Jumlah Sampel - Salmonella-bumbu basah",
  ],
  [
    574,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2265}1000",
  ],
  [
    575,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2265}1000",
  ],
  [
    576,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2265}1000",
  ],
  [
    577,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2265}1000",
  ],
  [
    578,
    "Bawang Hitam (12020211)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2265}1000",
  ],
  [579, "Bawang Merah (Shallot) (12020115)", "Salmonella (/25 g)"],
  [
    580,
    "Bawang Merah (Shallot) (12020115)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    581,
    "Bawang Merah (Shallot) (12020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    582,
    "Bawang Merah (Shallot) (12020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    583,
    "Bawang Merah (Shallot) (12020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    584,
    "Bawang Merah (Shallot) (12020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    585,
    "Bawang Merah (Shallot) (12020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    586,
    "Bawang Merah (Shallot) (12020115)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    587,
    "Bawang Merah (Shallot) (12020115)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    588,
    "Bawang Merah (Shallot) (12020115)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    589,
    "Bawang Merah (Shallot) (12020115)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    590,
    "Bawang Merah (Shallot) (12020115)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [591, "Bawang Putih (12020114)", "Salmonella (/25 g)"],
  [592, "Bawang Putih (12020114)", "Jumlah Sampel - Salmonella"],
  [
    593,
    "Bawang Putih (12020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    594,
    "Bawang Putih (12020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    595,
    "Bawang Putih (12020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    596,
    "Bawang Putih (12020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    597,
    "Bawang Putih (12020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    598,
    "Bawang Putih (12020114)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    599,
    "Bawang Putih (12020114)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    600,
    "Bawang Putih (12020114)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    601,
    "Bawang Putih (12020114)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    602,
    "Bawang Putih (12020114)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [603, "Bay Leaves (12020113)", "Salmonella (/25 g)"],
  [604, "Bay Leaves (12020113)", "Jumlah Sampel - Salmonella"],
  [605, "Bayam Beku (0402020106)", "Salmonella (/25 g)"],
  [606, "Bayam Beku (0402020106)", "Jumlah Sampel - Salmonella"],
  [
    607,
    "Bayam Beku (0402020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    608,
    "Bayam Beku (0402020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    609,
    "Bayam Beku (0402020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    610,
    "Bayam Beku (0402020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    611,
    "Bayam Beku (0402020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [612, "Bekasam/Bekasang (09020520)", "Salmonella (/25 g)"],
  [
    613,
    "Bekasam/Bekasang (09020520)",
    "Jumlah Sampel - Salmonella",
  ],
  [614, "Belut Kering (09020507)", "Salmonella (/25 g)"],
  [615, "Belut Kering (09020507)", "Jumlah Sampel - Salmonella"],
  [616, "Bergamot (120201A1)", "Salmonella (/25 g)"],
  [617, "Bergamot (120201A1)", "Jumlah Sampel - Salmonella"],
  [618, "Bihun (06040301)", "Salmonella (/25 g)"],
  [619, "Bihun (06040301)", "Jumlah Sampel - Salmonella"],
  [620, "Bihun Instan (06040305)", "Salmonella (/25 g)"],
  [621, "Bihun Instan (06040305)", "Jumlah Sampel - Salmonella"],
  [622, "Bihun Lainnya (06040317)", "Salmonella (/25 g)"],
  [623, "Bihun Lainnya (06040317)", "Jumlah Sampel - Salmonella"],
  [
    624,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Salmonella (/25 g)",
  ],
  [
    625,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    626,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Salmonella (/25 g)",
  ],
  [
    627,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    628,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    629,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    630,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    631,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    632,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    633,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    634,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    635,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    636,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    637,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [638, "Biji Jagung Beku (0402020109)", "Salmonella (/25 g)"],
  [
    639,
    "Biji Jagung Beku (0402020109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    640,
    "Biji Jagung Beku (0402020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    641,
    "Biji Jagung Beku (0402020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    642,
    "Biji Jagung Beku (0402020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    643,
    "Biji Jagung Beku (0402020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    644,
    "Biji Jagung Beku (0402020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [645, "Biji Kapulaga (12020149)", "Salmonella (/25 g)"],
  [646, "Biji Kapulaga (12020149)", "Jumlah Sampel - Salmonella"],
  [
    647,
    "Biji Kapulaga (12020149)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    648,
    "Biji Kapulaga (12020149)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    649,
    "Biji Kapulaga (12020149)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    650,
    "Biji Kapulaga (12020149)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    651,
    "Biji Kapulaga (12020149)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    652,
    "Biji Kapulaga (12020149)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    653,
    "Biji Kapulaga (12020149)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    654,
    "Biji Kapulaga (12020149)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    655,
    "Biji Kapulaga (12020149)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    656,
    "Biji Kapulaga (12020149)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    657,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Salmonella (/25 g)",
  ],
  [
    658,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    659,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    660,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    661,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    662,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    663,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    664,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    665,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    666,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    667,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    668,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    669,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Salmonella (/25 g)",
  ],
  [
    670,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    671,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    672,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    673,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    674,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    675,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    676,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    677,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    678,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    679,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    680,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [681, "Biji Sawi/Biji Mustard (12020119)", "Salmonella (/25 g)"],
  [
    682,
    "Biji Sawi/Biji Mustard (12020119)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    683,
    "Biji Sawi/Biji Mustard (12020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    684,
    "Biji Sawi/Biji Mustard (12020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    685,
    "Biji Sawi/Biji Mustard (12020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    686,
    "Biji Sawi/Biji Mustard (12020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    687,
    "Biji Sawi/Biji Mustard (12020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    688,
    "Biji Sawi/Biji Mustard (12020119)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    689,
    "Biji Sawi/Biji Mustard (12020119)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    690,
    "Biji Sawi/Biji Mustard (12020119)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    691,
    "Biji Sawi/Biji Mustard (12020119)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    692,
    "Biji Sawi/Biji Mustard (12020119)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [693, "Biji Seledri (12020118)", "Salmonella (/25 g)"],
  [694, "Biji Seledri (12020118)", "Jumlah Sampel - Salmonella"],
  [
    695,
    "Biji Seledri (12020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    696,
    "Biji Seledri (12020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    697,
    "Biji Seledri (12020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    698,
    "Biji Seledri (12020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    699,
    "Biji Seledri (12020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    700,
    "Biji Seledri (12020118)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    701,
    "Biji Seledri (12020118)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    702,
    "Biji Seledri (12020118)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    703,
    "Biji Seledri (12020118)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    704,
    "Biji Seledri (12020118)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [705, "Bika Ambon (07020118)", "Salmonella (/25 g)"],
  [706, "Bika Ambon (07020118)", "Jumlah Sampel - Salmonella"],
  [
    707,
    "Bika Ambon (07020118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    708,
    "Bika Ambon (07020118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    709,
    "Bika Ambon (07020118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    710,
    "Bika Ambon (07020118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    711,
    "Bika Ambon (07020118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [712, "Biskuit (07010301)", "Salmonella (/25 g)"],
  [713, "Biskuit (07010301)", "Jumlah Sampel - Salmonella"],
  [714, "Biskuit (07020139)", "Salmonella (/25 g)"],
  [715, "Biskuit (07020139)", "Jumlah Sampel - Salmonella"],
  [
    716,
    "Biskuit (07020139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    717,
    "Biskuit (07020139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    718,
    "Biskuit (07020139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    719,
    "Biskuit (07020139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    720,
    "Biskuit (07020139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    721,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Salmonella (/25 g)",
  ],
  [
    722,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    723,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    724,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    725,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    726,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    727,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [728, "Biskuit Bar Sereal Isi (07020130)", "Salmonella (/25 g)"],
  [
    729,
    "Biskuit Bar Sereal Isi (07020130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    730,
    "Biskuit Bar Sereal Isi (07020130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    731,
    "Biskuit Bar Sereal Isi (07020130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    732,
    "Biskuit Bar Sereal Isi (07020130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    733,
    "Biskuit Bar Sereal Isi (07020130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    734,
    "Biskuit Bar Sereal Isi (07020130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [735, "Biskuit Colek (07020127)", "Salmonella (/25 g)"],
  [736, "Biskuit Colek (07020127)", "Jumlah Sampel - Salmonella"],
  [
    737,
    "Biskuit Colek (07020127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    738,
    "Biskuit Colek (07020127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    739,
    "Biskuit Colek (07020127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    740,
    "Biskuit Colek (07020127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    741,
    "Biskuit Colek (07020127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    742,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Salmonella (/25 g)",
  ],
  [
    743,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    744,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    745,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    746,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    747,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    748,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [749, "Biskuit Marie (07020108)", "Salmonella (/25 g)"],
  [750, "Biskuit Marie (07020108)", "Jumlah Sampel - Salmonella"],
  [
    751,
    "Biskuit Marie (07020108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    752,
    "Biskuit Marie (07020108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    753,
    "Biskuit Marie (07020108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    754,
    "Biskuit Marie (07020108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    755,
    "Biskuit Marie (07020108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    756,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Salmonella (/25 g)",
  ],
  [
    757,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    758,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    759,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    760,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    761,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    762,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [763, "Biskuit non terigu (07020132)", "Salmonella (/25 g)"],
  [
    764,
    "Biskuit non terigu (07020132)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    765,
    "Biskuit non terigu (07020132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    766,
    "Biskuit non terigu (07020132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    767,
    "Biskuit non terigu (07020132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    768,
    "Biskuit non terigu (07020132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    769,
    "Biskuit non terigu (07020132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [770, "Bolu Emprit (07020215)", "Salmonella (/25 g)"],
  [
    771,
    "Bolu Emprit (07020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [772, "Bolu Kukus (07010504)", "Salmonella (/25 g)"],
  [773, "Bolu Kukus (07010504)", "Salmonella (/25 g)"],
  [774, "Bolu Kukus (07010504)", "Jumlah Sampel - Salmonella"],
  [775, "Bolu Kukus (07010504)", "Jumlah Sampel - Salmonella"],
  [776, "Bolu Kukus (07020138)", "Salmonella (/25 g)"],
  [777, "Bolu Kukus (07020138)", "Jumlah Sampel - Salmonella"],
  [
    778,
    "Bolu Kukus (07020138)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    779,
    "Bolu Kukus (07020138)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    780,
    "Bolu Kukus (07020138)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    781,
    "Bolu Kukus (07020138)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    782,
    "Bolu Kukus (07020138)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    783,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Salmonella (/25 g)",
  ],
  [
    784,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    785,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    786,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    787,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    788,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    789,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    790,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    791,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    792,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    793,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    794,
    "Brawn and Head Cheese (08030203)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [795, "Brawn and Head Cheese (08030203)", "Salmonella (/25 g)"],
  [796, "Brawn and Head Cheese (08030203)", "Salmonella (/25 g)"],
  [797, "Brawn and Head Cheese (08030203)", "Jumlah - Salmonella"],
  [798, "Brawn and Head Cheese (08030203)", "Jumlah - Salmonella"],
  [799, "Bread Stick (0701010114)", "Salmonella (/25 g)"],
  [800, "Bread Stick (0701010114)", "Jumlah Sampel - Salmonella"],
  [
    801,
    "Brem (060509)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    802,
    "Brem (060509)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    803,
    "Brem (060509)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    804,
    "Brem (060509)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    805,
    "Brem (060509)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [806, "Brem (060509)", "Salmonella (/25 g)"],
  [807, "Brem (060509)", "Jumlah Sampel - Salmonella"],
  [
    808,
    "Brem (060509)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    809,
    "Brem (060509)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    810,
    "Brem (060509)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    811,
    "Brem (060509)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    812,
    "Brem (060509)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [813, "Brokoli Beku (0402020104)", "Salmonella (/25 g)"],
  [814, "Brokoli Beku (0402020104)", "Jumlah Sampel - Salmonella"],
  [
    815,
    "Brokoli Beku (0402020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    816,
    "Brokoli Beku (0402020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    817,
    "Brokoli Beku (0402020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    818,
    "Brokoli Beku (0402020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    819,
    "Brokoli Beku (0402020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [820, "Brownies (07020131)", "Salmonella (/25 g)"],
  [821, "Brownies (07020131)", "Jumlah Sampel - Salmonella"],
  [
    822,
    "Brownies (07020131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    823,
    "Brownies (07020131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    824,
    "Brownies (07020131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    825,
    "Brownies (07020131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    826,
    "Brownies (07020131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [827, "Brussel Sprout Beku (0402020105)", "Salmonella (/25 g)"],
  [
    828,
    "Brussel Sprout Beku (0402020105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    829,
    "Brussel Sprout Beku (0402020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    830,
    "Brussel Sprout Beku (0402020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    831,
    "Brussel Sprout Beku (0402020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    832,
    "Brussel Sprout Beku (0402020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    833,
    "Brussel Sprout Beku (0402020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [834, "Buah Asin (0401020301)", "Jumlah Sampel - Salmonella"],
  [835, "Buah Asin (0401020301)", "Salmonella (/25 g)"],
  [836, "Buah Beku (0401020101)", "Jumlah Sampel - Salmonella"],
  [837, "Buah Beku (0401020101)", "Salmonella (negatif/25 g)"],
  [
    838,
    "Buah beku dalam gula kering (0401020102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    839,
    "Buah beku dalam gula kering (0401020102)",
    "Salmonella (negatif/25 g)",
  ],
  [
    840,
    "Buah beku dalam sirup (0401020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    841,
    "Buah beku dalam sirup (0401020103)",
    "Salmonella (negatif/25 g)",
  ],
  [
    842,
    "Buah dalam Kemasan (0401020404)",
    "Jumlah Sampel - Salmonella",
  ],
  [843, "Buah dalam Kemasan (0401020404)", "Salmonella (/25 g)"],
  [844, "Buah Goreng Beku (0401020104)", "Salmonella (/25 g)"],
  [
    845,
    "Buah Goreng Beku (0401020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [846, "Bubuk Buttermilk (01050111)", "Salmonella (/25 g)"],
  [
    847,
    "Bubuk Buttermilk (01050111)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    848,
    "Bubuk Buttermilk (01050111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    849,
    "Bubuk Buttermilk (01050111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    850,
    "Bubuk Buttermilk (01050111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    851,
    "Bubuk Buttermilk (01050111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    852,
    "Bubuk Buttermilk (01050111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    853,
    "Bubuk Buttermilk (01050204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    854,
    "Bubuk Buttermilk (01050204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    855,
    "Bubuk Buttermilk (01050204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    856,
    "Bubuk Buttermilk (01050204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    857,
    "Bubuk Buttermilk (01050204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [858, "Bubuk Buttermilk (01050204)", "Salmonella (/25 ml)"],
  [
    859,
    "Bubuk Buttermilk (01050204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    860,
    "Bubuk Kakao dengan Lemak Sedang (Medium Fat Cocoa) (05010103)",
    "Salmonella (/25 g)",
  ],
  [
    861,
    "Bubuk Kakao dengan Lemak Sedang (Medium Fat Cocoa) (05010103)",
    "Salmonella (/25 g)",
  ],
  [
    862,
    "Bubuk Kakao dengan Lemak Sedang (Medium Fat Cocoa) (05010103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    863,
    "Bubuk Kakao dengan Lemak Sedang (Medium Fat Cocoa) (05010103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    864,
    "Bubuk Kakao Rendah Lemak (Lowfat Cocoa) (05010104)",
    "Salmonella (/25 g)",
  ],
  [
    865,
    "Bubuk Kakao Rendah Lemak (Lowfat Cocoa) (05010104)",
    "Salmonella (/25 g)",
  ],
  [
    866,
    "Bubuk Kakao Rendah Lemak (Lowfat Cocoa) (05010104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    867,
    "Bubuk Kakao Rendah Lemak (Lowfat Cocoa) (05010104)",
    "Jumlah Sampel - Salmonella",
  ],
  [868, "Bubuk Kari (12020204)", "Salmonella (/25 g)"],
  [869, "Bubuk Kari (12020204)", "Jumlah Sampel - Salmonella"],
  [
    870,
    "Bubuk Kari (12020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    871,
    "Bubuk Kari (12020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    872,
    "Bubuk Kari (12020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    873,
    "Bubuk Kari (12020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    874,
    "Bubuk Kari (12020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    875,
    "Bubuk Kari (12020204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    876,
    "Bubuk Kari (12020204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    877,
    "Bubuk Kari (12020204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    878,
    "Bubuk Kari (12020204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    879,
    "Bubuk Kari (12020204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    880,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Salmonella (/25 g)",
  ],
  [
    881,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    882,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Salmonella (/25 g)",
  ],
  [
    883,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Jumlah Sampel - Salmonella",
  ],
  [884, "Bubuk Ngohyang (12020203)", "Salmonella (/25 g)"],
  [885, "Bubuk Ngohyang (12020203)", "Jumlah Sampel - Salmonella"],
  [
    886,
    "Bubuk Ngohyang (12020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    887,
    "Bubuk Ngohyang (12020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    888,
    "Bubuk Ngohyang (12020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    889,
    "Bubuk Ngohyang (12020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    890,
    "Bubuk Ngohyang (12020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    891,
    "Bubuk Ngohyang (12020203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    892,
    "Bubuk Ngohyang (12020203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    893,
    "Bubuk Ngohyang (12020203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    894,
    "Bubuk Ngohyang (12020203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    895,
    "Bubuk Ngohyang (12020203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    896,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Salmonella (/25ml)",
  ],
  [
    897,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [898, "Bubuk Whey (01080201)", "Salmonella (/25 g)"],
  [899, "Bubuk Whey (01080201)", "Jumlah Sampel - Salmonella"],
  [
    900,
    "Bubuk Whey (01080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    901,
    "Bubuk Whey (01080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    902,
    "Bubuk Whey (01080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    903,
    "Bubuk Whey (01080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    904,
    "Bubuk Whey (01080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [905, "Bubuk Whey Permeate (01080203)", "Salmonella (/25 g)"],
  [
    906,
    "Bubuk Whey Permeate (01080203)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    907,
    "Bubuk Whey Permeate (01080203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    908,
    "Bubuk Whey Permeate (01080203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    909,
    "Bubuk Whey Permeate (01080203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    910,
    "Bubuk Whey Permeate (01080203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    911,
    "Bubuk Whey Permeate (01080203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    912,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Salmonella (/25 g)",
  ],
  [
    913,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    914,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    915,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    916,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    917,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    918,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    919,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Salmonella (/25 g)- siap pakai kering",
  ],
  [
    920,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Jumlah Sampel - Salmonella-siap pakai kering",
    "\x{2265}",
  ],
  [
    921,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Bacillus cereus (koloni/g) - siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    922,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Bacillus cereus (koloni/g) - siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    923,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Bacillus cereus (koloni/g) - siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    924,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Bacillus cereus (koloni/g) - siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    925,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Bacillus cereus (koloni/g) - siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    926,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Clostridium pefringens (koloni/g) - siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    927,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Clostridium pefringens (koloni/g) - siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    928,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Clostridium pefringens (koloni/g) - siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    929,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Clostridium pefringens (koloni/g) - siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    930,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Clostridium pefringens (koloni/g) - siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    931,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Salmonella (/25 g)- siap pakai basah",
  ],
  [
    932,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Jumlah Sampel - Salmonella-siap pakai basah",
    "\x{2265}",
  ],
  [
    933,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Salmonella (/25 g)",
  ],
  [
    934,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Jumlah Sampel - Salmonella",
  ],
  [935, "Bubur (Pulp) Kentang (0402020603)", "Salmonella (/25 g)"],
  [
    936,
    "Bubur (Pulp) Kentang (0402020603)",
    "Jumlah Sampel - Salmonella",
  ],
  [937, "Bubur (Pulp) Sayur (0402020616)", "Salmonella (/25 g)"],
  [
    938,
    "Bubur (Pulp) Sayur (0402020616)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [939, "Bubur (Pulp) Tomat (0402020602)", "Salmonella (/25 g)"],
  [
    940,
    "Bubur (Pulp) Tomat (0402020602)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    941,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Salmonella (/25 g)",
  ],
  [
    942,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    943,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    944,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Salmonella (/25 g)",
  ],
  [945, "Bubur Cabe (12020123)", "Salmonella (/25 g)"],
  [946, "Bubur Cabe (12020123)", "Jumlah Sampel - Salmonella"],
  [
    947,
    "Bubur Cabe (12020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    948,
    "Bubur Cabe (12020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    949,
    "Bubur Cabe (12020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    950,
    "Bubur Cabe (12020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    951,
    "Bubur Cabe (12020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    952,
    "Bubur Cabe (12020123)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    953,
    "Bubur Cabe (12020123)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    954,
    "Bubur Cabe (12020123)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    955,
    "Bubur Cabe (12020123)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    956,
    "Bubur Cabe (12020123)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [957, "Bubur Jahe (12020139)", "Salmonella (/25 g)"],
  [958, "Bubur Jahe (12020139)", "Jumlah Sampel - Salmonella"],
  [
    959,
    "Bubur Jahe (12020139)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    960,
    "Bubur Jahe (12020139)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    961,
    "Bubur Jahe (12020139)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    962,
    "Bubur Jahe (12020139)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    963,
    "Bubur Jahe (12020139)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    964,
    "Bubur Jahe (12020139)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    965,
    "Bubur Jahe (12020139)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    966,
    "Bubur Jahe (12020139)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    967,
    "Bubur Jahe (12020139)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    968,
    "Bubur Jahe (12020139)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    969,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Salmonella (/25 g)",
  ],
  [
    970,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Jumlah Sampel - Salmonella",
  ],
  [971, "Bulgur (060301)", "Salmonella (/25 g)"],
  [972, "Bulgur (060301)", "Jumlah Sampel - Salmonella"],
  [
    973,
    "Bulgur (060301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    974,
    "Bulgur (060301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    975,
    "Bulgur (060301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    976,
    "Bulgur (060301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    977,
    "Bulgur (060301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [978, "Bumbu (12020201)", "Salmonella (/25 g)-bumbu kering"],
  [
    979,
    "Bumbu (12020201)",
    "Jumlah Sampel - Salmonella-bumbu kering",
  ],
  [
    980,
    "Bumbu (12020201)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    981,
    "Bumbu (12020201)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    982,
    "Bumbu (12020201)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    983,
    "Bumbu (12020201)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    984,
    "Bumbu (12020201)",
    "Bacillus cereus (koloni/g)-bumbu kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    985,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    986,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    987,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    988,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    989,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [990, "Bumbu (12020201)", "Salmonella (/25 g)-bumbu basah"],
  [
    991,
    "Bumbu (12020201)",
    "Jumlah Sampel - Salmonella-bumbu basah",
  ],
  [
    992,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    993,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    994,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    995,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    996,
    "Bumbu (12020201)",
    "Clostridium pefringens (koloni/g)-bumbu basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [997, "Bumbu Ekstrak Cumi (12020216)", "Salmonella (/25 g)"],
  [
    998,
    "Bumbu Ekstrak Cumi (12020216)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    999,
    "Bumbu Ekstrak Cumi (12020216)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1000,
    "Bumbu Ekstrak Cumi (12020216)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1001,
    "Bumbu Ekstrak Cumi (12020216)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1002,
    "Bumbu Ekstrak Cumi (12020216)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1003,
    "Bumbu Ekstrak Cumi (12020216)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1004,
    "Bumbu Ekstrak Cumi (12020216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1005,
    "Bumbu Ekstrak Cumi (12020216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1006,
    "Bumbu Ekstrak Cumi (12020216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1007,
    "Bumbu Ekstrak Cumi (12020216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1008,
    "Bumbu Ekstrak Cumi (12020216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1009,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Salmonella (/25 g)",
  ],
  [
    1010,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1011,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1012,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1013,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1014,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1015,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1016,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Salmonella (/25 g)",
  ],
  [
    1017,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1018,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1019,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1020,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1021,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1022,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1023,
    "Bumbu Ekstrak Udang (12020215)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1024,
    "Bumbu Ekstrak Udang (12020215)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1025,
    "Bumbu Ekstrak Udang (12020215)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1026,
    "Bumbu Ekstrak Udang (12020215)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1027,
    "Bumbu Ekstrak Udang (12020215)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1028,
    "Bumbu Ekstrak Udang (12020215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1029,
    "Bumbu Ekstrak Udang (12020215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1030,
    "Bumbu Ekstrak Udang (12020215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1031,
    "Bumbu Ekstrak Udang (12020215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1032,
    "Bumbu Ekstrak Udang (12020215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1033, "Bumbu Ekstrak Udang (12020215)", "Salmonella (/25 g)"],
  [
    1034,
    "Bumbu Ekstrak Udang (12020215)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [1035, "Bumbu Kacang (12060227)", "Salmonella (/25 g)"],
  [1036, "Bumbu Kacang (12060227)", "Jumlah Sampel - Salmonella"],
  [
    1037,
    "Bumbu Mi Instan (12020208)",
    "Salmonella (/25 g)-kering",
  ],
  [
    1038,
    "Bumbu Mi Instan (12020208)",
    "Jumlah Sampel - Salmonella-kering",
  ],
  [
    1039,
    "Bumbu Mi Instan (12020208)",
    "Bacillus cereus (koloni/g)-kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1040,
    "Bumbu Mi Instan (12020208)",
    "Bacillus cereus (koloni/g)-kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1041,
    "Bumbu Mi Instan (12020208)",
    "Bacillus cereus (koloni/g)-kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1042,
    "Bumbu Mi Instan (12020208)",
    "Bacillus cereus (koloni/g)-kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1043,
    "Bumbu Mi Instan (12020208)",
    "Bacillus cereus (koloni/g)-kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1044,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1045,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1046,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1047,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1048,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1049, "Bumbu Mi Instan (12020208)", "Salmonella (/25 g)-basah"],
  [
    1050,
    "Bumbu Mi Instan (12020208)",
    "Jumlah Sampel - Salmonella-basah",
  ],
  [
    1051,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1052,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1053,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1054,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1055,
    "Bumbu Mi Instan (12020208)",
    "Clostridium pefringens (koloni/g)-basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1056,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Salmonella (/25 g)",
  ],
  [
    1057,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1058,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1059,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1060,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1061,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1062,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1063,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Salmonella (/25 g)",
  ],
  [
    1064,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1065,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1066,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1067,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1068,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1069,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1070, "Bumbu Rasa Ayam (12020220)", "Salmonella (/25 g)"],
  [
    1071,
    "Bumbu Rasa Ayam (12020220)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1072,
    "Bumbu Rasa Ayam (12020220)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1073,
    "Bumbu Rasa Ayam (12020220)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1074,
    "Bumbu Rasa Ayam (12020220)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1075,
    "Bumbu Rasa Ayam (12020220)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1076,
    "Bumbu Rasa Ayam (12020220)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1077,
    "Bumbu Rasa Ayam (12020220)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1078,
    "Bumbu Rasa Ayam (12020220)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1079,
    "Bumbu Rasa Ayam (12020220)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1080,
    "Bumbu Rasa Ayam (12020220)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1081,
    "Bumbu Rasa Ayam (12020220)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1082, "Bumbu Rasa Ayam (12050208)", "Salmonella (/25 g)"],
  [
    1083,
    "Bumbu Rasa Ayam (12050208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1084,
    "Bumbu Rasa Ayam (12050208)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1085,
    "Bumbu Rasa Ayam (12050208)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1086,
    "Bumbu Rasa Ayam (12050208)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1087,
    "Bumbu Rasa Ayam (12050208)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1088,
    "Bumbu Rasa Ayam (12050208)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1089, "Bumbu Rasa Ikan (12020218)", "Salmonella (/25 g)"],
  [
    1090,
    "Bumbu Rasa Ikan (12020218)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1091,
    "Bumbu Rasa Ikan (12020218)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1092,
    "Bumbu Rasa Ikan (12020218)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1093,
    "Bumbu Rasa Ikan (12020218)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1094,
    "Bumbu Rasa Ikan (12020218)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1095,
    "Bumbu Rasa Ikan (12020218)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1096,
    "Bumbu Rasa Ikan (12020218)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1097,
    "Bumbu Rasa Ikan (12020218)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1098,
    "Bumbu Rasa Ikan (12020218)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1099,
    "Bumbu Rasa Ikan (12020218)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1100,
    "Bumbu Rasa Ikan (12020218)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [1101, "Bumbu Rasa Ikan (12050215)", "Salmonella (/25 g)"],
  [
    1102,
    "Bumbu Rasa Ikan (12050215)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1103,
    "Bumbu Rasa Ikan (12050215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1104,
    "Bumbu Rasa Ikan (12050215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1105,
    "Bumbu Rasa Ikan (12050215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1106,
    "Bumbu Rasa Ikan (12050215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1107,
    "Bumbu Rasa Ikan (12050215)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1108,
    "Bumbu Rasa Sapi (12020213)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1109,
    "Bumbu Rasa Sapi (12020213)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1110,
    "Bumbu Rasa Sapi (12020213)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1111,
    "Bumbu Rasa Sapi (12020213)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1112,
    "Bumbu Rasa Sapi (12020213)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1113, "Bumbu Rasa Sapi (12020213)", "Salmonella (/25 g)"],
  [
    1114,
    "Bumbu Rasa Sapi (12020213)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [1115, "Bumbu Rasa Sapi (12050206)", "Salmonella (/25 g)"],
  [
    1116,
    "Bumbu Rasa Sapi (12050206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1117,
    "Bumbu Rasa Sapi (12050206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1118,
    "Bumbu Rasa Sapi (12050206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1119,
    "Bumbu Rasa Sapi (12050206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1120,
    "Bumbu Rasa Sapi (12050206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1121,
    "Bumbu Rasa Sapi (12050206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1122, "Bumbu Rasa Udang (12020219)", "Salmonella (/25 g)"],
  [
    1123,
    "Bumbu Rasa Udang (12020219)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1124,
    "Bumbu Rasa Udang (12020219)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1125,
    "Bumbu Rasa Udang (12020219)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1126,
    "Bumbu Rasa Udang (12020219)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1127,
    "Bumbu Rasa Udang (12020219)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1128,
    "Bumbu Rasa Udang (12020219)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1129,
    "Bumbu Rasa Udang (12020219)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1130,
    "Bumbu Rasa Udang (12020219)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1131,
    "Bumbu Rasa Udang (12020219)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1132,
    "Bumbu Rasa Udang (12020219)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1133,
    "Bumbu Rasa Udang (12020219)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [1134, "Bumbu Rasa Udang (12050216)", "Salmonella (/25 g)"],
  [
    1135,
    "Bumbu Rasa Udang (12050216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1136,
    "Bumbu Rasa Udang (12050216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1137,
    "Bumbu Rasa Udang (12050216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1138,
    "Bumbu Rasa Udang (12050216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1139,
    "Bumbu Rasa Udang (12050216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1140,
    "Bumbu Rasa Udang (12050216)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1141,
    "Bumbu Siap Pakai (12020205)",
    "Salmonella (/25 g)-siap pakai kering",
  ],
  [
    1142,
    "Bumbu Siap Pakai (12020205)",
    "Jumlah Sampel - Salmonella-siap pakai kering",
  ],
  [
    1143,
    "Bumbu Siap Pakai (12020205)",
    "Bacillus cereus (koloni/g)-siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1144,
    "Bumbu Siap Pakai (12020205)",
    "Bacillus cereus (koloni/g)-siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1145,
    "Bumbu Siap Pakai (12020205)",
    "Bacillus cereus (koloni/g)-siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1146,
    "Bumbu Siap Pakai (12020205)",
    "Bacillus cereus (koloni/g)-siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1147,
    "Bumbu Siap Pakai (12020205)",
    "Bacillus cereus (koloni/g)-siap pakai kering",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1148,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1149,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1150,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1151,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1152,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai kering",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1153,
    "Bumbu Siap Pakai (12020205)",
    "Salmonella (/25 g)-siap pakai basah",
  ],
  [
    1154,
    "Bumbu Siap Pakai (12020205)",
    "Jumlah Sampel - Salmonella-siap pakai basah",
  ],
  [
    1155,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1156,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1157,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1158,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1159,
    "Bumbu Siap Pakai (12020205)",
    "Clostridium pefringens (koloni/g)-siap pakai basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1160, "Bun Kukus (07010505)", "Salmonella (/25 g)"],
  [1161, "Bun Kukus (07010505)", "Jumlah Sampel - Salmonella"],
  [1162, "Buncis Beku (0402020102)", "Salmonella (/25 g)"],
  [1163, "Buncis Beku (0402020102)", "Jumlah Sampel - Salmonella"],
  [
    1164,
    "Buncis Beku (0402020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    1165,
    "Buncis Beku (0402020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    1166,
    "Buncis Beku (0402020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    1167,
    "Buncis Beku (0402020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    1168,
    "Buncis Beku (0402020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [1169, "Burger Daging (08030320)", "Salmonella (koloni/25 ml)"],
  [1170, "Burger Daging (08030320)", "Jumlah Sampel - Salmonella"],
  [
    1171,
    "Burger Daging (08030320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1172,
    "Burger Daging (08030320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1173,
    "Burger Daging (08030320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1174,
    "Burger Daging (08030320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1175,
    "Burger Daging (08030320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1176,
    "Burger Daging (08030320)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1177,
    "Burger Daging (08030320)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1178,
    "Burger Ikan (0902040130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1179,
    "Burger Ikan (0902040130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1180,
    "Burger Ikan (0902040130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1181,
    "Burger Ikan (0902040130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1182,
    "Burger Ikan (0902040130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1183, "Buttermilk (Plain) (0101010201)", "Salmonella (/25 ml)"],
  [
    1184,
    "Buttermilk (Plain) (0101010201)",
    "Jumlah Sampel - Salmonella",
  ],
  [1185, "Butterscotch (05020204)", "Salmonella (Kembang"],
  [1186, "Gula/Permen"],
  [1187, "Lunak (bukan jeli)"],
  [1188, ") (/25 g)"],
  [1189, "Butterscotch (05020204)", "Jumlah Sampel - Salmonella"],
  [1190, "Butterscotch (05020204)", "Jumlah Sampel - Salmonella"],
  [
    1191,
    "Butterscotch (05020204)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [1192, "Cabe Bubuk (12020124)", "Salmonella (/25 g)"],
  [1193, "Cabe Bubuk (12020124)", "Jumlah Sampel - Salmonella"],
  [
    1194,
    "Cabe Bubuk (12020124)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1195,
    "Cabe Bubuk (12020124)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1196,
    "Cabe Bubuk (12020124)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1197,
    "Cabe Bubuk (12020124)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1198,
    "Cabe Bubuk (12020124)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1199,
    "Cabe Bubuk (12020124)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1200,
    "Cabe Bubuk (12020124)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1201,
    "Cabe Bubuk (12020124)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1202,
    "Cabe Bubuk (12020124)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1203,
    "Cabe Bubuk (12020124)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1204, "Cabe Jawa (12020121)", "Salmonella (/25 g)"],
  [1205, "Cabe Jawa (12020121)", "Jumlah Sampel - Salmonella"],
  [
    1206,
    "Cabe Jawa (12020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1207,
    "Cabe Jawa (12020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1208,
    "Cabe Jawa (12020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1209,
    "Cabe Jawa (12020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1210,
    "Cabe Jawa (12020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1211,
    "Cabe Jawa (12020121)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1212,
    "Cabe Jawa (12020121)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1213,
    "Cabe Jawa (12020121)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1214,
    "Cabe Jawa (12020121)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1215,
    "Cabe Jawa (12020121)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1216, "Cakue (07020123)", "Salmonella (/25 g)"],
  [1217, "Cakue (07020123)", "Jumlah Sampel - Salmonella"],
  [
    1218,
    "Cakue (07020123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1219,
    "Cakue (07020123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1220,
    "Cakue (07020123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1221,
    "Cakue (07020123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1222,
    "Cakue (07020123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1223,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Salmonella (/25 g)",
  ],
  [
    1224,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Salmonella (/25 g)",
  ],
  [
    1225,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1226,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1227,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1228,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1229,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Salmonella (negatif/25 g)",
  ],
  [
    1230,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Salmonella (negatif/25 g)",
  ],
  [
    1231,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1232,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1233,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1234,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1235,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1236,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1237,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1238,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1239,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1240,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1241,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1242,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Salmonella (/25 g)",
  ],
  [
    1243,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1244,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1245,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1246,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1247,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1248,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Salmonella (/25 g)",
  ],
  [
    1249,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1250,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1251,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1252,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1253,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1254,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1255,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1256,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1257,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1258,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1259,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1260,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Salmonella (/25 ml)",
  ],
  [
    1261,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1262,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    1263,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    1264,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    1265,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    1266,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    1267,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1268,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Salmonella (/25 g)",
  ],
  [
    1269,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1270,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1271,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1272,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1273,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1274,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Salmonella (/25 ml)",
  ],
  [
    1275,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1276,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Salmonella (/25 g)",
  ],
  [
    1277,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Salmonella (/25 g)",
  ],
  [
    1278,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1279,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1280,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1281,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1282,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1283,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1284,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1285,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1286,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1287,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1288,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1289,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1290, "Carabikang (07020122)", "Salmonella (/25 g)"],
  [1291, "Carabikang (07020122)", "Jumlah Sampel - Salmonella"],
  [
    1292,
    "Carabikang (07020122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1293,
    "Carabikang (07020122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1294,
    "Carabikang (07020122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1295,
    "Carabikang (07020122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1296,
    "Carabikang (07020122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [1297, "Carob Coatings (05010504)", "Salmonella (/25 g)"],
  [
    1298,
    "Carob Coatings (05010504)",
    "Jumlah Sampel - Salmonella",
  ],
  [1299, "Cengkeh (12020126)", "Salmonella (/25 g)"],
  [1300, "Cengkeh (12020126)", "Jumlah Sampel - Salmonella"],
  [
    1301,
    "Cengkeh (12020126)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1302,
    "Cengkeh (12020126)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1303,
    "Cengkeh (12020126)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1304,
    "Cengkeh (12020126)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1305,
    "Cengkeh (12020126)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1306,
    "Cengkeh (12020126)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1307,
    "Cengkeh (12020126)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1308,
    "Cengkeh (12020126)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1309,
    "Cengkeh (12020126)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1310,
    "Cengkeh (12020126)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1311, "Cengkeh Bubuk (12020127)", "Salmonella (/25 g)"],
  [1312, "Cengkeh Bubuk (12020127)", "Jumlah Sampel - Salmonella"],
  [
    1313,
    "Cengkeh Bubuk (12020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1314,
    "Cengkeh Bubuk (12020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1315,
    "Cengkeh Bubuk (12020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1316,
    "Cengkeh Bubuk (12020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1317,
    "Cengkeh Bubuk (12020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    1318,
    "Cengkeh Bubuk (12020127)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1319,
    "Cengkeh Bubuk (12020127)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1320,
    "Cengkeh Bubuk (12020127)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1321,
    "Cengkeh Bubuk (12020127)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1322,
    "Cengkeh Bubuk (12020127)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1323, "Chicken Strip Beku (08020307)", "Salmonella (/25 g)"],
  [
    1324,
    "Chicken Strip Beku (08020307)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1325,
    "Chicken Strip Beku (08020307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1326,
    "Chicken Strip Beku (08020307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1327,
    "Chicken Strip Beku (08020307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1328,
    "Chicken Strip Beku (08020307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1329,
    "Chicken Strip Beku (08020307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1330,
    "Chicken Strip Beku (08020307)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1331,
    "Chicken Strip Beku (08020307)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1332,
    "Chorizos (0803010302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1333,
    "Chorizos (0803010302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1334,
    "Chorizos (0803010302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1335,
    "Chorizos (0803010302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1336,
    "Chorizos (0803010302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1337, "Chorizos (0803010302)", "Salmonella (/25 g)"],
  [1338, "Chorizos (0803010302)", "Jumlah Sampel - Salmonella"],
  [
    1339,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1340,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Salmonella (/25 g)",
  ],
  [1341, "Cincau Hijau (0401020905)", "Salmonella (/25 g)"],
  [
    1342,
    "Cincau Hijau (0401020905)",
    "Jumlah Sampel - Salmonella",
  ],
  [1343, "Cincau Hitam (0401020906)", "Salmonella (/25 g)"],
  [
    1344,
    "Cincau Hitam (0401020906)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1345,
    "Cireng Seafood (0902040306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1346,
    "Cireng Seafood (0902040306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1347,
    "Cireng Seafood (0902040306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1348,
    "Cireng Seafood (0902040306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1349,
    "Cireng Seafood (0902040306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1350,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [1351, "Coating) (05010505)", "Salmonella (/25 g)"],
  [
    1352,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [1353, "Coating) (05010505)", "Jumlah Sampel - Salmonella"],
  [
    1354,
    "Cocoa Butter Equivalent (05010501)",
    "Salmonella (/25 g)",
  ],
  [
    1355,
    "Cocoa Butter Equivalent (05010501)",
    "Jumlah Sampel - Salmonella",
  ],
  [1356, "Cokelat Aerasi (05010420)", "Salmonella (/25 g)"],
  [
    1357,
    "Cokelat Aerasi (05010420)",
    "Jumlah Sampel - Salmonella",
  ],
  [1358, "Cokelat Bubuk (05010119)", "Salmonella (/25 g)"],
  [1359, "Cokelat Bubuk (05010119)", "Jumlah Sampel - Salmonella"],
  [
    1360,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Salmonella (/25 g)",
  ],
  [
    1361,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1362,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Salmonella (/25 g)",
  ],
  [
    1363,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1364,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Salmonella (/25 g)",
  ],
  [
    1365,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1366,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Salmonella (/25 g)",
  ],
  [
    1367,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Jumlah Sampel - Salmonella",
  ],
  [1368, "Cokelat Imitasi (05010510)", "Salmonella (/25 g)"],
  [
    1369,
    "Cokelat Imitasi (05010510)",
    "Jumlah Sampel - Salmonella",
  ],
  [1370, "Cokelat Instan (05010112)", "Salmonella (/25 g)"],
  [
    1371,
    "Cokelat Instan (05010112)",
    "Jumlah Sampel - Salmonella",
  ],
  [1372, "Cokelat Komposit (05010422)", "Salmonella (/25 g)"],
  [
    1373,
    "Cokelat Komposit (05010422)",
    "Jumlah Sampel - Salmonella",
  ],
  [1374, "Cokelat Laminasi (05010421)", "Salmonella (/25 g)"],
  [
    1375,
    "Cokelat Laminasi (05010421)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1376,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Salmonella (/25 g)",
  ],
  [
    1377,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1378,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Salmonella (/25 g)",
  ],
  [
    1379,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1380,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Salmonella (/25 g)",
  ],
  [
    1381,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1382,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Salmonella (/25 g)",
  ],
  [
    1383,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1384,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Salmonella (/25 g)",
  ],
  [
    1385,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1386,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Salmonella (/25 g)",
  ],
  [
    1387,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1388,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Salmonella (/25 g)",
  ],
  [
    1389,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1390,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Salmonella (/25 g)",
  ],
  [
    1391,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Salmonella (/25 g)",
  ],
  [
    1392,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1393,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1394,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Salmonella (/25 g)",
  ],
  [
    1395,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Salmonella (/25 g)",
  ],
  [
    1396,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1397,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1398,
    "Cokelat Pelapis (Couverture chocolate) (05010415)",
    "Salmonella (/25 g)",
  ],
  [
    1399,
    "Cokelat Pelapis (Couverture chocolate) (05010415)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1400,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Salmonella (/25 g)",
  ],
  [
    1401,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1402,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Salmonella (/25 g)",
  ],
  [
    1403,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1404,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Salmonella (/25 g)",
  ],
  [
    1405,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1406,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Salmonella (/25 g)",
  ],
  [
    1407,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Jumlah Sampel - Salmonella",
  ],
  [1408, "Cone untuk Es Krim (07020213)", "Salmonella (/25 g)"],
  [
    1409,
    "Cone untuk Es Krim (07020213)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1410,
    "Cone untuk Es Krim (07020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1411,
    "Cone untuk Es Krim (07020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1412,
    "Cone untuk Es Krim (07020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1413,
    "Cone untuk Es Krim (07020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1414,
    "Cone untuk Es Krim (07020213)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [1415, "Crepes (07020142)", "Salmonella (/25g)"],
  [
    1416,
    "Crepes (07020142)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    1417,
    "Crepes (07020142)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<100",
  ],
  [
    1418,
    "Crepes (07020142)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<100",
  ],
  [
    1419,
    "Crepes (07020142)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<100",
  ],
  [
    1420,
    "Crepes (07020142)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<100",
  ],
  [
    1421,
    "Crepes (07020142)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<100",
  ],
  [1422, "Crouton (07010401)", "Salmonella (/25 g)"],
  [1423, "Crouton (07010401)", "Jumlah Sampel - Salmonella"],
  [
    1424,
    "Cumi dan Sotong Kering (09020534)",
    "Salmonella (/25 g)",
  ],
  [
    1425,
    "Cumi dan Sotong Kering (09020534)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1426,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Salmonella (/25 g)",
  ],
  [
    1427,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1428,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Vibrio parahaemolyticus (APM/g) - Selain Ikan",
    "",
    "<3",
  ],
  [
    1429,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Vibrio parahaemolyticus (APM/g) - Selain Ikan",
    "",
    "<3",
  ],
  [
    1430,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Vibrio parahaemolyticus (APM/g) - Selain Ikan",
    "",
    "<3",
  ],
  [
    1431,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Vibrio parahaemolyticus (APM/g) - Selain Ikan",
    "",
    "<3",
  ],
  [
    1432,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Vibrio parahaemolyticus (APM/g) - Selain Ikan",
    "",
    "<3",
  ],
  [1433, "Cumi-cumi Dalam Kemasan (090416)", "Salmonella (/25 g)"],
  [
    1434,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1435,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1436,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [1437, "Cumi-Cumi Kering/Juhi (09020509)", "Salmonella (/25 g)"],
  [
    1438,
    "Cumi-Cumi Kering/Juhi (09020509)",
    "Jumlah Sampel - Salmonella",
  ],
  [1439, "Custard (100402)", "Salmonella (/25 g)"],
  [1440, "Custard (100402)", "Jumlah Sampel - Salmonella"],
  [
    1441,
    "Custard (100402)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    1442,
    "Custard (100402)",
    "Listeria monocytogenes (koloni/25 g) - Khusus Produk Beku",
  ],
  [1443, "Custard Beku (100403)", "Salmonella (/25 g)"],
  [1444, "Custard Beku (100403)", "Jumlah Sampel - Salmonella"],
  [
    1445,
    "Custard Beku (100403)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1446,
    "Custard Beku (100403)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [1447, "Dadih (0101010202)", "Salmonella (/25 ml)"],
  [1448, "Dadih (0101010202)", "Jumlah Sampel - Salmonella"],
  [1449, "Dadih (0102A0)", "Salmonella (/25 g)"],
  [
    1450,
    "Dadih (0102A0)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [1451, "Daging Asap (0802010108)", "Salmonella (/25 g)"],
  [1452, "Daging Asap (0802010108)", "Salmonella (/25 g)"],
  [1453, "Daging Asap (0802010108)", "Salmonella (/25 g)"],
  [1454, "Daging Asap (0802010108)", "Jumlah - Salmonella"],
  [
    1455,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1456,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1457,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1458,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1459,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1460,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1461,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1462,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1463,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1464,
    "Daging Asap (0802010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1465,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1466,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1467,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1468,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1469,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1470,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Salmonella (/25 g)",
  ],
  [
    1471,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1472,
    "Daging Cangkuk (0802010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1473,
    "Daging Cangkuk (0802010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1474,
    "Daging Cangkuk (0802010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1475,
    "Daging Cangkuk (0802010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1476,
    "Daging Cangkuk (0802010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [1477, "Daging Cangkuk (0802010303)", "Salmonella (/25 g)"],
  [1478, "Daging Cangkuk (0802010303)", "Jumlah - Salmonella"],
  [
    1479,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1480,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1481,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1482,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1483,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1484,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1485,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1486,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1487,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1488,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1489,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1490,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1491,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1492,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1493,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1494,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1495,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1496,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1497,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1498,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1499,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1500,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1501,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1502,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1503,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1504,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1505,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1506,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1507,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1508,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1509,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1510,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1511,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1512,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1513,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1514,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1515,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1516,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1517,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1518,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1519,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1520,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1521,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1522,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1523,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1524,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1525,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1526,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1527,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1528,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1529,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1530,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1531,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1532,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1533,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1534,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1535,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1536,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1537,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1538,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1539,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1540,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1541,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1542,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Salmonella (/25 g)",
  ],
  [
    1543,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1544,
    "Daging Kerang Abalon Kering (09020513)",
    "Salmonella (/25 g)",
  ],
  [
    1545,
    "Daging Kerang Abalon Kering (09020513)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1546,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1547,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1548,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1549,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1550,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1551,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1552,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1553,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1554,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1555,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1556,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1557,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1558,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1559,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1560,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1561,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Salmonella (/25 g)",
  ],
  [
    1562,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Salmonella (/25 g)",
  ],
  [
    1563,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Salmonella (/25 g)",
  ],
  [
    1564,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1565,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1566,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1567,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1568,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1569,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1570,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1571,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1572,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1573,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1574,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1575,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1576,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1577,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1578,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1579,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1580,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1581,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1582,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1583,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1584,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1585,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1586,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1587,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1588,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1589,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1590,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1591,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1592,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1593,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1594,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1595,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1596,
    "Daging Luncheon Matang (08030207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1597,
    "Daging Luncheon Matang (08030207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1598,
    "Daging Luncheon Matang (08030207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1599,
    "Daging Luncheon Matang (08030207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1600,
    "Daging Luncheon Matang (08030207)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1601,
    "Daging Luncheon Matang (08030207)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1602,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1603,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1604,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1605,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1606,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1607,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1608,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1609,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1610,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1611,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1612,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<250",
  ],
  [
    1613,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<250",
  ],
  [
    1614,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<250",
  ],
  [
    1615,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<250",
  ],
  [
    1616,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<250",
  ],
  [
    1617,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1618,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1619,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1620,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1621,
    "Daging Marinasi (0802010111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1622,
    "Daging Marinasi (0802010111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1623,
    "Daging Marinasi (0802010111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1624,
    "Daging Marinasi (0802010111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1625,
    "Daging Marinasi (0802010111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1626,
    "Daging Marinasi (0802010111)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1627,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1628,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1629,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1630,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1631,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1632,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1633,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1634,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1635,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1636,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1637,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1638,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1639,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1640,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1641,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1642,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1643,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1644,
    "Daging Marinasi (Beku) (08020310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1645,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1646,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1647,
    "Daging Marinasi (Beku) (08020310)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1648,
    "Daging Marinasi (Beku) (08020310)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1649,
    "Daging Marinasi (Beku) (08020310)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1650,
    "Daging Olahan Berbumbu (08020225)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1651,
    "Daging Olahan Berbumbu (08020225)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1652,
    "Daging Olahan Berbumbu (08020225)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1653,
    "Daging Olahan Berbumbu (08020225)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1654,
    "Daging Olahan Berbumbu (08020225)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1655,
    "Daging Olahan Berbumbu (08020225)",
    "Salmonella (/25 g)",
  ],
  [
    1656,
    "Daging Olahan Berbumbu (08020225)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1657,
    "Daging Olahan Berbumbu (08020225)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1658,
    "Daging Olahan Berbumbu (08020225)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1659,
    "Daging Olahan Berbumbu (08020225)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1660,
    "Daging Olahan Berbumbu (08020225)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1661,
    "Daging Olahan Berbumbu (08020225)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1662,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Salmonella (/25 g)",
  ],
  [
    1663,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Jumlah - Salmonella",
  ],
  [
    1664,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1665,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1666,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1667,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1668,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1669,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1670,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    1671,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1672,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1673,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1674,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1675,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1676,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1677,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1678,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1679,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1680,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1681,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Salmonella (/25 g)",
  ],
  [
    1682,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    1683,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1684,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1685,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1686,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1687,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1688,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Salmonella (/25 g)",
  ],
  [
    1689,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1690,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1691,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1692,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1693,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1694,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1695,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1696,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1697,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1698,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1699,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1700,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1701,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1702,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1703,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1704,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1705,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Salmonella (/25 g)",
  ],
  [
    1706,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1707,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Salmonella (/25 g)",
  ],
  [
    1708,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1709,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1710,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Jumlah Sampel -Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    1711,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Salmonella (/25 g)",
  ],
  [
    1712,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1713,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1714,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1715,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1716,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1717,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1718,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    1719,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    1720,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1721,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1722,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1723,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1724,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1725,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Salmonella (/25 g)",
  ],
  [
    1726,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Jumlah - Salmonella",
  ],
  [
    1727,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1728,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1729,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1730,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1731,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1732,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Salmonella (/25 g)",
  ],
  [
    1733,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Jumlah - Salmonella",
  ],
  [
    1734,
    "Daging Sei (0802010110)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1735,
    "Daging Sei (0802010110)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1736,
    "Daging Sei (0802010110)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1737,
    "Daging Sei (0802010110)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [
    1738,
    "Daging Sei (0802010110)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}250",
  ],
  [1739, "Daging Sei (0802010110)", "Salmonella (/25 g)"],
  [1740, "Daging Sei (0802010110)", "Jumlah - Salmonella"],
  [
    1741,
    "Dango (060502)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1742,
    "Dango (060502)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1743,
    "Dango (060502)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1744,
    "Dango (060502)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1745,
    "Dango (060502)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1746, "Dango (060502)", "Salmonella (/25 g)"],
  [1747, "Dango (060502)", "Jumlah Sampel - Salmonella"],
  [
    1748,
    "Dango (060502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1749,
    "Dango (060502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1750,
    "Dango (060502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1751,
    "Dango (060502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1752,
    "Dango (060502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [1753, "Dashi (12020207)", "Salmonella (/25 g)"],
  [1754, "Dashi (12020207)", "Jumlah Sampel - Salmonella"],
  [
    1755,
    "Dashi (12020207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1756,
    "Dashi (12020207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1757,
    "Dashi (12020207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1758,
    "Dashi (12020207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1759,
    "Dashi (12020207)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1760,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Salmonella (/25 g)",
  ],
  [
    1761,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Jumlah Sampel - Salmonella",
  ],
  [1762, "Daun Ketumbar (12020162)", "Salmonella (/25 g)"],
  [1763, "Daun Ketumbar (12020162)", "Jumlah Sampel - Salmonella"],
  [1764, "Daun Pandan (12020197)", "Salmonella (/25 g)"],
  [1765, "Daun Pandan (12020197)", "Jumlah Sampel - Salmonella"],
  [1766, "Daun Peterseli (120201A2)", "Salmonella (/25 g)"],
  [
    1767,
    "Daun Peterseli (120201A2)",
    "Jumlah Sampel - Salmonella",
  ],
  [1768, "Daun Salam (12020130)", "Salmonella (/25 g)"],
  [1769, "Daun Salam (12020130)", "Jumlah Sampel - Salmonella"],
  [1770, "Daun Seledri (12020131)", "Salmonella (/25 g)"],
  [1771, "Daun Seledri (12020131)", "Jumlah Sampel - Salmonella"],
  [1772, "Daun Sembung (120201A3)", "Salmonella (/25 g)"],
  [1773, "Daun Sembung (120201A3)", "Jumlah Sampel - Salmonella"],
  [1774, "Daun Suji (120201A4)", "Salmonella (/25 g)"],
  [1775, "Daun Suji (120201A4)", "Jumlah Sampel - Salmonella"],
  [
    1776,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Salmonella (/25 g)",
  ],
  [
    1777,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Salmonella (/25 g)",
  ],
  [
    1778,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1779,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1780,
    "Degermed Maize (Corn) Grits (060311)",
    "Salmonella (/25 g)",
  ],
  [
    1781,
    "Degermed Maize (Corn) Grits (060311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1782,
    "Degermed Maize (Corn) Grits (060311)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1783,
    "Degermed Maize (Corn) Grits (060311)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1784,
    "Degermed Maize (Corn) Grits (060311)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1785,
    "Degermed Maize (Corn) Grits (060311)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1786,
    "Degermed Maize (Corn) Grits (060311)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1787,
    "Degermed Maize (Corn) Meal (060307)",
    "Salmonella (/25 g)",
  ],
  [
    1788,
    "Degermed Maize (Corn) Meal (060307)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1789,
    "Degermed Maize (Corn) Meal (060307)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1790,
    "Degermed Maize (Corn) Meal (060307)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1791,
    "Degermed Maize (Corn) Meal (060307)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1792,
    "Degermed Maize (Corn) Meal (060307)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1793,
    "Degermed Maize (Corn) Meal (060307)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1794,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Salmonella (/25 g)",
  ],
  [1795, "Dekstrin (06020206)", "Salmonella (/25 g)"],
  [1796, "Dekstrin (06020206)", "Jumlah Sampel - Salmonella"],
  [
    1797,
    "Dekstrin (06020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1798,
    "Dekstrin (06020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1799,
    "Dekstrin (06020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1800,
    "Dekstrin (06020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1801,
    "Dekstrin (06020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1802,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1803,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1804,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1805,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1806,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1807,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1808,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1809,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1810,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1811,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1812,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Salmonella (/25 g)",
  ],
  [
    1813,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Salmonella (/25 g)",
  ],
  [
    1814,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Jumlah - Salmonella",
  ],
  [
    1815,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Jumlah - Salmonella",
  ],
  [
    1816,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1817,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1818,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1819,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1820,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1821,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1822,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1823,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1824,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1825,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1826,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1827,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1828,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1829,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1830,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1831,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1832,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1833,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1834,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1835,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1836,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Salmonella (/25 g)",
  ],
  [
    1837,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Salmonella (/25 g)",
  ],
  [
    1838,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Salmonella (/25 g)",
  ],
  [
    1839,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Jumlah - Salmonella",
  ],
  [
    1840,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1841,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1842,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1843,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1844,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1845,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1846,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1847,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1848,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1849,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [1850, "Dendeng Ikan (09020528)", "Salmonella (/25 g)"],
  [
    1851,
    "Dendeng Ikan (09020528)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [1852, "Dill Weed (12020129)", "Salmonella (/25 g)"],
  [1853, "Dill Weed (12020129)", "Jumlah Sampel - Salmonella"],
  [
    1854,
    "Dimsum Ikan (0902040126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1855,
    "Dimsum Ikan (0902040126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1856,
    "Dimsum Ikan (0902040126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1857,
    "Dimsum Ikan (0902040126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1858,
    "Dimsum Ikan (0902040126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1859, "Dimsum Udang (0902040213)", "Salmonella (/25 g)"],
  [
    1860,
    "Dimsum Udang (0902040213)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1861,
    "Dimsum Udang (0902040213)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1862,
    "Dimsum Udang (0902040213)",
    "Jumlah Sampel -Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    1863,
    "Dimsum Udang (0902040213)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1864,
    "Dimsum Udang (0902040213)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1865,
    "Dimsum Udang (0902040213)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1866,
    "Dimsum Udang (0902040213)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1867,
    "Dimsum Udang (0902040213)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    1868,
    "Dodol atau Lempok Buah (0401021208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1869,
    "Dodol atau Lempok Buah (0401021208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1870,
    "Dodol atau Lempok Buah (0401021208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1871,
    "Dodol atau Lempok Buah (0401021208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1872,
    "Dodol atau Lempok Buah (0401021208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    1873,
    "Dodol atau Lempok Buah (0401021208)",
    "Salmonella (/25 g)",
  ],
  [
    1874,
    "Dodol atau Lempok Buah (0401021208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1875,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Salmonella (/25 g)",
  ],
  [
    1876,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    1877,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1878,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1879,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1880,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1881,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1882,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1883,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1884,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1885,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1886,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1887,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1888,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1889,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1890,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1891,
    "Dodol/Jenang/Gelamai (060701)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1892, "Dodol/Jenang/Gelamai (060701)", "Salmonella (/25 g)"],
  [1893, "Dodol/Jenang/Gelamai (060701)", "Salmonella (/25 g)"],
  [
    1894,
    "Dodol/Jenang/Gelamai (060701)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1895,
    "Dodol/Jenang/Gelamai (060701)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1896,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1897,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1898,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1899,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1900,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1901,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1902,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1903,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1904,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1905,
    "Dodol/Jenang/Gelamai (060701)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [1906, "Donat (07020205)", "Salmonella (/25 g)"],
  [1907, "Donat (07020205)", "Jumlah Sampel - Salmonella"],
  [
    1908,
    "Donat (07020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1909,
    "Donat (07020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1910,
    "Donat (07020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1911,
    "Donat (07020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1912,
    "Donat (07020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [1913, "Dou chi (06080601)", "Salmonella (/25 g)"],
  [1914, "Dou chi (06080601)", "Jumlah Sampel - Salmonella"],
  [1915, "Ebi Bubuk (09020529)", "Salmonella (/25 g)"],
  [
    1916,
    "Ebi Bubuk (09020529)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [1917, "Ebi Katsu (08030316)", "Salmonella (koloni/25 ml)"],
  [1918, "Ebi Katsu (08030316)", "Jumlah Sampel - Salmonella"],
  [
    1919,
    "Ebi Katsu (08030316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1920,
    "Ebi Katsu (08030316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1921,
    "Ebi Katsu (08030316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1922,
    "Ebi Katsu (08030316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1923,
    "Ebi Katsu (08030316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [1924, "Ebi Katsu (08030316)", "Listeria monocytogenes (/25 g)"],
  [
    1925,
    "Ebi Katsu (08030316)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [1926, "Egg Roll (07020126)", "Salmonella (/25 g)"],
  [1927, "Egg Roll (07020126)", "Jumlah Sampel - Salmonella"],
  [
    1928,
    "Egg Roll (07020126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1929,
    "Egg Roll (07020126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1930,
    "Egg Roll (07020126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1931,
    "Egg Roll (07020126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1932,
    "Egg Roll (07020126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    1933,
    "Ekado/ Moneybag (08030324)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    1934,
    "Ekado/ Moneybag (08030324)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1935,
    "Ekado/ Moneybag (08030324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1936,
    "Ekado/ Moneybag (08030324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1937,
    "Ekado/ Moneybag (08030324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1938,
    "Ekado/ Moneybag (08030324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1939,
    "Ekado/ Moneybag (08030324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    1940,
    "Ekado/ Moneybag (08030324)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    1941,
    "Ekado/ Moneybag (08030324)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    1942,
    "Eko Tukir (060730)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1943,
    "Eko Tukir (060730)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1944,
    "Eko Tukir (060730)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1945,
    "Eko Tukir (060730)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    1946,
    "Eko Tukir (060730)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [1947, "Eko Tukir (060730)", "Salmonella (/25 g)"],
  [1948, "Eko Tukir (060730)", "Jumlah Sampel - Salmonella"],
  [
    1949,
    "Eko Tukir (060730)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1950,
    "Eko Tukir (060730)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1951,
    "Eko Tukir (060730)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1952,
    "Eko Tukir (060730)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    1953,
    "Eko Tukir (060730)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [1954, "Ekstrak Aloe (0402020605)", "Salmonella (/25 g)"],
  [
    1955,
    "Ekstrak Aloe (0402020605)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1956,
    "Empek-Empek Palembang (0902040113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1957,
    "Empek-Empek Palembang (0902040113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1958,
    "Empek-Empek Palembang (0902040113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1959,
    "Empek-Empek Palembang (0902040113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    1960,
    "Empek-Empek Palembang (0902040113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [1961, "Emping Melinjo Goreng (150130)", "Salmonella (/25 g)"],
  [
    1962,
    "Emping Melinjo Goreng (150130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1963,
    "Emping Melinjo Goreng (150130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1964,
    "Emping Melinjo Goreng (150130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1965,
    "Emping Melinjo Goreng (150130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1966,
    "Emping Melinjo Goreng (150130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1967,
    "Emping Melinjo Goreng (150130)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    1968,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1969,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Salmonella (/25 g)",
  ],
  [
    1970,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1971,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1972,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1973,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1974,
    "Emulsi Lemak Tipe Emulsi Minyak dalam Air, termasuk Produk Campuran Emulsi Lemak dengan atau Berperisa (0203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1975,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Salmonella (/25 g)",
  ],
  [
    1976,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1977,
    "Es Batu Untuk Konsumsi (0316)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [1978, "Es Batu Untuk Konsumsi (0316)", "Salmonella (/25 ml)"],
  [
    1979,
    "Es Buah (Fruit Ice) (0302)",
    "Jumlah Sampel - Salmonella",
  ],
  [1980, "Es Buah (Fruit Ice) (0302)", "Salmonella (/25 ml)"],
  [
    1981,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    1982,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Salmonella (/25 ml)",
  ],
  [1983, "Es Krim (010701)", "Salmonella (/25 g)"],
  [1984, "Es Krim (010701)", "Jumlah Sampel - Salmonella"],
  [
    1985,
    "Es Krim (010701)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1986,
    "Es Krim (010701)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1987,
    "Es Krim (010701)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1988,
    "Es Krim (010701)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1989,
    "Es Krim (010701)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1990,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1991,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1992,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1993,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1994,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1995,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1996,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1997,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1998,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    1999,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2000,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2001,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2002,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2003,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2004,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2005,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2006,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2007,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2008,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2009,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2010,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2011,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2012,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2013,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2014,
    "Es Krim Modifikasi (010719)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2015,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Salmonella (/25 g)",
  ],
  [
    2016,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    2017,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2018,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2019,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2020,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2021,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [2022, "Es Kue (0308)", "Jumlah Sampel - Salmonella"],
  [2023, "Es Kue (0308)", "Salmonella (/25 ml)"],
  [2024, "Es Lilin (0307)", "Jumlah Sampel - Salmonella"],
  [2025, "Es Lilin (0307)", "Salmonella (/25 ml)"],
  [2026, "Es Lilin Goyang (0306)", "Jumlah Sampel - Salmonella"],
  [2027, "Es Lilin Goyang (0306)", "Salmonella (/25 ml)"],
  [2028, "Es Loli (0314)", "Jumlah Sampel - Salmonella"],
  [2029, "Es Loli (0314)", "Salmonella (/25 ml)"],
  [2030, "Es Mambo (0303)", "Jumlah Sampel - Salmonella"],
  [2031, "Es Mambo (0303)", "Salmonella (/25 ml)"],
  [2032, "Es Mengandung Susu (0320)", "Salmonella (/25ml)"],
  [
    2033,
    "Es Mengandung Susu (0320)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [2034, "Es Pelangi (0312)", "Jumlah Sampel - Salmonella"],
  [2035, "Es Pelangi (0312)", "Salmonella (/25 ml)"],
  [2036, "Es Puter (0305)", "Jumlah Sampel - Salmonella"],
  [2037, "Es Puter (0305)", "Salmonella (/25 ml)"],
  [
    2038,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2039,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Salmonella (/25 ml)",
  ],
  [2040, "Es Susu (010703)", "Salmonella (/25 g)"],
  [2041, "Es Susu (010703)", "Jumlah Sampel - Salmonella"],
  [2042, "Es Tebak (0313)", "Jumlah Sampel - Salmonella"],
  [2043, "Es Tebak (0313)", "Salmonella (/25 ml)"],
  [
    2044,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Salmonella (/25 g)",
  ],
  [
    2045,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2046,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2047,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2048,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2049,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2050,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2051,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2052,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2053,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2054,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2055,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2056,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Salmonella (/25 g)",
  ],
  [
    2057,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2058,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2059,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2060,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2061,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2062,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2063,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2064,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2065,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2066,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2067,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2068,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Salmonella (/25 g)",
  ],
  [
    2069,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Jumlah Sampel - Salmonella",
  ],
  [2070, "Fish Kasu-zuke (09030202)", "Salmonella (/25 g)"],
  [
    2071,
    "Fish Kasu-zuke (09030202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2072,
    "Fish Kasu-zuke (09030202)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2073,
    "Fish Kasu-zuke (09030202)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [2074, "Fish Koji-zuke (09030201)", "Salmonella (/25 g)"],
  [
    2075,
    "Fish Koji-zuke (09030201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2076,
    "Fish Koji-zuke (09030201)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2077,
    "Fish Koji-zuke (09030201)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [2078, "Fish Miso-zuke (09030203)", "Salmonella (/25 g)"],
  [
    2079,
    "Fish Miso-zuke (09030203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2080,
    "Fish Miso-zuke (09030203)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2081,
    "Fish Miso-zuke (09030203)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [2082, "Fish Shoyu-zuke (09030204)", "Salmonella (/25 g)"],
  [
    2083,
    "Fish Shoyu-zuke (09030204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2084,
    "Fish Shoyu-zuke (09030204)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2085,
    "Fish Shoyu-zuke (09030204)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [2086, "Fish Su-zuke (09030205)", "Salmonella (/25 g)"],
  [2087, "Fish Su-zuke (09030205)", "Jumlah Sampel - Salmonella"],
  [
    2088,
    "Fish Su-zuke (09030205)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2089,
    "Fish Su-zuke (09030205)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [2090, "Fish Tsukudani (09030104)", "Salmonella (/25 g)"],
  [
    2091,
    "Fish Tsukudani (09030104)",
    "Jumlah Sampel - Salmonella",
  ],
  [2092, "Foie Gras and Pates (08020227)", "Salmonella (/25 g)"],
  [2093, "Foie Gras and Pates (08020227)", "Salmonella (/25 g)"],
  [2094, "Foie Gras and Pates (08020227)", "Jumlah - Salmonella"],
  [
    2095,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2096,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2097,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2098,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2099,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2100,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2101,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2102,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2103,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2104,
    "Foie Gras and Pates (08020227)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2105,
    "Foie Gras and Pates (08020227)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2106,
    "Foie Gras and Pates (08020227)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2107,
    "Foie Gras and Pates (08020227)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2108,
    "Foie Gras and Pates (08020227)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2109,
    "Foie Gras and Pates (08020227)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2110,
    "Formula Bayi Bubuk (13010101)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2111,
    "Formula Bayi Bubuk (13010101)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2112,
    "Formula Bayi Bubuk (13010101)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2113,
    "Formula Bayi Bubuk (13010101)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2114,
    "Formula Bayi Bubuk (13010101)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2115,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2116,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2117,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2118,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2119,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2120,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2121,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2122,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2123,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2124,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2125,
    "Formula Bayi Bubuk (13010101)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2126,
    "Formula Bayi Bubuk (13010101)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2127,
    "Formula Bayi Bubuk (13010101)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2128,
    "Formula Bayi Bubuk (13010101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2129,
    "Formula Bayi Cair (1308)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2130,
    "Formula Bayi Cair (1308)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2131,
    "Formula Bayi Cair (1308)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2132,
    "Formula Bayi Cair (1308)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2133,
    "Formula Bayi Cair (1308)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2134,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2135,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2136,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2137,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2138,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2139,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2140,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2141,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2142,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2143,
    "Formula Bayi Cair (1308)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2144,
    "Formula Bayi Cair (1308)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2145,
    "Formula Bayi Cair (1308)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [2146, "Formula Bayi Cair (1308)", "Salmonella (koloni/25 g)"],
  [2147, "Formula Bayi Cair (1308)", "Jumlah Sampel - Salmonella"],
  [
    2148,
    "Formula Bayi Padat (1307)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2149,
    "Formula Bayi Padat (1307)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2150,
    "Formula Bayi Padat (1307)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2151,
    "Formula Bayi Padat (1307)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2152,
    "Formula Bayi Padat (1307)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2153,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2154,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2155,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2156,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2157,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2158,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2159,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2160,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2161,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2162,
    "Formula Bayi Padat (1307)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2163,
    "Formula Bayi Padat (1307)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2164,
    "Formula Bayi Padat (1307)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [2165, "Formula Bayi Padat (1307)", "Salmonella (koloni/25 g)"],
  [
    2166,
    "Formula Bayi Padat (1307)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2167,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2168,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2169,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2170,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2171,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2172,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2173,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2174,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2175,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2176,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2177,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2178,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2179,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2180,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2181,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2182,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2183,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2184,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2185,
    "Formula Kedelai untuk Bayi (Soy Protein Formulas) (130315)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2186,
    "Formula Lanjutan Bubuk (13010201)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2187,
    "Formula Lanjutan Bubuk (13010201)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2188,
    "Formula Lanjutan Bubuk (13010201)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2189,
    "Formula Lanjutan Bubuk (13010201)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2190,
    "Formula Lanjutan Bubuk (13010201)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2191,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2192,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2193,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2194,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2195,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2196,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2197,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2198,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2199,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2200,
    "Formula Lanjutan Bubuk (13010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2201,
    "Formula Lanjutan Bubuk (13010201)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2202,
    "Formula Lanjutan Bubuk (13010201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2203,
    "Formula Lanjutan Padat (1309)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2204,
    "Formula Lanjutan Padat (1309)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2205,
    "Formula Lanjutan Padat (1309)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2206,
    "Formula Lanjutan Padat (1309)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2207,
    "Formula Lanjutan Padat (1309)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2208,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2209,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2210,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2211,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2212,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2213,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2214,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2215,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2216,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2217,
    "Formula Lanjutan Padat (1309)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2218,
    "Formula Lanjutan Padat (1309)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2219,
    "Formula Lanjutan Padat (1309)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2220,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2221,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2222,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2223,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2224,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2225,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2226,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2227,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2228,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2229,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2230,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2231,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2232,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2233,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2234,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2235,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2236,
    "Formula Makanan Pelengkap (Formulated Supplementary Foods) (130504)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2237,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2238,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2239,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2240,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2241,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2242,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2243,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2244,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2245,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2246,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    2247,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2248,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2249,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2250,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2251,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2252,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2253,
    "Formula Makanan Pengganti (Formulated Meal Replacements) (130503)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2254,
    "Formula Pertumbuhan Bubuk (13010401)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2255,
    "Formula Pertumbuhan Bubuk (13010401)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2256,
    "Formula Pertumbuhan Bubuk (13010401)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2257,
    "Formula Pertumbuhan Bubuk (13010401)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2258,
    "Formula Pertumbuhan Bubuk (13010401)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2259,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2260,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2261,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2262,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2263,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2264,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2265,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2266,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2267,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2268,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2269,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2270,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2271,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2272,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2273,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2274,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2275,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2276,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2277,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2278,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2279,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2280,
    "Formula Pertumbuhan Padat (1311)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2281,
    "Formula Pertumbuhan Padat (1311)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2282,
    "Formula Pertumbuhan Padat (1311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2283,
    "Formula Pertumbuhan Padat (1311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2284,
    "Formula Pertumbuhan Padat (1311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2285,
    "Formula Pertumbuhan Padat (1311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2286,
    "Formula Pertumbuhan Padat (1311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2287,
    "Formula Pertumbuhan Padat (1311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2288,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2289,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2290,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2291,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2292,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2293,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2294,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2295,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2296,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2297,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2298,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2299,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2300,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2301,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2302,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2303,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2304,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2305,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2306,
    "Formula Standar Berbasis Susu Sapi (Standard Milk-Based Formulas) (1301010103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2307,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2308,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2309,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2310,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2311,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2312,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2313,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2314,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2315,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2316,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2317,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2318,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2319,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2320,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2321,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2322,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2323,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2324,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2325,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2326,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2327,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2328,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2329,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2330,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2331,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2332,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2333,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2334,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2335,
    "Formula untuk Bayi Berat Badan Lahir Rendah (130317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2336,
    "Formula untuk Bayi Prematur (13010301)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2337,
    "Formula untuk Bayi Prematur (13010301)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2338,
    "Formula untuk Bayi Prematur (13010301)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2339,
    "Formula untuk Bayi Prematur (13010301)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2340,
    "Formula untuk Bayi Prematur (13010301)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2341,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2342,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2343,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2344,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2345,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2346,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2347,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2348,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2349,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2350,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2351,
    "Formula untuk Bayi Prematur (13010301)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2352,
    "Formula untuk Bayi Prematur (13010301)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2353,
    "Formula untuk Bayi Prematur (13010301)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2354,
    "Formula untuk Bayi Prematur (13010301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2355,
    "Formula untuk Bayi Prematur (13010301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2356,
    "Formula untuk Bayi Prematur (13010301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2357,
    "Formula untuk Bayi Prematur (13010301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2358,
    "Formula untuk Bayi Prematur (13010301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2359,
    "Formula untuk Bayi Prematur (13010301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2360,
    "Formula untuk Bayi Prematur (13010301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2361,
    "Formula untuk Bayi Prematur (13010301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2362,
    "Formula untuk Bayi Prematur (13010301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2363,
    "Formula untuk Bayi Prematur (13010301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2364,
    "Formula untuk Bayi Prematur (13010301)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2365,
    "Formula untuk Bayi Prematur (130316)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2366,
    "Formula untuk Bayi Prematur (130316)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2367,
    "Formula untuk Bayi Prematur (130316)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2368,
    "Formula untuk Bayi Prematur (130316)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2369,
    "Formula untuk Bayi Prematur (130316)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2370,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2371,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2372,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2373,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2374,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2375,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2376,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2377,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2378,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2379,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2380,
    "Formula untuk Bayi Prematur (130316)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2381,
    "Formula untuk Bayi Prematur (130316)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2382,
    "Formula untuk Bayi Prematur (130316)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2383,
    "Formula untuk Bayi Prematur (130316)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2384,
    "Formula untuk Bayi Prematur (130316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2385,
    "Formula untuk Bayi Prematur (130316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2386,
    "Formula untuk Bayi Prematur (130316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2387,
    "Formula untuk Bayi Prematur (130316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2388,
    "Formula untuk Bayi Prematur (130316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2389,
    "Formula untuk Bayi Prematur (130316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2390,
    "Formula untuk Bayi Prematur (130316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2391,
    "Formula untuk Bayi Prematur (130316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2392,
    "Formula untuk Bayi Prematur (130316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2393,
    "Formula untuk Bayi Prematur (130316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2394,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2395,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2396,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2397,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2398,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2399,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2400,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2401,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2402,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2403,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2404,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2405,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2406,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2407,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2408,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2409,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2410,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2411,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2412,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2413,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2414,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2415,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2416,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2417,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2418,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2419,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2420,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2421,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2422,
    "Formula Untuk Keperluan Medis Khusus bagi Bayi (130103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2423,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2424,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2425,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2426,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2427,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2428,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2429,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2430,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2431,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2432,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2433,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2434,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2435,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2436,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2437,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2438,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2439,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2440,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2441,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2442,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2443,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2444,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2445,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2446,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2447,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2448,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2449,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2450,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2451,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2452,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2453,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2454,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2455,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2456,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2457,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2458,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2459,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2460,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2461,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2462,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2463,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2464,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2465,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2466,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2467,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2468,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2469,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2470,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2471,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2472,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2473,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2474,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2475,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2476,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2477,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2478,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2479,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2480,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2481,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2482,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2483,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2484,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2485,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2486,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2487,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2488,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2489,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2490,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2491,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2492,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2493,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2494,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2495,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2496,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2497,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2498,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2499,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2500,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2501,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2502,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2503,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2504,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2505,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2506,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2507,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2508,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2509,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2510,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2511,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2512,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2513,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2514,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2515,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2516,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2517,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2518,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2519,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2520,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2521,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2522,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2523,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2524,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2525,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2526,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2527,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2528,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2529,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2530,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2531,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2532,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2533,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2534,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2535,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2536,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2537,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2538,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2539,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2540,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2541,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2542,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2543,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2544,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2545,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2546,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2547,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2548,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2549,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2550,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2551,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2552,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2553,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2554,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2555,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2556,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2557,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2558,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2559,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2560,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2561,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2562,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2563,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2564,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2565,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2566,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2567,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2568,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2569,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2570,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2571,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2572,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2573,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2574,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2575,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2576,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2577,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2578,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2579,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2580,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2581,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2582,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2583,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2584,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2585,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2586,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2587,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2588,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2589,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2590,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2591,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2592,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2593,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2594,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2595,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2596,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2597,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2598,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2599,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2600,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2601,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2602,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2603,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2604,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2605,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2606,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2607,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2608,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2609,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2610,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2611,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2612,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2613,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2614,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2615,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2616,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2617,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2618,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2619,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2620,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2621,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2622,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2623,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2624,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2625,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2626,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2627,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2628,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2629,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2630,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2631,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2632,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2633,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2634,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2635,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2636,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2637,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2638,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2639,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2640,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2641,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2642,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2643,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2644,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2645,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2646,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2647,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2648,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2649,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2650,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2651,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2652,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2653,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2654,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2655,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2656,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2657,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2658,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2659,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2660,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2661,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2662,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2663,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2664,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2665,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2666,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2667,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2668,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2669,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2670,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2671,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2672,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2673,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2674,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2675,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2676,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2677,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2678,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2679,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2680,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2681,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2682,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2683,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2684,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2685,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2686,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2687,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2688,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2689,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2690,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2691,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2692,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2693,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2694,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2695,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2696,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2697,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2698,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2699,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2700,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [2701, "French Dressing (12060104)", "Salmonella (/25 g)"],
  [
    2702,
    "French Dressing (12060104)",
    "Jumlah Sampel - Salmonella",
  ],
  [2703, "Frosting (050402)", "Salmonella (/25 g)"],
  [2704, "Frosting (050402)", "Jumlah Sampel - Salmonella"],
  [2705, "Fudge (05020203)", "Salmonella (Kembang"],
  [2706, "Gula/Permen"],
  [2707, "Lunak (bukan jeli)"],
  [2708, ") (/25 g)"],
  [2709, "Fudge (05020203)", "Jumlah Sampel - Salmonella"],
  [2710, "Fudge (05020203)", "Jumlah Sampel - Salmonella"],
  [
    2711,
    "Fudge (05020203)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [2712, "Fuli Bubuk (12020136)", "Salmonella (/25 g)"],
  [2713, "Fuli Bubuk (12020136)", "Jumlah Sampel - Salmonella"],
  [
    2714,
    "Fuli Bubuk (12020136)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2715,
    "Fuli Bubuk (12020136)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2716,
    "Fuli Bubuk (12020136)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2717,
    "Fuli Bubuk (12020136)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2718,
    "Fuli Bubuk (12020136)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2719,
    "Fuli Bubuk (12020136)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2720,
    "Fuli Bubuk (12020136)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2721,
    "Fuli Bubuk (12020136)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2722,
    "Fuli Bubuk (12020136)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2723,
    "Fuli Bubuk (12020136)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2724, "Fuli Kering (12020135)", "Salmonella (/25 g)"],
  [2725, "Fuli Kering (12020135)", "Jumlah Sampel - Salmonella"],
  [
    2726,
    "Fuli Kering (12020135)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2727,
    "Fuli Kering (12020135)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2728,
    "Fuli Kering (12020135)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2729,
    "Fuli Kering (12020135)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2730,
    "Fuli Kering (12020135)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2731,
    "Fuli Kering (12020135)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2732,
    "Fuli Kering (12020135)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2733,
    "Fuli Kering (12020135)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2734,
    "Fuli Kering (12020135)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2735,
    "Fuli Kering (12020135)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2736, "Furikake (12020206)", "Salmonella (/25 g)"],
  [2737, "Furikake (12020206)", "Jumlah Sampel - Salmonella"],
  [
    2738,
    "Furikake (12020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2739,
    "Furikake (12020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2740,
    "Furikake (12020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2741,
    "Furikake (12020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2742,
    "Furikake (12020206)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2743,
    "Furikake (12020206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2744,
    "Furikake (12020206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2745,
    "Furikake (12020206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2746,
    "Furikake (12020206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2747,
    "Furikake (12020206)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2748, "Gari (060312)", "Salmonella (/25 g)"],
  [2749, "Gari (060312)", "Jumlah Sampel - Salmonella"],
  [
    2750,
    "Gari (060312)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2751,
    "Gari (060312)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2752,
    "Gari (060312)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2753,
    "Gari (060312)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2754,
    "Gari (060312)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2755,
    "Geplak (0401021210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2756,
    "Geplak (0401021210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2757,
    "Geplak (0401021210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2758,
    "Geplak (0401021210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2759,
    "Geplak (0401021210)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [2760, "Geplak (0401021210)", "Salmonella (/25 g)"],
  [2761, "Geplak (0401021210)", "Jumlah Sampel - Salmonella"],
  [2762, "Getas (150307)", "Salmonella (/25 g)"],
  [2763, "Getas (150307)", "Jumlah Sampel - Salmonella"],
  [
    2764,
    "Getas (150307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2765,
    "Getas (150307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2766,
    "Getas (150307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2767,
    "Getas (150307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2768,
    "Getas (150307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [2769, "Getuk Singkong (0402020803)", "Salmonella (/25 g)"],
  [
    2770,
    "Getuk Singkong (0402020803)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2771,
    "Getuk Singkong (0402020803)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2772,
    "Getuk Singkong (0402020803)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2773,
    "Getuk Singkong (0402020803)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2774,
    "Getuk Singkong (0402020803)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2775,
    "Getuk Singkong (0402020803)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [2776, "Gochujang (0402020709)", "Salmonella (/25 g)"],
  [2777, "Gochujang (0402020709)", "Jumlah Sampel - Salmonella"],
  [2778, "Granola (060317)", "Salmonella (/25 g)"],
  [
    2779,
    "Granola (060317)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    2780,
    "Granola (060317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2781,
    "Granola (060317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2782,
    "Granola (060317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2783,
    "Granola (060317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2784,
    "Granola (060317)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [2785, "Gudeg (Yogya) (1602)", "Salmonella (koloni/25 g)"],
  [
    2786,
    "Gudeg (Yogya) (1602)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [2787, "Gudeg (Yogya) (1602)", "Listeria"],
  [2788, "monocytogenes (koloni/25 g)"],
  [2789, "Gudeg (Yogya) (1602)", "Jumlah Sampel - Listeria"],
  [2790, "monocytogenes", "", "\x{2265}5"],
  [2791, "Gudeg (Yogya) (1602)", "Staphylococcus"],
  [2792, "aureus (koloni/g)", "\x{2264}200", "\x{2264}100"],
  [2793, "Gudeg (Yogya) (1602)", "Staphylococcus"],
  [2794, "aureus (koloni/g)", "\x{2264}200", "\x{2264}100"],
  [2795, "Gudeg (Yogya) (1602)", "Staphylococcus"],
  [2796, "aureus (koloni/g)", "\x{2264}200", "\x{2264}100"],
  [2797, "Gudeg (Yogya) (1602)", "Staphylococcus"],
  [2798, "aureus (koloni/g)", "\x{2264}200", "\x{2264}100"],
  [2799, "Gudeg (Yogya) (1602)", "Staphylococcus"],
  [2800, "aureus (koloni/g)", "\x{2264}200", "\x{2264}100"],
  [
    2801,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Salmonella (/25 g)",
  ],
  [
    2802,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Jumlah Sampel - Salmonella",
  ],
  [2803, "Gulali (05020213)", "Salmonella (/25 g)"],
  [2804, "Gulali (05020213)", "Jumlah Sampel - Salmonella"],
  [2805, "Gyoza (08030304)", "Salmonella (/25 g)"],
  [
    2806,
    "Gyoza (08030304)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}5",
  ],
  [
    2807,
    "Gyoza (08030304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2808,
    "Gyoza (08030304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2809,
    "Gyoza (08030304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2810,
    "Gyoza (08030304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2811,
    "Gyoza (08030304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [2812, "Gyoza (08030304)", "Listeria monocytogenes (/25 g)"],
  [
    2813,
    "Gyoza (08030304)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [2814, "Half and Half (01040102)", "Salmonella (/25 ml)"],
  [2815, "Half and Half (01040102)", "Jumlah Sampel - Salmonella"],
  [
    2816,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2817,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2818,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2819,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2820,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2821,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Salmonella (/25 g)",
  ],
  [
    2822,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2823,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2824,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2825,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2826,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2827,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    2828,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Salmonella (/25 g)",
  ],
  [
    2829,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2830,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2831,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Salmonella (/25 g)",
  ],
  [
    2832,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2833,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2834,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2835,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    2836,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [2837, "Herba (12020101)", "Salmonella (/25 g)"],
  [2838, "Herba (12020101)", "Jumlah Sampel - Salmonella"],
  [
    2839,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Salmonella (/25 g)-Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [2840, ""],
  [
    2841,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Jumlah Sampel-Salmonella-Semua Herba Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    2842,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Salmonella (/25 g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    2843,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Jumlah Sampel - Salmonella-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
  ],
  [
    2844,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Bacillus cereus (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2845,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Bacillus cereus (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2846,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Bacillus cereus (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2847,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Bacillus cereus (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2848,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Bacillus cereus (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2849,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Clostridium pefringens (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2850,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Clostridium pefringens (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2851,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Clostridium pefringens (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2852,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Clostridium pefringens (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2853,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Clostridium pefringens (koloni/g)-Rempah Kering (Termasuk Bentuk Utuh dan Bubuk)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2854, "Huajuan (07010507)", "Salmonella (/25 g)"],
  [2855, "Huajuan (07010507)", "Jumlah Sampel - Salmonella"],
  [
    2856,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2857,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2858,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2859,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2860,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    2861,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2862,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2863,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2864,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2865,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2866,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2867,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2868,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2869,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2870,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    2871,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    2872,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    2873,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Salmonella (koloni/25 g)",
  ],
  [
    2874,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2875,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2876,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2877,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2878,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2879,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    2880,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2881,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2882,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2883,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    2884,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [2885, "Icing (050401)", "Salmonella (/25 g)"],
  [2886, "Icing (050401)", "Jumlah Sampel - Salmonella"],
  [2887, "Ikan Asap (09020501)", "Salmonella (/25 g)"],
  [2888, "Ikan Asap (09020501)", "Jumlah Sampel - Salmonella"],
  [2889, "Ikan Asin Jambal Roti (09020530)", "Salmonella (/25 g)"],
  [
    2890,
    "Ikan Asin Jambal Roti (09020530)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [2891, "Ikan Asin Kering (09020503)", "Salmonella (/25 g)"],
  [
    2892,
    "Ikan Asin Kering (09020503)",
    "Jumlah Sampel - Salmonella",
  ],
  [2893, "Ikan Dalam Kemasan (090418)", "Salmonella (/25 g)"],
  [
    2894,
    "Ikan Dalam Kemasan (090418)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    2895,
    "Ikan Dalam Kemasan (090418)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2896,
    "Ikan Dalam Kemasan (090418)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    2897,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2898,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2899,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2900,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2901,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [2902, "Ikan Kayu (09020502)", "Salmonella (/25 g)"],
  [2903, "Ikan Kayu (09020502)", "Jumlah Sampel - Salmonella"],
  [2904, "Ikan Kering (09020524)", "Salmonella (/25 g)"],
  [2905, "Ikan Kering (09020524)", "Jumlah Sampel - Salmonella"],
  [
    2906,
    "Ikan Panggang (0902040305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2907,
    "Ikan Panggang (0902040305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2908,
    "Ikan Panggang (0902040305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2909,
    "Ikan Panggang (0902040305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2910,
    "Ikan Panggang (0902040305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [2911, "Ikan Peda (09020531)", "Salmonella (/25 g)"],
  [
    2912,
    "Ikan Peda (09020531)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    2913,
    "Ikan Pindang (0902040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2914,
    "Ikan Pindang (0902040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2915,
    "Ikan Pindang (0902040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2916,
    "Ikan Pindang (0902040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2917,
    "Ikan Pindang (0902040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2918,
    "Ikan Pindang Air Garam (0902040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2919,
    "Ikan Pindang Air Garam (0902040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2920,
    "Ikan Pindang Air Garam (0902040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2921,
    "Ikan Pindang Air Garam (0902040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2922,
    "Ikan Pindang Air Garam (0902040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2923,
    "Ikan Pindang Garam (0902040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2924,
    "Ikan Pindang Garam (0902040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2925,
    "Ikan Pindang Garam (0902040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2926,
    "Ikan Pindang Garam (0902040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2927,
    "Ikan Pindang Garam (0902040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2928,
    "Ikan Renyah (0902040314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2929,
    "Ikan Renyah (0902040314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2930,
    "Ikan Renyah (0902040314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2931,
    "Ikan Renyah (0902040314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2932,
    "Ikan Renyah (0902040314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [2933, "Ikan Teri Asin Kering (09020504)", "Salmonella (/25 g)"],
  [
    2934,
    "Ikan Teri Asin Kering (09020504)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2935,
    "Ikan Teri Nasi Setengah Kering (09020505)",
    "Salmonella (/25 g)",
  ],
  [
    2936,
    "Ikan Teri Nasi Setengah Kering (09020505)",
    "Jumlah Sampel - Salmonella",
  ],
  [2937, "Ikura (09030307)", "Salmonella (/25 g)"],
  [2938, "Ikura (09030307)", "Jumlah Sampel - Salmonella"],
  [
    2939,
    "Ikura (09030307)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    2940,
    "Ikura (09030307)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    2941,
    "Ikura (09030307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2942,
    "Ikura (09030307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2943,
    "Ikura (09030307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2944,
    "Ikura (09030307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2945,
    "Ikura (09030307)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    2946,
    "Jadah Manten (060721)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2947,
    "Jadah Manten (060721)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2948,
    "Jadah Manten (060721)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2949,
    "Jadah Manten (060721)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2950,
    "Jadah Manten (060721)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2951, "Jadah Manten (060721)", "Salmonella (/25 g)"],
  [2952, "Jadah Manten (060721)", "Jumlah Sampel - Salmonella"],
  [
    2953,
    "Jadah Manten (060721)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2954,
    "Jadah Manten (060721)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2955,
    "Jadah Manten (060721)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2956,
    "Jadah Manten (060721)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    2957,
    "Jadah Manten (060721)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [2958, "Jagung Berondong (150119)", "Salmonella (/25 g)"],
  [
    2959,
    "Jagung Berondong (150119)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2960,
    "Jagung Berondong (150119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2961,
    "Jagung Berondong (150119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2962,
    "Jagung Berondong (150119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2963,
    "Jagung Berondong (150119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2964,
    "Jagung Berondong (150119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2965,
    "Jagung Bertongkol Beku (0402020110)",
    "Salmonella (/25 g)",
  ],
  [
    2966,
    "Jagung Bertongkol Beku (0402020110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    2967,
    "Jagung Bertongkol Beku (0402020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    2968,
    "Jagung Bertongkol Beku (0402020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    2969,
    "Jagung Bertongkol Beku (0402020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    2970,
    "Jagung Bertongkol Beku (0402020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    2971,
    "Jagung Bertongkol Beku (0402020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [2972, "Jagung Marning (150120)", "Salmonella (/25 g)"],
  [2973, "Jagung Marning (150120)", "Jumlah Sampel - Salmonella"],
  [
    2974,
    "Jagung Marning (150120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2975,
    "Jagung Marning (150120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2976,
    "Jagung Marning (150120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2977,
    "Jagung Marning (150120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    2978,
    "Jagung Marning (150120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [2979, "Jahe Bubuk (12020140)", "Salmonella (/25 g)"],
  [2980, "Jahe Bubuk (12020140)", "Jumlah Sampel - Salmonella"],
  [
    2981,
    "Jahe Bubuk (12020140)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2982,
    "Jahe Bubuk (12020140)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2983,
    "Jahe Bubuk (12020140)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2984,
    "Jahe Bubuk (12020140)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2985,
    "Jahe Bubuk (12020140)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2986,
    "Jahe Bubuk (12020140)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2987,
    "Jahe Bubuk (12020140)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2988,
    "Jahe Bubuk (12020140)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2989,
    "Jahe Bubuk (12020140)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2990,
    "Jahe Bubuk (12020140)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [2991, "Jahe Kering (12020138)", "Salmonella (/25 g)"],
  [2992, "Jahe Kering (12020138)", "Jumlah Sampel - Salmonella"],
  [
    2993,
    "Jahe Kering (12020138)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2994,
    "Jahe Kering (12020138)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2995,
    "Jahe Kering (12020138)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2996,
    "Jahe Kering (12020138)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2997,
    "Jahe Kering (12020138)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    2998,
    "Jahe Kering (12020138)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    2999,
    "Jahe Kering (12020138)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3000,
    "Jahe Kering (12020138)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3001,
    "Jahe Kering (12020138)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3002,
    "Jahe Kering (12020138)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3003, "Jahe Kristalisasi (0402020609)", "Salmonella (/25 g)"],
  [
    3004,
    "Jahe Kristalisasi (0402020609)",
    "Jumlah Sampel - Salmonella",
  ],
  [3005, "Jahe Segar (12020137)", "Salmonella (/25 g)"],
  [3006, "Jahe Segar (12020137)", "Jumlah Sampel - Salmonella"],
  [
    3007,
    "Jahe Segar (12020137)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3008,
    "Jahe Segar (12020137)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3009,
    "Jahe Segar (12020137)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3010,
    "Jahe Segar (12020137)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3011,
    "Jahe Segar (12020137)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3012,
    "Jahe Segar (12020137)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3013,
    "Jahe Segar (12020137)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3014,
    "Jahe Segar (12020137)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3015,
    "Jahe Segar (12020137)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3016,
    "Jahe Segar (12020137)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3017, "Jamur Asin (0402020303)", "Salmonella (/25 g)"],
  [3018, "Jamur Asin (0402020303)", "Jumlah Sampel - Salmonella"],
  [3019, "Jamur Beku (0402020108)", "Salmonella (/25 g)"],
  [3020, "Jamur Beku (0402020108)", "Jumlah Sampel - Salmonella"],
  [
    3021,
    "Jamur Beku (0402020108)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3022,
    "Jamur Beku (0402020108)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3023,
    "Jamur Beku (0402020108)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3024,
    "Jamur Beku (0402020108)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3025,
    "Jamur Beku (0402020108)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3026,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Salmonella (/25 g)",
  ],
  [
    3027,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Jumlah Sampel - Salmonella",
  ],
  [3028, "Jamur Fermentasi (0402020704)", "Salmonella (/25 g)"],
  [
    3029,
    "Jamur Fermentasi (0402020704)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3030,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Salmonella (/25 g)",
  ],
  [
    3031,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Jumlah Sampel - Salmonella",
  ],
  [3032, "Jintan Bubuk (12020142)", "Salmonella (/25 g)"],
  [3033, "Jintan Bubuk (12020142)", "Jumlah Sampel - Salmonella"],
  [
    3034,
    "Jintan Bubuk (12020142)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3035,
    "Jintan Bubuk (12020142)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3036,
    "Jintan Bubuk (12020142)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3037,
    "Jintan Bubuk (12020142)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3038,
    "Jintan Bubuk (12020142)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3039,
    "Jintan Bubuk (12020142)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3040,
    "Jintan Bubuk (12020142)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3041,
    "Jintan Bubuk (12020142)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3042,
    "Jintan Bubuk (12020142)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3043,
    "Jintan Bubuk (12020142)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3044, "Jintan Hitam (12020144)", "Salmonella (/25 g)"],
  [3045, "Jintan Hitam (12020144)", "Jumlah Sampel - Salmonella"],
  [
    3046,
    "Jintan Hitam (12020144)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3047,
    "Jintan Hitam (12020144)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3048,
    "Jintan Hitam (12020144)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3049,
    "Jintan Hitam (12020144)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3050,
    "Jintan Hitam (12020144)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3051,
    "Jintan Hitam (12020144)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3052,
    "Jintan Hitam (12020144)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3053,
    "Jintan Hitam (12020144)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3054,
    "Jintan Hitam (12020144)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3055,
    "Jintan Hitam (12020144)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3056, "Jintan Hitam Bubuk (12020145)", "Salmonella (/25 g)"],
  [
    3057,
    "Jintan Hitam Bubuk (12020145)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3058,
    "Jintan Hitam Bubuk (12020145)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3059,
    "Jintan Hitam Bubuk (12020145)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3060,
    "Jintan Hitam Bubuk (12020145)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3061,
    "Jintan Hitam Bubuk (12020145)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3062,
    "Jintan Hitam Bubuk (12020145)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3063,
    "Jintan Hitam Bubuk (12020145)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3064,
    "Jintan Hitam Bubuk (12020145)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3065,
    "Jintan Hitam Bubuk (12020145)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3066,
    "Jintan Hitam Bubuk (12020145)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3067,
    "Jintan Hitam Bubuk (12020145)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3068, "Jintan Manis (12020143)", "Salmonella (/25 g)"],
  [3069, "Jintan Manis (12020143)", "Jumlah Sampel - Salmonella"],
  [
    3070,
    "Jintan Manis (12020143)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3071,
    "Jintan Manis (12020143)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3072,
    "Jintan Manis (12020143)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3073,
    "Jintan Manis (12020143)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3074,
    "Jintan Manis (12020143)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3075,
    "Jintan Manis (12020143)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3076,
    "Jintan Manis (12020143)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3077,
    "Jintan Manis (12020143)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3078,
    "Jintan Manis (12020143)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3079,
    "Jintan Manis (12020143)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3080, "Jintan Putih Bubuk (12020147)", "Salmonella (/25 g)"],
  [
    3081,
    "Jintan Putih Bubuk (12020147)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3082,
    "Jintan Putih Bubuk (12020147)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3083,
    "Jintan Putih Bubuk (12020147)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3084,
    "Jintan Putih Bubuk (12020147)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3085,
    "Jintan Putih Bubuk (12020147)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3086,
    "Jintan Putih Bubuk (12020147)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3087,
    "Jintan Putih Bubuk (12020147)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3088,
    "Jintan Putih Bubuk (12020147)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3089,
    "Jintan Putih Bubuk (12020147)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3090,
    "Jintan Putih Bubuk (12020147)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3091,
    "Jintan Putih Bubuk (12020147)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3092, "Jintan Putih, Cumin (12020146)", "Salmonella (/25 g)"],
  [
    3093,
    "Jintan Putih, Cumin (12020146)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3094,
    "Jintan Putih, Cumin (12020146)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3095,
    "Jintan Putih, Cumin (12020146)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3096,
    "Jintan Putih, Cumin (12020146)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3097,
    "Jintan Putih, Cumin (12020146)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3098,
    "Jintan Putih, Cumin (12020146)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3099,
    "Jintan Putih, Cumin (12020146)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3100,
    "Jintan Putih, Cumin (12020146)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3101,
    "Jintan Putih, Cumin (12020146)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3102,
    "Jintan Putih, Cumin (12020146)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3103,
    "Jintan Putih, Cumin (12020146)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3104, "Jintan/Caraway (12020141)", "Salmonella (/25 g)"],
  [
    3105,
    "Jintan/Caraway (12020141)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3106,
    "Jintan/Caraway (12020141)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3107,
    "Jintan/Caraway (12020141)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3108,
    "Jintan/Caraway (12020141)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3109,
    "Jintan/Caraway (12020141)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3110,
    "Jintan/Caraway (12020141)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3111,
    "Jintan/Caraway (12020141)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3112,
    "Jintan/Caraway (12020141)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3113,
    "Jintan/Caraway (12020141)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3114,
    "Jintan/Caraway (12020141)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3115,
    "Jintan/Caraway (12020141)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3116, "Jipang Beras (150122 )", "Salmonella (/25 g)"],
  [3117, "Jipang Beras (150122 )", "Jumlah Sampel - Salmonella"],
  [
    3118,
    "Jipang Beras (150122 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3119,
    "Jipang Beras (150122 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3120,
    "Jipang Beras (150122 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3121,
    "Jipang Beras (150122 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3122,
    "Jipang Beras (150122 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3123,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Salmonella (/25 g)",
  ],
  [
    3124,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3125,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3126,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3127,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3128,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3129,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [3130, "Jipang Jagung (150121)", "Salmonella (/25 g)"],
  [3131, "Jipang Jagung (150121)", "Jumlah Sampel - Salmonella"],
  [
    3132,
    "Jipang Jagung (150121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3133,
    "Jipang Jagung (150121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3134,
    "Jipang Jagung (150121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3135,
    "Jipang Jagung (150121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3136,
    "Jipang Jagung (150121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [3137, "Jipang/Kipang Kacang (150210)", "Salmonella (/25 g)"],
  [
    3138,
    "Jipang/Kipang Kacang (150210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3139,
    "Jongkong Kelapa Muda (060710)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3140,
    "Jongkong Kelapa Muda (060710)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3141,
    "Jongkong Kelapa Muda (060710)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3142,
    "Jongkong Kelapa Muda (060710)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3143,
    "Jongkong Kelapa Muda (060710)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3144, "Jongkong Kelapa Muda (060710)", "Salmonella (/25 g)"],
  [
    3145,
    "Jongkong Kelapa Muda (060710)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3146,
    "Jongkong Kelapa Muda (060710)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3147,
    "Jongkong Kelapa Muda (060710)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3148,
    "Jongkong Kelapa Muda (060710)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3149,
    "Jongkong Kelapa Muda (060710)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3150,
    "Jongkong Kelapa Muda (060710)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3151,
    "Juadah Kering/Mayang Papan (060713)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3152,
    "Juadah Kering/Mayang Papan (060713)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3153,
    "Juadah Kering/Mayang Papan (060713)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3154,
    "Juadah Kering/Mayang Papan (060713)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3155,
    "Juadah Kering/Mayang Papan (060713)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3156,
    "Juadah Kering/Mayang Papan (060713)",
    "Salmonella (/25 g)",
  ],
  [
    3157,
    "Juadah Kering/Mayang Papan (060713)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3158,
    "Juadah Kering/Mayang Papan (060713)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3159,
    "Juadah Kering/Mayang Papan (060713)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3160,
    "Juadah Kering/Mayang Papan (060713)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3161,
    "Juadah Kering/Mayang Papan (060713)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3162,
    "Juadah Kering/Mayang Papan (060713)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3163,
    "Junior Food Mi (130207)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3164,
    "Junior Food Mi (130207)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3165,
    "Junior Food Mi (130207)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3166,
    "Junior Food Mi (130207)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3167,
    "Junior Food Mi (130207)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3168,
    "Junior Food Mi (130207)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    3169,
    "Junior Food Mi (130207)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    3170,
    "Junior Food Mi (130207)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    3171,
    "Junior Food Mi (130207)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    3172,
    "Junior Food Mi (130207)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [3173, "Junior Food Mi (130207)", "Salmonella (koloni/25 g)"],
  [3174, "Junior Food Mi (130207)", "Jumlah Sampel - Salmonella"],
  [
    3175,
    "Junior Food Mi (130207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    3176,
    "Junior Food Mi (130207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    3177,
    "Junior Food Mi (130207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    3178,
    "Junior Food Mi (130207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    3179,
    "Junior Food Mi (130207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [3180, "Kacang Atom Lainnya (150216)", "Salmonella (/25 g)"],
  [
    3181,
    "Kacang Atom Lainnya (150216)",
    "Jumlah Sampel - Salmonella",
  ],
  [3182, "Kacang Atom/Sukro (150207 )", "Salmonella (/25 g)"],
  [
    3183,
    "Kacang Atom/Sukro (150207 )",
    "Jumlah Sampel - Salmonella",
  ],
  [3184, "Kacang Bali (150203)", "Salmonella (/25 g)"],
  [3185, "Kacang Bali (150203)", "Jumlah Sampel - Salmonella"],
  [
    3186,
    "Kacang Bawang / Kacang Tojin (150202)",
    "Salmonella (/25 g)",
  ],
  [
    3187,
    "Kacang Bawang / Kacang Tojin (150202)",
    "Jumlah Sampel - Salmonella",
  ],
  [3188, "Kacang Bersalut (150220)", "Salmonella (/25 g)"],
  [
    3189,
    "Kacang Bersalut (150220)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3190, "Kacang Bogor (150213 )", "Salmonella (/25 g)"],
  [3191, "Kacang Bogor (150213 )", "Jumlah Sampel - Salmonella"],
  [
    3192,
    "Kacang Garing/Kacang Kulit (150201 )",
    "Salmonella (/25 g)",
  ],
  [
    3193,
    "Kacang Garing/Kacang Kulit (150201 )",
    "Jumlah Sampel - Salmonella",
  ],
  [3194, "Kacang Goreng (150221)", "Salmonella (/25 g)"],
  [
    3195,
    "Kacang Goreng (150221)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3196, "Kacang Goreng Lainnya (150218)", "Salmonella (/25 g)"],
  [
    3197,
    "Kacang Goreng Lainnya (150218)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3198, "Kacang Goyang (150209)", "Salmonella (/25 g)"],
  [3199, "Kacang Goyang (150209)", "Jumlah Sampel - Salmonella"],
  [3200, "Kacang Kapri (150211 )", "Salmonella (/25 g)"],
  [3201, "Kacang Kapri (150211 )", "Jumlah Sampel - Salmonella"],
  [3202, "Kacang Kapri Beku (0402020103)", "Salmonella (/25 g)"],
  [
    3203,
    "Kacang Kapri Beku (0402020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3204,
    "Kacang Kapri Beku (0402020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3205,
    "Kacang Kapri Beku (0402020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3206,
    "Kacang Kapri Beku (0402020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3207,
    "Kacang Kapri Beku (0402020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3208,
    "Kacang Kapri Beku (0402020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [3209, "Kacang Koro (150212 )", "Salmonella (/25 g)"],
  [3210, "Kacang Koro (150212 )", "Jumlah Sampel - Salmonella"],
  [3211, "Kacang Mede (150205)", "Salmonella (/25 g)"],
  [3212, "Kacang Mede (150205)", "Jumlah Sampel - Salmonella"],
  [3213, "Kacang Panggang (150204 )", "Salmonella (/25 g)"],
  [
    3214,
    "Kacang Panggang (150204 )",
    "Jumlah Sampel - Salmonella",
  ],
  [3215, "Kacang Panggang Lainnya (150219)", "Salmonella (/25 g)"],
  [
    3216,
    "Kacang Panggang Lainnya (150219)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3217, "Kacang Pistacio (150214 )", "Salmonella (/25 g)"],
  [
    3218,
    "Kacang Pistacio (150214 )",
    "Jumlah Sampel - Salmonella",
  ],
  [3219, "Kacang Sangrai (150217)", "Salmonella (/25 g)"],
  [
    3220,
    "Kacang Sangrai (150217)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3221, "Kacang Telur (150208 )", "Salmonella (/25 g)"],
  [3222, "Kacang Telur (150208 )", "Jumlah Sampel - Salmonella"],
  [3223, "Kakao Bubuk (05010101)", "Salmonella (/25 g)"],
  [3224, "Kakao Bubuk (05010101)", "Jumlah Sampel - Salmonella"],
  [
    3225,
    "Kakao Bubuk Sangat Halus (Cocoa Fineness) (05010106)",
    "Salmonella (/25 g)",
  ],
  [
    3226,
    "Kakao Bubuk Sangat Halus (Cocoa Fineness) (05010106)",
    "Salmonella (/25 g)",
  ],
  [
    3227,
    "Kakao Bubuk Sangat Halus (Cocoa Fineness) (05010106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3228,
    "Kakao Bubuk Sangat Halus (Cocoa Fineness) (05010106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3229,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Salmonella (/25 g)",
  ],
  [
    3230,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Salmonella (/25 g)",
  ],
  [
    3231,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3232,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Jumlah Sampel - Salmonella",
  ],
  [3233, "Kakao Instan (05010118)", "Salmonella (/25 g)"],
  [3234, "Kakao Instan (05010118)", "Jumlah Sampel - Salmonella"],
  [
    3235,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Salmonella (/25 g)",
  ],
  [
    3236,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3237,
    "Kamaboko (0902040106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3238,
    "Kamaboko (0902040106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3239,
    "Kamaboko (0902040106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3240,
    "Kamaboko (0902040106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3241,
    "Kamaboko (0902040106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [3242, "Kapulaga (12020148)", "Salmonella (/25 g)"],
  [3243, "Kapulaga (12020148)", "Jumlah Sampel - Salmonella"],
  [
    3244,
    "Kapulaga (12020148)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3245,
    "Kapulaga (12020148)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3246,
    "Kapulaga (12020148)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3247,
    "Kapulaga (12020148)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3248,
    "Kapulaga (12020148)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3249,
    "Kapulaga (12020148)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3250,
    "Kapulaga (12020148)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3251,
    "Kapulaga (12020148)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3252,
    "Kapulaga (12020148)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3253,
    "Kapulaga (12020148)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3254,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Salmonella (/25 g)",
  ],
  [
    3255,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3256,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3257,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3258,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3259,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3260,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3261,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3262,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3263,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3264,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3265,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3266,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Salmonella (/25 g)",
  ],
  [
    3267,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3268,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3269,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3270,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3271,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3272,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3273,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3274,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3275,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3276,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3277,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3278, "Kapulaga Bubuk (12020153)", "Salmonella (/25 g)"],
  [
    3279,
    "Kapulaga Bubuk (12020153)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3280,
    "Kapulaga Bubuk (12020153)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3281,
    "Kapulaga Bubuk (12020153)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3282,
    "Kapulaga Bubuk (12020153)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3283,
    "Kapulaga Bubuk (12020153)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3284,
    "Kapulaga Bubuk (12020153)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3285,
    "Kapulaga Bubuk (12020153)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3286,
    "Kapulaga Bubuk (12020153)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3287,
    "Kapulaga Bubuk (12020153)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3288,
    "Kapulaga Bubuk (12020153)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3289,
    "Kapulaga Bubuk (12020153)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3290, "Kapulaga Lokal (12020150)", "Salmonella (/25 g)"],
  [
    3291,
    "Kapulaga Lokal (12020150)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3292,
    "Kapulaga Lokal (12020150)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3293,
    "Kapulaga Lokal (12020150)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3294,
    "Kapulaga Lokal (12020150)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3295,
    "Kapulaga Lokal (12020150)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3296,
    "Kapulaga Lokal (12020150)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3297,
    "Kapulaga Lokal (12020150)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3298,
    "Kapulaga Lokal (12020150)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3299,
    "Kapulaga Lokal (12020150)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3300,
    "Kapulaga Lokal (12020150)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3301,
    "Kapulaga Lokal (12020150)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3302, "Kastengel (07020135)", "Salmonella (/25 g)"],
  [3303, "Kastengel (07020135)", "Jumlah Sampel - Salmonella"],
  [
    3304,
    "Kastengel (07020135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3305,
    "Kastengel (07020135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3306,
    "Kastengel (07020135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3307,
    "Kastengel (07020135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3308,
    "Kastengel (07020135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3309,
    "Katrisolo (060729)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3310,
    "Katrisolo (060729)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3311,
    "Katrisolo (060729)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3312,
    "Katrisolo (060729)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3313,
    "Katrisolo (060729)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3314, "Katrisolo (060729)", "Salmonella (/25 g)"],
  [3315, "Katrisolo (060729)", "Jumlah Sampel - Salmonella"],
  [
    3316,
    "Katrisolo (060729)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3317,
    "Katrisolo (060729)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3318,
    "Katrisolo (060729)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3319,
    "Katrisolo (060729)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3320,
    "Katrisolo (060729)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [3321, "Kayu Manis (12020155)", "Salmonella (/25 g)"],
  [3322, "Kayu Manis (12020155)", "Jumlah Sampel - Salmonella"],
  [
    3323,
    "Kayu Manis (12020155)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3324,
    "Kayu Manis (12020155)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3325,
    "Kayu Manis (12020155)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3326,
    "Kayu Manis (12020155)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3327,
    "Kayu Manis (12020155)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3328,
    "Kayu Manis (12020155)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3329,
    "Kayu Manis (12020155)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3330,
    "Kayu Manis (12020155)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3331,
    "Kayu Manis (12020155)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3332,
    "Kayu Manis (12020155)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3333, "Kayu Manis Bubuk (12020156)", "Salmonella (/25 g)"],
  [
    3334,
    "Kayu Manis Bubuk (12020156)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3335,
    "Kayu Manis Bubuk (12020156)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3336,
    "Kayu Manis Bubuk (12020156)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3337,
    "Kayu Manis Bubuk (12020156)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3338,
    "Kayu Manis Bubuk (12020156)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3339,
    "Kayu Manis Bubuk (12020156)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3340,
    "Kayu Manis Bubuk (12020156)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3341,
    "Kayu Manis Bubuk (12020156)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3342,
    "Kayu Manis Bubuk (12020156)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3343,
    "Kayu Manis Bubuk (12020156)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3344,
    "Kayu Manis Bubuk (12020156)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3345, "Kecap Ikan (12060401)", "Salmonella (/25 g)"],
  [3346, "Kecap Ikan (12060401)", "Salmonella (/25 g)"],
  [3347, "Kecap Ikan (12060401)", "Jumlah Sampel - Salmonella"],
  [3348, "Kecap Ikan (12060401)", "Jumlah Sampel - Salmonella"],
  [
    3349,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Salmonella (/25 g)",
  ],
  [
    3350,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Salmonella (/25 g)",
  ],
  [
    3351,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3352,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Jumlah Sampel - Salmonella",
  ],
  [3353, "Kecimpring (150114)", "Salmonella (/25 g)"],
  [3354, "Kecimpring (150114)", "Jumlah Sampel - Salmonella"],
  [
    3355,
    "Kecimpring (150114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3356,
    "Kecimpring (150114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3357,
    "Kecimpring (150114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3358,
    "Kecimpring (150114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3359,
    "Kecimpring (150114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3360,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Salmonella (/25 g)",
  ],
  [
    3361,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3362,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3363,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3364,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3365,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3366,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3367,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3368,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3369,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3370,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3371,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3372, "Keecho/Heecho (08030317)", "Salmonella (koloni/25 ml)"],
  [3373, "Keecho/Heecho (08030317)", "Jumlah Sampel - Salmonella"],
  [
    3374,
    "Keecho/Heecho (08030317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    3375,
    "Keecho/Heecho (08030317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    3376,
    "Keecho/Heecho (08030317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    3377,
    "Keecho/Heecho (08030317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    3378,
    "Keecho/Heecho (08030317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    3379,
    "Keecho/Heecho (08030317)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    3380,
    "Keecho/Heecho (08030317)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [3381, "Kefir (010201A9)", "Salmonella (/25 ml)"],
  [3382, "Kefir (010201A9)", "Jumlah Sampel - Salmonella"],
  [
    3383,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Salmonella (negatif/25 g)",
  ],
  [
    3384,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    3385,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Salmonella (/25 g)",
  ],
  [
    3386,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [3387, "Keik (Cake) (07020102)", "Salmonella (/25 g)"],
  [3388, "Keik (Cake) (07020102)", "Jumlah Sampel - Salmonella"],
  [
    3389,
    "Keik (Cake) (07020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3390,
    "Keik (Cake) (07020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3391,
    "Keik (Cake) (07020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3392,
    "Keik (Cake) (07020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3393,
    "Keik (Cake) (07020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3394,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Salmonella (/25 g)",
  ],
  [
    3395,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3396,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3397,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3398,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3399,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3400,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3401,
    "Keik Keju (Cheese Cake) (07020104)",
    "Salmonella (/25 g)",
  ],
  [
    3402,
    "Keik Keju (Cheese Cake) (07020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3403,
    "Keik Keju (Cheese Cake) (07020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3404,
    "Keik Keju (Cheese Cake) (07020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3405,
    "Keik Keju (Cheese Cake) (07020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3406,
    "Keik Keju (Cheese Cake) (07020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3407,
    "Keik Keju (Cheese Cake) (07020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3408,
    "Keik Mentega (Butter Cake) (07020103)",
    "Salmonella (/25 g)",
  ],
  [
    3409,
    "Keik Mentega (Butter Cake) (07020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3410,
    "Keik Mentega (Butter Cake) (07020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3411,
    "Keik Mentega (Butter Cake) (07020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3412,
    "Keik Mentega (Butter Cake) (07020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3413,
    "Keik Mentega (Butter Cake) (07020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3414,
    "Keik Mentega (Butter Cake) (07020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3415,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Salmonella (/25 g)",
  ],
  [
    3416,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3417,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3418,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3419,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3420,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3421,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3422,
    "Keju Amerika (American Cheese) (0106040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3423,
    "Keju Amerika (American Cheese) (0106040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3424,
    "Keju Amerika (American Cheese) (0106040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3425,
    "Keju Amerika (American Cheese) (0106040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3426,
    "Keju Amerika (American Cheese) (0106040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3427,
    "Keju Amerika (American Cheese) (0106040102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3428,
    "Keju Amerika (American Cheese) (0106040102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3429,
    "Keju Amerika (American Cheese) (0106040102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3430,
    "Keju Amerika (American Cheese) (0106040102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3431,
    "Keju Amerika (American Cheese) (0106040102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3432,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3433,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3434,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3435,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3436,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3437,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3438,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3439,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3440,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3441,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3442,
    "Keju Bath (0106020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3443,
    "Keju Bath (0106020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3444,
    "Keju Bath (0106020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3445,
    "Keju Bath (0106020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3446,
    "Keju Bath (0106020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3447,
    "Keju Bath (0106020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3448,
    "Keju Bath (0106020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3449,
    "Keju Bath (0106020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3450,
    "Keju Bath (0106020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3451,
    "Keju Bath (0106020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3452,
    "Keju Bath (010602A5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3453,
    "Keju Bath (010602A5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3454,
    "Keju Bath (010602A5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3455,
    "Keju Bath (010602A5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3456,
    "Keju Bath (010602A5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3457,
    "Keju Bath (010602A5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3458,
    "Keju Bath (010602A5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3459,
    "Keju Bath (010602A5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3460,
    "Keju Bath (010602A5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3461,
    "Keju Bath (010602A5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3462,
    "Keju Biru (Blue cheese) (0106020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3463,
    "Keju Biru (Blue cheese) (0106020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3464,
    "Keju Biru (Blue cheese) (0106020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3465,
    "Keju Biru (Blue cheese) (0106020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3466,
    "Keju Biru (Blue cheese) (0106020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3467,
    "Keju Biru (Blue cheese) (0106020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3468,
    "Keju Biru (Blue cheese) (0106020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3469,
    "Keju Biru (Blue cheese) (0106020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3470,
    "Keju Biru (Blue cheese) (0106020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3471,
    "Keju Biru (Blue cheese) (0106020101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3472,
    "Keju Bocconcini (01060104)",
    "Listeria monocytogenes (koloni/g)",
  ],
  [
    3473,
    "Keju Bocconcini (01060104)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3474,
    "Keju Bocconcini (01060104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3475,
    "Keju Bocconcini (01060104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3476,
    "Keju Bocconcini (01060104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3477,
    "Keju Bocconcini (01060104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3478,
    "Keju Bocconcini (01060104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3479, "Keju Bocconcini (01060104)", "Salmonella (/25 g)"],
  [
    3480,
    "Keju Bocconcini (01060104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3481,
    "Keju Bondard (0106020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3482,
    "Keju Bondard (0106020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3483,
    "Keju Bondard (0106020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3484,
    "Keju Bondard (0106020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3485,
    "Keju Bondard (0106020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3486,
    "Keju Bondard (0106020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3487,
    "Keju Bondard (0106020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3488,
    "Keju Bondard (0106020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3489,
    "Keju Bondard (0106020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3490,
    "Keju Bondard (0106020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3491,
    "Keju Bondard (010602A6)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3492,
    "Keju Bondard (010602A6)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3493,
    "Keju Bondard (010602A6)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3494,
    "Keju Bondard (010602A6)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3495,
    "Keju Bondard (010602A6)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3496,
    "Keju Bondard (010602A6)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3497,
    "Keju Bondard (010602A6)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3498,
    "Keju Bondard (010602A6)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3499,
    "Keju Bondard (010602A6)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3500,
    "Keju Bondard (010602A6)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3501,
    "Keju Bougon (0106020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3502,
    "Keju Bougon (0106020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3503,
    "Keju Bougon (0106020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3504,
    "Keju Bougon (0106020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3505,
    "Keju Bougon (0106020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3506,
    "Keju Bougon (0106020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3507,
    "Keju Bougon (0106020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3508,
    "Keju Bougon (0106020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3509,
    "Keju Bougon (0106020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3510,
    "Keju Bougon (0106020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3511,
    "Keju Bougon (010602A7)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3512,
    "Keju Bougon (010602A7)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3513,
    "Keju Bougon (010602A7)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3514,
    "Keju Bougon (010602A7)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3515,
    "Keju Bougon (010602A7)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3516,
    "Keju Bougon (010602A7)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3517,
    "Keju Bougon (010602A7)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3518,
    "Keju Bougon (010602A7)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3519,
    "Keju Bougon (010602A7)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3520,
    "Keju Bougon (010602A7)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3521,
    "Keju Bouquet des moines (0106020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3522,
    "Keju Bouquet des moines (0106020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3523,
    "Keju Bouquet des moines (0106020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3524,
    "Keju Bouquet des moines (0106020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3525,
    "Keju Bouquet des moines (0106020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3526,
    "Keju Bouquet des moines (0106020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3527,
    "Keju Bouquet des moines (0106020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3528,
    "Keju Bouquet des moines (0106020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3529,
    "Keju Bouquet des moines (0106020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3530,
    "Keju Bouquet des moines (0106020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3531,
    "Keju Bouquet des moines (010602A8)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3532,
    "Keju Bouquet des moines (010602A8)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3533,
    "Keju Bouquet des moines (010602A8)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3534,
    "Keju Bouquet des moines (010602A8)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3535,
    "Keju Bouquet des moines (010602A8)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3536,
    "Keju Bouquet des moines (010602A8)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3537,
    "Keju Bouquet des moines (010602A8)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3538,
    "Keju Bouquet des moines (010602A8)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3539,
    "Keju Bouquet des moines (010602A8)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3540,
    "Keju Bouquet des moines (010602A8)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3541,
    "Keju Boursault (010602A9)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3542,
    "Keju Boursault (010602A9)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3543,
    "Keju Boursault (010602A9)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3544,
    "Keju Boursault (010602A9)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3545,
    "Keju Boursault (010602A9)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3546,
    "Keju Boursault (010602A9)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3547,
    "Keju Boursault (010602A9)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3548,
    "Keju Boursault (010602A9)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3549,
    "Keju Boursault (010602A9)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3550,
    "Keju Boursault (010602A9)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3551,
    "Keju Brie (0106020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3552,
    "Keju Brie (0106020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3553,
    "Keju Brie (0106020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3554,
    "Keju Brie (0106020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3555,
    "Keju Brie (0106020105)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3556,
    "Keju Brie (0106020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3557,
    "Keju Brie (0106020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3558,
    "Keju Brie (0106020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3559,
    "Keju Brie (0106020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3560,
    "Keju Brie (0106020105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3561,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3562,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3563,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3564,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3565,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3566,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3567,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3568,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3569,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3570,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3571,
    "Keju Camembert (0106020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3572,
    "Keju Camembert (0106020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3573,
    "Keju Camembert (0106020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3574,
    "Keju Camembert (0106020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3575,
    "Keju Camembert (0106020110)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3576,
    "Keju Camembert (0106020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3577,
    "Keju Camembert (0106020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3578,
    "Keju Camembert (0106020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3579,
    "Keju Camembert (0106020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3580,
    "Keju Camembert (0106020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3581,
    "Keju Camembert (010602A4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3582,
    "Keju Camembert (010602A4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3583,
    "Keju Camembert (010602A4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3584,
    "Keju Camembert (010602A4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3585,
    "Keju Camembert (010602A4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3586,
    "Keju Camembert (010602A4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3587,
    "Keju Camembert (010602A4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3588,
    "Keju Camembert (010602A4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3589,
    "Keju Camembert (010602A4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3590,
    "Keju Camembert (010602A4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3591,
    "Keju Cheddar (0106020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3592,
    "Keju Cheddar (0106020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3593,
    "Keju Cheddar (0106020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3594,
    "Keju Cheddar (0106020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3595,
    "Keju Cheddar (0106020109)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3596,
    "Keju Cheddar (0106020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3597,
    "Keju Cheddar (0106020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3598,
    "Keju Cheddar (0106020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3599,
    "Keju Cheddar (0106020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3600,
    "Keju Cheddar (0106020109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3601,
    "Keju Cheddar (010602A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3602,
    "Keju Cheddar (010602A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3603,
    "Keju Cheddar (010602A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3604,
    "Keju Cheddar (010602A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3605,
    "Keju Cheddar (010602A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3606,
    "Keju Cheddar (010602A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3607,
    "Keju Cheddar (010602A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3608,
    "Keju Cheddar (010602A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3609,
    "Keju Cheddar (010602A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3610,
    "Keju Cheddar (010602A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3611,
    "Keju Cheddar Olahan (010604A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3612,
    "Keju Cheddar Olahan (010604A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3613,
    "Keju Cheddar Olahan (010604A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3614,
    "Keju Cheddar Olahan (010604A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3615,
    "Keju Cheddar Olahan (010604A1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3616,
    "Keju Cheddar Olahan (010604A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3617,
    "Keju Cheddar Olahan (010604A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3618,
    "Keju Cheddar Olahan (010604A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3619,
    "Keju Cheddar Olahan (010604A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3620,
    "Keju Cheddar Olahan (010604A1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3621,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3622,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3623,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3624,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3625,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3626,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3627,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3628,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3629,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3630,
    "Keju Cheddar Rendah Sodium (010602A2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3631,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3632,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3633,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3634,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3635,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3636,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3637,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3638,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3639,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3640,
    "Keju Chevre Log atau Keju Buchette (010602B0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3641,
    "Keju Club Luncheon (0106040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3642,
    "Keju Club Luncheon (0106040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3643,
    "Keju Club Luncheon (0106040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3644,
    "Keju Club Luncheon (0106040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3645,
    "Keju Club Luncheon (0106040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3646,
    "Keju Club Luncheon (0106040101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3647,
    "Keju Club Luncheon (0106040101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3648,
    "Keju Club Luncheon (0106040101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3649,
    "Keju Club Luncheon (0106040101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3650,
    "Keju Club Luncheon (0106040101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3651,
    "Keju Coach Farm (010602B1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3652,
    "Keju Coach Farm (010602B1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3653,
    "Keju Coach Farm (010602B1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3654,
    "Keju Coach Farm (010602B1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3655,
    "Keju Coach Farm (010602B1)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3656,
    "Keju Coach Farm (010602B1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3657,
    "Keju Coach Farm (010602B1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3658,
    "Keju Coach Farm (010602B1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3659,
    "Keju Coach Farm (010602B1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3660,
    "Keju Coach Farm (010602B1)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3661,
    "Keju Colby (010602B5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3662,
    "Keju Colby (010602B5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3663,
    "Keju Colby (010602B5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3664,
    "Keju Colby (010602B5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3665,
    "Keju Colby (010602B5)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3666,
    "Keju Colby (010602B5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3667,
    "Keju Colby (010602B5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3668,
    "Keju Colby (010602B5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3669,
    "Keju Colby (010602B5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3670,
    "Keju Colby (010602B5)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3671,
    "Keju Cold Pack (0106040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3672,
    "Keju Cold Pack (0106040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3673,
    "Keju Cold Pack (0106040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3674,
    "Keju Cold Pack (0106040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3675,
    "Keju Cold Pack (0106040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3676,
    "Keju Cold Pack (0106040103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3677,
    "Keju Cold Pack (0106040103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3678,
    "Keju Cold Pack (0106040103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3679,
    "Keju Cold Pack (0106040103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3680,
    "Keju Cold Pack (0106040103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3681,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Listeria monocytogenes (koloni/g)",
  ],
  [
    3682,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3683,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3684,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3685,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3686,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3687,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3688,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Salmonella (/25 g)",
  ],
  [
    3689,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3690,
    "Keju Edam (010602A3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3691,
    "Keju Edam (010602A3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3692,
    "Keju Edam (010602A3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3693,
    "Keju Edam (010602A3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3694,
    "Keju Edam (010602A3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3695,
    "Keju Edam (010602A3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3696,
    "Keju Edam (010602A3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3697,
    "Keju Edam (010602A3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3698,
    "Keju Edam (010602A3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3699,
    "Keju Edam (010602A3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3700,
    "Keju Gouda (0106020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3701,
    "Keju Gouda (0106020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3702,
    "Keju Gouda (0106020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3703,
    "Keju Gouda (0106020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3704,
    "Keju Gouda (0106020103)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3705,
    "Keju Gouda (0106020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3706,
    "Keju Gouda (0106020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3707,
    "Keju Gouda (0106020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3708,
    "Keju Gouda (0106020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3709,
    "Keju Gouda (0106020103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3710,
    "Keju Gubbeen (010602B4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3711,
    "Keju Gubbeen (010602B4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3712,
    "Keju Gubbeen (010602B4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3713,
    "Keju Gubbeen (010602B4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3714,
    "Keju Gubbeen (010602B4)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3715,
    "Keju Gubbeen (010602B4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3716,
    "Keju Gubbeen (010602B4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3717,
    "Keju Gubbeen (010602B4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3718,
    "Keju Gubbeen (010602B4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3719,
    "Keju Gubbeen (010602B4)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3720,
    "Keju Haloumy (010607)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3721,
    "Keju Haloumy (010607)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3722,
    "Keju Haloumy (010607)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3723,
    "Keju Haloumy (010607)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3724,
    "Keju Haloumy (010607)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3725,
    "Keju Havarti (0106020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3726,
    "Keju Havarti (0106020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3727,
    "Keju Havarti (0106020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3728,
    "Keju Havarti (0106020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3729,
    "Keju Havarti (0106020104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3730,
    "Keju Havarti (0106020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3731,
    "Keju Havarti (0106020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3732,
    "Keju Havarti (0106020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3733,
    "Keju Havarti (0106020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3734,
    "Keju Havarti (0106020104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3735,
    "Keju Krim (Cream Cheese) (01060102)",
    "Listeria monocytogenes (koloni/g)",
  ],
  [
    3736,
    "Keju Krim (Cream Cheese) (01060102)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3737,
    "Keju Krim (Cream Cheese) (01060102)",
    "Staphylococcus aureus (koloni/g) (Hanya untuk yang dibuat dari susu segar)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    3738,
    "Keju Krim (Cream Cheese) (01060102)",
    "Staphylococcus aureus (koloni/g) (Hanya untuk yang dibuat dari susu segar)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    3739,
    "Keju Krim (Cream Cheese) (01060102)",
    "Staphylococcus aureus (koloni/g) (Hanya untuk yang dibuat dari susu segar)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    3740,
    "Keju Krim (Cream Cheese) (01060102)",
    "Staphylococcus aureus (koloni/g) (Hanya untuk yang dibuat dari susu segar)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    3741,
    "Keju Krim (Cream Cheese) (01060102)",
    "Staphylococcus aureus (koloni/g) (Hanya untuk yang dibuat dari susu segar)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    3742,
    "Keju Krim (Cream Cheese) (01060102)",
    "Salmonella (/25 g) (Hanya untuk yang dibuat dari susu segar)",
  ],
  [
    3743,
    "Keju Krim (Cream Cheese) (01060102)",
    "Jumlah Sampel - Salmonella (Hanya untuk yang dibuat dari susu segar)",
    "",
    "\x{2265}5",
  ],
  [
    3744,
    "Keju Mozzarella (01060103)",
    "Listeria monocytogenes (koloni/g)",
  ],
  [
    3745,
    "Keju Mozzarella (01060103)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3746,
    "Keju Mozzarella (01060103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3747,
    "Keju Mozzarella (01060103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3748,
    "Keju Mozzarella (01060103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3749,
    "Keju Mozzarella (01060103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3750,
    "Keju Mozzarella (01060103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3751, "Keju Mozzarella (01060103)", "Salmonella (/25 g)"],
  [
    3752,
    "Keju Mozzarella (01060103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3753,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3754,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3755,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3756,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3757,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3758,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3759,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3760,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3761,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3762,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3763,
    "Keju Olahan (010604A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3764,
    "Keju Olahan (010604A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3765,
    "Keju Olahan (010604A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3766,
    "Keju Olahan (010604A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3767,
    "Keju Olahan (010604A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3768,
    "Keju Olahan (010604A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3769,
    "Keju Olahan (010604A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3770,
    "Keju Olahan (010604A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3771,
    "Keju Olahan (010604A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3772,
    "Keju Olahan (010604A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3773,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3774,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3775,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3776,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3777,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3778,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3779,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3780,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3781,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3782,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3783,
    "Keju Olahan Plain (01060401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3784,
    "Keju Olahan Plain (01060401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3785,
    "Keju Olahan Plain (01060401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3786,
    "Keju Olahan Plain (01060401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3787,
    "Keju Olahan Plain (01060401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3788,
    "Keju Olahan Plain (01060401)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3789,
    "Keju Olahan Plain (01060401)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3790,
    "Keju Olahan Plain (01060401)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3791,
    "Keju Olahan Plain (01060401)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3792,
    "Keju Olahan Plain (01060401)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3793,
    "Keju Olahan Plain (0106040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3794,
    "Keju Olahan Plain (0106040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3795,
    "Keju Olahan Plain (0106040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3796,
    "Keju Olahan Plain (0106040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3797,
    "Keju Olahan Plain (0106040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3798,
    "Keju Olahan Plain (0106040104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3799,
    "Keju Olahan Plain (0106040104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3800,
    "Keju Olahan Plain (0106040104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3801,
    "Keju Olahan Plain (0106040104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3802,
    "Keju Olahan Plain (0106040104)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3803,
    "Keju Olivet Cendre (010602B2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3804,
    "Keju Olivet Cendre (010602B2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3805,
    "Keju Olivet Cendre (010602B2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3806,
    "Keju Olivet Cendre (010602B2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3807,
    "Keju Olivet Cendre (010602B2)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3808,
    "Keju Olivet Cendre (010602B2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3809,
    "Keju Olivet Cendre (010602B2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3810,
    "Keju Olivet Cendre (010602B2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3811,
    "Keju Olivet Cendre (010602B2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3812,
    "Keju Olivet Cendre (010602B2)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3813,
    "Keju Palet de Babligny (010602B3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3814,
    "Keju Palet de Babligny (010602B3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3815,
    "Keju Palet de Babligny (010602B3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3816,
    "Keju Palet de Babligny (010602B3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3817,
    "Keju Palet de Babligny (010602B3)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3818,
    "Keju Palet de Babligny (010602B3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3819,
    "Keju Palet de Babligny (010602B3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3820,
    "Keju Palet de Babligny (010602B3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3821,
    "Keju Palet de Babligny (010602B3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3822,
    "Keju Palet de Babligny (010602B3)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3823,
    "Keju Parmesan (0106020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3824,
    "Keju Parmesan (0106020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3825,
    "Keju Parmesan (0106020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3826,
    "Keju Parmesan (0106020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3827,
    "Keju Parmesan (0106020106)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3828,
    "Keju Parmesan (0106020106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3829,
    "Keju Parmesan (0106020106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3830,
    "Keju Parmesan (0106020106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3831,
    "Keju Parmesan (0106020106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3832,
    "Keju Parmesan (0106020106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3833,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3834,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3835,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3836,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3837,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3838,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3839,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3840,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3841,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3842,
    "Keju Pepper Jack (Keju Monterey Jack dan Potongan Lada) (0106040202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    3843,
    "Keju Peram (010602A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3844,
    "Keju Peram (010602A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3845,
    "Keju Peram (010602A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3846,
    "Keju Peram (010602A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3847,
    "Keju Peram (010602A0)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3848,
    "Keju Peram (010602A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3849,
    "Keju Peram (010602A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3850,
    "Keju Peram (010602A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3851,
    "Keju Peram (010602A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3852,
    "Keju Peram (010602A0)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3853,
    "Keju Peram Lainnya (0106020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3854,
    "Keju Peram Lainnya (0106020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3855,
    "Keju Peram Lainnya (0106020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3856,
    "Keju Peram Lainnya (0106020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3857,
    "Keju Peram Lainnya (0106020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3858,
    "Keju Peram Lainnya (0106020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3859,
    "Keju Peram Lainnya (0106020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3860,
    "Keju Peram Lainnya (0106020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3861,
    "Keju Peram Lainnya (0106020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3862,
    "Keju Peram Lainnya (0106020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3863,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    3864,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3865,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3866,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3867,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3868,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3869,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3870,
    "Keju Swiss (0106020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3871,
    "Keju Swiss (0106020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3872,
    "Keju Swiss (0106020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3873,
    "Keju Swiss (0106020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3874,
    "Keju Swiss (0106020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    3875,
    "Keju Swiss (0106020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3876,
    "Keju Swiss (0106020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3877,
    "Keju Swiss (0106020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3878,
    "Keju Swiss (0106020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3879,
    "Keju Swiss (0106020107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3880,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Listeria monocytogenes (koloni/g)",
  ],
  [
    3881,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    3882,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3883,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3884,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3885,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3886,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3887,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Salmonella (/25 g)",
  ],
  [
    3888,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [3889, "Keju Whey (010603)", "Listeria monocytogenes (/25 g)"],
  [
    3890,
    "Keju Whey (010603)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    3891,
    "Keju Whey (010603)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3892,
    "Keju Whey (010603)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3893,
    "Keju Whey (010603)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3894,
    "Keju Whey (010603)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3895,
    "Keju Whey (010603)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    3896,
    "Kekicak/Gegicak (060727)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3897,
    "Kekicak/Gegicak (060727)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3898,
    "Kekicak/Gegicak (060727)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3899,
    "Kekicak/Gegicak (060727)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3900,
    "Kekicak/Gegicak (060727)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3901, "Kekicak/Gegicak (060727)", "Salmonella (/25 g)"],
  [3902, "Kekicak/Gegicak (060727)", "Jumlah Sampel - Salmonella"],
  [
    3903,
    "Kekicak/Gegicak (060727)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3904,
    "Kekicak/Gegicak (060727)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3905,
    "Kekicak/Gegicak (060727)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3906,
    "Kekicak/Gegicak (060727)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3907,
    "Kekicak/Gegicak (060727)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3908,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Salmonella (/25 g)",
  ],
  [
    3909,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3910,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Salmonella (/25 g)",
  ],
  [
    3911,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3912,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Salmonella (/25 g)",
  ],
  [
    3913,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3914,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Salmonella (/25 g)",
  ],
  [
    3915,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3916,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Salmonella (Kembang",
  ],
  [3917, "Gula/Permen"],
  [3918, "Lunak (bukan jeli)"],
  [3919, ") (/25 g)"],
  [
    3920,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3921,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3922,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [
    3923,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Salmonella (/25 g)",
  ],
  [
    3924,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3925,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Salmonella (/25 g)",
  ],
  [
    3926,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3927,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Salmonella (Kembang",
  ],
  [3928, "Gula/Permen"],
  [3929, "Lunak (bukan jeli)"],
  [3930, ") (/25 g)"],
  [
    3931,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3932,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3933,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [3934, "Kembang Tahu (06080201)", "Salmonella (/25 g)"],
  [3935, "Kembang Tahu (06080201)", "Jumlah Sampel - Salmonella"],
  [
    3936,
    "Kembang Tahu (06080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3937,
    "Kembang Tahu (06080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3938,
    "Kembang Tahu (06080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3939,
    "Kembang Tahu (06080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3940,
    "Kembang Tahu (06080201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [3941, "Kemplang (150304 )", "Salmonella (/25 g)"],
  [3942, "Kemplang (150304 )", "Jumlah Sampel - Salmonella"],
  [
    3943,
    "Kemplang (150304 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3944,
    "Kemplang (150304 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3945,
    "Kemplang (150304 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3946,
    "Kemplang (150304 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3947,
    "Kemplang (150304 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [3948, "Kencur (12020159)", "Salmonella (/25 g)"],
  [3949, "Kencur (12020159)", "Jumlah Sampel - Salmonella"],
  [
    3950,
    "Kencur (12020159)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3951,
    "Kencur (12020159)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3952,
    "Kencur (12020159)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3953,
    "Kencur (12020159)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3954,
    "Kencur (12020159)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3955,
    "Kencur (12020159)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3956,
    "Kencur (12020159)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3957,
    "Kencur (12020159)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3958,
    "Kencur (12020159)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3959,
    "Kencur (12020159)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [3960, "Kencur Bubuk (12020160)", "Salmonella (/25 g)"],
  [3961, "Kencur Bubuk (12020160)", "Jumlah Sampel - Salmonella"],
  [
    3962,
    "Kencur Bubuk (12020160)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3963,
    "Kencur Bubuk (12020160)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3964,
    "Kencur Bubuk (12020160)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3965,
    "Kencur Bubuk (12020160)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3966,
    "Kencur Bubuk (12020160)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    3967,
    "Kencur Bubuk (12020160)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3968,
    "Kencur Bubuk (12020160)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3969,
    "Kencur Bubuk (12020160)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3970,
    "Kencur Bubuk (12020160)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3971,
    "Kencur Bubuk (12020160)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    3972,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Salmonella (/25 g)",
  ],
  [
    3973,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3974,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3975,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3976,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3977,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3978,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    3979,
    "Keping Jagung (Corn Flake) (060302)",
    "Salmonella (/25 g)",
  ],
  [
    3980,
    "Keping Jagung (Corn Flake) (060302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3981,
    "Keping Jagung (Corn Flake) (060302)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3982,
    "Keping Jagung (Corn Flake) (060302)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3983,
    "Keping Jagung (Corn Flake) (060302)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3984,
    "Keping Jagung (Corn Flake) (060302)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    3985,
    "Keping Jagung (Corn Flake) (060302)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [3986, "Keripik Bayam (0402020801)", "Salmonella (/25 g)"],
  [
    3987,
    "Keripik Bayam (0402020801)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    3988,
    "Keripik Bayam (0402020801)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3989,
    "Keripik Bayam (0402020801)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3990,
    "Keripik Bayam (0402020801)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3991,
    "Keripik Bayam (0402020801)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3992,
    "Keripik Bayam (0402020801)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    3993,
    "Keripik Belut (0902040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3994,
    "Keripik Belut (0902040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3995,
    "Keripik Belut (0902040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3996,
    "Keripik Belut (0902040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    3997,
    "Keripik Belut (0902040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [3998, "Keripik Gadung (150102)", "Salmonella (/25 g)"],
  [3999, "Keripik Gadung (150102)", "Jumlah Sampel - Salmonella"],
  [
    4000,
    "Keripik Gadung (150102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4001,
    "Keripik Gadung (150102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4002,
    "Keripik Gadung (150102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4003,
    "Keripik Gadung (150102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4004,
    "Keripik Gadung (150102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4005,
    "Keripik Ikan (0902040315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4006,
    "Keripik Ikan (0902040315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4007,
    "Keripik Ikan (0902040315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4008,
    "Keripik Ikan (0902040315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4009,
    "Keripik Ikan (0902040315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4010,
    "Keripik Jamur Kancing (0402020802)",
    "Salmonella (/25 g)",
  ],
  [
    4011,
    "Keripik Jamur Kancing (0402020802)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4012,
    "Keripik Jamur Kancing (0402020802)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4013,
    "Keripik Jamur Kancing (0402020802)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4014,
    "Keripik Jamur Kancing (0402020802)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4015,
    "Keripik Jamur Kancing (0402020802)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4016,
    "Keripik Jamur Kancing (0402020802)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4017, "Keripik Kentang (150101)", "Salmonella (/25 g)"],
  [4018, "Keripik Kentang (150101)", "Jumlah Sampel - Salmonella"],
  [
    4019,
    "Keripik Kentang (150101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4020,
    "Keripik Kentang (150101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4021,
    "Keripik Kentang (150101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4022,
    "Keripik Kentang (150101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4023,
    "Keripik Kentang (150101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4024,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4025,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4026,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4027,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4028,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [4029, "Keripik Lainnya (150131)", "Salmonella (/25 g)"],
  [4030, "Keripik Lainnya (150131)", "Jumlah Sampel - Salmonella"],
  [
    4031,
    "Keripik Lainnya (150131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4032,
    "Keripik Lainnya (150131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4033,
    "Keripik Lainnya (150131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4034,
    "Keripik Lainnya (150131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4035,
    "Keripik Lainnya (150131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4036, "Keripik Oncom (150110)", "Salmonella (/25 g)"],
  [4037, "Keripik Oncom (150110)", "Jumlah Sampel - Salmonella"],
  [
    4038,
    "Keripik Oncom (150110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4039,
    "Keripik Oncom (150110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4040,
    "Keripik Oncom (150110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4041,
    "Keripik Oncom (150110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4042,
    "Keripik Oncom (150110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4043,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4044,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4045,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4046,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4047,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4048,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4049,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4050,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4051,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4052,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4053,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4054,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4055,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4056,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4057,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4058,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4059,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4060,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4061,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4062,
    "Keripik Paru (08020215)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4063, "Keripik Paru (08020215)", "Salmonella (/25 g)"],
  [4064, "Keripik Paru (08020215)", "Salmonella (/25 g)"],
  [4065, "Keripik Paru (08020215)", "Salmonella (/25 g)"],
  [4066, "Keripik Paru (08020215)", "Salmonella (/25 g)"],
  [4067, "Keripik Paru (08020215)", "Jumlah Sampel - Salmonella"],
  [4068, "Keripik Paru (08020215)", "Jumlah Sampel - Salmonella"],
  [4069, "Keripik Paru (08020215)", "Jumlah Sampel - Salmonella"],
  [4070, "Keripik Paru (08020215)", "Jumlah Sampel - Salmonella"],
  [
    4071,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4072,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4073,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4074,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4075,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4076,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4077,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4078,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4079,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4080,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4081,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4082,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4083,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4084,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4085,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4086,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4087,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4088,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4089,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4090,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4091,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4092,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4093,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4094,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4095,
    "Keripik Paru (08020215)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4096, "Keripik Sanjai (150106)", "Salmonella (/25 g)"],
  [4097, "Keripik Sanjai (150106)", "Jumlah Sampel - Salmonella"],
  [
    4098,
    "Keripik Sanjai (150106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4099,
    "Keripik Sanjai (150106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4100,
    "Keripik Sanjai (150106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4101,
    "Keripik Sanjai (150106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4102,
    "Keripik Sanjai (150106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4103, "Keripik Singkong (150104)", "Salmonella (/25 g)"],
  [
    4104,
    "Keripik Singkong (150104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4105,
    "Keripik Singkong (150104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4106,
    "Keripik Singkong (150104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4107,
    "Keripik Singkong (150104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4108,
    "Keripik Singkong (150104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4109,
    "Keripik Singkong (150104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4110,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Salmonella (/25 g)",
  ],
  [
    4111,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4112,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4113,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4114,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4115,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4116,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4117, "Keripik Talas (150112)", "Salmonella (/25 g)"],
  [4118, "Keripik Talas (150112)", "Jumlah Sampel - Salmonella"],
  [
    4119,
    "Keripik Talas (150112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4120,
    "Keripik Talas (150112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4121,
    "Keripik Talas (150112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4122,
    "Keripik Talas (150112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4123,
    "Keripik Talas (150112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4124, "Keripik Tempe (150109)", "Salmonella (/25 g)"],
  [4125, "Keripik Tempe (150109)", "Jumlah Sampel - Salmonella"],
  [
    4126,
    "Keripik Tempe (150109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4127,
    "Keripik Tempe (150109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4128,
    "Keripik Tempe (150109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4129,
    "Keripik Tempe (150109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4130,
    "Keripik Tempe (150109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4131, "Keripik Ubi Jalar (150108)", "Salmonella (/25 g)"],
  [
    4132,
    "Keripik Ubi Jalar (150108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4133,
    "Keripik Ubi Jalar (150108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4134,
    "Keripik Ubi Jalar (150108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4135,
    "Keripik Ubi Jalar (150108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4136,
    "Keripik Ubi Jalar (150108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4137,
    "Keripik Ubi Jalar (150108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4138, "Kerupuk Beras (150123)", "Salmonella (/25 g)"],
  [4139, "Kerupuk Beras (150123)", "Jumlah Sampel - Salmonella"],
  [
    4140,
    "Kerupuk Beras (150123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4141,
    "Kerupuk Beras (150123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4142,
    "Kerupuk Beras (150123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4143,
    "Kerupuk Beras (150123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4144,
    "Kerupuk Beras (150123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4145,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4146,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4147,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4148,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4149,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4150,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4151,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4152,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4153,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4154,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4155,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4156,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4157,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4158,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4159,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4160,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4161,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4162,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4163,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4164,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4165,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4166,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4167,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4168,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4169,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4170,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Salmonella (/25 g)",
  ],
  [
    4171,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Salmonella (/25 g)",
  ],
  [
    4172,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Salmonella (/25 g)",
  ],
  [
    4173,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Salmonella (/25 g)",
  ],
  [
    4174,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Salmonella (/25 g)",
  ],
  [
    4175,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4176,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4177,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4178,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4179,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4180,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4181,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4182,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4183,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4184,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4185,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4186,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4187,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4188,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4189,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4190,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4191,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4192,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4193,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4194,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4195,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4196,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4197,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4198,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4199,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4200,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4201,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4202,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4203,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4204,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4205, "Kerupuk Cumi (150303 )", "Salmonella (/25 g)"],
  [4206, "Kerupuk Cumi (150303 )", "Jumlah Sampel - Salmonella"],
  [
    4207,
    "Kerupuk Cumi (150303 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4208,
    "Kerupuk Cumi (150303 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4209,
    "Kerupuk Cumi (150303 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4210,
    "Kerupuk Cumi (150303 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4211,
    "Kerupuk Cumi (150303 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4212, "Kerupuk Ikan (09020506)", "Salmonella (/25 g)"],
  [4213, "Kerupuk Ikan (09020506)", "Jumlah Sampel - Salmonella"],
  [4214, "Kerupuk Ikan (150301)", "Salmonella (/25 g)"],
  [4215, "Kerupuk Ikan (150301)", "Jumlah Sampel - Salmonella"],
  [
    4216,
    "Kerupuk Ikan (150301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4217,
    "Kerupuk Ikan (150301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4218,
    "Kerupuk Ikan (150301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4219,
    "Kerupuk Ikan (150301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4220,
    "Kerupuk Ikan (150301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4221, "Kerupuk Intip (150126)", "Salmonella (/25 g)"],
  [4222, "Kerupuk Intip (150126)", "Jumlah Sampel - Salmonella"],
  [
    4223,
    "Kerupuk Intip (150126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4224,
    "Kerupuk Intip (150126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4225,
    "Kerupuk Intip (150126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4226,
    "Kerupuk Intip (150126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4227,
    "Kerupuk Intip (150126)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4228, "Kerupuk Jengkol (0402020808)", "Salmonella (/25 g)"],
  [
    4229,
    "Kerupuk Jengkol (0402020808)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4230,
    "Kerupuk Jengkol (0402020808)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4231,
    "Kerupuk Jengkol (0402020808)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4232,
    "Kerupuk Jengkol (0402020808)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4233,
    "Kerupuk Jengkol (0402020808)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4234,
    "Kerupuk Jengkol (0402020808)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4235, "Kerupuk Karak (150125)", "Salmonella (/25 g)"],
  [4236, "Kerupuk Karak (150125)", "Jumlah Sampel - Salmonella"],
  [
    4237,
    "Kerupuk Karak (150125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4238,
    "Kerupuk Karak (150125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4239,
    "Kerupuk Karak (150125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4240,
    "Kerupuk Karak (150125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4241,
    "Kerupuk Karak (150125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4242,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Salmonella (/25 g)",
  ],
  [
    4243,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [4244, "Kerupuk Lainnya (150132 )", "Salmonella (/25 g)"],
  [
    4245,
    "Kerupuk Lainnya (150132 )",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4246,
    "Kerupuk Lainnya (150132 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4247,
    "Kerupuk Lainnya (150132 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4248,
    "Kerupuk Lainnya (150132 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4249,
    "Kerupuk Lainnya (150132 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4250,
    "Kerupuk Lainnya (150132 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4251, "Kerupuk Mentah (06040324)", "Salmonella (/25 g)"],
  [
    4252,
    "Kerupuk Mentah (06040324)",
    "Jumlah Sampel - Salmonella",
  ],
  [4253, "Kerupuk Puli (150124)", "Salmonella (/25 g)"],
  [4254, "Kerupuk Puli (150124)", "Jumlah Sampel - Salmonella"],
  [
    4255,
    "Kerupuk Puli (150124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4256,
    "Kerupuk Puli (150124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4257,
    "Kerupuk Puli (150124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4258,
    "Kerupuk Puli (150124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4259,
    "Kerupuk Puli (150124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4260, "Kerupuk Udang Matang (150302)", "Salmonella (/25 g)"],
  [
    4261,
    "Kerupuk Udang Matang (150302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4262,
    "Kerupuk Udang Matang (150302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4263,
    "Kerupuk Udang Matang (150302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4264,
    "Kerupuk Udang Matang (150302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4265,
    "Kerupuk Udang Matang (150302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4266,
    "Kerupuk Udang Matang (150302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4267, "Kerupuk Udang Mentah (09020510)", "Salmonella (/25 g)"],
  [
    4268,
    "Kerupuk Udang Mentah (09020510)",
    "Jumlah Sampel - Salmonella",
  ],
  [4269, "Ketumbar (12020161)", "Salmonella (/25 g)"],
  [4270, "Ketumbar (12020161)", "Jumlah Sampel - Salmonella"],
  [
    4271,
    "Ketumbar (12020161)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4272,
    "Ketumbar (12020161)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4273,
    "Ketumbar (12020161)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4274,
    "Ketumbar (12020161)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4275,
    "Ketumbar (12020161)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4276,
    "Ketumbar (12020161)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4277,
    "Ketumbar (12020161)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4278,
    "Ketumbar (12020161)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4279,
    "Ketumbar (12020161)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4280,
    "Ketumbar (12020161)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4281, "Ketumbar Bubuk (12020163)", "Salmonella (/25 g)"],
  [
    4282,
    "Ketumbar Bubuk (12020163)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4283,
    "Ketumbar Bubuk (12020163)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4284,
    "Ketumbar Bubuk (12020163)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4285,
    "Ketumbar Bubuk (12020163)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4286,
    "Ketumbar Bubuk (12020163)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4287,
    "Ketumbar Bubuk (12020163)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4288,
    "Ketumbar Bubuk (12020163)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4289,
    "Ketumbar Bubuk (12020163)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4290,
    "Ketumbar Bubuk (12020163)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4291,
    "Ketumbar Bubuk (12020163)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4292,
    "Ketumbar Bubuk (12020163)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4293,
    "Khoa (01030110)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4294,
    "Khoa (01030110)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4295,
    "Khoa (01030110)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4296,
    "Khoa (01030110)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4297,
    "Khoa (01030110)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [4298, "Kimchi (0402020708)", "Salmonella (/25 g)"],
  [4299, "Kimchi (0402020708)", "Jumlah Sampel - Salmonella"],
  [4300, "Kinako (06020123)", "Salmonella (/25 g)"],
  [4301, "Kinako (06020123)", "Jumlah Sampel - Salmonella"],
  [
    4302,
    "Kinako (06020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4303,
    "Kinako (06020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4304,
    "Kinako (06020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4305,
    "Kinako (06020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4306,
    "Kinako (06020123)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4307, "Kipang Kacang Mete (150206)", "Salmonella (/25 g)"],
  [
    4308,
    "Kipang Kacang Mete (150206)",
    "Jumlah Sampel - Salmonella",
  ],
  [4309, "Kitosan (Chitosan) (09020525)", "Salmonella (/25 g)"],
  [4310, "Kitosan (Chitosan) (09020525)", "Salmonella (/25 g)"],
  [4311, "Kitosan (Chitosan) (09020525)", "Salmonella (/25 g)"],
  [4312, "Kitosan (Chitosan) (09020525)", "Salmonella (/25 g)"],
  [
    4313,
    "Kitosan (Chitosan) (09020525)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4314,
    "Kitosan (Chitosan) (09020525)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4315,
    "Kitosan (Chitosan) (09020525)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4316,
    "Kitosan (Chitosan) (09020525)",
    "Jumlah Sampel - Salmonella",
  ],
  [4317, "Kluwek (12020165)", "Salmonella (/25 g)"],
  [4318, "Kluwek (12020165)", "Jumlah Sampel - Salmonella"],
  [
    4319,
    "Kluwek (12020165)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4320,
    "Kluwek (12020165)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4321,
    "Kluwek (12020165)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4322,
    "Kluwek (12020165)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4323,
    "Kluwek (12020165)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4324,
    "Kluwek (12020165)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4325,
    "Kluwek (12020165)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4326,
    "Kluwek (12020165)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4327,
    "Kluwek (12020165)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4328,
    "Kluwek (12020165)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4329,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Salmonella (/25 g)",
  ],
  [
    4330,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    4331,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4332,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Salmonella (/25 g)",
  ],
  [4333, "Kondimen (12020202)", "Salmonella (/25 g)-herba basah"],
  [
    4334,
    "Kondimen (12020202)",
    "Jumlah Sampel - Salmonella-herba basah",
  ],
  [
    4335,
    "Kondimen (12020202)",
    "Clostridium pefringens (koloni/g)-herba basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4336,
    "Kondimen (12020202)",
    "Clostridium pefringens (koloni/g)-herba basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4337,
    "Kondimen (12020202)",
    "Clostridium pefringens (koloni/g)-herba basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4338,
    "Kondimen (12020202)",
    "Clostridium pefringens (koloni/g)-herba basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4339,
    "Kondimen (12020202)",
    "Clostridium pefringens (koloni/g)-herba basah",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4340,
    "Konsentrat Lemonade Beku (1401040301)",
    "Salmonella (/25 g)",
  ],
  [
    4341,
    "Konsentrat Lemonade Beku (1401040301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4342,
    "Konsentrat Sari Kedelai (06080104)",
    "Salmonella (/25 g)",
  ],
  [
    4343,
    "Konsentrat Sari Kedelai (06080104)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [4344, "Kopra (0401020204)", "Jumlah Sampel - Salmonella"],
  [4345, "Kopra (0401020204)", "Salmonella (/25 g)"],
  [4346, "Kornet Daging (Beku) (08030308)", "Salmonella (/25 g)"],
  [4347, "Kornet Daging (Beku) (08030308)", "Salmonella (/25 g)"],
  [4348, "Kornet Daging (Beku) (08030308)", "Salmonella (/25 g)"],
  [4349, "Kornet Daging (Beku) (08030308)", "Jumlah - Salmonella"],
  [4350, "Kornet Daging (Beku) (08030308)", "Jumlah - Salmonella"],
  [
    4351,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4352,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4353,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4354,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4355,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4356,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4357,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4358,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4359,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4360,
    "Kornet Daging (Beku) (08030308)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4361,
    "Kornet Daging (Beku) (08030308)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4362,
    "Kornet Daging (Beku) (08030308)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4363,
    "Kornet Daging (Beku) (08030308)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4364,
    "Kornet Daging (Beku) (08030308)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    4365,
    "Kornet Daging (Beku) (08030308)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    4366,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Salmonella (/25 g)",
  ],
  [
    4367,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Salmonella (/25 g)",
  ],
  [
    4368,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Salmonella (/25 g)",
  ],
  [
    4369,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Jumlah - Salmonella",
  ],
  [
    4370,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Jumlah - Salmonella",
  ],
  [
    4371,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4372,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4373,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4374,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4375,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4376,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4377,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4378,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4379,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4380,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4381,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4382,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4383,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4384,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    4385,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    4386,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4387,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4388,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4389,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4390,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4391,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Salmonella (/25 g)",
  ],
  [
    4392,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Salmonella (/25 g)",
  ],
  [
    4393,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Jumlah - Salmonella",
  ],
  [
    4394,
    "Kornet Daging non sterilisasi (0803010111)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4395,
    "Kornet Daging non sterilisasi (0803010111)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4396,
    "Kornet Daging non sterilisasi (0803010111)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4397,
    "Kornet Daging non sterilisasi (0803010111)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4398,
    "Kornet Daging non sterilisasi (0803010111)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4399,
    "Kornet Daging non sterilisasi (0803010111)",
    "Salmonella (/25 g)",
  ],
  [
    4400,
    "Kornet Daging non sterilisasi (0803010111)",
    "Salmonella (/25 g)",
  ],
  [
    4401,
    "Kornet Daging non sterilisasi (0803010111)",
    "Jumlah - Salmonella",
  ],
  [4402, "Kornet Ikan (090411)", "Salmonella (/25 g)"],
  [4403, "Kornet Ikan (090411)", "Jumlah Sampel - Salmonella"],
  [
    4404,
    "Kornet Ikan (090411)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4405,
    "Kornet Ikan (090411)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    4406,
    "Kornet Unggas (Beku) (08030310)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    4407,
    "Kornet Unggas (Beku) (08030310)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4408,
    "Kornet Unggas (Beku) (08030310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4409,
    "Kornet Unggas (Beku) (08030310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4410,
    "Kornet Unggas (Beku) (08030310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4411,
    "Kornet Unggas (Beku) (08030310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4412,
    "Kornet Unggas (Beku) (08030310)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4413,
    "Kornet Unggas (Beku) (08030310)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    4414,
    "Kornet Unggas (Beku) (08030310)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    4415,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    4416,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4417,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4418,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4419,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4420,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4421,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4422,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    4423,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    4424,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4425,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4426,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4427,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4428,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4429,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Salmonella (/25 g)",
  ],
  [
    4430,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4431,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4432,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4433,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4434,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4435,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4436,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Salmonella (/25 g)",
  ],
  [
    4437,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Jumlah Sampel - Salmonella",
  ],
  [4438, "Krekers (07010201)", "Salmonella (/25 g)"],
  [4439, "Krekers (07010201)", "Jumlah Sampel - Salmonella"],
  [
    4440,
    "Krekers (07010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4441,
    "Krekers (07010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4442,
    "Krekers (07010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4443,
    "Krekers (07010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4444,
    "Krekers (07010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4445, "Krekers Beras (Senbei) (150103)", "Salmonella (/25 g)"],
  [
    4446,
    "Krekers Beras (Senbei) (150103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4447,
    "Krekers Beras (Senbei) (150103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4448,
    "Krekers Beras (Senbei) (150103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4449,
    "Krekers Beras (Senbei) (150103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4450,
    "Krekers Beras (Senbei) (150103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4451,
    "Krekers Beras (Senbei) (150103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4452,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Salmonella (/25 g)",
  ],
  [
    4453,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4454,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4455,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4456,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4457,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4458,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4459, "Krekers Krim (07010202)", "Salmonella (/25 g)"],
  [4460, "Krekers Krim (07010202)", "Jumlah Sampel - Salmonella"],
  [
    4461,
    "Krekers Krim (07010202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4462,
    "Krekers Krim (07010202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4463,
    "Krekers Krim (07010202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4464,
    "Krekers Krim (07010202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4465,
    "Krekers Krim (07010202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4466, "Krekers Rasa (150135)", "Salmonella (/25 g)"],
  [
    4467,
    "Krekers Rasa (150135)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    4468,
    "Krekers Rasa (150135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4469,
    "Krekers Rasa (150135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4470,
    "Krekers Rasa (150135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4471,
    "Krekers Rasa (150135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4472,
    "Krekers Rasa (150135)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [4473, "Krekers Sandwich (07010203)", "Salmonella (/25 g)"],
  [
    4474,
    "Krekers Sandwich (07010203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4475,
    "Krekers Sandwich (07010203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4476,
    "Krekers Sandwich (07010203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4477,
    "Krekers Sandwich (07010203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4478,
    "Krekers Sandwich (07010203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4479,
    "Krekers Sandwich (07010203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4480, "Krekers Sandwich (150136)", "Salmonella (/25 g)"],
  [
    4481,
    "Krekers Sandwich (150136)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    4482,
    "Krekers Sandwich (150136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4483,
    "Krekers Sandwich (150136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4484,
    "Krekers Sandwich (150136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4485,
    "Krekers Sandwich (150136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    4486,
    "Krekers Sandwich (150136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [4487, "Krekers Soda (07010206)", "Salmonella (/25 g)"],
  [4488, "Krekers Soda (07010206)", "Jumlah Sampel - Salmonella"],
  [
    4489,
    "Krekers Soda (07010206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4490,
    "Krekers Soda (07010206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4491,
    "Krekers Soda (07010206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4492,
    "Krekers Soda (07010206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4493,
    "Krekers Soda (07010206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [4494, "Krim (0104AA)", "Salmonella (/25 ml)"],
  [4495, "Krim (0104AA)", "Jumlah Sampel - Salmonella"],
  [
    4496,
    "Krim \x{201C}Whipping\x{201D} (Whipping Cream) Rendah Lemak (01040203)",
    "Salmonella (/25 ml)",
  ],
  [
    4497,
    "Krim \x{201C}Whipping\x{201D} (Whipping Cream) Rendah Lemak (01040203)",
    "Jumlah Sampel - Salmonella",
  ],
  [4498, "Krim Asam (01040301)", "Salmonella (/25 ml)"],
  [4499, "Krim Asam (01040301)", "Jumlah Sampel - Salmonella"],
  [
    4500,
    "Krim Bubuk (01050105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4501,
    "Krim Bubuk (01050105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4502,
    "Krim Bubuk (01050105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4503,
    "Krim Bubuk (01050105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4504,
    "Krim Bubuk (01050105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [4505, "Krim Bubuk (01050105)", "Salmonella (/25 ml)"],
  [4506, "Krim Bubuk (01050105)", "Jumlah Sampel - Salmonella"],
  [
    4507,
    "Krim Kental Manis (01030108)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4508,
    "Krim Kental Manis (01030108)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4509,
    "Krim Kental Manis (01030108)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4510,
    "Krim Kental Manis (01030108)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4511,
    "Krim Kental Manis (01030108)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4512,
    "Krim Nabati (01040401)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4513,
    "Krim Nabati (01040401)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4514,
    "Krim Nabati (01040401)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4515,
    "Krim Nabati (01040401)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4516,
    "Krim Nabati (01040401)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [4517, "Krim Nabati (01040401)", "Salmonella (/25 ml)"],
  [4518, "Krim Nabati (01040401)", "Jumlah Sampel - Salmonella"],
  [4519, "Krim Nabati Bubuk (01040402)", "Salmonella (/25 g)"],
  [
    4520,
    "Krim Nabati Bubuk (01040402)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    4521,
    "Krim Nabati Bubuk (01040402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4522,
    "Krim Nabati Bubuk (01040402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4523,
    "Krim Nabati Bubuk (01040402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4524,
    "Krim Nabati Bubuk (01040402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4525,
    "Krim Nabati Bubuk (01040402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4526,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Salmonella (/25 ml)",
  ],
  [
    4527,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Jumlah Sampel - Salmonella",
  ],
  [4528, "Krim Rendah Lemak (01040202)", "Salmonella (/25 ml)"],
  [
    4529,
    "Krim Rendah Lemak (01040202)",
    "Jumlah Sampel - Salmonella",
  ],
  [4530, "Krim yang Diasamkan (01040302)", "Salmonella (/25 ml)"],
  [
    4531,
    "Krim yang Diasamkan (01040302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4532,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Salmonella (/25 g)",
  ],
  [
    4533,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    4534,
    "Krimer Kental Manis (01030109)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4535,
    "Krimer Kental Manis (01030109)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4536,
    "Krimer Kental Manis (01030109)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4537,
    "Krimer Kental Manis (01030109)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4538,
    "Krimer Kental Manis (01030109)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4539,
    "Krimer Kental Manis (01030204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4540,
    "Krimer Kental Manis (01030204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4541,
    "Krimer Kental Manis (01030204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4542,
    "Krimer Kental Manis (01030204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4543,
    "Krimer Kental Manis (01030204)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4544,
    "Krimer Minuman (01030201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4545,
    "Krimer Minuman (01030201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4546,
    "Krimer Minuman (01030201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4547,
    "Krimer Minuman (01030201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    4548,
    "Krimer Minuman (01030201)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [4549, "Krimer Minuman (01030201)", "Salmonella (/25 ml)"],
  [
    4550,
    "Krimer Minuman (01030201)",
    "Jumlah Sampel - Salmonella",
  ],
  [4551, "Krokant/Brittles (05020212)", "Salmonella (Kembang"],
  [4552, "Gula/Permen"],
  [4553, "Lunak (bukan jeli)"],
  [4554, ") (/25 g)"],
  [
    4555,
    "Krokant/Brittles (05020212)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4556,
    "Krokant/Brittles (05020212)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4557,
    "Krokant/Brittles (05020212)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [4558, "Kucai/Chives (12020125)", "Salmonella (/25 g)"],
  [4559, "Kucai/Chives (12020125)", "Jumlah Sampel - Salmonella"],
  [4560, "Kue Ape (07020125)", "Salmonella (/25 g)"],
  [4561, "Kue Ape (07020125)", "Jumlah Sampel - Salmonella"],
  [
    4562,
    "Kue Ape (07020125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4563,
    "Kue Ape (07020125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4564,
    "Kue Ape (07020125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4565,
    "Kue Ape (07020125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4566,
    "Kue Ape (07020125)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4567,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4568,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4569,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4570,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4571,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4572,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Salmonella (/25 g)",
  ],
  [
    4573,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4574,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4575,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4576,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4577,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4578,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4579,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Salmonella (/25 g)",
  ],
  [
    4580,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4581,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4582,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4583,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4584,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4585,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4586, "Kue Cucur (07020121)", "Salmonella (/25 g)"],
  [4587, "Kue Cucur (07020121)", "Jumlah Sampel - Salmonella"],
  [
    4588,
    "Kue Cucur (07020121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4589,
    "Kue Cucur (07020121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4590,
    "Kue Cucur (07020121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4591,
    "Kue Cucur (07020121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4592,
    "Kue Cucur (07020121)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4593,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Salmonella (/25 g)",
  ],
  [
    4594,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    4595,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    4596,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    4597,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    4598,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    4599,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    4600,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4601,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    4602,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4603,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4604,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4605,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4606,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4607,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4608,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4609,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4610,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4611,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4612,
    "Kue Ku (060723)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4613,
    "Kue Ku (060723)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4614,
    "Kue Ku (060723)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4615,
    "Kue Ku (060723)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4616,
    "Kue Ku (060723)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4617, "Kue Ku (060723)", "Salmonella (/25 g)"],
  [4618, "Kue Ku (060723)", "Jumlah Sampel - Salmonella"],
  [
    4619,
    "Kue Ku (060723)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4620,
    "Kue Ku (060723)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4621,
    "Kue Ku (060723)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4622,
    "Kue Ku (060723)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4623,
    "Kue Ku (060723)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4624,
    "Kue Lapis Beras (060712)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4625,
    "Kue Lapis Beras (060712)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4626,
    "Kue Lapis Beras (060712)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4627,
    "Kue Lapis Beras (060712)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4628,
    "Kue Lapis Beras (060712)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4629, "Kue Lapis Beras (060712)", "Salmonella (/25 g)"],
  [4630, "Kue Lapis Beras (060712)", "Jumlah Sampel - Salmonella"],
  [
    4631,
    "Kue Lapis Beras (060712)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4632,
    "Kue Lapis Beras (060712)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4633,
    "Kue Lapis Beras (060712)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4634,
    "Kue Lapis Beras (060712)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4635,
    "Kue Lapis Beras (060712)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4636,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4637,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4638,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4639,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4640,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4641,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Salmonella (/25 g)",
  ],
  [
    4642,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4643,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4644,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4645,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4646,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4647,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4648,
    "Kue Mayang (060708)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4649,
    "Kue Mayang (060708)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4650,
    "Kue Mayang (060708)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4651,
    "Kue Mayang (060708)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4652,
    "Kue Mayang (060708)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4653, "Kue Mayang (060708)", "Salmonella (/25 g)"],
  [4654, "Kue Mayang (060708)", "Jumlah Sampel - Salmonella"],
  [
    4655,
    "Kue Mayang (060708)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4656,
    "Kue Mayang (060708)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4657,
    "Kue Mayang (060708)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4658,
    "Kue Mayang (060708)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4659,
    "Kue Mayang (060708)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4660,
    "Kue Mochi (060703)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4661,
    "Kue Mochi (060703)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4662,
    "Kue Mochi (060703)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4663,
    "Kue Mochi (060703)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4664,
    "Kue Mochi (060703)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4665, "Kue Mochi (060703)", "Salmonella (/25 g)"],
  [4666, "Kue Mochi (060703)", "Jumlah Sampel - Salmonella"],
  [
    4667,
    "Kue Mochi (060703)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4668,
    "Kue Mochi (060703)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4669,
    "Kue Mochi (060703)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4670,
    "Kue Mochi (060703)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4671,
    "Kue Mochi (060703)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4672,
    "Kue Putu (060707)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4673,
    "Kue Putu (060707)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4674,
    "Kue Putu (060707)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4675,
    "Kue Putu (060707)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4676,
    "Kue Putu (060707)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4677, "Kue Putu (060707)", "Salmonella (/25 g)"],
  [4678, "Kue Putu (060707)", "Jumlah Sampel - Salmonella"],
  [
    4679,
    "Kue Putu (060707)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4680,
    "Kue Putu (060707)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4681,
    "Kue Putu (060707)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4682,
    "Kue Putu (060707)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4683,
    "Kue Putu (060707)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4684,
    "Kue Teuck/Tteok (060704)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4685,
    "Kue Teuck/Tteok (060704)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4686,
    "Kue Teuck/Tteok (060704)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4687,
    "Kue Teuck/Tteok (060704)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4688,
    "Kue Teuck/Tteok (060704)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4689, "Kue Teuck/Tteok (060704)", "Salmonella (/25 g)"],
  [4690, "Kue Teuck/Tteok (060704)", "Jumlah Sampel - Salmonella"],
  [
    4691,
    "Kue Teuck/Tteok (060704)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4692,
    "Kue Teuck/Tteok (060704)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4693,
    "Kue Teuck/Tteok (060704)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4694,
    "Kue Teuck/Tteok (060704)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4695,
    "Kue Teuck/Tteok (060704)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [4696, "Kuetiaw Instan (06040306)", "Salmonella (/25 g)"],
  [
    4697,
    "Kuetiaw Instan (06040306)",
    "Jumlah Sampel - Salmonella",
  ],
  [4698, "Kuetiaw Kering (06040201)", "Salmonella (/25 g)"],
  [
    4699,
    "Kuetiaw Kering (06040201)",
    "Jumlah Sampel - Salmonella",
  ],
  [4700, "Kuetiaw Lainnya (06040220)", "Salmonella (/25 g)"],
  [
    4701,
    "Kuetiaw Lainnya (06040220)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [4702, "Kukis (07020115)", "Salmonella (/25 g)"],
  [4703, "Kukis (07020115)", "Jumlah Sampel - Salmonella"],
  [
    4704,
    "Kukis (07020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4705,
    "Kukis (07020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4706,
    "Kukis (07020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4707,
    "Kukis (07020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4708,
    "Kukis (07020115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4709, "Kukis Gula (07020116)", "Salmonella (/25 g)"],
  [4710, "Kukis Gula (07020116)", "Jumlah Sampel - Salmonella"],
  [
    4711,
    "Kukis Gula (07020116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4712,
    "Kukis Gula (07020116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4713,
    "Kukis Gula (07020116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4714,
    "Kukis Gula (07020116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4715,
    "Kukis Gula (07020116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4716,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Salmonella (/25 g)",
  ],
  [
    4717,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4718,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4719,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4720,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4721,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4722,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4723, "Kukis Oatmeal (07020117)", "Salmonella (/25 g)"],
  [4724, "Kukis Oatmeal (07020117)", "Jumlah Sampel - Salmonella"],
  [
    4725,
    "Kukis Oatmeal (07020117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4726,
    "Kukis Oatmeal (07020117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4727,
    "Kukis Oatmeal (07020117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4728,
    "Kukis Oatmeal (07020117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4729,
    "Kukis Oatmeal (07020117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [4730, "Kulit Ayam Goreng (08020311)", "Salmonella (/25 g)"],
  [
    4731,
    "Kulit Ayam Goreng (08020311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4732,
    "Kulit Ayam Goreng (08020311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4733,
    "Kulit Ayam Goreng (08020311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4734,
    "Kulit Ayam Goreng (08020311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4735,
    "Kulit Ayam Goreng (08020311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4736,
    "Kulit Ayam Goreng (08020311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    4737,
    "Kulit Ayam Goreng (08020311)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    4738,
    "Kulit Ayam Goreng (08020311)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    4739,
    "Kulit Keju Peram (01060202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    4740,
    "Kulit Keju Peram (01060202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    4741,
    "Kulit Keju Peram (01060202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    4742,
    "Kulit Keju Peram (01060202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    4743,
    "Kulit Keju Peram (01060202)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    4744,
    "Kulit Keju Peram (01060202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4745,
    "Kulit Keju Peram (01060202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4746,
    "Kulit Keju Peram (01060202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4747,
    "Kulit Keju Peram (01060202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4748,
    "Kulit Keju Peram (01060202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    4749,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Salmonella (/25 g)",
  ],
  [
    4750,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4751,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4752,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4753,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4754,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    4755,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [4756, "Kumys (010201B0)", "Salmonella (/25 ml)"],
  [4757, "Kumys (010201B0)", "Jumlah Sampel - Salmonella"],
  [
    4758,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Salmonella (negatif/25 g)",
  ],
  [
    4759,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    4760,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Salmonella (/25 g)",
  ],
  [
    4761,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [4762, "Kuning Telur Beku (10020203)", "Salmonella (/25 g)"],
  [
    4763,
    "Kuning Telur Beku (10020203)",
    "Jumlah Sampel - Salmonella",
  ],
  [4764, "Kunyit (12020166)", "Salmonella (/25 g)"],
  [4765, "Kunyit (12020166)", "Jumlah Sampel - Salmonella"],
  [
    4766,
    "Kunyit (12020166)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4767,
    "Kunyit (12020166)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4768,
    "Kunyit (12020166)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4769,
    "Kunyit (12020166)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4770,
    "Kunyit (12020166)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4771,
    "Kunyit (12020166)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4772,
    "Kunyit (12020166)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4773,
    "Kunyit (12020166)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4774,
    "Kunyit (12020166)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4775,
    "Kunyit (12020166)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4776, "Kunyit Bubuk (12020167)", "Salmonella (/25 g)"],
  [4777, "Kunyit Bubuk (12020167)", "Jumlah Sampel - Salmonella"],
  [
    4778,
    "Kunyit Bubuk (12020167)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4779,
    "Kunyit Bubuk (12020167)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4780,
    "Kunyit Bubuk (12020167)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4781,
    "Kunyit Bubuk (12020167)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4782,
    "Kunyit Bubuk (12020167)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4783,
    "Kunyit Bubuk (12020167)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4784,
    "Kunyit Bubuk (12020167)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4785,
    "Kunyit Bubuk (12020167)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4786,
    "Kunyit Bubuk (12020167)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4787,
    "Kunyit Bubuk (12020167)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4788, "Lada Bubuk Campuran (12020172)", "Salmonella (/25 g)"],
  [
    4789,
    "Lada Bubuk Campuran (12020172)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4790,
    "Lada Bubuk Campuran (12020172)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4791,
    "Lada Bubuk Campuran (12020172)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4792,
    "Lada Bubuk Campuran (12020172)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4793,
    "Lada Bubuk Campuran (12020172)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4794,
    "Lada Bubuk Campuran (12020172)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4795,
    "Lada Bubuk Campuran (12020172)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4796,
    "Lada Bubuk Campuran (12020172)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4797,
    "Lada Bubuk Campuran (12020172)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4798,
    "Lada Bubuk Campuran (12020172)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4799,
    "Lada Bubuk Campuran (12020172)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4800, "Lada Hitam (12020168)", "Salmonella (/25 g)"],
  [4801, "Lada Hitam (12020168)", "Jumlah Sampel - Salmonella"],
  [
    4802,
    "Lada Hitam (12020168)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4803,
    "Lada Hitam (12020168)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4804,
    "Lada Hitam (12020168)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4805,
    "Lada Hitam (12020168)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4806,
    "Lada Hitam (12020168)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4807,
    "Lada Hitam (12020168)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4808,
    "Lada Hitam (12020168)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4809,
    "Lada Hitam (12020168)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4810,
    "Lada Hitam (12020168)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4811,
    "Lada Hitam (12020168)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4812, "Lada Hitam Bubuk (12020169)", "Salmonella (/25 g)"],
  [
    4813,
    "Lada Hitam Bubuk (12020169)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4814,
    "Lada Hitam Bubuk (12020169)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4815,
    "Lada Hitam Bubuk (12020169)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4816,
    "Lada Hitam Bubuk (12020169)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4817,
    "Lada Hitam Bubuk (12020169)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4818,
    "Lada Hitam Bubuk (12020169)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4819,
    "Lada Hitam Bubuk (12020169)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4820,
    "Lada Hitam Bubuk (12020169)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4821,
    "Lada Hitam Bubuk (12020169)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4822,
    "Lada Hitam Bubuk (12020169)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4823,
    "Lada Hitam Bubuk (12020169)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4824, "Lada Putih (12020170)", "Salmonella (/25 g)"],
  [4825, "Lada Putih (12020170)", "Jumlah Sampel - Salmonella"],
  [
    4826,
    "Lada Putih (12020170)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4827,
    "Lada Putih (12020170)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4828,
    "Lada Putih (12020170)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4829,
    "Lada Putih (12020170)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4830,
    "Lada Putih (12020170)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4831,
    "Lada Putih (12020170)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4832,
    "Lada Putih (12020170)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4833,
    "Lada Putih (12020170)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4834,
    "Lada Putih (12020170)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4835,
    "Lada Putih (12020170)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4836, "Lada Putih Bubuk (12020171)", "Salmonella (/25 g)"],
  [
    4837,
    "Lada Putih Bubuk (12020171)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4838,
    "Lada Putih Bubuk (12020171)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4839,
    "Lada Putih Bubuk (12020171)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4840,
    "Lada Putih Bubuk (12020171)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4841,
    "Lada Putih Bubuk (12020171)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4842,
    "Lada Putih Bubuk (12020171)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4843,
    "Lada Putih Bubuk (12020171)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4844,
    "Lada Putih Bubuk (12020171)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4845,
    "Lada Putih Bubuk (12020171)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4846,
    "Lada Putih Bubuk (12020171)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4847,
    "Lada Putih Bubuk (12020171)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4848,
    "Lalampa (060728)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4849,
    "Lalampa (060728)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4850,
    "Lalampa (060728)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4851,
    "Lalampa (060728)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4852,
    "Lalampa (060728)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4853, "Lalampa (060728)", "Salmonella (/25 g)"],
  [4854, "Lalampa (060728)", "Jumlah Sampel - Salmonella"],
  [
    4855,
    "Lalampa (060728)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4856,
    "Lalampa (060728)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4857,
    "Lalampa (060728)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4858,
    "Lalampa (060728)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4859,
    "Lalampa (060728)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4860,
    "Lamang (060732)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4861,
    "Lamang (060732)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4862,
    "Lamang (060732)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4863,
    "Lamang (060732)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4864,
    "Lamang (060732)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4865, "Lamang (060732)", "Salmonella (/25 g)"],
  [4866, "Lamang (060732)", "Jumlah Sampel - Salmonella"],
  [
    4867,
    "Lamang (060732)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4868,
    "Lamang (060732)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4869,
    "Lamang (060732)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4870,
    "Lamang (060732)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4871,
    "Lamang (060732)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4872,
    "Lampu-Lampu (060716)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4873,
    "Lampu-Lampu (060716)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4874,
    "Lampu-Lampu (060716)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4875,
    "Lampu-Lampu (060716)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4876,
    "Lampu-Lampu (060716)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4877, "Lampu-Lampu (060716)", "Salmonella (/25 g)"],
  [4878, "Lampu-Lampu (060716)", "Jumlah Sampel - Salmonella"],
  [
    4879,
    "Lampu-Lampu (060716)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4880,
    "Lampu-Lampu (060716)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4881,
    "Lampu-Lampu (060716)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4882,
    "Lampu-Lampu (060716)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4883,
    "Lampu-Lampu (060716)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4884,
    "Lapek Bugis (060731)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4885,
    "Lapek Bugis (060731)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4886,
    "Lapek Bugis (060731)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4887,
    "Lapek Bugis (060731)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4888,
    "Lapek Bugis (060731)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4889, "Lapek Bugis (060731)", "Salmonella (/25 g)"],
  [4890, "Lapek Bugis (060731)", "Jumlah Sampel - Salmonella"],
  [
    4891,
    "Lapek Bugis (060731)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4892,
    "Lapek Bugis (060731)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4893,
    "Lapek Bugis (060731)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4894,
    "Lapek Bugis (060731)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4895,
    "Lapek Bugis (060731)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [4896, "Lassi (Plain) (01010205)", "Salmonella (/25 ml)"],
  [4897, "Lassi (Plain) (01010205)", "Jumlah Sampel - Salmonella"],
  [
    4898,
    "Legomoro (060735)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4899,
    "Legomoro (060735)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4900,
    "Legomoro (060735)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4901,
    "Legomoro (060735)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4902,
    "Legomoro (060735)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4903, "Legomoro (060735)", "Salmonella (/25 g)"],
  [
    4904,
    "Legomoro (060735)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    4905,
    "Legomoro (060735)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4906,
    "Legomoro (060735)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4907,
    "Legomoro (060735)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4908,
    "Legomoro (060735)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4909,
    "Legomoro (060735)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4910,
    "Legondo (060724)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4911,
    "Legondo (060724)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4912,
    "Legondo (060724)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4913,
    "Legondo (060724)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4914,
    "Legondo (060724)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4915, "Legondo (060724)", "Salmonella (/25 g)"],
  [4916, "Legondo (060724)", "Jumlah Sampel - Salmonella"],
  [
    4917,
    "Legondo (060724)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4918,
    "Legondo (060724)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4919,
    "Legondo (060724)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4920,
    "Legondo (060724)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4921,
    "Legondo (060724)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4922,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Salmonella (/25 g)",
  ],
  [
    4923,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4924,
    "Lemak Kakao untuk Confectionery (05010405)",
    "Salmonella (/25 g)",
  ],
  [
    4925,
    "Lemak Kakao untuk Confectionery (05010405)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4926,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4927,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Salmonella (/25 g)",
  ],
  [
    4928,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    4929,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    4930,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    4931,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    4932,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    4933,
    "Lemper Ayam (060719)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4934,
    "Lemper Ayam (060719)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4935,
    "Lemper Ayam (060719)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4936,
    "Lemper Ayam (060719)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4937,
    "Lemper Ayam (060719)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4938, "Lemper Ayam (060719)", "Salmonella (/25 g)"],
  [4939, "Lemper Ayam (060719)", "Jumlah Sampel - Salmonella"],
  [
    4940,
    "Lemper Ayam (060719)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4941,
    "Lemper Ayam (060719)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4942,
    "Lemper Ayam (060719)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4943,
    "Lemper Ayam (060719)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4944,
    "Lemper Ayam (060719)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [4945, "Lempuyang (120201A5)", "Salmonella (/25 g)"],
  [4946, "Lempuyang (120201A5)", "Jumlah Sampel - Salmonella"],
  [
    4947,
    "Lempuyang (120201A5)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4948,
    "Lempuyang (120201A5)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4949,
    "Lempuyang (120201A5)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4950,
    "Lempuyang (120201A5)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4951,
    "Lempuyang (120201A5)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4952,
    "Lempuyang (120201A5)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4953,
    "Lempuyang (120201A5)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4954,
    "Lempuyang (120201A5)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4955,
    "Lempuyang (120201A5)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4956,
    "Lempuyang (120201A5)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4957, "Lengkuas/Laos (12020174)", "Salmonella (/25 g)"],
  [4958, "Lengkuas/Laos (12020174)", "Jumlah Sampel - Salmonella"],
  [
    4959,
    "Lengkuas/Laos (12020174)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4960,
    "Lengkuas/Laos (12020174)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4961,
    "Lengkuas/Laos (12020174)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4962,
    "Lengkuas/Laos (12020174)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4963,
    "Lengkuas/Laos (12020174)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4964,
    "Lengkuas/Laos (12020174)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4965,
    "Lengkuas/Laos (12020174)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4966,
    "Lengkuas/Laos (12020174)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4967,
    "Lengkuas/Laos (12020174)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4968,
    "Lengkuas/Laos (12020174)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4969, "Lengkuas/Laos Bubuk (12020175)", "Salmonella (/25 g)"],
  [
    4970,
    "Lengkuas/Laos Bubuk (12020175)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    4971,
    "Lengkuas/Laos Bubuk (12020175)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4972,
    "Lengkuas/Laos Bubuk (12020175)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4973,
    "Lengkuas/Laos Bubuk (12020175)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4974,
    "Lengkuas/Laos Bubuk (12020175)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4975,
    "Lengkuas/Laos Bubuk (12020175)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    4976,
    "Lengkuas/Laos Bubuk (12020175)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4977,
    "Lengkuas/Laos Bubuk (12020175)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4978,
    "Lengkuas/Laos Bubuk (12020175)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4979,
    "Lengkuas/Laos Bubuk (12020175)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4980,
    "Lengkuas/Laos Bubuk (12020175)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4981,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4982,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4983,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4984,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4985,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4986,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4987,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4988,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4989,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    4990,
    "Lepet Ketan (060722)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [4991, "Lepet Ketan (060722)", "Salmonella (/25 g)"],
  [4992, "Lepet Ketan (060722)", "Salmonella (/25 g)"],
  [4993, "Lepet Ketan (060722)", "Jumlah Sampel - Salmonella"],
  [4994, "Lepet Ketan (060722)", "Jumlah Sampel - Salmonella"],
  [
    4995,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4996,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4997,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4998,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    4999,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5000,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5001,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5002,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5003,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5004,
    "Lepet Ketan (060722)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5005, "Licorice (05020205)", "Salmonella (Kembang"],
  [5006, "Gula/Permen"],
  [5007, "Lunak (bukan jeli)"],
  [5008, ") (/25 g)"],
  [5009, "Licorice (05020205)", "Jumlah Sampel - Salmonella"],
  [5010, "Licorice (05020205)", "Jumlah Sampel - Salmonella"],
  [
    5011,
    "Licorice (05020205)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [
    5012,
    "Lobster Rebus Beku (0902040203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    5013,
    "Lobster Rebus Beku (0902040203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    5014,
    "Lobster Rebus Beku (0902040203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    5015,
    "Lobster Rebus Beku (0902040203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    5016,
    "Lobster Rebus Beku (0902040203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [5017, "Lobster Rebus Beku (0902040203)", "Salmonella (/25 g)"],
  [
    5018,
    "Lobster Rebus Beku (0902040203)",
    "Jumlah Sampel - Salmonella",
  ],
  [5019, "Lumpia Daging (08030314)", "Salmonella (/25 g)"],
  [5020, "Lumpia Daging (08030314)", "Salmonella (/25 g)"],
  [5021, "Lumpia Daging (08030314)", "Jumlah - Salmonella"],
  [5022, "Lumpia Daging (08030314)", "Jumlah - Salmonella"],
  [
    5023,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5024,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5025,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5026,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5027,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5028,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5029,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5030,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5031,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5032,
    "Lumpia Daging (08030314)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5033,
    "Lumpia Daging (08030314)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5034,
    "Lumpia Daging (08030314)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5035,
    "Lumpia Daging (08030314)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    5036,
    "Lumpia Daging (08030314)",
    "Jumlah - Listeria monocytogenes",
  ],
  [5037, "Maida (06020125)", "Salmonella (/25 g)"],
  [5038, "Maida (06020125)", "Jumlah Sampel - Salmonella"],
  [
    5039,
    "Maida (06020125)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5040,
    "Maida (06020125)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5041,
    "Maida (06020125)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5042,
    "Maida (06020125)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5043,
    "Maida (06020125)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5044,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5045,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5046,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5047,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5048,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5049,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5050,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5051,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5052,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5053,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5054,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5055,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5056,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5057,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5058,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5059,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5060,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5061,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5062,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5063,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5064,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5065,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5066,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5067,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5068,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5069,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5070,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5071,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5072,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5073,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5074,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5075,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5076,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5077,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5078,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5079,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5080,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5081,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5082,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5083,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5084,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5085,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5086,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5087,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5088,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5089,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5090,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5091,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5092,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5093,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5094,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5095,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5096,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5097,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5098,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5099,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5100,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5101,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5102,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5103,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5104,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5105,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5106,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5107,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5108,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5109,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5110,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5111,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5112,
    "Makanan Diet Kurang Laktosa (130303)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5113,
    "Makanan Diet Kurang Laktosa (130303)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5114,
    "Makanan Diet Kurang Laktosa (130303)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5115,
    "Makanan Diet Kurang Laktosa (130303)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5116,
    "Makanan Diet Kurang Laktosa (130303)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5117,
    "Makanan Diet Kurang Laktosa (130303)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5118,
    "Makanan Diet Kurang Laktosa (130303)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5119,
    "Makanan Diet Kurang Laktosa (130303)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5120,
    "Makanan Diet Kurang Laktosa (130303)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5121,
    "Makanan Diet Kurang Laktosa (130303)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5122,
    "Makanan Diet Kurang Laktosa (130303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5123,
    "Makanan Diet Kurang Laktosa (130303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5124,
    "Makanan Diet Kurang Laktosa (130303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5125,
    "Makanan Diet Kurang Laktosa (130303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5126,
    "Makanan Diet Kurang Laktosa (130303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5127,
    "Makanan Diet Kurang Laktosa (130303)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5128,
    "Makanan Diet Kurang Laktosa (130303)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5129,
    "Makanan Diet Rendah Laktosa (130304)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5130,
    "Makanan Diet Rendah Laktosa (130304)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5131,
    "Makanan Diet Rendah Laktosa (130304)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5132,
    "Makanan Diet Rendah Laktosa (130304)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5133,
    "Makanan Diet Rendah Laktosa (130304)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5134,
    "Makanan Diet Rendah Laktosa (130304)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5135,
    "Makanan Diet Rendah Laktosa (130304)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5136,
    "Makanan Diet Rendah Laktosa (130304)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5137,
    "Makanan Diet Rendah Laktosa (130304)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5138,
    "Makanan Diet Rendah Laktosa (130304)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5139,
    "Makanan Diet Rendah Laktosa (130304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5140,
    "Makanan Diet Rendah Laktosa (130304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5141,
    "Makanan Diet Rendah Laktosa (130304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5142,
    "Makanan Diet Rendah Laktosa (130304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5143,
    "Makanan Diet Rendah Laktosa (130304)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5144,
    "Makanan Diet Rendah Laktosa (130304)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5145,
    "Makanan Diet Rendah Laktosa (130304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5146,
    "Makanan Diet Rendah Natrium (130311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5147,
    "Makanan Diet Rendah Natrium (130311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5148,
    "Makanan Diet Rendah Natrium (130311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5149,
    "Makanan Diet Rendah Natrium (130311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5150,
    "Makanan Diet Rendah Natrium (130311)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5151,
    "Makanan Diet Rendah Natrium (130311)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5152,
    "Makanan Diet Rendah Natrium (130311)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5153,
    "Makanan Diet Rendah Natrium (130311)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5154,
    "Makanan Diet Rendah Natrium (130311)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5155,
    "Makanan Diet Rendah Natrium (130311)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5156,
    "Makanan Diet Rendah Natrium (130311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5157,
    "Makanan Diet Rendah Natrium (130311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5158,
    "Makanan Diet Rendah Natrium (130311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5159,
    "Makanan Diet Rendah Natrium (130311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5160,
    "Makanan Diet Rendah Natrium (130311)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5161,
    "Makanan Diet Rendah Natrium (130311)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5162,
    "Makanan Diet Rendah Natrium (130311)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5163,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5164,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5165,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5166,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5167,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5168,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5169,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5170,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5171,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5172,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5173,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5174,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5175,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5176,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5177,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5178,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5179,
    "Makanan Diet Sangat Rendah Natrium (130313)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5180,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5181,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5182,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5183,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5184,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5185,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5186,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5187,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5188,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5189,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5190,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5191,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5192,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5193,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5194,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5195,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5196,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5197,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5198,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5199,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5200,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5201,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5202,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5203,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5204,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5205,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5206,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5207,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5208,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5209,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5210,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5211,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5212,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5213,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5214,
    "Makanan Hipoalergenik (130301)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5215,
    "Makanan Hipoalergenik (130301)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5216,
    "Makanan Hipoalergenik (130301)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5217,
    "Makanan Hipoalergenik (130301)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5218,
    "Makanan Hipoalergenik (130301)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5219,
    "Makanan Hipoalergenik (130301)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5220,
    "Makanan Hipoalergenik (130301)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5221,
    "Makanan Hipoalergenik (130301)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5222,
    "Makanan Hipoalergenik (130301)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5223,
    "Makanan Hipoalergenik (130301)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5224,
    "Makanan Hipoalergenik (130301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5225,
    "Makanan Hipoalergenik (130301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5226,
    "Makanan Hipoalergenik (130301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5227,
    "Makanan Hipoalergenik (130301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5228,
    "Makanan Hipoalergenik (130301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5229,
    "Makanan Hipoalergenik (130301)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5230,
    "Makanan Hipoalergenik (130301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5231,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5232,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5233,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5234,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5235,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5236,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5237,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5238,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5239,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5240,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5241,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5242,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5243,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5244,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5245,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5246,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5247,
    "Makanan Pendamping ASI (MP-ASI) Biskuit (130205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5248,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5249,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5250,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5251,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5252,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5253,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5254,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5255,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5256,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5257,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5258,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5259,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5260,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5261,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5262,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5263,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5264,
    "Makanan Pendamping ASI (MP-ASI) Bubuk Instan (130202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5265,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5266,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5267,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5268,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5269,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5270,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5271,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5272,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5273,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5274,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5275,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5276,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5277,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5278,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5279,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5280,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5281,
    "Makanan Pendamping ASI (MP-ASI) Siap Masak (130204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5282,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5283,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5284,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5285,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5286,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5287,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5288,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5289,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5290,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5291,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5292,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5293,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5294,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5295,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5296,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5297,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5298,
    "Makanan Pendamping ASI (MP-ASI) Siap Santap (130203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5299,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Salmonella (/25 g)",
  ],
  [
    5300,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5301,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Salmonella (/25 g)",
  ],
  [
    5302,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5303,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5304,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5305,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5306,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5307,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5308,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Salmonella (/25 g)",
  ],
  [
    5309,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5310,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5311,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5312,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5313,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5314,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5315,
    "Makanan Ringan Ekstrudat (150129 )",
    "Salmonella (/25 g)",
  ],
  [
    5316,
    "Makanan Ringan Ekstrudat (150129 )",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5317,
    "Makanan Ringan Ekstrudat (150129 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5318,
    "Makanan Ringan Ekstrudat (150129 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5319,
    "Makanan Ringan Ekstrudat (150129 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5320,
    "Makanan Ringan Ekstrudat (150129 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5321,
    "Makanan Ringan Ekstrudat (150129 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [5322, "Makanan Ringan Lain (150133)", "Salmonella (/25 g)"],
  [
    5323,
    "Makanan Ringan Lain (150133)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5324,
    "Makanan Ringan Lain (150133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5325,
    "Makanan Ringan Lain (150133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5326,
    "Makanan Ringan Lain (150133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5327,
    "Makanan Ringan Lain (150133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5328,
    "Makanan Ringan Lain (150133)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [5329, "Makanan Ringan Simulasi (150113)", "Salmonella (/25 g)"],
  [
    5330,
    "Makanan Ringan Simulasi (150113)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5331,
    "Makanan Ringan Simulasi (150113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5332,
    "Makanan Ringan Simulasi (150113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5333,
    "Makanan Ringan Simulasi (150113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5334,
    "Makanan Ringan Simulasi (150113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5335,
    "Makanan Ringan Simulasi (150113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5336,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Salmonella (/25 g)",
  ],
  [
    5337,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5338,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5339,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5340,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5341,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5342,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5343,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5344,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5345,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Salmonella (/25 g)",
  ],
  [
    5346,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5347,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5348,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5349,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5350,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5351,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5352,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5353,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5354,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Salmonella (/25 g)",
  ],
  [
    5355,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5356,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5357,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5358,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5359,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5360,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5361,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5362,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5363,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Salmonella (/25 g)",
  ],
  [
    5364,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5365,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5366,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5367,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5368,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5369,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5370,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5371,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5372,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5373,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5374,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5375,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5376,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Salmonella (/25 g)",
  ],
  [
    5377,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5378,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5379,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5380,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5381,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5382,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5383,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5384,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5385,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Salmonella (/25 g)",
  ],
  [
    5386,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5387,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5388,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5389,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5390,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5391,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5392,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5393,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5394,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Salmonella (/25 g)",
  ],
  [
    5395,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5396,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5397,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5398,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5399,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5400,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5401,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5402,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [
    5403,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Salmonella (/25 g)",
  ],
  [
    5404,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5405,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5406,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5407,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5408,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5409,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5410,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5411,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Jumlah Sampel - Listeria monocytogenes",
    "",
    "\x{2265}5",
  ],
  [5412, "Makaroni (06040202)", "Salmonella (/25 g)"],
  [5413, "Makaroni (06040202)", "Jumlah Sampel - Salmonella"],
  [5414, "Makaroni (06040302)", "Salmonella (/25 g)"],
  [5415, "Makaroni (06040302)", "Jumlah Sampel - Salmonella"],
  [5416, "Makaroni Instan (06040307)", "Salmonella (/25 g)"],
  [
    5417,
    "Makaroni Instan (06040307)",
    "Jumlah Sampel - Salmonella",
  ],
  [5418, "Malkist (07010204)", "Salmonella (/25 g)"],
  [5419, "Malkist (07010204)", "Jumlah Sampel - Salmonella"],
  [
    5420,
    "Malkist (07010204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5421,
    "Malkist (07010204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5422,
    "Malkist (07010204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5423,
    "Malkist (07010204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5424,
    "Malkist (07010204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [5425, "Malkist (150137)", "Salmonella (/25 g)"],
  [
    5426,
    "Malkist (150137)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    5427,
    "Malkist (150137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5428,
    "Malkist (150137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5429,
    "Malkist (150137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5430,
    "Malkist (150137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5431,
    "Malkist (150137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [5432, "Manjyu (07010508)", "Salmonella (/25 g)"],
  [5433, "Manjyu (07010508)", "Jumlah Sampel - Salmonella"],
  [5434, "Mantao (07010501)", "Salmonella (/25 g)"],
  [5435, "Mantao (07010501)", "Jumlah Sampel - Salmonella"],
  [5436, "Margarin (02020205)", "Jumlah Sampel - Salmonella"],
  [5437, "Margarin (02020205)", "Salmonella (/25 g)"],
  [
    5438,
    "Margarin (02020205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5439,
    "Margarin (02020205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5440,
    "Margarin (02020205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5441,
    "Margarin (02020205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5442,
    "Margarin (02020205)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5443,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5444,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Salmonella (/25 g)",
  ],
  [
    5445,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5446,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5447,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5448,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5449,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [5450, "Margarin Meja (02020207)", "Jumlah Sampel - Salmonella"],
  [5451, "Margarin Meja (02020207)", "Salmonella (/25 g)"],
  [
    5452,
    "Margarin Meja (02020207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5453,
    "Margarin Meja (02020207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5454,
    "Margarin Meja (02020207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5455,
    "Margarin Meja (02020207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5456,
    "Margarin Meja (02020207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [5457, "Marjoram (12020177)", "Salmonella (/25 g)"],
  [5458, "Marjoram (12020177)", "Jumlah Sampel - Salmonella"],
  [5459, "Marshmallow (05020208)", "Salmonella (Kembang"],
  [5460, "Gula/Permen"],
  [5461, "Lunak (bukan jeli)"],
  [5462, ") (/25 g)"],
  [5463, "Marshmallow (05020208)", "Jumlah Sampel - Salmonella"],
  [5464, "Marshmallow (05020208)", "Jumlah Sampel - Salmonella"],
  [
    5465,
    "Marshmallow (05020208)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [5466, "Martabak Telur (100405)", "Salmonella (/25 g)"],
  [5467, "Martabak Telur (100405)", "Jumlah Sampel - Salmonella"],
  [
    5468,
    "Martabak Telur (100405)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    5469,
    "Martabak Telur (100405)",
    "Listeria monocytogenes (koloni/25 g) - Khusus Produk Beku",
  ],
  [
    5470,
    "Marzipan, Almond Paste (05020306)",
    "Salmonella (/25 g)",
  ],
  [
    5471,
    "Marzipan, Almond Paste (05020306)",
    "Jumlah Sampel - Salmonella",
  ],
  [5472, "Masin (09020521)", "Salmonella (/25 g)"],
  [5473, "Masin (09020521)", "Jumlah Sampel - Salmonella"],
  [5474, "Mayonais, Mayonnaise (12060101)", "Salmonella (/25 g)"],
  [
    5475,
    "Mayonais, Mayonnaise (12060101)",
    "Jumlah Sampel - Salmonella",
  ],
  [5476, "Meal (060303)", "Salmonella (/25 g)"],
  [5477, "Meal (060303)", "Jumlah Sampel - Salmonella"],
  [
    5478,
    "Meal (060303)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5479,
    "Meal (060303)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5480,
    "Meal (060303)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5481,
    "Meal (060303)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5482,
    "Meal (060303)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5483,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Salmonella (/25 g)",
  ],
  [
    5484,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5485,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5486,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5487,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5488,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5489,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5490,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5491,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Salmonella (/25 g)",
  ],
  [5492, "Mentega (0202010101)", "Jumlah Sampel - Salmonella"],
  [5493, "Mentega (0202010101)", "Salmonella (/25 g)"],
  [
    5494,
    "Mentega (0202010101)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5495,
    "Mentega (0202010101)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5496,
    "Mentega (0202010101)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5497,
    "Mentega (0202010101)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5498,
    "Mentega (0202010101)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5499,
    "Mentega Rekombinasi (0202010102)",
    "Jumlah Sampel - Salmonella",
  ],
  [5500, "Mentega Rekombinasi (0202010102)", "Salmonella (/25 g)"],
  [
    5501,
    "Mentega Rekombinasi (0202010102)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5502,
    "Mentega Rekombinasi (0202010102)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5503,
    "Mentega Rekombinasi (0202010102)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5504,
    "Mentega Rekombinasi (0202010102)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5505,
    "Mentega Rekombinasi (0202010102)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5506,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Salmonella (/25 g)",
  ],
  [
    5507,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5508,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Salmonella (/25 g)",
  ],
  [
    5509,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Jumlah Sampel - Salmonella",
  ],
  [5510, "Mesoyi (120201A6)", "Salmonella (/25 g)"],
  [5511, "Mesoyi (120201A6)", "Jumlah Sampel - Salmonella"],
  [5512, "Mi Basah Matang (06040308)", "Salmonella (/25 g)"],
  [
    5513,
    "Mi Basah Matang (06040308)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5514,
    "Mi Basah Matang (06040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5515,
    "Mi Basah Matang (06040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5516,
    "Mi Basah Matang (06040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5517,
    "Mi Basah Matang (06040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5518,
    "Mi Basah Matang (06040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5519,
    "Mi Basah Matang Lainnya (06040316)",
    "Salmonella (/25 g)",
  ],
  [
    5520,
    "Mi Basah Matang Lainnya (06040316)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5521,
    "Mi Basah Matang Lainnya (06040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5522,
    "Mi Basah Matang Lainnya (06040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5523,
    "Mi Basah Matang Lainnya (06040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5524,
    "Mi Basah Matang Lainnya (06040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5525,
    "Mi Basah Matang Lainnya (06040316)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5526, "Mi Basah Mentah (06040101)", "Salmonella (/25 g)"],
  [
    5527,
    "Mi Basah Mentah (06040101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5528,
    "Mi Basah Mentah (06040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5529,
    "Mi Basah Mentah (06040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5530,
    "Mi Basah Mentah (06040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5531,
    "Mi Basah Mentah (06040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5532,
    "Mi Basah Mentah (06040101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5533,
    "Mi Basah Mentah lainnya (06040104)",
    "Salmonella (/25 g)",
  ],
  [
    5534,
    "Mi Basah Mentah lainnya (06040104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5535,
    "Mi Basah Mentah lainnya (06040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5536,
    "Mi Basah Mentah lainnya (06040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5537,
    "Mi Basah Mentah lainnya (06040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5538,
    "Mi Basah Mentah lainnya (06040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5539,
    "Mi Basah Mentah lainnya (06040104)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [5540, "Mi Instan (06040309)", "Salmonella (/25 g)"],
  [5541, "Mi Instan (06040309)", "Jumlah Sampel - Salmonella"],
  [5542, "Mi Instan Lainnya (06040310)", "Salmonella (/25 g)"],
  [
    5543,
    "Mi Instan Lainnya (06040310)",
    "Jumlah Sampel - Salmonella",
  ],
  [5544, "Mi Kering Gandum (06040303)", "Salmonella (/25 g)"],
  [
    5545,
    "Mi Kering Gandum (06040303)",
    "Jumlah Sampel - Salmonella",
  ],
  [5546, "Mi Kering Lainnya (06040304)", "Salmonella (/25 g)"],
  [
    5547,
    "Mi Kering Lainnya (06040304)",
    "Jumlah Sampel - Salmonella",
  ],
  [5548, "Mi Soa (06040322)", "Salmonella (/25 g)"],
  [5549, "Mi Soa (06040322)", "Jumlah Sampel - Salmonella"],
  [
    5550,
    "Minarin Meja atau Halvarine (02020209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5551,
    "Minarin Meja atau Halvarine (02020209)",
    "Salmonella (/25 g)",
  ],
  [
    5552,
    "Minarin Meja atau Halvarine (02020209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5553,
    "Minarin Meja atau Halvarine (02020209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5554,
    "Minarin Meja atau Halvarine (02020209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5555,
    "Minarin Meja atau Halvarine (02020209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5556,
    "Minarin Meja atau Halvarine (02020209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [5557, "Mint (12020178)", "Salmonella (/25 g)"],
  [5558, "Mint (12020178)", "Jumlah Sampel - Salmonella"],
  [
    5559,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Salmonella (/25 g)",
  ],
  [
    5560,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5561,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Salmonella (/25 g)",
  ],
  [
    5562,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5563,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5564,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5565,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5566,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5567,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5568,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5569,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5570,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5571,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5572,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5573,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5574,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5575,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5576,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5577,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5578,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5579,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5580,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5581,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5582,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5583,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5584,
    "Minuman Ibu Hamil dan atau Ibu Menyusui (130502)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5585,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5586,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5587,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5588,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5589,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    5590,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Salmonella (/25 ml)",
  ],
  [
    5591,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5592,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Salmonella (/25 ml)",
  ],
  [
    5593,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5594,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Salmonella (/25 g)",
  ],
  [
    5595,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5596,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5597,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5598,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5599,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5600,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5601,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Salmonella (/25 g)",
  ],
  [
    5602,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5603,
    "Minuman Ringan (Plain) (1401040252)",
    "Pseudomonas aeruginosa (/250 ml)",
  ],
  [
    5604,
    "Minuman Ringan (Plain) (1401040252)",
    "Jumlah Sampel - Pseudomonas aeruginosa",
  ],
  [
    5605,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Salmonella (/25 ml)",
  ],
  [
    5606,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5607,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Salmonella (/25 ml)",
  ],
  [
    5608,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5609,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Salmonella (/25 g)",
  ],
  [
    5610,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5611,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Salmonella (/25 ml)",
  ],
  [
    5612,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5613,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5614,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5615,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5616,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5617,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5618,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5619,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5620,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5621,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5622,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5623,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5624,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5625,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5626,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5627,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5628,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5629,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5630,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5631,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5632,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5633,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5634,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5635,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5636,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5637,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5638,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5639,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    5640,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5641,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5642,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5643,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5644,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5645,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5646,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5647,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Salmonella (/25 ml)",
  ],
  [
    5648,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5649,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5650,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5651,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5652,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5653,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5654,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5655,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5656,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5657,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5658,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5659,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5660,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5661,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5662,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5663,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5664,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5665,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5666,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5667,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5668,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5669,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5670,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5671,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5672,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5673,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5674,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5675,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5676,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5677,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5678,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5679,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5680,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5681,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5682,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5683,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5684,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5685,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5686,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5687,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5688,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5689,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5690,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5691,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5692,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5693,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5694,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5695,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5696,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5697,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5698,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5699,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5700,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5701,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5702,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5703,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5704,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5705,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5706,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5707,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
  ],
  [
    5708,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
  ],
  [
    5709,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
  ],
  [
    5710,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
  ],
  [
    5711,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
  ],
  [
    5712,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5713,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5714,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5715,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5716,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5717,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5718,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5719,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5720,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5721,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5722,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5723,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5724,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5725,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5726,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5727,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5728,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    5729,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5730,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5731,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5732,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5733,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5734,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5735,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5736,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5737,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5738,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5739,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5740,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5741,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5742,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5743,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5744,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5745,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}10",
  ],
  [
    5746,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5747,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5748,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5749,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5750,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    5751,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5752,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5753,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5754,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5755,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Koliform (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    5756,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5757,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5758,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5759,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5760,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5761,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5762,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    5763,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5764,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5765,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5766,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5767,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    5768,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Salmonella (koloni/25 g)",
  ],
  [
    5769,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5770,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    ">0",
  ],
  [
    5771,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    ">0",
  ],
  [
    5772,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    ">0",
  ],
  [
    5773,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    ">0",
  ],
  [
    5774,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    ">0",
  ],
  [
    5775,
    "Muffin Amerika (American Muffin) (07020206)",
    "Salmonella (/25 g)",
  ],
  [
    5776,
    "Muffin Amerika (American Muffin) (07020206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5777,
    "Muffin Amerika (American Muffin) (07020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5778,
    "Muffin Amerika (American Muffin) (07020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5779,
    "Muffin Amerika (American Muffin) (07020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5780,
    "Muffin Amerika (American Muffin) (07020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5781,
    "Muffin Amerika (American Muffin) (07020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5782,
    "Muffin Inggris (English Muffin) (07010304)",
    "Salmonella (/25 g)",
  ],
  [
    5783,
    "Muffin Inggris (English Muffin) (07010304)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5784,
    "Musipan (060503)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5785,
    "Musipan (060503)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5786,
    "Musipan (060503)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5787,
    "Musipan (060503)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5788,
    "Musipan (060503)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [5789, "Musipan (060503)", "Salmonella (/25 g)"],
  [5790, "Musipan (060503)", "Jumlah Sampel - Salmonella"],
  [
    5791,
    "Musipan (060503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5792,
    "Musipan (060503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5793,
    "Musipan (060503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5794,
    "Musipan (060503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5795,
    "Musipan (060503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5796, "Mustard (1204)", "Salmonella (koloni/25 g)"],
  [5797, "Mustard (1204)", "Salmonella (koloni/25 g)"],
  [5798, "Mustard (1204)", "Jumlah Sampel - Salmonella"],
  [5799, "Mustard (1204)", "Jumlah Sampel - Salmonella"],
  [
    5800,
    "Nagamishi (060504)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5801,
    "Nagamishi (060504)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5802,
    "Nagamishi (060504)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5803,
    "Nagamishi (060504)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5804,
    "Nagamishi (060504)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [5805, "Nagamishi (060504)", "Salmonella (/25 g)"],
  [5806, "Nagamishi (060504)", "Jumlah Sampel - Salmonella"],
  [
    5807,
    "Nagamishi (060504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5808,
    "Nagamishi (060504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5809,
    "Nagamishi (060504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5810,
    "Nagamishi (060504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5811,
    "Nagamishi (060504)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5812,
    "Nagasari/Kue Pisang (060705)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5813,
    "Nagasari/Kue Pisang (060705)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5814,
    "Nagasari/Kue Pisang (060705)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5815,
    "Nagasari/Kue Pisang (060705)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5816,
    "Nagasari/Kue Pisang (060705)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [5817, "Nagasari/Kue Pisang (060705)", "Salmonella (/25 g)"],
  [
    5818,
    "Nagasari/Kue Pisang (060705)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5819,
    "Nagasari/Kue Pisang (060705)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5820,
    "Nagasari/Kue Pisang (060705)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5821,
    "Nagasari/Kue Pisang (060705)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5822,
    "Nagasari/Kue Pisang (060705)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5823,
    "Nagasari/Kue Pisang (060705)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5824, "Naget Ayam (08030321)", "Salmonella (koloni/25 ml)"],
  [5825, "Naget Ayam (08030321)", "Jumlah Sampel - Salmonella"],
  [
    5826,
    "Naget Ayam (08030321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5827,
    "Naget Ayam (08030321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5828,
    "Naget Ayam (08030321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5829,
    "Naget Ayam (08030321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5830,
    "Naget Ayam (08030321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5831,
    "Naget Ayam (08030321)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    5832,
    "Naget Ayam (08030321)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [
    5833,
    "Naget Ayam Kombinasi (08030306)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    5834,
    "Naget Ayam Kombinasi (08030306)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5835,
    "Naget Ayam Kombinasi (08030306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5836,
    "Naget Ayam Kombinasi (08030306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5837,
    "Naget Ayam Kombinasi (08030306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5838,
    "Naget Ayam Kombinasi (08030306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5839,
    "Naget Ayam Kombinasi (08030306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    5840,
    "Naget Ayam Kombinasi (08030306)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    5841,
    "Naget Ayam Kombinasi (08030306)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [5842, "Naget Daging Sapi (08030322)", "Salmonella (/25 g)"],
  [5843, "Naget Daging Sapi (08030322)", "Jumlah - Salmonella"],
  [
    5844,
    "Naget Daging Sapi (08030322)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5845,
    "Naget Daging Sapi (08030322)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5846,
    "Naget Daging Sapi (08030322)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5847,
    "Naget Daging Sapi (08030322)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5848,
    "Naget Daging Sapi (08030322)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5849,
    "Naget Daging Sapi (08030322)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5850,
    "Naget Daging Sapi (08030322)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    5851,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Salmonella (/25 g)",
  ],
  [
    5852,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Jumlah - Salmonella",
  ],
  [
    5853,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5854,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5855,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5856,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5857,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5858,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5859,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    5860,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5861,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5862,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5863,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5864,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5865,
    "Naget Udang (09020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5866,
    "Naget Udang (09020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5867,
    "Naget Udang (09020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5868,
    "Naget Udang (09020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5869,
    "Naget Udang (09020205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [5870, "Namagashi (0402020610)", "Salmonella (/25 g)"],
  [5871, "Namagashi (0402020610)", "Jumlah Sampel - Salmonella"],
  [
    5872,
    "Nasi Beku (06070101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5873,
    "Nasi Beku (06070101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5874,
    "Nasi Beku (06070101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5875,
    "Nasi Beku (06070101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5876,
    "Nasi Beku (06070101)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5877,
    "Nasi Beku (06070101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5878,
    "Nasi Beku (06070101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5879,
    "Nasi Beku (06070101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5880,
    "Nasi Beku (06070101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5881,
    "Nasi Beku (06070101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [5882, "Nasi Instan (06040311)", "Salmonella (/25 g)"],
  [5883, "Nasi Instan (06040311)", "Jumlah Sampel - Salmonella"],
  [5884, "Nasi Jagung (060308)", "Salmonella (/25 g)"],
  [5885, "Nasi Jagung (060308)", "Jumlah Sampel - Salmonella"],
  [
    5886,
    "Nasi Jagung (060308)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5887,
    "Nasi Jagung (060308)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5888,
    "Nasi Jagung (060308)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5889,
    "Nasi Jagung (060308)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5890,
    "Nasi Jagung (060308)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5891, "Nastar (07020134)", "Salmonella (/25 g)"],
  [5892, "Nastar (07020134)", "Jumlah Sampel - Salmonella"],
  [
    5893,
    "Nastar (07020134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5894,
    "Nastar (07020134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5895,
    "Nastar (07020134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5896,
    "Nastar (07020134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5897,
    "Nastar (07020134)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [5898, "Nata Dalam Kemasan (0401020902)", "Salmonella (/25 g)"],
  [
    5899,
    "Nata Dalam Kemasan (0401020902)",
    "Jumlah Sampel - Salmonella",
  ],
  [5900, "Natto (06080602)", "Salmonella (/25 g)"],
  [5901, "Natto (06080602)", "Jumlah Sampel - Salmonella"],
  [
    5902,
    "Non-Dairy Mousse (020402)",
    "Jumlah Sampel - Salmonella",
  ],
  [5903, "Non-Dairy Mousse (020402)", "Salmonella (/25 g)"],
  [
    5904,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5905,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Salmonella (/25 g)",
  ],
  [
    5906,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5907,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5908,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5909,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5910,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [5911, "Non-Dairy Whipped Cream (020302)", "Salmonella (/25 g)"],
  [
    5912,
    "Non-Dairy Whipped Cream (020302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5913,
    "Non-Dairy Whipped Cream (020302)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5914,
    "Non-Dairy Whipped Cream (020302)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5915,
    "Non-Dairy Whipped Cream (020302)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5916,
    "Non-Dairy Whipped Cream (020302)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    5917,
    "Non-Dairy Whipped Cream (020302)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [5918, "Nopia (07020217)", "Salmonella (/25 g)"],
  [5919, "Nopia (07020217)", "Jumlah Sampel - Salmonella"],
  [
    5920,
    "Nopia (07020217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5921,
    "Nopia (07020217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5922,
    "Nopia (07020217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5923,
    "Nopia (07020217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5924,
    "Nopia (07020217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [5925, "Nougat (05020301)", "Salmonella (/25 g)"],
  [5926, "Nougat (05020301)", "Jumlah Sampel - Salmonella"],
  [5927, "Oatmeal (060305)", "Salmonella (/25 g)"],
  [5928, "Oatmeal (060305)", "Jumlah Sampel - Salmonella"],
  [
    5929,
    "Oatmeal (060305)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5930,
    "Oatmeal (060305)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5931,
    "Oatmeal (060305)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5932,
    "Oatmeal (060305)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5933,
    "Oatmeal (060305)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [5934, "Odading/Kue Bantal (07020124)", "Salmonella (/25 g)"],
  [
    5935,
    "Odading/Kue Bantal (07020124)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5936,
    "Odading/Kue Bantal (07020124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5937,
    "Odading/Kue Bantal (07020124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5938,
    "Odading/Kue Bantal (07020124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5939,
    "Odading/Kue Bantal (07020124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    5940,
    "Odading/Kue Bantal (07020124)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [5941, "Okra yang Digoreng (0402020806)", "Salmonella (/25 g)"],
  [
    5942,
    "Okra yang Digoreng (0402020806)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5943,
    "Okra yang Digoreng (0402020806)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5944,
    "Okra yang Digoreng (0402020806)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5945,
    "Okra yang Digoreng (0402020806)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5946,
    "Okra yang Digoreng (0402020806)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5947,
    "Okra yang Digoreng (0402020806)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    5948,
    "Olahan Ikan Berbumbu (0902040122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5949,
    "Olahan Ikan Berbumbu (0902040122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5950,
    "Olahan Ikan Berbumbu (0902040122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5951,
    "Olahan Ikan Berbumbu (0902040122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5952,
    "Olahan Ikan Berbumbu (0902040122)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5953,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Salmonella (/25 g)",
  ],
  [
    5954,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5955,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    5956,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    5957,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5958,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5959,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5960,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5961,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    5962,
    "Olesan Berbasis Kacang (0402020508)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5963,
    "Olesan Berbasis Kacang (0402020508)",
    "Salmonella (/25 g)",
  ],
  [
    5964,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Salmonella (/25 g)",
  ],
  [
    5965,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5966,
    "Olesan Berbasis Sayur (0402020506)",
    "Salmonella (/25 g)",
  ],
  [
    5967,
    "Olesan Berbasis Sayur (0402020506)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    5968,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Salmonella (/25 g)",
  ],
  [
    5969,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Jumlah Sampel - Salmonella",
  ],
  [5970, "Olesan Kacang (0402020509)", "Salmonella (/25ml)"],
  [
    5971,
    "Olesan Kacang (0402020509)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5972,
    "Olesan Mengandung Kacang (0402020510)",
    "Salmonella (/25ml)",
  ],
  [
    5973,
    "Olesan Mengandung Kacang (0402020510)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [5974, "Olesan/Saus (120703)", "Salmonella (/25 g)"],
  [5975, "Olesan/Saus (120703)", "Jumlah Sampel - Salmonella"],
  [5976, "Ombus-ombus (060734)", "Salmonella (/25 g)"],
  [
    5977,
    "Ombus-ombus (060734)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    5978,
    "Ombus-ombus (060734)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5979,
    "Ombus-ombus (060734)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5980,
    "Ombus-ombus (060734)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5981,
    "Ombus-ombus (060734)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5982,
    "Ombus-ombus (060734)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5983,
    "Ombus-ombus (060734)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5984,
    "Ombus-ombus (060734)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5985,
    "Ombus-ombus (060734)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5986,
    "Ombus-ombus (060734)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5987,
    "Ombus-ombus (060734)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5988,
    "Onde-Onde (060725)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5989,
    "Onde-Onde (060725)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5990,
    "Onde-Onde (060725)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5991,
    "Onde-Onde (060725)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    5992,
    "Onde-Onde (060725)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [5993, "Onde-Onde (060725)", "Salmonella (/25 g)"],
  [5994, "Onde-Onde (060725)", "Jumlah Sampel - Salmonella"],
  [
    5995,
    "Onde-Onde (060725)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5996,
    "Onde-Onde (060725)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5997,
    "Onde-Onde (060725)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5998,
    "Onde-Onde (060725)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    5999,
    "Onde-Onde (060725)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    6000,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Salmonella (/25 g)",
  ],
  [
    6001,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6002,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6003,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6004,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6005,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6006,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6007,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6008,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6009,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6010,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6011,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6012, "Onion/Bawang Bombay (12020179)", "Salmonella (/25 g)"],
  [
    6013,
    "Onion/Bawang Bombay (12020179)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6014,
    "Onion/Bawang Bombay (12020179)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6015,
    "Onion/Bawang Bombay (12020179)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6016,
    "Onion/Bawang Bombay (12020179)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6017,
    "Onion/Bawang Bombay (12020179)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6018,
    "Onion/Bawang Bombay (12020179)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6019,
    "Onion/Bawang Bombay (12020179)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6020,
    "Onion/Bawang Bombay (12020179)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6021,
    "Onion/Bawang Bombay (12020179)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6022,
    "Onion/Bawang Bombay (12020179)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6023,
    "Onion/Bawang Bombay (12020179)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6024, "Opak (150115)", "Salmonella (/25 g)"],
  [6025, "Opak (150115)", "Jumlah Sampel - Salmonella"],
  [
    6026,
    "Opak (150115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6027,
    "Opak (150115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6028,
    "Opak (150115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6029,
    "Opak (150115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6030,
    "Opak (150115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [6031, "Oregano (12020181)", "Salmonella (/25 g)"],
  [6032, "Oregano (12020181)", "Jumlah Sampel - Salmonella"],
  [
    6033,
    "Otak-Otak Ikan (0902040109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6034,
    "Otak-Otak Ikan (0902040109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6035,
    "Otak-Otak Ikan (0902040109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6036,
    "Otak-Otak Ikan (0902040109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6037,
    "Otak-Otak Ikan (0902040109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6038,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6039,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6040,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6041,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6042,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6043,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Salmonella (/25 g)",
  ],
  [
    6044,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    6045,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    6046,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [6047, "Pai (07020136)", "Salmonella (/25 g)"],
  [6048, "Pai (07020136)", "Jumlah Sampel - Salmonella"],
  [
    6049,
    "Pai (07020136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6050,
    "Pai (07020136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6051,
    "Pai (07020136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6052,
    "Pai (07020136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6053,
    "Pai (07020136)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [6054, "Pai Isi (07020137)", "Salmonella (/25 g)"],
  [6055, "Pai Isi (07020137)", "Jumlah Sampel - Salmonella"],
  [
    6056,
    "Pai Isi (07020137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6057,
    "Pai Isi (07020137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6058,
    "Pai Isi (07020137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6059,
    "Pai Isi (07020137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6060,
    "Pai Isi (07020137)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [6061, "Pala (12020182)", "Salmonella (/25 g)"],
  [6062, "Pala (12020182)", "Jumlah Sampel - Salmonella"],
  [
    6063,
    "Pala (12020182)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6064,
    "Pala (12020182)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6065,
    "Pala (12020182)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6066,
    "Pala (12020182)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6067,
    "Pala (12020182)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6068,
    "Pala (12020182)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6069,
    "Pala (12020182)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6070,
    "Pala (12020182)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6071,
    "Pala (12020182)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6072,
    "Pala (12020182)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6073, "Pala Bubuk (12020184)", "Salmonella (/25 g)"],
  [6074, "Pala Bubuk (12020184)", "Jumlah Sampel - Salmonella"],
  [
    6075,
    "Pala Bubuk (12020184)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6076,
    "Pala Bubuk (12020184)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6077,
    "Pala Bubuk (12020184)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6078,
    "Pala Bubuk (12020184)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6079,
    "Pala Bubuk (12020184)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6080,
    "Pala Bubuk (12020184)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6081,
    "Pala Bubuk (12020184)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6082,
    "Pala Bubuk (12020184)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6083,
    "Pala Bubuk (12020184)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6084,
    "Pala Bubuk (12020184)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6085, "Pala Untuk Destilasi (12020183)", "Salmonella (/25 g)"],
  [
    6086,
    "Pala Untuk Destilasi (12020183)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6087,
    "Pala Untuk Destilasi (12020183)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6088,
    "Pala Untuk Destilasi (12020183)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6089,
    "Pala Untuk Destilasi (12020183)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6090,
    "Pala Untuk Destilasi (12020183)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6091,
    "Pala Untuk Destilasi (12020183)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6092,
    "Pala Untuk Destilasi (12020183)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6093,
    "Pala Untuk Destilasi (12020183)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6094,
    "Pala Untuk Destilasi (12020183)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6095,
    "Pala Untuk Destilasi (12020183)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6096,
    "Pala Untuk Destilasi (12020183)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6097,
    "Palai Bada/Teri (0902040117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6098,
    "Palai Bada/Teri (0902040117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6099,
    "Palai Bada/Teri (0902040117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6100,
    "Palai Bada/Teri (0902040117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6101,
    "Palai Bada/Teri (0902040117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [6102, "Panekuk (07020214)", "Salmonella (/25 g)"],
  [6103, "Panekuk (07020214)", "Jumlah Sampel - Salmonella"],
  [
    6104,
    "Panekuk (07020214)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6105,
    "Panekuk (07020214)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6106,
    "Panekuk (07020214)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6107,
    "Panekuk (07020214)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6108,
    "Panekuk (07020214)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6109,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6110,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6111,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6112,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6113,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6114,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6115,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6116,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6117,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6118,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6119,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6120,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6121,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6122,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6123,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6124,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6125,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6126,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6127,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6128,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6129,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6130,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6131,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6132,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6133,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6134,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6135,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    6136,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6137,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6138,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6139,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6140,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6141,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6142,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6143,
    "Pangan Ibu Hamil Cair (1322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6144,
    "Pangan Ibu Hamil Cair (1322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6145,
    "Pangan Ibu Hamil Cair (1322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6146,
    "Pangan Ibu Hamil Cair (1322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6147,
    "Pangan Ibu Hamil Cair (1322)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6148,
    "Pangan Ibu Hamil Cair (1322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6149,
    "Pangan Ibu Hamil Cair (1322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6150,
    "Pangan Ibu Hamil Cair (1322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6151,
    "Pangan Ibu Hamil Cair (1322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6152,
    "Pangan Ibu Hamil Cair (1322)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6153,
    "Pangan Ibu Hamil Cair (1322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6154,
    "Pangan Ibu Hamil Cair (1322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6155,
    "Pangan Ibu Hamil Cair (1322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6156,
    "Pangan Ibu Hamil Cair (1322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6157,
    "Pangan Ibu Hamil Cair (1322)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6158,
    "Pangan Ibu Hamil Cair (1322)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6159,
    "Pangan Ibu Hamil Cair (1322)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6160,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6161,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6162,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6163,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6164,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6165,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6166,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6167,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6168,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6169,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6170,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6171,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6172,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6173,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6174,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6175,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6176,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6177,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6178,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6179,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6180,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6181,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6182,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6183,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6184,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6185,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6186,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6187,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6188,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6189,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6190,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6191,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6192,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6193,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6194,
    "Pangan Ibu Hamil Padat (1321)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6195,
    "Pangan Ibu Hamil Padat (1321)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6196,
    "Pangan Ibu Hamil Padat (1321)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6197,
    "Pangan Ibu Hamil Padat (1321)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6198,
    "Pangan Ibu Hamil Padat (1321)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6199,
    "Pangan Ibu Hamil Padat (1321)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6200,
    "Pangan Ibu Hamil Padat (1321)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6201,
    "Pangan Ibu Hamil Padat (1321)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6202,
    "Pangan Ibu Hamil Padat (1321)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6203,
    "Pangan Ibu Hamil Padat (1321)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6204,
    "Pangan Ibu Hamil Padat (1321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6205,
    "Pangan Ibu Hamil Padat (1321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6206,
    "Pangan Ibu Hamil Padat (1321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6207,
    "Pangan Ibu Hamil Padat (1321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6208,
    "Pangan Ibu Hamil Padat (1321)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6209,
    "Pangan Ibu Hamil Padat (1321)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6210,
    "Pangan Ibu Hamil Padat (1321)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6211,
    "Pangan Ibu Menyusui Padat (1323)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6212,
    "Pangan Ibu Menyusui Padat (1323)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6213,
    "Pangan Ibu Menyusui Padat (1323)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6214,
    "Pangan Ibu Menyusui Padat (1323)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6215,
    "Pangan Ibu Menyusui Padat (1323)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6216,
    "Pangan Ibu Menyusui Padat (1323)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6217,
    "Pangan Ibu Menyusui Padat (1323)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6218,
    "Pangan Ibu Menyusui Padat (1323)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6219,
    "Pangan Ibu Menyusui Padat (1323)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6220,
    "Pangan Ibu Menyusui Padat (1323)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6221,
    "Pangan Ibu Menyusui Padat (1323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6222,
    "Pangan Ibu Menyusui Padat (1323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6223,
    "Pangan Ibu Menyusui Padat (1323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6224,
    "Pangan Ibu Menyusui Padat (1323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6225,
    "Pangan Ibu Menyusui Padat (1323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6226,
    "Pangan Ibu Menyusui Padat (1323)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6227,
    "Pangan Ibu Menyusui Padat (1323)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6228,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6229,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6230,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6231,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6232,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6233,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6234,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6235,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6236,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6237,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6238,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6239,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6240,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6241,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6242,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6243,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6244,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6245,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6246,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6247,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6248,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Salmonella (/25 g)",
  ],
  [
    6249,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6250,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Cronobacter sakazakii (/10 g)",
  ],
  [
    6251,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Jumlah Sampel - Cronobacter sakazakii",
  ],
  [
    6252,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6253,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6254,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6255,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6256,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6257,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6258,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6259,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6260,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6261,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6262,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6263,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6264,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6265,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6266,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6267,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6268,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6269,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6270,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6271,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Enterobacteriaceae (/10 g)",
  ],
  [
    6272,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6273,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6274,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6275,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6276,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6277,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Salmonella (/25 g)",
  ],
  [
    6278,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6279,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Cronobacter sakazakii (/10 g)",
  ],
  [
    6280,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Jumlah Sampel - Cronobacter sakazakii",
  ],
  [
    6281,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6282,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6283,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6284,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6285,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6286,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6287,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6288,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6289,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6290,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6291,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Enterobacteriaceae (koloni/ml)",
    "\x{2264}10",
    "<1",
  ],
  [
    6292,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Enterobacteriaceae (koloni/ml)",
    "\x{2264}10",
    "<1",
  ],
  [
    6293,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Enterobacteriaceae (koloni/ml)",
    "\x{2264}10",
    "<1",
  ],
  [
    6294,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Enterobacteriaceae (koloni/ml)",
    "\x{2264}10",
    "<1",
  ],
  [
    6295,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Enterobacteriaceae (koloni/ml)",
    "\x{2264}10",
    "<1",
  ],
  [
    6296,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6297,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6298,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6299,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6300,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6301,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Salmonella (/25 g)",
  ],
  [
    6302,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}10",
  ],
  [
    6303,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6304,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6305,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6306,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6307,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "<10000",
  ],
  [
    6308,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6309,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6310,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6311,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6312,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6313,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6314,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6315,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6316,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6317,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "<10",
  ],
  [
    6318,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Salmonella (/25 g)",
  ],
  [
    6319,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}10",
  ],
  [
    6320,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6321,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6322,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6323,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6324,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6325,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6326,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6327,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6328,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6329,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6330,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6331,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6332,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6333,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6334,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6335,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6336,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6337,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6338,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6339,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6340,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6341,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6342,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6343,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6344,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6345,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6346,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6347,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6348,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6349,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6350,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6351,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6352,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6353,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6354,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6355,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6356,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6357,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6358,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6359,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6360,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6361,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6362,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6363,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6364,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6365,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6366,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6367,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6368,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6369,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6370,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6371,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6372,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6373,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6374,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6375,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6376,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6377,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6378,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6379,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6380,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6381,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6382,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6383,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6384,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6385,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6386,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6387,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6388,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6389,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6390,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6391,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6392,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6393,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6394,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6395,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6396,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6397,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6398,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6399,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6400,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6401,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6402,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6403,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6404,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6405,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6406,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6407,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6408,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6409,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6410,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6411,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6412,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6413,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6414,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6415,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6416,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6417,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6418,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6419,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}0",
  ],
  [
    6420,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Enterobacter sakazakii (koloni/10 g)",
  ],
  [
    6421,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Jumlah Sampel - Enterobacter sakazakii",
  ],
  [
    6422,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6423,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6424,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6425,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6426,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6427,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6428,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6429,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6430,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6431,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6432,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6433,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}500",
    "\x{2264}50",
  ],
  [
    6434,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6435,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6436,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6437,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6438,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6439,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6440,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6441,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6442,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6443,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6444,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6445,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6446,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6447,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6448,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6449,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6450,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6451,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6452,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6453,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Salmonella (/25 g)",
  ],
  [
    6454,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6455,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6456,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6457,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6458,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Enterobacteriaceae (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6459,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6460,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6461,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6462,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6463,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6464,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6465,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6466,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6467,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6468,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6469,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6470,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6471,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6472,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6473,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6474,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6475,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6476,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6477,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6478,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6479,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6480,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6481,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6482,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6483,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6484,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6485,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6486,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6487,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6488,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6489,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6490,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6491,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6492,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6493,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6494,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6495,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6496,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6497,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6498,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6499,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6500,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6501,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6502,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6503,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6504,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6505,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6506,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6507,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6508,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6509,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6510,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6511,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6512,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6513,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6514,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6515,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6516,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6517,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6518,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6519,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6520,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6521,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6522,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6523,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6524,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6525,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6526,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6527,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6528,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6529,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6530,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6531,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6532,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6533,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6534,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6535,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6536,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6537,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6538,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6539,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6540,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6541,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6542,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6543,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6544,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6545,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6546,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6547,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6548,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "ALT (koloni/g)",
    "\x{2264}5000",
    "\x{2264}500",
  ],
  [
    6549,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kapang dan khamir (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6550,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kapang dan khamir (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6551,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kapang dan khamir (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6552,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kapang dan khamir (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6553,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kapang dan khamir (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6554,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6555,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6556,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6557,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6558,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6559,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6560,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6561,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6562,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6563,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6564,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6565,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6566,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6567,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6568,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6569,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6570,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6571,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6572,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6573,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6574,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6575,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6576,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6577,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6578,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6579,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6580,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6581,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6582,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6583,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6584,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6585,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6586,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6587,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6588,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6589,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6590,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6591,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6592,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6593,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6594,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6595,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6596,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6597,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6598,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6599,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6600,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6601,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6602,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6603,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6604,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6605,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6606,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6607,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6608,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6609,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6610,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6611,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6612,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "ALT (koloni/ml)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6613,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6614,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6615,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6616,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6617,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6618,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6619,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6620,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6621,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6622,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Koliform (APM/100 ml)",
    "\x{2264}10",
    "<1.8",
  ],
  [
    6623,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6624,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6625,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6626,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6627,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Pseudomonas aeruginosa (/100 ml)",
  ],
  [
    6628,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6629,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6630,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6631,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6632,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6633,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6634,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6635,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6636,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6637,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6638,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6639,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6640,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6641,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6642,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6643,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6644,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6645,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6646,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6647,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6648,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6649,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6650,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6651,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6652,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6653,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6654,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6655,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6656,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6657,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6658,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6659,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6660,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6661,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6662,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6663,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6664,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6665,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6666,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6667,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6668,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6669,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6670,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6671,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6672,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6673,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6674,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6675,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6676,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6677,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6678,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6679,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6680,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6681,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6682,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6683,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6684,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6685,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6686,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6687,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6688,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6689,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6690,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6691,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6692,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6693,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6694,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6695,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6696,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6697,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6698,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6699,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6700,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6701,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6702,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6703,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6704,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6705,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6706,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6707,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6708,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6709,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6710,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6711,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6712,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6713,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6714,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6715,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6716,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6717,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6718,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6719,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6720,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6721,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6722,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6723,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6724,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6725,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6726,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6727,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6728,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6729,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6730,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6731,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6732,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6733,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6734,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6735,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6736,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6737,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6738,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6739,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6740,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6741,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6742,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6743,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6744,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6745,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6746,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6747,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6748,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6749,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6750,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6751,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6752,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6753,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6754,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6755,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6756,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6757,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6758,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6759,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6760,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6761,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6762,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6763,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6764,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6765,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6766,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6767,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6768,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "ALT (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6769,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6770,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6771,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6772,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6773,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Enterobacteriaceae (koloni/10 g)",
    "\x{2264}10",
    "\x{2264}1",
  ],
  [
    6774,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6775,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6776,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6777,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6778,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    6779,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Salmonella (koloni/25 g)",
  ],
  [
    6780,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Jumlah Sampel - Salmonella",
  ],
  [6781, "Pangsit Daging (08030315)", "Salmonella (/25 g)"],
  [6782, "Pangsit Daging (08030315)", "Jumlah - Salmonella"],
  [
    6783,
    "Pangsit Daging (08030315)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6784,
    "Pangsit Daging (08030315)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6785,
    "Pangsit Daging (08030315)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6786,
    "Pangsit Daging (08030315)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6787,
    "Pangsit Daging (08030315)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6788,
    "Pangsit Daging (08030315)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    6789,
    "Pangsit Daging (08030315)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    6790,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6791,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6792,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6793,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6794,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6795,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6796,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6797,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6798,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6799,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6800,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6801,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6802,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6803,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6804,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6805,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Salmonella (/25 g)",
  ],
  [
    6806,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    6807,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Salmonella (/25 g)",
  ],
  [
    6808,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    6809,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    6810,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    6811,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    6812,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    6813,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [6814, "Paprika Bubuk (12020186)", "Salmonella (/25 g)"],
  [6815, "Paprika Bubuk (12020186)", "Jumlah Sampel - Salmonella"],
  [
    6816,
    "Paprika Bubuk (12020186)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6817,
    "Paprika Bubuk (12020186)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6818,
    "Paprika Bubuk (12020186)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6819,
    "Paprika Bubuk (12020186)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6820,
    "Paprika Bubuk (12020186)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6821,
    "Paprika Bubuk (12020186)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6822,
    "Paprika Bubuk (12020186)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6823,
    "Paprika Bubuk (12020186)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6824,
    "Paprika Bubuk (12020186)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6825,
    "Paprika Bubuk (12020186)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6826, "Parsley (12020185)", "Salmonella (/25 g)"],
  [6827, "Parsley (12020185)", "Jumlah Sampel - Salmonella"],
  [6828, "Pasta (06040218)", "Salmonella (/25 g)"],
  [6829, "Pasta (06040218)", "Jumlah Sampel - Salmonella"],
  [6830, "Pasta (0604A0)", "Salmonella (/25 g)"],
  [6831, "Pasta (0604A0)", "Jumlah Sampel - Salmonella"],
  [
    6832,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Salmonella (/25 g)",
  ],
  [
    6833,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Jumlah Sampel - Salmonella",
  ],
  [6834, "Pasta Buah (0401020803)", "Jumlah Sampel - Salmonella"],
  [6835, "Pasta Buah (0401020803)", "Salmonella (/25 g)"],
  [
    6836,
    "Pasta Daging (08030208)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6837,
    "Pasta Daging (08030208)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6838,
    "Pasta Daging (08030208)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6839,
    "Pasta Daging (08030208)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6840,
    "Pasta Daging (08030208)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [6841, "Pasta Daging (08030208)", "Salmonella (/25 g)"],
  [6842, "Pasta Daging (08030208)", "Salmonella (/25 g)"],
  [6843, "Pasta Daging (08030208)", "Jumlah - Salmonella"],
  [
    6844,
    "Pasta Daging (08030208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6845,
    "Pasta Daging (08030208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6846,
    "Pasta Daging (08030208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6847,
    "Pasta Daging (08030208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6848,
    "Pasta Daging (08030208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [6849, "Pasta Gonad Bulu Babi (09020523)", "Salmonella (/25 g)"],
  [
    6850,
    "Pasta Gonad Bulu Babi (09020523)",
    "Jumlah Sampel - Salmonella",
  ],
  [6851, "Pasta Ikan (09020518)", "Salmonella (/25 g)"],
  [6852, "Pasta Ikan (09020518)", "Jumlah Sampel - Salmonella"],
  [6853, "Pasta Instan (06040321)", "Salmonella (/25 g)"],
  [6854, "Pasta Instan (06040321)", "Jumlah Sampel - Salmonella"],
  [6855, "Pasta Instan Lainnya (06040320)", "Salmonella (/25 g)"],
  [
    6856,
    "Pasta Instan Lainnya (06040320)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6857,
    "Pasta Kacang Merah Manis (0402020607)",
    "Salmonella (/25 g)",
  ],
  [
    6858,
    "Pasta Kacang Merah Manis (0402020607)",
    "Jumlah Sampel - Salmonella",
  ],
  [6859, "Pasta lainnya (06040219)", "Salmonella (/25 g)"],
  [6860, "Pasta lainnya (06040219)", "Jumlah Sampel - Salmonella"],
  [6861, "Pasta Tomat (0402020601)", "Salmonella (/25 g)"],
  [6862, "Pasta Tomat (0402020601)", "Jumlah Sampel - Salmonella"],
  [6863, "Pasta Umbi (0402020615)", "Salmonella (/25ml)"],
  [
    6864,
    "Pasta Umbi (0402020615)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [6865, "Pastiles (05020102)", "Salmonella (/25 g)"],
  [6866, "Pastiles (05020102)", "Jumlah Sampel - Salmonella"],
  [6867, "Pastri (07020201)", "Salmonella (/25 g)"],
  [6868, "Pastri (07020201)", "Jumlah Sampel - Salmonella"],
  [
    6869,
    "Pastri (07020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6870,
    "Pastri (07020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6871,
    "Pastri (07020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6872,
    "Pastri (07020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    6873,
    "Pastri (07020201)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [6874, "Pati Garut (06020201)", "Salmonella (/25 g)"],
  [6875, "Pati Garut (06020201)", "Jumlah Sampel - Salmonella"],
  [
    6876,
    "Pati Garut (06020201)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6877,
    "Pati Garut (06020201)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6878,
    "Pati Garut (06020201)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6879,
    "Pati Garut (06020201)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6880,
    "Pati Garut (06020201)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6881,
    "Pati Jagung atau Maizena (06020202)",
    "Salmonella (/25 g)",
  ],
  [
    6882,
    "Pati Jagung atau Maizena (06020202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6883,
    "Pati Jagung atau Maizena (06020202)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6884,
    "Pati Jagung atau Maizena (06020202)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6885,
    "Pati Jagung atau Maizena (06020202)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6886,
    "Pati Jagung atau Maizena (06020202)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6887,
    "Pati Jagung atau Maizena (06020202)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6888,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Salmonella (/25 g)",
  ],
  [
    6889,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6890,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6891,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6892,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6893,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6894,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6895,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Salmonella (/25 g)",
  ],
  [
    6896,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    6897,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    6898,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    6899,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    6900,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    6901,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [6902, "Pati Pragelatinisasi (06020208)", "Salmonella (/25 g)"],
  [
    6903,
    "Pati Pragelatinisasi (06020208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6904,
    "Pati Pragelatinisasi (06020208)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6905,
    "Pati Pragelatinisasi (06020208)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6906,
    "Pati Pragelatinisasi (06020208)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6907,
    "Pati Pragelatinisasi (06020208)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6908,
    "Pati Pragelatinisasi (06020208)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6909, "Pati Sagu (06020203)", "Salmonella (/25 g)"],
  [6910, "Pati Sagu (06020203)", "Jumlah Sampel - Salmonella"],
  [
    6911,
    "Pati Sagu (06020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6912,
    "Pati Sagu (06020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6913,
    "Pati Sagu (06020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6914,
    "Pati Sagu (06020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6915,
    "Pati Sagu (06020203)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [6916, "Pati Termodifikasi (06020207)", "Salmonella (/25 g)"],
  [
    6917,
    "Pati Termodifikasi (06020207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6918,
    "Pati Termodifikasi (06020207)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6919,
    "Pati Termodifikasi (06020207)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6920,
    "Pati Termodifikasi (06020207)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6921,
    "Pati Termodifikasi (06020207)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6922,
    "Pati Termodifikasi (06020207)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6923,
    "Patilo / Rengginang Singkong (150139)",
    "Salmonella (/25 g)",
  ],
  [
    6924,
    "Patilo / Rengginang Singkong (150139)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    6925,
    "Patilo / Rengginang Singkong (150139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6926,
    "Patilo / Rengginang Singkong (150139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6927,
    "Patilo / Rengginang Singkong (150139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6928,
    "Patilo / Rengginang Singkong (150139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6929,
    "Patilo / Rengginang Singkong (150139)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6930,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6931,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6932,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6933,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6934,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6935,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Salmonella (/25 g)",
  ],
  [
    6936,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Salmonella (/25 g)",
  ],
  [
    6937,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Jumlah - Salmonella",
  ],
  [
    6938,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Salmonella (/25 g)",
  ],
  [
    6939,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6940,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6941,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6942,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6943,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6944,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    6945,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6946,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6947,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6948,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6949,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    6950,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6951,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6952,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6953,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6954,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6955,
    "Pempek Ikan (Rebus) (0902040112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6956,
    "Pempek Ikan (Rebus) (0902040112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6957,
    "Pempek Ikan (Rebus) (0902040112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6958,
    "Pempek Ikan (Rebus) (0902040112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6959,
    "Pempek Ikan (Rebus) (0902040112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6960,
    "Pempek Ikan Rebus Beku (09020132)",
    "Salmonella (/25 g)",
  ],
  [
    6961,
    "Pempek Ikan Rebus Beku (09020132)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    6962,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    6963,
    "Substitute=CBS Lauric) (05010502)",
    "Salmonella (/25 g)",
  ],
  [
    6964,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    6965,
    "Substitute=CBS Lauric) (05010502)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6966,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    6967,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Salmonella (/25 g)",
  ],
  [
    6968,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    6969,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6970,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    6971,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Salmonella (/25 g)",
  ],
  [
    6972,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    6973,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    6974,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    6975,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    6976,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    6977,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6978,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6979,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6980,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    6981,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [6982, "Pepes Udang (0902040207)", "Salmonella (/25 g)"],
  [6983, "Pepes Udang (0902040207)", "Jumlah Sampel - Salmonella"],
  [
    6984,
    "Pepes Udang (0902040207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    6985,
    "Pepes Udang (0902040207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    6986,
    "Pepes Udang (0902040207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    6987,
    "Pepes Udang (0902040207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    6988,
    "Pepes Udang (0902040207)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    6989,
    "Pepes Udang (0902040207)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    6990,
    "Pepes Udang (0902040207)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    6991,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6992,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6993,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6994,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6995,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6996,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6997,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6998,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    6999,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7000,
    "Pepperoni (08030243)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7001, "Pepperoni (08030243)", "Salmonella (/25 g)"],
  [7002, "Pepperoni (08030243)", "Salmonella (/25 g)"],
  [7003, "Pepperoni (08030243)", "Jumlah - Salmonella"],
  [7004, "Pepperoni (08030243)", "Jumlah - Salmonella"],
  [
    7005,
    "Perkedel Kentang Beku (0402020116)",
    "Salmonella (/25ml)",
  ],
  [
    7006,
    "Perkedel Kentang Beku (0402020116)",
    "Listeria monocytogenes (koloni/ g)",
    "",
    "<100",
  ],
  [
    7007,
    "Perkedel Kentang Beku (0402020116)",
    "Listeria monocytogenes (koloni/ g)",
    "",
    "<100",
  ],
  [
    7008,
    "Perkedel Kentang Beku (0402020116)",
    "Listeria monocytogenes (koloni/ g)",
    "",
    "<100",
  ],
  [
    7009,
    "Perkedel Kentang Beku (0402020116)",
    "Listeria monocytogenes (koloni/ g)",
    "",
    "<100",
  ],
  [
    7010,
    "Perkedel Kentang Beku (0402020116)",
    "Listeria monocytogenes (koloni/ g)",
    "",
    "<100",
  ],
  [
    7011,
    "Perkedel Kentang Beku (0402020116)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7012,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Salmonella (/25 g)",
  ],
  [
    7013,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7014,
    "Petah (060714)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7015,
    "Petah (060714)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7016,
    "Petah (060714)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7017,
    "Petah (060714)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7018,
    "Petah (060714)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7019, "Petah (060714)", "Salmonella (/25 g)"],
  [7020, "Petah (060714)", "Jumlah Sampel - Salmonella"],
  [
    7021,
    "Petah (060714)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7022,
    "Petah (060714)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7023,
    "Petah (060714)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7024,
    "Petah (060714)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7025,
    "Petah (060714)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [7026, "Petis Udang (09020519)", "Salmonella (/25 g)"],
  [7027, "Petis Udang (09020519)", "Jumlah Sampel - Salmonella"],
  [7028, "Picalili (0402020311)", "Salmonella (/25 g)"],
  [7029, "Picalili (0402020311)", "Jumlah Sampel - Salmonella"],
  [7030, "Picung (12020164)", "Salmonella (/25 g)"],
  [7031, "Picung (12020164)", "Jumlah Sampel - Salmonella"],
  [
    7032,
    "Picung (12020164)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7033,
    "Picung (12020164)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7034,
    "Picung (12020164)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7035,
    "Picung (12020164)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7036,
    "Picung (12020164)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7037,
    "Picung (12020164)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7038,
    "Picung (12020164)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7039,
    "Picung (12020164)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7040,
    "Picung (12020164)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7041,
    "Picung (12020164)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7042, "Pikel (fermentasi) (0402020701)", "Salmonella (/25 g)"],
  [
    7043,
    "Pikel (fermentasi) (0402020701)",
    "Jumlah Sampel - Salmonella",
  ],
  [7044, "Pikel Buah (0401021005)", "Salmonella (/25 g)"],
  [
    7045,
    "Pikel Buah (0401021005)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7046,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Salmonella (/25 g)",
  ],
  [
    7047,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7048,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7049,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [7050, "Pikel Ikan Haring (09030208)", "Salmonella (/25 g)"],
  [
    7051,
    "Pikel Ikan Haring (09030208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7052,
    "Pikel Ikan Haring (09030208)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7053,
    "Pikel Ikan Haring (09030208)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [7054, "Pikel Jahe (0402020706)", "Salmonella (/25 g)"],
  [7055, "Pikel Jahe (0402020706)", "Jumlah Sampel - Salmonella"],
  [7056, "Pikel Mentimun (0402020705)", "Salmonella (/25 g)"],
  [
    7057,
    "Pikel Mentimun (0402020705)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7058,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Salmonella (/25 g)",
  ],
  [
    7059,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7060,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Salmonella (/25 g)",
  ],
  [
    7061,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Jumlah Sampel - Salmonella",
  ],
  [7062, "Pikel Sprat (09030207)", "Salmonella (/25 g)"],
  [7063, "Pikel Sprat (09030207)", "Jumlah Sampel - Salmonella"],
  [
    7064,
    "Pikel Sprat (09030207)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7065,
    "Pikel Sprat (09030207)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    7066,
    "Pikel Zaitun (Olives) (0402020707)",
    "Salmonella (/25 g)",
  ],
  [
    7067,
    "Pikel Zaitun (Olives) (0402020707)",
    "Jumlah Sampel - Salmonella",
  ],
  [7068, "Pilus (150118)", "Salmonella (/25 g)"],
  [7069, "Pilus (150118)", "Jumlah Sampel - Salmonella"],
  [
    7070,
    "Pilus (150118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7071,
    "Pilus (150118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7072,
    "Pilus (150118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7073,
    "Pilus (150118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7074,
    "Pilus (150118)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7075,
    "Pisang Hijau (060717)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7076,
    "Pisang Hijau (060717)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7077,
    "Pisang Hijau (060717)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7078,
    "Pisang Hijau (060717)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7079,
    "Pisang Hijau (060717)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7080, "Pisang Hijau (060717)", "Salmonella (/25 g)"],
  [7081, "Pisang Hijau (060717)", "Jumlah Sampel - Salmonella"],
  [
    7082,
    "Pisang Hijau (060717)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7083,
    "Pisang Hijau (060717)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7084,
    "Pisang Hijau (060717)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7085,
    "Pisang Hijau (060717)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7086,
    "Pisang Hijau (060717)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [7087, "Pizza (07020209)", "Salmonella (/25 g)"],
  [7088, "Pizza (07020209)", "Jumlah Sampel - Salmonella"],
  [
    7089,
    "Pizza (07020209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7090,
    "Pizza (07020209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7091,
    "Pizza (07020209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7092,
    "Pizza (07020209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7093,
    "Pizza (07020209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7094,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "ALT (koloni/g)",
  ],
  [7095, "", "\x{2264}100000", "\x{2264}10000"],
  [
    7096,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "ALT (koloni/g)",
  ],
  [7097, "", "\x{2264}100000", "\x{2264}10000"],
  [
    7098,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "ALT (koloni/g)",
  ],
  [7099, "", "\x{2264}100000", "\x{2264}10000"],
  [
    7100,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "ALT (koloni/g)",
  ],
  [7101, "", "\x{2264}100000", "\x{2264}10000"],
  [
    7102,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "ALT (koloni/g)",
  ],
  [7103, "", "\x{2264}100000", "\x{2264}10000"],
  [
    7104,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Enterobacteriaceae (koloni/g)",
  ],
  [7105, "", "\x{2264}100", "\x{2264}10"],
  [
    7106,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Enterobacteriaceae (koloni/g)",
  ],
  [7107, "", "\x{2264}100", "\x{2264}10"],
  [
    7108,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Enterobacteriaceae (koloni/g)",
  ],
  [7109, "", "\x{2264}100", "\x{2264}10"],
  [
    7110,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Enterobacteriaceae (koloni/g)",
  ],
  [7111, "", "\x{2264}100", "\x{2264}10"],
  [
    7112,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Enterobacteriaceae (koloni/g)",
  ],
  [7113, "", "\x{2264}100", "\x{2264}10"],
  [
    7114,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [7115, "", "\x{2264}100", "\x{2264}10"],
  [
    7116,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [7117, "", "\x{2264}100", "\x{2264}10"],
  [
    7118,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [7119, "", "\x{2264}100", "\x{2264}10"],
  [
    7120,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [7121, "", "\x{2264}100", "\x{2264}10"],
  [
    7122,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [7123, "", "\x{2264}100", "\x{2264}10"],
  [
    7124,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Salmonella (koloni/25 g)",
  ],
  [
    7125,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7126,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Salmonella (/25 g)",
  ],
  [
    7127,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Salmonella (/25 g)",
  ],
  [
    7128,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Salmonella (/25 g)",
  ],
  [
    7129,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Jumlah - Salmonella",
  ],
  [
    7130,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7131,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7132,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7133,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7134,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7135,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7136,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7137,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7138,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    7139,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7140,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7141,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7142,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7143,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7144,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7145,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7146,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7147,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7148,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7149,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Salmonella (/25 g)",
  ],
  [
    7150,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Salmonella (/25 g)",
  ],
  [
    7151,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Jumlah - Salmonella",
  ],
  [
    7152,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Jumlah - Salmonella",
  ],
  [7153, "Praline (05010428)", "Salmonella (/25 g)"],
  [7154, "Praline (05010428)", "Jumlah Sampel - Salmonella"],
  [7155, "Pre-Fried Potatoes (0402020805)", "Salmonella (/25 g)"],
  [
    7156,
    "Pre-Fried Potatoes (0402020805)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7157,
    "Pre-Fried Potatoes (0402020805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7158,
    "Pre-Fried Potatoes (0402020805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7159,
    "Pre-Fried Potatoes (0402020805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7160,
    "Pre-Fried Potatoes (0402020805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7161,
    "Pre-Fried Potatoes (0402020805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7162, "Premiks Es Bentuk Bubuk (0321)", "Salmonella (/25ml)"],
  [
    7163,
    "Premiks Es Bentuk Bubuk (0321)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [7164, "Premiks Es Bentuk Cair (0322)", "Salmonella (/25ml)"],
  [
    7165,
    "Premiks Es Bentuk Cair (0322)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7166,
    "Premiks Es Krim (Bubuk) (010712)",
    "Salmonella (koloni/25 g)",
  ],
  [
    7167,
    "Premiks Es Krim (Bubuk) (010712)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    7168,
    "Premiks Es Krim (Bubuk) (010712)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7169,
    "Premiks Es Krim (Bubuk) (010712)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7170,
    "Premiks Es Krim (Bubuk) (010712)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7171,
    "Premiks Es Krim (Bubuk) (010712)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7172,
    "Premiks Es Krim (Bubuk) (010712)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7173,
    "Premiks Es Krim (Cair) (010715)",
    "Salmonella (koloni/25 g)",
  ],
  [
    7174,
    "Premiks Es Krim (Cair) (010715)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    7175,
    "Premiks Es Krim (Cair) (010715)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7176,
    "Premiks Es Krim (Cair) (010715)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7177,
    "Premiks Es Krim (Cair) (010715)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7178,
    "Premiks Es Krim (Cair) (010715)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7179,
    "Premiks Es Krim (Cair) (010715)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7180,
    "Premiks Es Susu (Bubuk) (010721)",
    "Salmonella (koloni/25 g)",
  ],
  [
    7181,
    "Premiks Es Susu (Bubuk) (010721)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    7182,
    "Premiks Es Susu (Cair) (010722)",
    "Salmonella (koloni/25 g)",
  ],
  [
    7183,
    "Premiks Es Susu (Cair) (010722)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    7184,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Salmonella (/25 g)",
  ],
  [
    7185,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7186,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7187,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7188,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7189,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7190,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7191,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Salmonella (/25 g)",
  ],
  [
    7192,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7193,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7194,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7195,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7196,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7197,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7198,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Salmonella (/25 g)",
  ],
  [
    7199,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7200,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Salmonella (/25 g)",
  ],
  [
    7201,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7202,
    "Premiks Untuk Stuffing (07010405)",
    "Salmonella (/25 g)",
  ],
  [
    7203,
    "Premiks Untuk Stuffing (07010405)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7204,
    "Pressed Candy/Lozenges (05020103)",
    "Salmonella (/25 g)",
  ],
  [
    7205,
    "Pressed Candy/Lozenges (05020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7206,
    "Produk Buah Oles (0401020603)",
    "Salmonella (/25 g) - Semua produk dengan proses pasteurisasi",
  ],
  [
    7207,
    "Produk Buah Oles (0401020603)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7208,
    "Produk Buah Oles (0401020603)",
    "Salmonella (/25 g) - Semua produk dengan proses non pasteurisasi",
  ],
  [
    7209,
    "Produk Buah Oles (0401020603)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7210,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Salmonella (/25 g)",
  ],
  [
    7211,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7212,
    "Produk Makaroni Diperkaya (06040203)",
    "Salmonella (/25 g)",
  ],
  [
    7213,
    "Produk Makaroni Diperkaya (06040203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7214,
    "Produk Makaroni Diperkaya dan Fortifikasi Protein (06040204)",
    "Salmonella (/25 g)",
  ],
  [
    7215,
    "Produk Makaroni Diperkaya dan Fortifikasi Protein (06040204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7216,
    "Produk Makaroni Sayur yang Diperkaya (06040209)",
    "Salmonella (/25 g)",
  ],
  [
    7217,
    "Produk Makaroni Sayur yang Diperkaya (06040209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7218,
    "Produk Makaroni Susu Tanpa Lemak (06040210)",
    "Salmonella (/25 g)",
  ],
  [
    7219,
    "Produk Makaroni Susu Tanpa Lemak (06040210)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7220,
    "Produk Makaroni Susu Tanpa Lemak Yang Diperkaya (06040211)",
    "Salmonella (/25 g)",
  ],
  [
    7221,
    "Produk Makaroni Susu Tanpa Lemak Yang Diperkaya (06040211)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7222,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Salmonella (/25 g)",
  ],
  [
    7223,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Jumlah Sampel - Salmonella",
  ],
  [7224, "Produk Mi Sayur (06040214)", "Salmonella (/25 g)"],
  [
    7225,
    "Produk Mi Sayur (06040214)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7226,
    "Produk Mi Sayur yang Diperkaya (06040215)",
    "Salmonella (/25 g)",
  ],
  [
    7227,
    "Produk Mi Sayur yang Diperkaya (06040215)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7228,
    "Produk Mi yang Diperkaya (06040212)",
    "Salmonella (/25 g)",
  ],
  [
    7229,
    "Produk Mi yang Diperkaya (06040212)",
    "Jumlah Sampel - Salmonella",
  ],
  [7230, "Produk Oles Untuk Salad (120701)", "Salmonella (/25 g)"],
  [7231, "Produk Oles Untuk Salad (120701)", "Salmonella (/25 g)"],
  [
    7232,
    "Produk Oles Untuk Salad (120701)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7233,
    "Produk Oles Untuk Salad (120701)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7234,
    "Produk Oles Untuk Salad (Misalnya Salad Makaroni, Salad Kentang) dan Sandwich, Tidak Mencakup Produk Oles Berbasis Cokelat dan Kacang Dari Kategori 04.2.2.5 dan 05.1.3 (1207)",
    "Salmonella (/25 g)",
  ],
  [
    7235,
    "Produk Oles Untuk Salad (Misalnya Salad Makaroni, Salad Kentang) dan Sandwich, Tidak Mencakup Produk Oles Berbasis Cokelat dan Kacang Dari Kategori 04.2.2.5 dan 05.1.3 (1207)",
    "Salmonella (/25 g)",
  ],
  [
    7236,
    "Produk Oles Untuk Salad (Misalnya Salad Makaroni, Salad Kentang) dan Sandwich, Tidak Mencakup Produk Oles Berbasis Cokelat dan Kacang Dari Kategori 04.2.2.5 dan 05.1.3 (1207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7237,
    "Produk Oles Untuk Salad (Misalnya Salad Makaroni, Salad Kentang) dan Sandwich, Tidak Mencakup Produk Oles Berbasis Cokelat dan Kacang Dari Kategori 04.2.2.5 dan 05.1.3 (1207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7238,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Salmonella (/25 g)",
  ],
  [
    7239,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7240,
    "Produk Pasta Gandum Utuh (06040205)",
    "Salmonella (/25 g)",
  ],
  [
    7241,
    "Produk Pasta Gandum Utuh (06040205)",
    "Jumlah Sampel - Salmonella",
  ],
  [7242, "Produk Pasta Sayur (06040208)", "Salmonella (/25 g)"],
  [
    7243,
    "Produk Pasta Sayur (06040208)",
    "Jumlah Sampel - Salmonella",
  ],
  [7244, "Produk Pasta Susu (06040207)", "Salmonella (/25 g)"],
  [
    7245,
    "Produk Pasta Susu (06040207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7246,
    "Puding berbahan dasar susu (010710)",
    "Salmonella (/25 g)",
  ],
  [
    7247,
    "Puding berbahan dasar susu (010710)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7248,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Salmonella (/25 g)",
  ],
  [
    7249,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7250,
    "Puding Nasi (060505)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7251,
    "Puding Nasi (060505)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7252,
    "Puding Nasi (060505)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7253,
    "Puding Nasi (060505)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7254,
    "Puding Nasi (060505)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7255, "Puding Nasi (060505)", "Salmonella (/25 g)"],
  [7256, "Puding Nasi (060505)", "Jumlah Sampel - Salmonella"],
  [
    7257,
    "Puding Nasi (060505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7258,
    "Puding Nasi (060505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7259,
    "Puding Nasi (060505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7260,
    "Puding Nasi (060505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7261,
    "Puding Nasi (060505)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7262,
    "Puding Tapioka (060506)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7263,
    "Puding Tapioka (060506)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7264,
    "Puding Tapioka (060506)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7265,
    "Puding Tapioka (060506)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7266,
    "Puding Tapioka (060506)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7267, "Puding Tapioka (060506)", "Salmonella (/25 g)"],
  [7268, "Puding Tapioka (060506)", "Jumlah Sampel - Salmonella"],
  [
    7269,
    "Puding Tapioka (060506)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7270,
    "Puding Tapioka (060506)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7271,
    "Puding Tapioka (060506)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7272,
    "Puding Tapioka (060506)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7273,
    "Puding Tapioka (060506)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [7274, "Pukis (07020120)", "Salmonella (/25 g)"],
  [7275, "Pukis (07020120)", "Jumlah Sampel - Salmonella"],
  [
    7276,
    "Pukis (07020120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7277,
    "Pukis (07020120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7278,
    "Pukis (07020120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7279,
    "Pukis (07020120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7280,
    "Pukis (07020120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7281, "Puree Buah (0401020802)", "Jumlah Sampel - Salmonella"],
  [7282, "Puree Buah (0401020802)", "Salmonella (/25 g)"],
  [7283, "Puree Tomat (0402020501)", "Salmonella (/25 g)"],
  [7284, "Puree Tomat (0402020501)", "Jumlah Sampel - Salmonella"],
  [7285, "Putih Telur Beku (10020202)", "Salmonella (/25 g)"],
  [
    7286,
    "Putih Telur Beku (10020202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7287,
    "Putu Ayu (060706)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7288,
    "Putu Ayu (060706)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7289,
    "Putu Ayu (060706)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7290,
    "Putu Ayu (060706)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7291,
    "Putu Ayu (060706)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7292, "Putu Ayu (060706)", "Salmonella (/25 g)"],
  [7293, "Putu Ayu (060706)", "Jumlah Sampel - Salmonella"],
  [
    7294,
    "Putu Ayu (060706)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7295,
    "Putu Ayu (060706)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7296,
    "Putu Ayu (060706)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7297,
    "Putu Ayu (060706)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7298,
    "Putu Ayu (060706)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7299,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Salmonella (/25 g)",
  ],
  [
    7300,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Jumlah Sampel - Salmonella",
  ],
  [7301, "Rebon (09020533)", "Salmonella (/25 g)"],
  [
    7302,
    "Rebon (09020533)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7303,
    "Remahan Biskuit (07020216)",
    "Jumlah Sampel - Salmonella",
  ],
  [7304, "Remahan Biskuit (07020216)", "Salmonella (/25 g)"],
  [
    7305,
    "Remahan Biskuit (07020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7306,
    "Remahan Biskuit (07020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7307,
    "Remahan Biskuit (07020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7308,
    "Remahan Biskuit (07020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7309,
    "Remahan Biskuit (07020216)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7310, "Rempah (12020102)", "Salmonella (/25 g)"],
  [7311, "Rempah (12020102)", "Jumlah Sampel - Salmonella"],
  [
    7312,
    "Rempah (12020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7313,
    "Rempah (12020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7314,
    "Rempah (12020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7315,
    "Rempah (12020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7316,
    "Rempah (12020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7317,
    "Rempah (12020102)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7318,
    "Rempah (12020102)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7319,
    "Rempah (12020102)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7320,
    "Rempah (12020102)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7321,
    "Rempah (12020102)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7322, "Rempah Bubuk (12020103)", "Salmonella (/25 g)"],
  [7323, "Rempah Bubuk (12020103)", "Jumlah Sampel - Salmonella"],
  [
    7324,
    "Rempah Bubuk (12020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7325,
    "Rempah Bubuk (12020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7326,
    "Rempah Bubuk (12020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7327,
    "Rempah Bubuk (12020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7328,
    "Rempah Bubuk (12020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7329,
    "Rempah Bubuk (12020103)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7330,
    "Rempah Bubuk (12020103)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7331,
    "Rempah Bubuk (12020103)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7332,
    "Rempah Bubuk (12020103)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7333,
    "Rempah Bubuk (12020103)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7334, "Rempeyek (150128)", "Salmonella (/25 g)"],
  [7335, "Rempeyek (150128)", "Jumlah Sampel - Salmonella"],
  [
    7336,
    "Rempeyek (150128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7337,
    "Rempeyek (150128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7338,
    "Rempeyek (150128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7339,
    "Rempeyek (150128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7340,
    "Rempeyek (150128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7341, "Rempeyek Ikan (150305)", "Salmonella (/25 g)"],
  [7342, "Rempeyek Ikan (150305)", "Jumlah Sampel - Salmonella"],
  [
    7343,
    "Rempeyek Ikan (150305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7344,
    "Rempeyek Ikan (150305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7345,
    "Rempeyek Ikan (150305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7346,
    "Rempeyek Ikan (150305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7347,
    "Rempeyek Ikan (150305)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7348,
    "Rendang Ikan Tuna (0902040318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7349,
    "Rendang Ikan Tuna (0902040318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7350,
    "Rendang Ikan Tuna (0902040318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7351,
    "Rendang Ikan Tuna (0902040318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7352,
    "Rendang Ikan Tuna (0902040318)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7353,
    "Rendang Kerang (0902040319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7354,
    "Rendang Kerang (0902040319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7355,
    "Rendang Kerang (0902040319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7356,
    "Rendang Kerang (0902040319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7357,
    "Rendang Kerang (0902040319)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7358, "Rendang Telur (10020305)", "Salmonella (koloni/25 g)"],
  [
    7359,
    "Rendang Telur (10020305)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [7360, "Rengginang/ Batiah (150127 )", "Salmonella (/25 g)"],
  [
    7361,
    "Rengginang/ Batiah (150127 )",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7362,
    "Rengginang/ Batiah (150127 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7363,
    "Rengginang/ Batiah (150127 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7364,
    "Rengginang/ Batiah (150127 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7365,
    "Rengginang/ Batiah (150127 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7366,
    "Rengginang/ Batiah (150127 )",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7367,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7368,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7369,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7370,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7371,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7372,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7373,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7374,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7375,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7376,
    "Rolade Daging (08030219)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7377, "Rolade Daging (08030219)", "Salmonella (/25 g)"],
  [7378, "Rolade Daging (08030219)", "Salmonella (/25 g)"],
  [7379, "Rolade Daging (08030219)", "Jumlah - Salmonella"],
  [7380, "Rolade Daging (08030219)", "Jumlah - Salmonella"],
  [
    7381,
    "Rolade Ikan (0902040129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7382,
    "Rolade Ikan (0902040129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7383,
    "Rolade Ikan (0902040129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7384,
    "Rolade Ikan (0902040129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7385,
    "Rolade Ikan (0902040129)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7386, "Rollmops (09030101)", "Salmonella (/25 g)"],
  [7387, "Rollmops (09030101)", "Jumlah Sampel - Salmonella"],
  [7388, "Rosemari (12020188)", "Salmonella (/25 g)"],
  [7389, "Rosemari (12020188)", "Jumlah Sampel - Salmonella"],
  [7390, "Roti Bagelen (07020110)", "Salmonella (/25 g)"],
  [7391, "Roti Bagelen (07020110)", "Jumlah Sampel - Salmonella"],
  [
    7392,
    "Roti Bagelen (07020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7393,
    "Roti Bagelen (07020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7394,
    "Roti Bagelen (07020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7395,
    "Roti Bagelen (07020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7396,
    "Roti Bagelen (07020110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7397, "Roti Bagelen Pisang (07020111)", "Salmonella (/25 g)"],
  [
    7398,
    "Roti Bagelen Pisang (07020111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7399,
    "Roti Bagelen Pisang (07020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7400,
    "Roti Bagelen Pisang (07020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7401,
    "Roti Bagelen Pisang (07020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7402,
    "Roti Bagelen Pisang (07020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7403,
    "Roti Bagelen Pisang (07020111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7404,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Salmonella (/25 g)",
  ],
  [
    7405,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Jumlah Sampel - Salmonella",
  ],
  [7406, "Roti Buaya (07020207)", "Salmonella (/25 g)"],
  [7407, "Roti Buaya (07020207)", "Jumlah Sampel - Salmonella"],
  [
    7408,
    "Roti Buaya (07020207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7409,
    "Roti Buaya (07020207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7410,
    "Roti Buaya (07020207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7411,
    "Roti Buaya (07020207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7412,
    "Roti Buaya (07020207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7413,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Salmonella (/25 g)",
  ],
  [
    7414,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7415,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Salmonella (/25 g)",
  ],
  [
    7416,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Jumlah Sampel - Salmonella",
  ],
  [7417, "Roti Diperkaya (0701010102)", "Salmonella (/25 g)"],
  [
    7418,
    "Roti Diperkaya (0701010102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7419,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Salmonella (/25 g)",
  ],
  [
    7420,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Jumlah Sampel - Salmonella",
  ],
  [7421, "Roti Isi (07020203)", "Salmonella (/25 g)"],
  [7422, "Roti Isi (07020203)", "Jumlah Sampel - Salmonella"],
  [
    7423,
    "Roti Isi (07020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7424,
    "Roti Isi (07020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7425,
    "Roti Isi (07020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7426,
    "Roti Isi (07020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7427,
    "Roti Isi (07020203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7428, "Roti Jala (07010307)", "Salmonella (/25 g)"],
  [7429, "Roti Jala (07010307)", "Jumlah Sampel - Salmonella"],
  [7430, "Roti Kadet (0701010103)", "Salmonella (/25 g)"],
  [7431, "Roti Kadet (0701010103)", "Jumlah Sampel - Salmonella"],
  [7432, "Roti Kadet Gandum (0701010119)", "Salmonella (/25 g)"],
  [
    7433,
    "Roti Kadet Gandum (0701010119)",
    "Jumlah Sampel - Salmonella",
  ],
  [7434, "Roti Kadet Susu (0701010120)", "Salmonella (/25 g)"],
  [
    7435,
    "Roti Kadet Susu (0701010120)",
    "Jumlah Sampel - Salmonella",
  ],
  [7436, "Roti Malt (0701010118)", "Salmonella (/25 g)"],
  [7437, "Roti Malt (0701010118)", "Jumlah Sampel - Salmonella"],
  [7438, "Roti Manis (07020202)", "Salmonella (/25 g)"],
  [7439, "Roti Manis (07020202)", "Jumlah Sampel - Salmonella"],
  [
    7440,
    "Roti Manis (07020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7441,
    "Roti Manis (07020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7442,
    "Roti Manis (07020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7443,
    "Roti Manis (07020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7444,
    "Roti Manis (07020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7445, "Roti Meal (0701010109)", "Salmonella (/25 g)"],
  [7446, "Roti Meal (0701010109)", "Jumlah Sampel - Salmonella"],
  [
    7447,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Salmonella (/25 g)",
  ],
  [
    7448,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7449,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Salmonella (/25 g)",
  ],
  [
    7450,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Jumlah Sampel - Salmonella",
  ],
  [7451, "Roti Pita (07010303)", "Salmonella (/25 g)"],
  [7452, "Roti Pita (07010303)", "Jumlah Sampel - Salmonella"],
  [7453, "Roti Pumpernickel (0701010113)", "Salmonella (/25 g)"],
  [
    7454,
    "Roti Pumpernickel (0701010113)",
    "Jumlah Sampel - Salmonella",
  ],
  [7455, "Roti Putih (0701010105)", "Salmonella (/25 g)"],
  [7456, "Roti Putih (0701010105)", "Jumlah Sampel - Salmonella"],
  [7457, "Roti Rye (0701010112)", "Salmonella (/25 g)"],
  [7458, "Roti Rye (0701010112)", "Jumlah Sampel - Salmonella"],
  [7459, "Roti Soda (07010102)", "Salmonella (/25 g)"],
  [7460, "Roti Soda (07010102)", "Jumlah Sampel - Salmonella"],
  [7461, "Roti Soda (0701010201)", "Salmonella (/25 g)"],
  [7462, "Roti Soda (0701010201)", "Jumlah Sampel - Salmonella"],
  [
    7463,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Salmonella (/25 g)",
  ],
  [
    7464,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Jumlah Sampel - Salmonella",
  ],
  [7465, "Roti Tawar (0701010104)", "Salmonella (/25 g)"],
  [7466, "Roti Tawar (0701010104)", "Jumlah Sampel - Salmonella"],
  [
    7467,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Salmonella (/25 g)",
  ],
  [
    7468,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Jumlah Sampel - Salmonella",
  ],
  [7469, "Roti Tawar Kupas (0701010106)", "Salmonella (/25 g)"],
  [
    7470,
    "Roti Tawar Kupas (0701010106)",
    "Jumlah Sampel - Salmonella",
  ],
  [7471, "Roti Untuk Stuffing (07010404)", "Salmonella (/25 g)"],
  [
    7472,
    "Roti Untuk Stuffing (07010404)",
    "Jumlah Sampel - Salmonella",
  ],
  [7473, "Roti Wheat-Germ (0701010108)", "Salmonella (/25 g)"],
  [
    7474,
    "Roti Wheat-Germ (0701010108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7475,
    "Roti Yang Dikembangkan Dengan Kamir dan Roti Istimewa (07010101)",
    "Salmonella (/25 g)",
  ],
  [
    7476,
    "Roti Yang Dikembangkan Dengan Kamir dan Roti Istimewa (07010101)",
    "Jumlah Sampel - Salmonella",
  ],
  [7477, "Rujak (0401020303)", "Jumlah Sampel - Salmonella"],
  [7478, "Rujak (0401020303)", "Salmonella (/25 g)"],
  [7479, "Rusip (09020532)", "Salmonella (/25 g)"],
  [
    7480,
    "Rusip (09020532)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [7481, "Saffron (12020190)", "Salmonella (/25 g)"],
  [7482, "Saffron (12020190)", "Jumlah Sampel - Salmonella"],
  [
    7483,
    "Saffron (12020190)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7484,
    "Saffron (12020190)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7485,
    "Saffron (12020190)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7486,
    "Saffron (12020190)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7487,
    "Saffron (12020190)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    7488,
    "Saffron (12020190)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7489,
    "Saffron (12020190)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7490,
    "Saffron (12020190)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7491,
    "Saffron (12020190)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7492,
    "Saffron (12020190)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7493, "Saga (12020189)", "Salmonella (/25 g)"],
  [7494, "Saga (12020189)", "Jumlah Sampel - Salmonella"],
  [
    7495,
    "Sagu/Pati Mutiara (060511)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7496,
    "Sagu/Pati Mutiara (060511)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7497,
    "Sagu/Pati Mutiara (060511)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7498,
    "Sagu/Pati Mutiara (060511)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7499,
    "Sagu/Pati Mutiara (060511)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7500, "Sagu/Pati Mutiara (060511)", "Salmonella (/25 g)"],
  [
    7501,
    "Sagu/Pati Mutiara (060511)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7502,
    "Sagu/Pati Mutiara (060511)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7503,
    "Sagu/Pati Mutiara (060511)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7504,
    "Sagu/Pati Mutiara (060511)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7505,
    "Sagu/Pati Mutiara (060511)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7506,
    "Sagu/Pati Mutiara (060511)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7507,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Salmonella (/25 g)",
  ],
  [
    7508,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7509,
    "Salami (0803010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7510,
    "Salami (0803010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7511,
    "Salami (0803010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7512,
    "Salami (0803010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7513,
    "Salami (0803010303)",
    "Staphylococcus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7514, "Salami (0803010303)", "Salmonella (/25 g)"],
  [7515, "Salami (0803010303)", "Salmonella (/25 g)"],
  [7516, "Salami (0803010303)", "Jumlah - Salmonella"],
  [
    7517,
    "Salami (0803010303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7518,
    "Salami (0803010303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7519,
    "Salami (0803010303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7520,
    "Salami (0803010303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7521,
    "Salami (0803010303)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7522, "Salami (0803010303)", "Jumlah Sampel - Salmonella"],
  [
    7523,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7524,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7525,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7526,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7527,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7528,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7529,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7530,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7531,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7532,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7533,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Salmonella (/25 g)",
  ],
  [
    7534,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Salmonella (/25 g)",
  ],
  [
    7535,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Jumlah - Salmonella",
  ],
  [
    7536,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Jumlah - Salmonella",
  ],
  [7537, "Salsa (0402020606)", "Salmonella (/25 g)"],
  [7538, "Salsa (0402020606)", "Jumlah Sampel - Salmonella"],
  [7539, "Sambal Buah (0401020602)", "Jumlah Sampel - Salmonella"],
  [7540, "Sambal Buah (0401020602)", "Salmonella (/25 g)"],
  [
    7541,
    "Sambal Goreng Ikan (0902040312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7542,
    "Sambal Goreng Ikan (0902040312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7543,
    "Sambal Goreng Ikan (0902040312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7544,
    "Sambal Goreng Ikan (0902040312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7545,
    "Sambal Goreng Ikan (0902040312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7546,
    "Sambal Goreng Udang (0902040301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7547,
    "Sambal Goreng Udang (0902040301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7548,
    "Sambal Goreng Udang (0902040301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7549,
    "Sambal Goreng Udang (0902040301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7550,
    "Sambal Goreng Udang (0902040301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7551,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7552,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7553,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7554,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7555,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7556,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Salmonella (/25 g)",
  ],
  [
    7557,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Jumlah Sampel - Salmonella",
  ],
  [7558, "Sandwich Spread (12060108)", "Salmonella (/25 g)"],
  [
    7559,
    "Sandwich Spread (12060108)",
    "Jumlah Sampel - Salmonella",
  ],
  [7560, "Santan Bubuk (0401020209)", "Salmonella (/25g)"],
  [
    7561,
    "Santan Bubuk (0401020209)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7562,
    "Santan Ekstraksi Air (0401020808)",
    "Salmonella (/25 g)",
  ],
  [
    7563,
    "Santan Ekstraksi Air (0401020808)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7564,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Salmonella (/25 g)",
  ],
  [
    7565,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Jumlah Sampel - Salmonella",
  ],
  [7566, "Sarden Media Saus Tomat (090409)", "Salmonella (/25 g)"],
  [7567, "Sarden Media Saus Tomat (090409)", "Salmonella (/25 g)"],
  [
    7568,
    "Sarden Media Saus Tomat (090409)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7569,
    "Sarden Media Saus Tomat (090409)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7570,
    "Sarden Media Saus Tomat (090409)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7571,
    "Sarden Media Saus Tomat (090409)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7572,
    "Sarden Media Saus Tomat (090409)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    7573,
    "Sarden Media Saus Tomat (090409)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [7574, "Sari Buah (1401020101)", "Salmonella (/25 ml)"],
  [7575, "Sari Buah (1401020101)", "Salmonella (/25 ml)"],
  [7576, "Sari Buah (1401020101)", "Jumlah Sampel - Salmonella"],
  [7577, "Sari Buah (1401020101)", "Jumlah Sampel - Salmonella"],
  [
    7578,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Salmonella (/25 ml)",
  ],
  [
    7579,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Salmonella (/25 ml)",
  ],
  [
    7580,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7581,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Jumlah Sampel - Salmonella",
  ],
  [7582, "Sari Buah Anggur (1401020112)", "Salmonella (/25 ml)"],
  [7583, "Sari Buah Anggur (1401020112)", "Salmonella (/25 ml)"],
  [
    7584,
    "Sari Buah Anggur (1401020112)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7585,
    "Sari Buah Anggur (1401020112)",
    "Jumlah Sampel - Salmonella",
  ],
  [7586, "Sari Buah Apel (1401020104)", "Salmonella (/25 ml)"],
  [7587, "Sari Buah Apel (1401020104)", "Salmonella (/25 ml)"],
  [
    7588,
    "Sari Buah Apel (1401020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7589,
    "Sari Buah Apel (1401020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7590,
    "Sari Buah Belimbing (1401020118)",
    "Salmonella (/25 ml)",
  ],
  [
    7591,
    "Sari Buah Belimbing (1401020118)",
    "Salmonella (/25 ml)",
  ],
  [
    7592,
    "Sari Buah Belimbing (1401020118)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7593,
    "Sari Buah Belimbing (1401020118)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7594,
    "Sari Buah Blackberry (1401020126)",
    "Salmonella (/25 ml)",
  ],
  [
    7595,
    "Sari Buah Blackberry (1401020126)",
    "Salmonella (/25 ml)",
  ],
  [
    7596,
    "Sari Buah Blackberry (1401020126)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7597,
    "Sari Buah Blackberry (1401020126)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7598,
    "Sari Buah Blackcurrant (1401020114)",
    "Salmonella (/25 ml)",
  ],
  [
    7599,
    "Sari Buah Blackcurrant (1401020114)",
    "Salmonella (/25 ml)",
  ],
  [
    7600,
    "Sari Buah Blackcurrant (1401020114)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7601,
    "Sari Buah Blackcurrant (1401020114)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7602,
    "Sari Buah Blueberry (1401020136)",
    "Salmonella (/25 ml)",
  ],
  [
    7603,
    "Sari Buah Blueberry (1401020136)",
    "Salmonella (/25 ml)",
  ],
  [
    7604,
    "Sari Buah Blueberry (1401020136)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7605,
    "Sari Buah Blueberry (1401020136)",
    "Jumlah Sampel - Salmonella",
  ],
  [7606, "Sari Buah Campuran (1401020102)", "Salmonella (/25 ml)"],
  [7607, "Sari Buah Campuran (1401020102)", "Salmonella (/25 ml)"],
  [
    7608,
    "Sari Buah Campuran (1401020102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7609,
    "Sari Buah Campuran (1401020102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7610,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Salmonella (/25 ml)",
  ],
  [
    7611,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Salmonella (/25 ml)",
  ],
  [
    7612,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7613,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Jumlah Sampel - Salmonella",
  ],
  [7614, "Sari Buah Delima (1401020123)", "Salmonella (/25 ml)"],
  [7615, "Sari Buah Delima (1401020123)", "Salmonella (/25 ml)"],
  [
    7616,
    "Sari Buah Delima (1401020123)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7617,
    "Sari Buah Delima (1401020123)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7618,
    "Sari Buah Jambu Biji (1401020122)",
    "Salmonella (/25 ml)",
  ],
  [
    7619,
    "Sari Buah Jambu Biji (1401020122)",
    "Salmonella (/25 ml)",
  ],
  [
    7620,
    "Sari Buah Jambu Biji (1401020122)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7621,
    "Sari Buah Jambu Biji (1401020122)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7622,
    "Sari Buah Jeruk Bali (1401020105)",
    "Salmonella (/25 ml)",
  ],
  [
    7623,
    "Sari Buah Jeruk Bali (1401020105)",
    "Salmonella (/25 ml)",
  ],
  [
    7624,
    "Sari Buah Jeruk Bali (1401020105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7625,
    "Sari Buah Jeruk Bali (1401020105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7626,
    "Sari Buah Jeruk Garut (1401020133)",
    "Salmonella (/25 ml)",
  ],
  [
    7627,
    "Sari Buah Jeruk Garut (1401020133)",
    "Salmonella (/25 ml)",
  ],
  [
    7628,
    "Sari Buah Jeruk Garut (1401020133)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7629,
    "Sari Buah Jeruk Garut (1401020133)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7630,
    "Sari Buah Jeruk Medan (1401020134)",
    "Salmonella (/25 ml)",
  ],
  [
    7631,
    "Sari Buah Jeruk Medan (1401020134)",
    "Salmonella (/25 ml)",
  ],
  [
    7632,
    "Sari Buah Jeruk Medan (1401020134)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7633,
    "Sari Buah Jeruk Medan (1401020134)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7634,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Salmonella (/25 ml)",
  ],
  [
    7635,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Salmonella (/25 ml)",
  ],
  [
    7636,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7637,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7638,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Salmonella (/25 ml)",
  ],
  [
    7639,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Salmonella (/25 ml)",
  ],
  [
    7640,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7641,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Jumlah Sampel - Salmonella",
  ],
  [7642, "Sari Buah Kiwi (1401020138)", "Salmonella (/25 ml)"],
  [7643, "Sari Buah Kiwi (1401020138)", "Salmonella (/25 ml)"],
  [
    7644,
    "Sari Buah Kiwi (1401020138)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7645,
    "Sari Buah Kiwi (1401020138)",
    "Jumlah Sampel - Salmonella",
  ],
  [7646, "Sari Buah Leci (1401020137)", "Salmonella (/25 ml)"],
  [7647, "Sari Buah Leci (1401020137)", "Salmonella (/25 ml)"],
  [
    7648,
    "Sari Buah Leci (1401020137)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7649,
    "Sari Buah Leci (1401020137)",
    "Jumlah Sampel - Salmonella",
  ],
  [7650, "Sari Buah Lemon (1401020110)", "Salmonella (/25 ml)"],
  [7651, "Sari Buah Lemon (1401020110)", "Salmonella (/25 ml)"],
  [
    7652,
    "Sari Buah Lemon (1401020110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7653,
    "Sari Buah Lemon (1401020110)",
    "Jumlah Sampel - Salmonella",
  ],
  [7654, "Sari Buah Mangga (1401020115)", "Salmonella (/25 ml)"],
  [7655, "Sari Buah Mangga (1401020115)", "Salmonella (/25 ml)"],
  [
    7656,
    "Sari Buah Mangga (1401020115)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7657,
    "Sari Buah Mangga (1401020115)",
    "Jumlah Sampel - Salmonella",
  ],
  [7658, "Sari Buah Manggis (1401020129)", "Salmonella (/25 ml)"],
  [7659, "Sari Buah Manggis (1401020129)", "Salmonella (/25 ml)"],
  [
    7660,
    "Sari Buah Manggis (1401020129)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7661,
    "Sari Buah Manggis (1401020129)",
    "Jumlah Sampel - Salmonella",
  ],
  [7662, "Sari Buah Markisa (1401020111)", "Salmonella (/25 ml)"],
  [7663, "Sari Buah Markisa (1401020111)", "Salmonella (/25 ml)"],
  [
    7664,
    "Sari Buah Markisa (1401020111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7665,
    "Sari Buah Markisa (1401020111)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7666,
    "Sari Buah Naga (1401020139)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7667,
    "Sari Buah Naga (1401020139)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [7668, "Sari Buah Nanas (1401020109)", "Salmonella (/25 ml)"],
  [7669, "Sari Buah Nanas (1401020109)", "Salmonella (/25 ml)"],
  [
    7670,
    "Sari Buah Nanas (1401020109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7671,
    "Sari Buah Nanas (1401020109)",
    "Jumlah Sampel - Salmonella",
  ],
  [7672, "Sari Buah Peach (1401020121)", "Salmonella (/25 ml)"],
  [7673, "Sari Buah Peach (1401020121)", "Salmonella (/25 ml)"],
  [
    7674,
    "Sari Buah Peach (1401020121)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7675,
    "Sari Buah Peach (1401020121)",
    "Jumlah Sampel - Salmonella",
  ],
  [7676, "Sari Buah Pir (1401020124)", "Salmonella (/25 ml)"],
  [7677, "Sari Buah Pir (1401020124)", "Salmonella (/25 ml)"],
  [
    7678,
    "Sari Buah Pir (1401020124)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7679,
    "Sari Buah Pir (1401020124)",
    "Jumlah Sampel - Salmonella",
  ],
  [7680, "Sari Buah Plum (1401020120)", "Salmonella (/25 ml)"],
  [7681, "Sari Buah Plum (1401020120)", "Salmonella (/25 ml)"],
  [
    7682,
    "Sari Buah Plum (1401020120)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7683,
    "Sari Buah Plum (1401020120)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7684,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Salmonella (/25 ml)",
  ],
  [
    7685,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Salmonella (/25 ml)",
  ],
  [
    7686,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7687,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7688,
    "Sari Buah Raspberry (1401020127)",
    "Salmonella (/25 ml)",
  ],
  [
    7689,
    "Sari Buah Raspberry (1401020127)",
    "Salmonella (/25 ml)",
  ],
  [
    7690,
    "Sari Buah Raspberry (1401020127)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7691,
    "Sari Buah Raspberry (1401020127)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7692,
    "Sari Buah Redcurrant (1401020125)",
    "Salmonella (/25 ml)",
  ],
  [
    7693,
    "Sari Buah Redcurrant (1401020125)",
    "Salmonella (/25 ml)",
  ],
  [
    7694,
    "Sari Buah Redcurrant (1401020125)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7695,
    "Sari Buah Redcurrant (1401020125)",
    "Jumlah Sampel - Salmonella",
  ],
  [7696, "Sari Buah Sirsak (1401020116)", "Salmonella (/25 ml)"],
  [7697, "Sari Buah Sirsak (1401020116)", "Salmonella (/25 ml)"],
  [
    7698,
    "Sari Buah Sirsak (1401020116)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7699,
    "Sari Buah Sirsak (1401020116)",
    "Jumlah Sampel - Salmonella",
  ],
  [7700, "Sari Buah Stroberi (1401020128)", "Salmonella (/25 ml)"],
  [7701, "Sari Buah Stroberi (1401020128)", "Salmonella (/25 ml)"],
  [
    7702,
    "Sari Buah Stroberi (1401020128)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7703,
    "Sari Buah Stroberi (1401020128)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7704,
    "Sari Buah Terong Belanda (1401020130)",
    "Salmonella (/25 ml)",
  ],
  [
    7705,
    "Sari Buah Terong Belanda (1401020130)",
    "Salmonella (/25 ml)",
  ],
  [
    7706,
    "Sari Buah Terong Belanda (1401020130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7707,
    "Sari Buah Terong Belanda (1401020130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7708,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Salmonella (/25 ml)",
  ],
  [
    7709,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Salmonella (/25 ml)",
  ],
  [
    7710,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7711,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Jumlah Sampel - Salmonella",
  ],
  [7712, "Sari Kedelai (06080101)", "Salmonella (/25 g)"],
  [7713, "Sari Kedelai (06080101)", "Jumlah Sampel - Salmonella"],
  [
    7714,
    "Sari Sayur (1401020201)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7715,
    "Sari Sayur (1401020201)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [
    7716,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7717,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [
    7718,
    "Sari Sayur Campuran (1401020206)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7719,
    "Sari Sayur Campuran (1401020206)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [
    7720,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7721,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [
    7722,
    "Sari Tomat (1401020202)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7723,
    "Sari Tomat (1401020202)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [
    7724,
    "Sari Wortel (1401020203)",
    "Salmonella (koloni/25 ml) - Tidak DiPasteurisasi",
  ],
  [
    7725,
    "Sari Wortel (1401020203)",
    "Jumlah Sampel - Salmonella - Tidak DiPasteurisasi",
  ],
  [7726, "Sauerkraut (0402020703)", "Salmonella (/25 g)"],
  [7727, "Sauerkraut (0402020703)", "Jumlah Sampel - Salmonella"],
  [
    7728,
    "Saus Apel (Applesauce) (0401020805)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7729,
    "Saus Apel (Applesauce) (0401020805)",
    "Salmonella (/25 g)",
  ],
  [7730, "Saus Asam Manis (12060221)", "Salmonella (/25 g)"],
  [
    7731,
    "Saus Asam Manis (12060221)",
    "Jumlah Sampel - Salmonella",
  ],
  [7732, "Saus Buah (0401020804)", "Jumlah Sampel - Salmonella"],
  [7733, "Saus Buah (0401020804)", "Salmonella (/25 g)"],
  [
    7734,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Salmonella (/25 g)",
  ],
  [
    7735,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Jumlah Sampel - Salmonella",
  ],
  [7736, "Saus Bumbu Teremulsi (12060106)", "Salmonella (/25 g)"],
  [
    7737,
    "Saus Bumbu Teremulsi (12060106)",
    "Jumlah Sampel - Salmonella",
  ],
  [7738, "Saus Butterscotch (050403)", "Salmonella (/25 g)"],
  [
    7739,
    "Saus Butterscotch (050403)",
    "Jumlah Sampel - Salmonella",
  ],
  [7740, "Saus Cabe (12060201)", "Salmonella (/25 g)"],
  [7741, "Saus Cabe (12060201)", "Jumlah Sampel - Salmonella"],
  [
    7742,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Salmonella (/25 g)",
  ],
  [
    7743,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Salmonella (/25 g)",
  ],
  [
    7744,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7745,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Jumlah Sampel - Salmonella",
  ],
  [7746, "Saus Lobak (12060210)", "Salmonella (/25 g)"],
  [7747, "Saus Lobak (12060210)", "Salmonella (/25 g)"],
  [7748, "Saus Lobak (12060210)", "Jumlah Sampel - Salmonella"],
  [7749, "Saus Lobak (12060210)", "Jumlah Sampel - Salmonella"],
  [
    7750,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Salmonella (/25 g)",
  ],
  [
    7751,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Salmonella (/25 g)",
  ],
  [
    7752,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7753,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7754,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Salmonella (/25 g)",
  ],
  [
    7755,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Salmonella (/25 g)",
  ],
  [
    7756,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7757,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7758,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Salmonella (/25 g)",
  ],
  [
    7759,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [7760, "Saus Salsa (12060230)", "Salmonella (/25 g)"],
  [7761, "Saus Salsa (12060230)", "Jumlah Sampel - Salmonella"],
  [
    7762,
    "Saus Sambal Cabe Hijau (12060203)",
    "Salmonella (/25 g)",
  ],
  [
    7763,
    "Saus Sambal Cabe Hijau (12060203)",
    "Jumlah Sampel - Salmonella",
  ],
  [7764, "Saus Sate (12060213)", "Salmonella (/25 g)"],
  [7765, "Saus Sate (12060213)", "Jumlah Sampel - Salmonella"],
  [
    7766,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Salmonella (/25 g)",
  ],
  [
    7767,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}5",
  ],
  [
    7768,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Salmonella (/25 g)",
  ],
  [
    7769,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Salmonella (/25 g)",
  ],
  [
    7770,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7771,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Jumlah Sampel - Salmonella",
  ],
  [7772, "Saus Teriyaki (12060228)", "Salmonella (/25 g)"],
  [7773, "Saus Teriyaki (12060228)", "Jumlah Sampel - Salmonella"],
  [7774, "Saus Tiram (12060215)", "Salmonella (/25 g)"],
  [7775, "Saus Tiram (12060215)", "Salmonella (/25 g)"],
  [7776, "Saus Tiram (12060215)", "Jumlah Sampel - Salmonella"],
  [7777, "Saus Tiram (12060215)", "Jumlah Sampel - Salmonella"],
  [7778, "Saus Tiram Bening (12060402)", "Salmonella (/25 g)"],
  [
    7779,
    "Saus Tiram Bening (12060402)",
    "Jumlah Sampel - Salmonella",
  ],
  [7780, "Saus Tomat (12060217)", "Salmonella (/25 g)"],
  [7781, "Saus Tomat (12060217)", "Salmonella (/25 g)"],
  [7782, "Saus Tomat (12060217)", "Jumlah Sampel - Salmonella"],
  [7783, "Saus Tomat (12060217)", "Jumlah Sampel - Salmonella"],
  [
    7784,
    "Saus Toping/Saus Siram (12060229)",
    "Salmonella (/25 g)",
  ],
  [
    7785,
    "Saus Toping/Saus Siram (12060229)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7786,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Salmonella (/25 g)",
  ],
  [
    7787,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7788,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Salmonella (/25 g)",
  ],
  [
    7789,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Salmonella (/25 g)",
  ],
  [
    7790,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7791,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7792,
    "Saus/Topping/Olesan Manis (050408)",
    "Salmonella (/25 g)",
  ],
  [
    7793,
    "Saus/Topping/Olesan Manis (050408)",
    "Jumlah Sampel - Salmonella",
  ],
  [7794, "Sawi Asin (0402020702)", "Salmonella (/25 g)"],
  [7795, "Sawi Asin (0402020702)", "Jumlah Sampel - Salmonella"],
  [7796, "Sayur Asin (0402020302)", "Salmonella (/25 g)"],
  [7797, "Sayur Asin (0402020302)", "Jumlah Sampel - Salmonella"],
  [7798, "Sayur Beku (0402020101)", "Salmonella (/25 g)"],
  [7799, "Sayur Beku (0402020101)", "Jumlah Sampel - Salmonella"],
  [
    7800,
    "Sayur Beku (0402020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7801,
    "Sayur Beku (0402020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7802,
    "Sayur Beku (0402020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7803,
    "Sayur Beku (0402020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7804,
    "Sayur Beku (0402020101)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7805,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Salmonella (/25 g)",
  ],
  [
    7806,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7807,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7808,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7809,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7810,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7811,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [7812, "Sayur Goreng Beku (0402020115)", "Salmonella (/25 g)"],
  [
    7813,
    "Sayur Goreng Beku (0402020115)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7814,
    "Sayur Goreng Beku (0402020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7815,
    "Sayur Goreng Beku (0402020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7816,
    "Sayur Goreng Beku (0402020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7817,
    "Sayur Goreng Beku (0402020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7818,
    "Sayur Goreng Beku (0402020115)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    7819,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Salmonella (/25 g)",
  ],
  [
    7820,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    7821,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    7822,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    7823,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    7824,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    7825,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [7826, "Scone (07020204)", "Salmonella (/25 g)"],
  [7827, "Scone (07020204)", "Jumlah Sampel - Salmonella"],
  [
    7828,
    "Scone (07020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7829,
    "Scone (07020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7830,
    "Scone (07020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7831,
    "Scone (07020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7832,
    "Scone (07020204)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [7833, "Sea Gel (09030102)", "Salmonella (/25 g)"],
  [7834, "Sea Gel (09030102)", "Jumlah Sampel - Salmonella"],
  [
    7835,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7836,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Salmonella (/25 ml)",
  ],
  [
    7837,
    "Selai Kacang (0402020502)",
    "Jumlah Sampel - Salmonella",
  ],
  [7838, "Selai Kacang (0402020502)", "Salmonella (/25 g)"],
  [
    7839,
    "Selai Kacang Lainnya (0402020504)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7840,
    "Selai Kacang Lainnya (0402020504)",
    "Salmonella (/25 g)",
  ],
  [
    7841,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7842,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Salmonella (/25 g)",
  ],
  [7843, "Selai Kaya (100401)", "Salmonella (/25 g)"],
  [
    7844,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7845,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Salmonella (/25 g)",
  ],
  [7846, "Selai Sayur (0402020511)", "Salmonella (/25 g)"],
  [
    7847,
    "Selai Sayur (0402020511)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7848,
    "Semar Mendem (060720)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7849,
    "Semar Mendem (060720)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7850,
    "Semar Mendem (060720)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7851,
    "Semar Mendem (060720)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7852,
    "Semar Mendem (060720)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7853, "Semar Mendem (060720)", "Salmonella (/25 g)"],
  [7854, "Semar Mendem (060720)", "Jumlah Sampel - Salmonella"],
  [
    7855,
    "Semar Mendem (060720)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7856,
    "Semar Mendem (060720)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7857,
    "Semar Mendem (060720)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7858,
    "Semar Mendem (060720)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7859,
    "Semar Mendem (060720)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7860,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Salmonella (/25 g)",
  ],
  [
    7861,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7862,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7863,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7864,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7865,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7866,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7867,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Salmonella (/25 g)",
  ],
  [
    7868,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7869,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7870,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7871,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7872,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7873,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7874, "Serabi (07020119)", "Salmonella (/25 g)"],
  [7875, "Serabi (07020119)", "Jumlah Sampel - Salmonella"],
  [
    7876,
    "Serabi (07020119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7877,
    "Serabi (07020119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7878,
    "Serabi (07020119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7879,
    "Serabi (07020119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7880,
    "Serabi (07020119)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    7881,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Salmonella (/25 g)",
  ],
  [
    7882,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7883,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7884,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7885,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7886,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7887,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}100",
  ],
  [
    7888,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Salmonella (/25 g)",
  ],
  [
    7889,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    7890,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    7891,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    7892,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    7893,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    7894,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    7895,
    "Serbuk Minuman Kedelai (06080103)",
    "Salmonella (/25 g)",
  ],
  [
    7896,
    "Serbuk Minuman Kedelai (06080103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7897,
    "Serbuk Minuman Kedelai (06080103)",
    "Staphylococcus aureus (koloni/ g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    7898,
    "Serbuk Minuman Kedelai (06080103)",
    "Staphylococcus aureus (koloni/ g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    7899,
    "Serbuk Minuman Kedelai (06080103)",
    "Staphylococcus aureus (koloni/ g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    7900,
    "Serbuk Minuman Kedelai (06080103)",
    "Staphylococcus aureus (koloni/ g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    7901,
    "Serbuk Minuman Kedelai (06080103)",
    "Staphylococcus aureus (koloni/ g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [7902, "Serbuk Minuman Sereal (060313)", "Salmonella (/25 g)"],
  [
    7903,
    "Serbuk Minuman Sereal (060313)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7904,
    "Serbuk Minuman Sereal (060313)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7905,
    "Serbuk Minuman Sereal (060313)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7906,
    "Serbuk Minuman Sereal (060313)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7907,
    "Serbuk Minuman Sereal (060313)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7908,
    "Serbuk Minuman Sereal (060313)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7909,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Salmonella (/25 g)",
  ],
  [
    7910,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7911,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7912,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7913,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7914,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7915,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7916,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Salmonella (/25 g)",
  ],
  [
    7917,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7918,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7919,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7920,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7921,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7922,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7923,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Salmonella (/25 g)",
  ],
  [
    7924,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7925,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7926,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7927,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7928,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7929,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [7930, "Sereh (120201A7)", "Salmonella (/25 g)"],
  [7931, "Sereh (120201A7)", "Jumlah Sampel - Salmonella"],
  [
    7932,
    "Seri Muka (060726)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7933,
    "Seri Muka (060726)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7934,
    "Seri Muka (060726)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7935,
    "Seri Muka (060726)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    7936,
    "Seri Muka (060726)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [7937, "Seri Muka (060726)", "Salmonella (/25 g)"],
  [7938, "Seri Muka (060726)", "Jumlah Sampel - Salmonella"],
  [
    7939,
    "Seri Muka (060726)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7940,
    "Seri Muka (060726)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7941,
    "Seri Muka (060726)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7942,
    "Seri Muka (060726)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    7943,
    "Seri Muka (060726)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [7944, "Sherbet (0309)", "Jumlah Sampel - Salmonella"],
  [7945, "Sherbet (0309)", "Salmonella (/25 ml)"],
  [7946, "Shortened Bread (07010305)", "Salmonella (/25 g)"],
  [
    7947,
    "Shortened Bread (07010305)",
    "Jumlah Sampel - Salmonella",
  ],
  [7948, "Sidat Panggang Beku (09020131)", "Salmonella (/25 g)"],
  [
    7949,
    "Sidat Panggang Beku (09020131)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [7950, "Simmered Beans (0402020804)", "Salmonella (/25 g)"],
  [
    7951,
    "Simmered Beans (0402020804)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7952,
    "Simmered Beans (0402020804)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7953,
    "Simmered Beans (0402020804)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7954,
    "Simmered Beans (0402020804)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7955,
    "Simmered Beans (0402020804)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7956,
    "Simmered Beans (0402020804)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7957, "Simping (150116)", "Salmonella (/25 g)"],
  [7958, "Simping (150116)", "Jumlah Sampel - Salmonella"],
  [
    7959,
    "Simping (150116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7960,
    "Simping (150116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7961,
    "Simping (150116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7962,
    "Simping (150116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7963,
    "Simping (150116)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [7964, "Siomay Daging (08030323)", "Salmonella (/25 g)"],
  [7965, "Siomay Daging (08030323)", "Jumlah - Salmonella"],
  [
    7966,
    "Siomay Daging (08030323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7967,
    "Siomay Daging (08030323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7968,
    "Siomay Daging (08030323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7969,
    "Siomay Daging (08030323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7970,
    "Siomay Daging (08030323)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7971,
    "Siomay Daging (08030323)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7972,
    "Siomay Daging (08030323)",
    "Jumlah - Listeria monocytogenes",
  ],
  [
    7973,
    "Siomay Ikan (0902040111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7974,
    "Siomay Ikan (0902040111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7975,
    "Siomay Ikan (0902040111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7976,
    "Siomay Ikan (0902040111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    7977,
    "Siomay Ikan (0902040111)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [7978, "Siomay Udang (0902040206)", "Salmonella (/25 g)"],
  [
    7979,
    "Siomay Udang (0902040206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7980,
    "Siomay Udang (0902040206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    7981,
    "Siomay Udang (0902040206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    7982,
    "Siomay Udang (0902040206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    7983,
    "Siomay Udang (0902040206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    7984,
    "Siomay Udang (0902040206)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    7985,
    "Siomay Udang (0902040206)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    7986,
    "Siomay Udang (0902040206)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [7987, "Sirip Cucut Kering (09020514)", "Salmonella (/25 g)"],
  [
    7988,
    "Sirip Cucut Kering (09020514)",
    "Jumlah Sampel - Salmonella",
  ],
  [7989, "Slondok (150117)", "Salmonella (/25 g)"],
  [7990, "Slondok (150117)", "Jumlah Sampel - Salmonella"],
  [
    7991,
    "Slondok (150117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7992,
    "Slondok (150117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7993,
    "Slondok (150117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7994,
    "Slondok (150117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7995,
    "Slondok (150117)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    7996,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    7997,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    7998,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    7999,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8000,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8001,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8002,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8003,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Listeria monocytogenes (/25 g)",
  ],
  [
    8004,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Jumlah Sampel - Listeria monocytogenes",
  ],
  [8005, "Sohun (06040318)", "Salmonella (/25 g)"],
  [8006, "Sohun (06040318)", "Jumlah Sampel - Salmonella"],
  [8007, "Sohun Instan (06040323)", "Salmonella (/25 g)"],
  [8008, "Sohun Instan (06040323)", "Jumlah Sampel - Salmonella"],
  [8009, "Sohun Lainnya (06040319)", "Salmonella (/25 g)"],
  [8010, "Sohun Lainnya (06040319)", "Jumlah Sampel - Salmonella"],
  [8011, "Sorbet (0310)", "Jumlah Sampel - Salmonella"],
  [8012, "Sorbet (0310)", "Salmonella (/25 ml)"],
  [
    8013,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8014,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8015,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8016,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8017,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8018,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8019,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8020,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8021,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8022,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8023,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8024,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8025,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8026,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8027,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8028,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8029,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8030,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8031,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8032,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8033,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8034,
    "Sosis Asap (0803010106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [8035, "Sosis Asap (0803010106)", "Jumlah Sampel - Salmonella"],
  [8036, "Sosis Asap (0803010106)", "Jumlah Sampel - Salmonella"],
  [8037, "Sosis Asap (0803010106)", "Jumlah Sampel - Salmonella"],
  [8038, "Sosis Asap (0803010106)", "Salmonella (koloni/25 ml)"],
  [
    8039,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8040,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8041,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8042,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8043,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8044,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8045,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8046,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8047,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8048,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8049,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8050,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8051,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8052,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8053,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8054,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8055,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8056,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8057,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8058,
    "Sosis Asap Kombinasi (0803010108)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8059,
    "Sosis Asap Kombinasi (0803010108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8060,
    "Sosis Asap Kombinasi (0803010108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8061,
    "Sosis Asap Kombinasi (0803010108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8062,
    "Sosis Asap Kombinasi (0803010108)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8063,
    "Sosis Asap Kombinasi (0803010108)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8064,
    "Sosis Asap Kombinasi (0803010108)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8065,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8066,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8067,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8068,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8069,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8070,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8071,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8072,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8073,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8074,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8075,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Salmonella (/25 g)",
  ],
  [
    8076,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8077,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8078,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8079,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8080,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8081,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8082,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8083,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8084,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8085,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8086,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8087,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8088,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Salmonella (/25 g)",
  ],
  [
    8089,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8090,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8091,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8092,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8093,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8094,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8095,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8096,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8097,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Salmonella (/25 g)",
  ],
  [
    8098,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Jumlah - Salmonella",
  ],
  [
    8099,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8100,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8101,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8102,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8103,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8104,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8105,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8106,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8107,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8108,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8109,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8110,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8111,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8112,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8113,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8114,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8115,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8116,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8117,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8118,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8119,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8120,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8121,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8122,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8123,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8124,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8125,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8126,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8127,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8128,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Salmonella (/25 g)",
  ],
  [
    8129,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Salmonella (/25 g)",
  ],
  [
    8130,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Salmonella (/25 g)",
  ],
  [
    8131,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Jumlah - Salmonella",
  ],
  [
    8132,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Jumlah - Salmonella",
  ],
  [
    8133,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8134,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8135,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8136,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8137,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8138,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8139,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8140,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8141,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8142,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8143,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8144,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8145,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8146,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8147,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "<1000",
  ],
  [
    8148,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8149,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8150,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8151,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8152,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8153,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8154,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8155,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8156,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8157,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8158,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8159,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8160,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8161,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8162,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8163,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8164,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8165,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8166,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8167,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8168,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8169,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8170,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8171,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8172,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8173,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8174,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8175,
    "Sosis Daging Non Casing (08030238)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8176,
    "Sosis Daging Non Casing (08030238)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8177,
    "Sosis Daging Non Casing (08030238)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8178,
    "Sosis Daging Non Casing (08030238)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8179,
    "Sosis Ikan (0902040115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8180,
    "Sosis Ikan (0902040115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8181,
    "Sosis Ikan (0902040115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8182,
    "Sosis Ikan (0902040115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8183,
    "Sosis Ikan (0902040115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8184,
    "Sosis Ikan Kombinasi (0902040128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8185,
    "Sosis Ikan Kombinasi (0902040128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8186,
    "Sosis Ikan Kombinasi (0902040128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8187,
    "Sosis Ikan Kombinasi (0902040128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8188,
    "Sosis Ikan Kombinasi (0902040128)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8189,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Salmonella (/25 g)",
  ],
  [
    8190,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8191,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    8192,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    8193,
    "Sosis Siap Santap (0902040120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8194,
    "Sosis Siap Santap (0902040120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8195,
    "Sosis Siap Santap (0902040120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8196,
    "Sosis Siap Santap (0902040120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8197,
    "Sosis Siap Santap (0902040120)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8198, "Sosis Udang (0902040208)", "Salmonella (/25 g)"],
  [8199, "Sosis Udang (0902040208)", "Jumlah Sampel - Salmonella"],
  [
    8200,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8201,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8202,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8203,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8204,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8205,
    "Sosis Udang (0902040208)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    8206,
    "Sosis Udang (0902040208)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    8207,
    "Sosis Udang (0902040208)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [8208, "Sotong Dalam Kemasan (090417)", "Salmonella (/25 g)"],
  [
    8209,
    "Sotong Dalam Kemasan (090417)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8210,
    "Sotong Dalam Kemasan (090417)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    8211,
    "Sotong Dalam Kemasan (090417)",
    "Jumlah Sampel - Listeria monocytogenes",
    "\x{2265}",
  ],
  [
    8212,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8213,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8214,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8215,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8216,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8217,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8218,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8219,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8220,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8221,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8222,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8223,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8224,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8225,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8226,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8227, "Stroopwafel (07020212)", "Salmonella (/25 g)"],
  [8228, "Stroopwafel (07020212)", "Jumlah Sampel - Salmonella"],
  [
    8229,
    "Stroopwafel (07020212)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    8230,
    "Stroopwafel (07020212)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    8231,
    "Stroopwafel (07020212)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    8232,
    "Stroopwafel (07020212)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    8233,
    "Stroopwafel (07020212)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [8234, "Sumpia Udang (150306)", "Salmonella (/25 g)"],
  [8235, "Sumpia Udang (150306)", "Jumlah Sampel - Salmonella"],
  [
    8236,
    "Sumpia Udang (150306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8237,
    "Sumpia Udang (150306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8238,
    "Sumpia Udang (150306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8239,
    "Sumpia Udang (150306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8240,
    "Sumpia Udang (150306)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [8241, "Sup Krim Instan (12050203)", "Salmonella (/25 g)"],
  [
    8242,
    "Sup Krim Instan (12050203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8243,
    "Sup Krim Instan (12050203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8244,
    "Sup Krim Instan (12050203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8245,
    "Sup Krim Instan (12050203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8246,
    "Sup Krim Instan (12050203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8247,
    "Sup Krim Instan (12050203)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8248,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Salmonella (/25 g)",
  ],
  [
    8249,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8250,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8251,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8252,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8253,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8254,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8255,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Salmonella (/25 g)",
  ],
  [
    8256,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8257,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8258,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8259,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8260,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8261,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8262,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Salmonella (/25 ml)",
  ],
  [
    8263,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8264,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Salmonella (negatif/25 g)",
  ],
  [
    8265,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8266,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Salmonella (/25 g)",
  ],
  [
    8267,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8268,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Salmonella (/25 ml)",
  ],
  [
    8269,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8270,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Salmonella (/25 g)",
  ],
  [
    8271,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8272,
    "Susu Bubuk (01050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8273,
    "Susu Bubuk (01050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8274,
    "Susu Bubuk (01050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8275,
    "Susu Bubuk (01050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8276,
    "Susu Bubuk (01050106)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [8277, "Susu Bubuk (01050106)", "Salmonella (/25 g)"],
  [8278, "Susu Bubuk (01050106)", "Jumlah Sampel - Salmonella"],
  [
    8279,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8280,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8281,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8282,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8283,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8284,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Salmonella (/25 g)",
  ],
  [
    8285,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8286,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8287,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8288,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8289,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8290,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8291,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Salmonella (/25 g)",
  ],
  [
    8292,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8293,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8294,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8295,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8296,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8297,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8298,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Salmonella (/25 ml)",
  ],
  [
    8299,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8300,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8301,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8302,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8303,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8304,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8305,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Salmonella (/25 ml)",
  ],
  [
    8306,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8307,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Salmonella (/25 g)",
  ],
  [
    8308,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8309,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8310,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8311,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8312,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8313,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8314,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8315,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8316,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8317,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8318,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8319,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Salmonella (/25 g)",
  ],
  [
    8320,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8321,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8322,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8323,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8324,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8325,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8326,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Salmonella (/25 g)",
  ],
  [
    8327,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8328,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8329,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8330,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8331,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8332,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8333,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Salmonella (/25 g)",
  ],
  [
    8334,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8335,
    "Susu Bubuk Skim (01050104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8336,
    "Susu Bubuk Skim (01050104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8337,
    "Susu Bubuk Skim (01050104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8338,
    "Susu Bubuk Skim (01050104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8339,
    "Susu Bubuk Skim (01050104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [8340, "Susu Bubuk Skim (01050104)", "Salmonella (/25 ml)"],
  [
    8341,
    "Susu Bubuk Skim (01050104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8342,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8343,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8344,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8345,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8346,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8347,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Salmonella (/25 g)",
  ],
  [
    8348,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8349,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8350,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8351,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8352,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8353,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8354,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Salmonella (/25 g)",
  ],
  [
    8355,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8356,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8357,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8358,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8359,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8360,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8361,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Salmonella (/25 g)",
  ],
  [
    8362,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    8363,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8364,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8365,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8366,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8367,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Staphylococcus aureus (koloni/g)",
  ],
  [
    8368,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Salmonella (/25 g)",
  ],
  [
    8369,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8370,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8371,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8372,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8373,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8374,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8375,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Salmonella (/25 g)",
  ],
  [
    8376,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8377,
    "Susu Bubuk untuk Kue (01050107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8378,
    "Susu Bubuk untuk Kue (01050107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8379,
    "Susu Bubuk untuk Kue (01050107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8380,
    "Susu Bubuk untuk Kue (01050107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    8381,
    "Susu Bubuk untuk Kue (01050107)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [8382, "Susu Bubuk untuk Kue (01050107)", "Salmonella (/25 g)"],
  [
    8383,
    "Susu Bubuk untuk Kue (01050107)",
    "Jumlah Sampel - Salmonella",
  ],
  [8384, "Susu Diasamkan (010201A0)", "Salmonella (/25 ml)"],
  [
    8385,
    "Susu Diasamkan (010201A0)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8386,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Salmonella (/25 g)",
  ],
  [
    8387,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8388,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Salmonella (/25 g)",
  ],
  [
    8389,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8390,
    "Susu Evaporasi (01030101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8391,
    "Susu Evaporasi (01030101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8392,
    "Susu Evaporasi (01030101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8393,
    "Susu Evaporasi (01030101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8394,
    "Susu Evaporasi (01030101)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8395,
    "Susu Fermentasi (Plain) (010201)",
    "Salmonella (/25 ml)",
  ],
  [
    8396,
    "Susu Fermentasi (Plain) (010201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8397,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Salmonella (/25 ml)",
  ],
  [
    8398,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8399,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Salmonella (negatif/25 g)",
  ],
  [
    8400,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8401,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Salmonella (/25 g)",
  ],
  [
    8402,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8403,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Salmonella (/25 g)",
  ],
  [
    8404,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8405,
    "Susu Kental Manis (01030104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8406,
    "Susu Kental Manis (01030104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8407,
    "Susu Kental Manis (01030104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8408,
    "Susu Kental Manis (01030104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8409,
    "Susu Kental Manis (01030104)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8410,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8411,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8412,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8413,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8414,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8415,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8416,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8417,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8418,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8419,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8420, "Susu Kuda (0101010114)", "Salmonella (/25 ml)"],
  [8421, "Susu Kuda (0101010114)", "Jumlah Sampel - Salmonella"],
  [
    8422,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8423,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8424,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8425,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8426,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8427,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8428,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8429,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8430,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8431,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8432,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8433,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8434,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Salmonella (/25 ml)",
  ],
  [
    8435,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8436,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8437,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8438,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8439,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8440,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8441,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8442, "Susu Pasteurisasi (0101010103)", "Salmonella (/25 ml)"],
  [
    8443,
    "Susu Pasteurisasi (0101010103)",
    "Jumlah Sampel - Salmonella",
  ],
  [8444, "Susu Skim (0101010106)", "Salmonella (/25 ml)"],
  [8445, "Susu Skim (0101010106)", "Jumlah Sampel - Salmonella"],
  [
    8446,
    "Susu Skim Evaporasi (01030102)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8447,
    "Susu Skim Evaporasi (01030102)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8448,
    "Susu Skim Evaporasi (01030102)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8449,
    "Susu Skim Evaporasi (01030102)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8450,
    "Susu Skim Evaporasi (01030102)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8451,
    "Susu Skim Kental Manis (01030106)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8452,
    "Susu Skim Kental Manis (01030106)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8453,
    "Susu Skim Kental Manis (01030106)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8454,
    "Susu Skim Kental Manis (01030106)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8455,
    "Susu Skim Kental Manis (01030106)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8456,
    "Susu Skim Plain (Cair) (010101A1)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8457,
    "Susu Skim Plain (Cair) (010101A1)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8458,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8459,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8460,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8461,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8462,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8463,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8464,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Staphylococcus aureus (koloni/ml)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8465,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Salmonella (/25 ml)",
  ],
  [
    8466,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8467,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8468,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8469,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Salmonella (/25 ml) (Hanya untuk Susu Pasteurisasi)",
  ],
  [
    8470,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8471, "Sweet Mayo (12060105)", "Salmonella (/25 g)"],
  [8472, "Sweet Mayo (12060105)", "Jumlah Sampel - Salmonella"],
  [8473, "Sweet Paprika Bubuk (12020187)", "Salmonella (/25 g)"],
  [
    8474,
    "Sweet Paprika Bubuk (12020187)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8475,
    "Sweet Paprika Bubuk (12020187)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8476,
    "Sweet Paprika Bubuk (12020187)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8477,
    "Sweet Paprika Bubuk (12020187)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8478,
    "Sweet Paprika Bubuk (12020187)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8479,
    "Sweet Paprika Bubuk (12020187)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8480,
    "Sweet Paprika Bubuk (12020187)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8481,
    "Sweet Paprika Bubuk (12020187)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8482,
    "Sweet Paprika Bubuk (12020187)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8483,
    "Sweet Paprika Bubuk (12020187)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8484,
    "Sweet Paprika Bubuk (12020187)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8485,
    "Swikiau/Kuotieh Daging (08030313)",
    "Salmonella (/25 g)",
  ],
  [
    8486,
    "Swikiau/Kuotieh Daging (08030313)",
    "Jumlah - Salmonella",
  ],
  [
    8487,
    "Swikiau/Kuotieh Daging (08030313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8488,
    "Swikiau/Kuotieh Daging (08030313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8489,
    "Swikiau/Kuotieh Daging (08030313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8490,
    "Swikiau/Kuotieh Daging (08030313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8491,
    "Swikiau/Kuotieh Daging (08030313)",
    "Staphylococcus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    8492,
    "Swikiau/Kuotieh Daging (08030313)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    8493,
    "Swikiau/Kuotieh Daging (08030313)",
    "Jumlah - Listeria monocytogenes",
  ],
  [8494, "Taburan Berbasis Gula (050410)", "Salmonella (/25 g)"],
  [
    8495,
    "Taburan Berbasis Gula (050410)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8496,
    "Tahu (06080301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8497,
    "Tahu (06080301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8498,
    "Tahu (06080301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8499,
    "Tahu (06080301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8500,
    "Tahu (06080301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8501, "Tahu (06080301)", "Salmonella (/25 g)"],
  [8502, "Tahu (06080301)", "Jumlah Sampel - Salmonella"],
  [
    8503,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Salmonella (/25 g)",
  ],
  [
    8504,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Jumlah Sampel - Salmonella",
  ],
  [8505, "Tahu Kering (060805)", "Salmonella (/25 g)"],
  [8506, "Tahu Kering (060805)", "Jumlah Sampel - Salmonella"],
  [
    8507,
    "Tahu Kering (060805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8508,
    "Tahu Kering (060805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8509,
    "Tahu Kering (060805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8510,
    "Tahu Kering (060805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8511,
    "Tahu Kering (060805)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8512,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Salmonella (/25 g)",
  ],
  [
    8513,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8514,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8515,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8516,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8517,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8518,
    "Tahu Semi-Kering Yang Digoreng Deep-Fried (06080402)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8519,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Salmonella (/25 g)",
  ],
  [
    8520,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8521,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8522,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8523,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8524,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8525,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8526,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Salmonella (/25 g)",
  ],
  [
    8527,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8528,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8529,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8530,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8531,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8532,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8533,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Salmonella (/25 g)",
  ],
  [
    8534,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8535,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8536,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8537,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8538,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8539,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8540,
    "Talam Ebi (060711)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8541,
    "Talam Ebi (060711)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8542,
    "Talam Ebi (060711)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8543,
    "Talam Ebi (060711)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8544,
    "Talam Ebi (060711)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8545, "Talam Ebi (060711)", "Salmonella (/25 g)"],
  [8546, "Talam Ebi (060711)", "Jumlah Sampel - Salmonella"],
  [
    8547,
    "Talam Ebi (060711)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8548,
    "Talam Ebi (060711)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8549,
    "Talam Ebi (060711)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8550,
    "Talam Ebi (060711)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8551,
    "Talam Ebi (060711)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8552,
    "Tape Beras Ketan (060507)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8553,
    "Tape Beras Ketan (060507)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8554,
    "Tape Beras Ketan (060507)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8555,
    "Tape Beras Ketan (060507)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8556,
    "Tape Beras Ketan (060507)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8557, "Tape Beras Ketan (060507)", "Salmonella (/25 g)"],
  [
    8558,
    "Tape Beras Ketan (060507)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8559,
    "Tape Beras Ketan (060507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8560,
    "Tape Beras Ketan (060507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8561,
    "Tape Beras Ketan (060507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8562,
    "Tape Beras Ketan (060507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8563,
    "Tape Beras Ketan (060507)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8564,
    "Tape Singkong (060508)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8565,
    "Tape Singkong (060508)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8566,
    "Tape Singkong (060508)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8567,
    "Tape Singkong (060508)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8568,
    "Tape Singkong (060508)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8569, "Tape Singkong (060508)", "Salmonella (/25 g)"],
  [8570, "Tape Singkong (060508)", "Jumlah Sampel - Salmonella"],
  [
    8571,
    "Tape Singkong (060508)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8572,
    "Tape Singkong (060508)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8573,
    "Tape Singkong (060508)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8574,
    "Tape Singkong (060508)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8575,
    "Tape Singkong (060508)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8576,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Salmonella (/25 g)",
  ],
  [
    8577,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8578,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8579,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8580,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8581,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8582,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8583, "Tarragon (12020193)", "Salmonella (/25 g)"],
  [8584, "Tarragon (12020193)", "Jumlah Sampel - Salmonella"],
  [8585, "Tauco (06080604)", "Salmonella (/25 g)"],
  [8586, "Tauco (06080604)", "Jumlah Sampel - Salmonella"],
  [
    8587,
    "Tekwan Ikan (0902040127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8588,
    "Tekwan Ikan (0902040127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8589,
    "Tekwan Ikan (0902040127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8590,
    "Tekwan Ikan (0902040127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8591,
    "Tekwan Ikan (0902040127)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8592, "Telur Asin Matang (100302)", "Salmonella (/25 g)"],
  [
    8593,
    "Telur Asin Matang (100302)",
    "Jumlah Sampel - Salmonella",
  ],
  [8594, "Telur Beku Utuh (10020201)", "Salmonella (/25 g)"],
  [
    8595,
    "Telur Beku Utuh (10020201)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8596,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Salmonella (koloni/25 g)",
  ],
  [
    8597,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8598,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Salmonella (/25 g)",
  ],
  [
    8599,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [8600, "Telur Ikan (09030301)", "Salmonella (/25 g)"],
  [8601, "Telur Ikan (09030301)", "Jumlah Sampel - Salmonella"],
  [
    8602,
    "Telur Ikan (09030301)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    8603,
    "Telur Ikan (09030301)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    8604,
    "Telur Ikan (09030301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8605,
    "Telur Ikan (09030301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8606,
    "Telur Ikan (09030301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8607,
    "Telur Ikan (09030301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8608,
    "Telur Ikan (09030301)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8609,
    "Telur Ikan Masak (0902040132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8610,
    "Telur Ikan Masak (0902040132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8611,
    "Telur Ikan Masak (0902040132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8612,
    "Telur Ikan Masak (0902040132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8613,
    "Telur Ikan Masak (0902040132)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8614,
    "Telur Matang/Setengah Matang (10020306)",
    "Salmonella (koloni/25 g)",
  ],
  [
    8615,
    "Telur Matang/Setengah Matang (10020306)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8616, "Telur Pindang (100303)", "Salmonella (/25 g)"],
  [8617, "Telur Pindang (100303)", "Jumlah Sampel - Salmonella"],
  [
    8618,
    "Temo Coe (060718)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8619,
    "Temo Coe (060718)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8620,
    "Temo Coe (060718)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8621,
    "Temo Coe (060718)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8622,
    "Temo Coe (060718)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8623, "Temo Coe (060718)", "Salmonella (/25 g)"],
  [8624, "Temo Coe (060718)", "Jumlah Sampel - Salmonella"],
  [
    8625,
    "Temo Coe (060718)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8626,
    "Temo Coe (060718)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8627,
    "Temo Coe (060718)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8628,
    "Temo Coe (060718)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8629,
    "Temo Coe (060718)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [8630, "Tempe (06080603)", "Salmonella (/25 g)"],
  [8631, "Tempe (06080603)", "Jumlah Sampel - Salmonella"],
  [
    8632,
    "Tempe Selain Kedelai (0402020710)",
    "Salmonella (/25 ml)",
  ],
  [
    8633,
    "Tempe Selain Kedelai (0402020710)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    8634,
    "Tempoyak / Pakasam (0401021003)",
    "Jumlah Sampel - Salmonella",
  ],
  [8635, "Tempoyak / Pakasam (0401021003)", "Salmonella (/25 g)"],
  [
    8636,
    "Tempura Beku (09020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8637,
    "Tempura Beku (09020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8638,
    "Tempura Beku (09020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8639,
    "Tempura Beku (09020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8640,
    "Tempura Beku (09020206)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8641, "Temu Kunci (12020192)", "Salmonella (/25 g)"],
  [8642, "Temu Kunci (12020192)", "Jumlah Sampel - Salmonella"],
  [
    8643,
    "Temu Kunci (12020192)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8644,
    "Temu Kunci (12020192)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8645,
    "Temu Kunci (12020192)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8646,
    "Temu Kunci (12020192)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8647,
    "Temu Kunci (12020192)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    8648,
    "Temu Kunci (12020192)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8649,
    "Temu Kunci (12020192)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8650,
    "Temu Kunci (12020192)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8651,
    "Temu Kunci (12020192)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8652,
    "Temu Kunci (12020192)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8653, "Tepung Almond (06020128)", "Salmonella (/25 g)"],
  [8654, "Tepung Almond (06020128)", "Jumlah Sampel - Salmonella"],
  [
    8655,
    "Tepung Almond (06020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8656,
    "Tepung Almond (06020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8657,
    "Tepung Almond (06020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8658,
    "Tepung Almond (06020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8659,
    "Tepung Almond (06020128)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8660, "Tepung Aren (06020122)", "Salmonella (/25 g)"],
  [8661, "Tepung Aren (06020122)", "Jumlah Sampel - Salmonella"],
  [
    8662,
    "Tepung Aren (06020122)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8663,
    "Tepung Aren (06020122)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8664,
    "Tepung Aren (06020122)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8665,
    "Tepung Aren (06020122)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8666,
    "Tepung Aren (06020122)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8667,
    "Tepung Bakso (060602)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8668,
    "Tepung Bakso (060602)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8669,
    "Tepung Bakso (060602)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8670,
    "Tepung Bakso (060602)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8671,
    "Tepung Bakso (060602)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8672, "Tepung Bakso (060602)", "Salmonella (/25 g)"],
  [
    8673,
    "Tepung Bakso (060602)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8674,
    "Tepung Bakso (060605)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8675,
    "Tepung Bakso (060605)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8676,
    "Tepung Bakso (060605)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8677,
    "Tepung Bakso (060605)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8678,
    "Tepung Bakso (060605)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8679, "Tepung Bakso (060605)", "Salmonella (/25 g)"],
  [
    8680,
    "Tepung Bakso (060605)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8681,
    "Tepung Bakwan (060604)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8682,
    "Tepung Bakwan (060604)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8683,
    "Tepung Bakwan (060604)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8684,
    "Tepung Bakwan (060604)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8685,
    "Tepung Bakwan (060604)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8686, "Tepung Bakwan (060604)", "Salmonella (/25 g)"],
  [
    8687,
    "Tepung Bakwan (060604)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8688, "Tepung Beras (06020101)", "Salmonella (/25 g)"],
  [8689, "Tepung Beras (06020101)", "Jumlah Sampel - Salmonella"],
  [
    8690,
    "Tepung Beras (06020101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8691,
    "Tepung Beras (06020101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8692,
    "Tepung Beras (06020101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8693,
    "Tepung Beras (06020101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8694,
    "Tepung Beras (06020101)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8695, "Tepung Beras Ketan (06020102)", "Salmonella (/25 g)"],
  [
    8696,
    "Tepung Beras Ketan (06020102)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8697,
    "Tepung Beras Ketan (06020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8698,
    "Tepung Beras Ketan (06020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8699,
    "Tepung Beras Ketan (06020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8700,
    "Tepung Beras Ketan (06020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8701,
    "Tepung Beras Ketan (06020102)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8702, "Tepung Buah (0401020210)", "Salmonella (/25g)"],
  [
    8703,
    "Tepung Buah (0401020210)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8704, "Tepung Buckwheat (06020134)", "Salmonella (/25 g)"],
  [
    8705,
    "Tepung Buckwheat (06020134)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8706,
    "Tepung Buckwheat (06020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8707,
    "Tepung Buckwheat (06020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8708,
    "Tepung Buckwheat (06020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8709,
    "Tepung Buckwheat (06020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8710,
    "Tepung Buckwheat (06020134)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8711,
    "Tepung Bumbu (060601)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8712,
    "Tepung Bumbu (060601)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8713,
    "Tepung Bumbu (060601)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8714,
    "Tepung Bumbu (060601)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8715,
    "Tepung Bumbu (060601)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8716, "Tepung Bumbu (060601)", "Salmonella (/25 g)"],
  [
    8717,
    "Tepung Bumbu (060601)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8718, "Tepung Campur (06020133)", "Salmonella (/25 g)"],
  [
    8719,
    "Tepung Campur (06020133)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    8720,
    "Tepung Campur (06020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8721,
    "Tepung Campur (06020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8722,
    "Tepung Campur (06020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8723,
    "Tepung Campur (06020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8724,
    "Tepung Campur (06020133)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8725, "Tepung Ceshnut (06020127)", "Salmonella (/25 g)"],
  [
    8726,
    "Tepung Ceshnut (06020127)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8727,
    "Tepung Ceshnut (06020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8728,
    "Tepung Ceshnut (06020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8729,
    "Tepung Ceshnut (06020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8730,
    "Tepung Ceshnut (06020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8731,
    "Tepung Ceshnut (06020127)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8732, "Tepung Custard (100404)", "Salmonella (/25 g)"],
  [8733, "Tepung Custard (100404)", "Jumlah Sampel - Salmonella"],
  [
    8734,
    "Tepung Custard (100404)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [
    8735,
    "Tepung Custard (100404)",
    "Listeria monocytogenes (koloni/25 g) - Khusus Produk Beku",
  ],
  [
    8736,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8737,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8738,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8739,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8740,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8741,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Salmonella (/25 g)",
  ],
  [
    8742,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8743,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8744,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8745,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8746,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8747,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [8748, "Tepung Flaxseed (06020129)", "Salmonella (/25 g)"],
  [
    8749,
    "Tepung Flaxseed (06020129)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8750,
    "Tepung Flaxseed (06020129)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8751,
    "Tepung Flaxseed (06020129)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8752,
    "Tepung Flaxseed (06020129)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8753,
    "Tepung Flaxseed (06020129)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8754,
    "Tepung Flaxseed (06020129)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8755, "Tepung Gaplek (06020120)", "Salmonella (/25 g)"],
  [8756, "Tepung Gaplek (06020120)", "Jumlah Sampel - Salmonella"],
  [
    8757,
    "Tepung Gaplek (06020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8758,
    "Tepung Gaplek (06020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8759,
    "Tepung Gaplek (06020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8760,
    "Tepung Gaplek (06020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8761,
    "Tepung Gaplek (06020120)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8762,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Salmonella (/25 g)",
  ],
  [
    8763,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8764,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8765,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8766,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8767,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8768,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8769, "Tepung Hazelnut (06020130)", "Salmonella (/25 g)"],
  [
    8770,
    "Tepung Hazelnut (06020130)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8771,
    "Tepung Hazelnut (06020130)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8772,
    "Tepung Hazelnut (06020130)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8773,
    "Tepung Hazelnut (06020130)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8774,
    "Tepung Hazelnut (06020130)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8775,
    "Tepung Hazelnut (06020130)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8776, "Tepung Ikan (09020522)", "Salmonella (/25 g)"],
  [8777, "Tepung Ikan (09020522)", "Jumlah Sampel - Salmonella"],
  [8778, "Tepung Jagung (06020103)", "Salmonella (/25 g)"],
  [8779, "Tepung Jagung (06020103)", "Jumlah Sampel - Salmonella"],
  [
    8780,
    "Tepung Jagung (06020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8781,
    "Tepung Jagung (06020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8782,
    "Tepung Jagung (06020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8783,
    "Tepung Jagung (06020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8784,
    "Tepung Jagung (06020103)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8785,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Salmonella (/25 g)",
  ],
  [
    8786,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8787,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8788,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8789,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8790,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8791,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8792,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Salmonella (/25 g)",
  ],
  [
    8793,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8794,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8795,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8796,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8797,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8798,
    "Tepung Kacang Hijau Tanpa Kulit (06020104)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8799,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Salmonella (/25 g)",
  ],
  [
    8800,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8801,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8802,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8803,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8804,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8805,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8806, "Tepung Kacang Lainnya (06020132)", "Salmonella (/25 g)"],
  [
    8807,
    "Tepung Kacang Lainnya (06020132)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8808,
    "Tepung Kacang Lainnya (06020132)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8809,
    "Tepung Kacang Lainnya (06020132)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8810,
    "Tepung Kacang Lainnya (06020132)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8811,
    "Tepung Kacang Lainnya (06020132)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8812,
    "Tepung Kacang Lainnya (06020132)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8813, "Tepung Kacang Merah (06020106)", "Salmonella (/25 g)"],
  [
    8814,
    "Tepung Kacang Merah (06020106)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8815,
    "Tepung Kacang Merah (06020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8816,
    "Tepung Kacang Merah (06020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8817,
    "Tepung Kacang Merah (06020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8818,
    "Tepung Kacang Merah (06020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8819,
    "Tepung Kacang Merah (06020106)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8820,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Salmonella (/25 g)",
  ],
  [
    8821,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8822,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8823,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8824,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8825,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8826,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8827,
    "Tepung Kelapa (0401020818)",
    "Jumlah Sampel - Salmonella",
  ],
  [8828, "Tepung Kelapa (0401020818)", "Salmonella (/25 g)"],
  [
    8829,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Salmonella (/25 g)",
  ],
  [
    8830,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8831,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8832,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8833,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8834,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8835,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8836, "Tepung Kuning Telur (10020303)", "Salmonella (/25 g)"],
  [
    8837,
    "Tepung Kuning Telur (10020303)",
    "Jumlah Sampel - Salmonella",
  ],
  [8838, "Tepung Mokaf (06020131)", "Salmonella (/25 g)"],
  [8839, "Tepung Mokaf (06020131)", "Jumlah Sampel - Salmonella"],
  [
    8840,
    "Tepung Mokaf (06020131)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8841,
    "Tepung Mokaf (06020131)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8842,
    "Tepung Mokaf (06020131)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8843,
    "Tepung Mokaf (06020131)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8844,
    "Tepung Mokaf (06020131)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8845,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Salmonella (/25 g)",
  ],
  [
    8846,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Jumlah Sampel - Salmonella",
    "",
    "\x{2265}5",
  ],
  [
    8847,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "<10",
  ],
  [
    8848,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "<10",
  ],
  [
    8849,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "<10",
  ],
  [
    8850,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "<10",
  ],
  [
    8851,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "<10",
  ],
  [8852, "Tepung Panir (07010402)", "Salmonella (/25 g)"],
  [8853, "Tepung Panir (07010402)", "Jumlah Sampel - Salmonella"],
  [
    8854,
    "Tepung Pelapis (060603)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8855,
    "Tepung Pelapis (060603)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8856,
    "Tepung Pelapis (060603)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8857,
    "Tepung Pelapis (060603)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8858,
    "Tepung Pelapis (060603)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8859, "Tepung Pelapis (060603)", "Salmonella (/25 g)"],
  [
    8860,
    "Tepung Pelapis (060603)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8861, "Tepung Putih Telur (10020302)", "Salmonella (/25 g)"],
  [
    8862,
    "Tepung Putih Telur (10020302)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8863,
    "Tepung Roti / Bread Crumb (07010403)",
    "Salmonella (/25 g)",
  ],
  [
    8864,
    "Tepung Roti / Bread Crumb (07010403)",
    "Jumlah Sampel - Salmonella",
  ],
  [8865, "Tepung Singkong (06020119)", "Salmonella (/25 g)"],
  [
    8866,
    "Tepung Singkong (06020119)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8867,
    "Tepung Singkong (06020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8868,
    "Tepung Singkong (06020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8869,
    "Tepung Singkong (06020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8870,
    "Tepung Singkong (06020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8871,
    "Tepung Singkong (06020119)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8872, "Tepung Sorgum (06020111)", "Salmonella (/25 g)"],
  [8873, "Tepung Sorgum (06020111)", "Jumlah Sampel - Salmonella"],
  [
    8874,
    "Tepung Sorgum (06020111)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8875,
    "Tepung Sorgum (06020111)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8876,
    "Tepung Sorgum (06020111)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8877,
    "Tepung Sorgum (06020111)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8878,
    "Tepung Sorgum (06020111)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8879,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Salmonella (koloni/25 g)",
  ],
  [
    8880,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8881, "Tepung Telur Utuh (10020301)", "Salmonella (/25 g)"],
  [
    8882,
    "Tepung Telur Utuh (10020301)",
    "Jumlah Sampel - Salmonella",
  ],
  [8883, "Tepung Terigu (06020112)", "Salmonella (/25 g)"],
  [8884, "Tepung Terigu (06020112)", "Jumlah Sampel - Salmonella"],
  [
    8885,
    "Tepung Terigu (06020112)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8886,
    "Tepung Terigu (06020112)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8887,
    "Tepung Terigu (06020112)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8888,
    "Tepung Terigu (06020112)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8889,
    "Tepung Terigu (06020112)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8890,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Salmonella (/25 g)",
  ],
  [
    8891,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8892,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8893,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8894,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8895,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8896,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8897,
    "Tepung Terigu Self-Raising (06020113)",
    "Salmonella (/25 g)",
  ],
  [
    8898,
    "Tepung Terigu Self-Raising (06020113)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8899,
    "Tepung Terigu Self-Raising (06020113)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8900,
    "Tepung Terigu Self-Raising (06020113)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8901,
    "Tepung Terigu Self-Raising (06020113)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8902,
    "Tepung Terigu Self-Raising (06020113)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8903,
    "Tepung Terigu Self-Raising (06020113)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8904,
    "Tepung Terigu Terklorinasi (06020114)",
    "Salmonella (/25 g)",
  ],
  [
    8905,
    "Tepung Terigu Terklorinasi (06020114)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8906,
    "Tepung Terigu Terklorinasi (06020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8907,
    "Tepung Terigu Terklorinasi (06020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8908,
    "Tepung Terigu Terklorinasi (06020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8909,
    "Tepung Terigu Terklorinasi (06020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8910,
    "Tepung Terigu Terklorinasi (06020114)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8911,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Salmonella (/25 g)",
  ],
  [
    8912,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8913,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8914,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8915,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8916,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8917,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8918,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Salmonella (/25 g)",
  ],
  [
    8919,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8920,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8921,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8922,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8923,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    8924,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [8925, "Terasi Udang (09020517)", "Salmonella (/25 g)"],
  [8926, "Terasi Udang (09020517)", "Jumlah Sampel - Salmonella"],
  [8927, "Teripang Kering (09020512)", "Salmonella (/25 g)"],
  [
    8928,
    "Teripang Kering (09020512)",
    "Jumlah Sampel - Salmonella",
  ],
  [8929, "Terong Beku (0402020112)", "Salmonella (/25 g)"],
  [8930, "Terong Beku (0402020112)", "Jumlah Sampel - Salmonella"],
  [
    8931,
    "Terong Beku (0402020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    8932,
    "Terong Beku (0402020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    8933,
    "Terong Beku (0402020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    8934,
    "Terong Beku (0402020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    8935,
    "Terong Beku (0402020112)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    8936,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8937,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8938,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8939,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8940,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "<100",
  ],
  [
    8941,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Salmonella (koloni/25 ml)",
  ],
  [
    8942,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Jumlah Sampel - Salmonella",
  ],
  [8943, "Thymi/Thyme (12020194)", "Salmonella (/25 g)"],
  [8944, "Thymi/Thyme (12020194)", "Jumlah Sampel - Salmonella"],
  [8945, "Tiwul (060310)", "Salmonella (/25 g)"],
  [8946, "Tiwul (060310)", "Jumlah Sampel - Salmonella"],
  [
    8947,
    "Tiwul (060310)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8948,
    "Tiwul (060310)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8949,
    "Tiwul (060310)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8950,
    "Tiwul (060310)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8951,
    "Tiwul (060310)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    8952,
    "Toddler Biscuit (130208)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    8953,
    "Toddler Biscuit (130208)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    8954,
    "Toddler Biscuit (130208)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    8955,
    "Toddler Biscuit (130208)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    8956,
    "Toddler Biscuit (130208)",
    "ALT (koloni/g)",
    "\x{2264}10000",
    "\x{2264}3000",
  ],
  [
    8957,
    "Toddler Biscuit (130208)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    8958,
    "Toddler Biscuit (130208)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    8959,
    "Toddler Biscuit (130208)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    8960,
    "Toddler Biscuit (130208)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [
    8961,
    "Toddler Biscuit (130208)",
    "Enterobacteriaceae (koloni/10 g)",
    "",
    "\x{2264}10",
  ],
  [8962, "Toddler Biscuit (130208)", "Salmonella (koloni/25 g)"],
  [8963, "Toddler Biscuit (130208)", "Jumlah Sampel - Salmonella"],
  [
    8964,
    "Toddler Biscuit (130208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    8965,
    "Toddler Biscuit (130208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    8966,
    "Toddler Biscuit (130208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    8967,
    "Toddler Biscuit (130208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [
    8968,
    "Toddler Biscuit (130208)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10",
    "\x{2264}0",
  ],
  [8969, "Toffee (05020206)", "Salmonella (Kembang"],
  [8970, "Gula/Permen"],
  [8971, "Lunak (bukan jeli)"],
  [8972, ") (/25 g)"],
  [8973, "Toffee (05020206)", "Jumlah Sampel - Salmonella"],
  [8974, "Toffee (05020206)", "Jumlah Sampel - Salmonella"],
  [
    8975,
    "Toffee (05020206)",
    "Salmonella (Kembang Gula/Permen Lunak (jeli)) (/25 g)",
  ],
  [
    8976,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Salmonella (/25 g)",
  ],
  [
    8977,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Jumlah Sampel - Salmonella",
  ],
  [8978, "Topping Buah (0401020806)", "Salmonella (/25 g)"],
  [
    8979,
    "Topping Buah (0401020806)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    8980,
    "Tortila Ikan (0902040317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8981,
    "Tortila Ikan (0902040317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8982,
    "Tortila Ikan (0902040317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8983,
    "Tortila Ikan (0902040317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8984,
    "Tortila Ikan (0902040317)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8985, "Tortilla (06040103)", "Salmonella (/25 g)"],
  [8986, "Tortilla (06040103)", "Jumlah Sampel - Salmonella"],
  [
    8987,
    "Tortilla (06040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8988,
    "Tortilla (06040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8989,
    "Tortilla (06040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8990,
    "Tortilla (06040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8991,
    "Tortilla (06040103)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [8992, "Tortilla (07010308)", "Salmonella (/25 g)"],
  [
    8993,
    "Tortilla (07010308)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [8994, "Truffles (05010404)", "Salmonella (/25 g)"],
  [8995, "Truffles (05010404)", "Jumlah Sampel - Salmonella"],
  [8996, "Tsukemono (0402020312)", "Salmonella (/25 g)"],
  [8997, "Tsukemono (0402020312)", "Jumlah Sampel - Salmonella"],
  [
    8998,
    "Tsukudani (0902040131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    8999,
    "Tsukudani (0902040131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9000,
    "Tsukudani (0902040131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9001,
    "Tsukudani (0902040131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9002,
    "Tsukudani (0902040131)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [9003, "Ubi Beku (0402020113)", "Salmonella (/25 g)"],
  [9004, "Ubi Beku (0402020113)", "Jumlah Sampel - Salmonella"],
  [
    9005,
    "Ubi Beku (0402020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9006,
    "Ubi Beku (0402020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9007,
    "Ubi Beku (0402020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9008,
    "Ubi Beku (0402020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9009,
    "Ubi Beku (0402020113)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [9010, "Ubur-Ubur Asin (09020511)", "Salmonella (/25 g)"],
  [
    9011,
    "Ubur-Ubur Asin (09020511)",
    "Jumlah Sampel - Salmonella",
  ],
  [9012, "Udang Beku (09020116)", "Salmonella (/25 g)"],
  [9013, "Udang Beku (09020116)", "Jumlah Sampel - Salmonella"],
  [
    9014,
    "Udang Beku (09020116)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9015,
    "Udang Beku (09020116)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9016,
    "Udang Beku (09020116)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9017,
    "Udang Beku (09020116)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9018,
    "Udang Beku (09020116)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9019,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Salmonella (/25 g)",
  ],
  [
    9020,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9021,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9022,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9023,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9024,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9025,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Listeria monocytogenes (koloni/25 g)",
  ],
  [
    9026,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Jumlah Sampel -Listeria monocytogenes",
  ],
  [9027, "Udang Kering (09020508)", "Salmonella (/25 g)"],
  [9028, "Udang Kering (09020508)", "Jumlah Sampel - Salmonella"],
  [
    9029,
    "Udang Kupas Mentah Beku (09020117)",
    "Salmonella (/25 g)",
  ],
  [
    9030,
    "Udang Kupas Mentah Beku (09020117)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9031,
    "Udang Kupas Mentah Beku (09020117)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9032,
    "Udang Kupas Mentah Beku (09020117)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9033,
    "Udang Kupas Mentah Beku (09020117)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9034,
    "Udang Kupas Mentah Beku (09020117)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9035,
    "Udang Kupas Mentah Beku (09020117)",
    "Vibrio parahaemolyticus (APM/g)",
    "",
    "<3",
  ],
  [
    9036,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9037,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9038,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9039,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9040,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Staphylococcus aureus (koloni/g)",
    "",
    "\x{2264}1000",
  ],
  [
    9041,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Salmonella (/25 g)",
  ],
  [
    9042,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9043,
    "Udang Lapis Tepung Beku (09020203)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9044,
    "Udang Lapis Tepung Beku (09020203)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9045,
    "Udang Lapis Tepung Beku (09020203)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9046,
    "Udang Lapis Tepung Beku (09020203)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9047,
    "Udang Lapis Tepung Beku (09020203)",
    "Staphylococcus aureus (koloni/g)-dengan pemanasan",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9048,
    "Udang Popcorn (0902040309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9049,
    "Udang Popcorn (0902040309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9050,
    "Udang Popcorn (0902040309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9051,
    "Udang Popcorn (0902040309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9052,
    "Udang Popcorn (0902040309)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}100",
  ],
  [
    9053,
    "Urutan (0803010115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9054,
    "Urutan (0803010115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9055,
    "Urutan (0803010115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9056,
    "Urutan (0803010115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9057,
    "Urutan (0803010115)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [9058, "Urutan (0803010115)", "Salmonella (/25 g)"],
  [9059, "Urutan (0803010115)", "Jumlah Sampel - Salmonella"],
  [
    9060,
    "Usus Ayam Goreng (08020224)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9061,
    "Usus Ayam Goreng (08020224)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9062,
    "Usus Ayam Goreng (08020224)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9063,
    "Usus Ayam Goreng (08020224)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9064,
    "Usus Ayam Goreng (08020224)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [9065, "Usus Ayam Goreng (08020224)", "Salmonella (/25 g)"],
  [
    9066,
    "Usus Ayam Goreng (08020224)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9067,
    "Usus Ayam Goreng (08020224)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9068,
    "Usus Ayam Goreng (08020224)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9069,
    "Usus Ayam Goreng (08020224)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9070,
    "Usus Ayam Goreng (08020224)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9071,
    "Usus Ayam Goreng (08020224)",
    "Clostridium perfringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [9072, "Vegetable Kasu-zuke (0402020314)", "Salmonella (/25 g)"],
  [
    9073,
    "Vegetable Kasu-zuke (0402020314)",
    "Jumlah Sampel - Salmonella",
  ],
  [9074, "Vegetable Koji-zuke (0402020313)", "Salmonella (/25 g)"],
  [
    9075,
    "Vegetable Koji-zuke (0402020313)",
    "Jumlah Sampel - Salmonella",
  ],
  [9076, "Vegetable Miso-zuke (0402020315)", "Salmonella (/25 g)"],
  [
    9077,
    "Vegetable Miso-zuke (0402020315)",
    "Jumlah Sampel - Salmonella",
  ],
  [9078, "Vegetable Shio-zuke (0402020318)", "Salmonella (/25 g)"],
  [
    9079,
    "Vegetable Shio-zuke (0402020318)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9080,
    "Vegetable Shoyu-zuke (0402020316)",
    "Salmonella (/25 g)",
  ],
  [
    9081,
    "Vegetable Shoyu-zuke (0402020316)",
    "Jumlah Sampel - Salmonella",
  ],
  [9082, "Vegetable Su-zuke (0402020317)", "Salmonella (/25 g)"],
  [
    9083,
    "Vegetable Su-zuke (0402020317)",
    "Jumlah Sampel - Salmonella",
  ],
  [9084, "Vegetable Tsukudani (0402020807)", "Salmonella (/25 g)"],
  [
    9085,
    "Vegetable Tsukudani (0402020807)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9086,
    "Vegetable Tsukudani (0402020807)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9087,
    "Vegetable Tsukudani (0402020807)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9088,
    "Vegetable Tsukudani (0402020807)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9089,
    "Vegetable Tsukudani (0402020807)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9090,
    "Vegetable Tsukudani (0402020807)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [9091, "Wafel (07020211)", "Salmonella (/25 g)"],
  [9092, "Wafel (07020211)", "Jumlah Sampel - Salmonella"],
  [
    9093,
    "Wafel (07020211)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9094,
    "Wafel (07020211)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9095,
    "Wafel (07020211)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9096,
    "Wafel (07020211)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9097,
    "Wafel (07020211)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [9098, "Wafer (07020112)", "Salmonella (/25 g)"],
  [9099, "Wafer (07020112)", "Jumlah Sampel - Salmonella"],
  [
    9100,
    "Wafer (07020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9101,
    "Wafer (07020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9102,
    "Wafer (07020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9103,
    "Wafer (07020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9104,
    "Wafer (07020112)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9105,
    "Wafer Roll / Wafer Stick (07020113)",
    "Salmonella (/25 g)",
  ],
  [
    9106,
    "Wafer Roll / Wafer Stick (07020113)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9107,
    "Wafer Roll / Wafer Stick (07020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9108,
    "Wafer Roll / Wafer Stick (07020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9109,
    "Wafer Roll / Wafer Stick (07020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9110,
    "Wafer Roll / Wafer Stick (07020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9111,
    "Wafer Roll / Wafer Stick (07020113)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [9112, "Wafer Salut (07020114)", "Salmonella (/25 g)"],
  [9113, "Wafer Salut (07020114)", "Jumlah Sampel - Salmonella"],
  [
    9114,
    "Wafer Salut (07020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9115,
    "Wafer Salut (07020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9116,
    "Wafer Salut (07020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9117,
    "Wafer Salut (07020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9118,
    "Wafer Salut (07020114)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}10000",
    "\x{2264}100",
  ],
  [
    9119,
    "Wajit Buah (0401021209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    9120,
    "Wajit Buah (0401021209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    9121,
    "Wajit Buah (0401021209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    9122,
    "Wajit Buah (0401021209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [
    9123,
    "Wajit Buah (0401021209)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}100",
    "\x{2264}10",
  ],
  [9124, "Wajit Buah (0401021209)", "Salmonella (/25 g)"],
  [9125, "Wajit Buah (0401021209)", "Jumlah Sampel - Salmonella"],
  [9126, "Wasabi (120201A8)", "Salmonella (/25 g)"],
  [9127, "Wasabi (120201A8)", "Jumlah Sampel - Salmonella"],
  [
    9128,
    "Wasabi (120201A8)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9129,
    "Wasabi (120201A8)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9130,
    "Wasabi (120201A8)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9131,
    "Wasabi (120201A8)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9132,
    "Wasabi (120201A8)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9133,
    "Wasabi (120201A8)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9134,
    "Wasabi (120201A8)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9135,
    "Wasabi (120201A8)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9136,
    "Wasabi (120201A8)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9137,
    "Wasabi (120201A8)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [9138, "Water Biscuit (07010205)", "Salmonella (/25 g)"],
  [9139, "Water Biscuit (07010205)", "Jumlah Sampel - Salmonella"],
  [
    9140,
    "Water Biscuit (07010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9141,
    "Water Biscuit (07010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9142,
    "Water Biscuit (07010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9143,
    "Water Biscuit (07010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [
    9144,
    "Water Biscuit (07010205)",
    "Staphylococcus aureus (koloni/g)",
    "\x{2264}200",
    "\x{2264}100",
  ],
  [9145, "Water Ices (0301)", "Jumlah Sampel - Salmonella"],
  [9146, "Water Ices (0301)", "Salmonella (/25 ml)"],
  [9147, "Whey (01080101)", "Salmonella (/25 ml)"],
  [9148, "Whey (01080101)", "Jumlah Sampel - Salmonella"],
  [9149, "Whey Asam (01080102)", "Salmonella (/25 ml)"],
  [9150, "Whey Asam (01080102)", "Jumlah Sampel - Salmonella"],
  [9151, "Whipped Cream (01040201)", "Salmonella (/25 ml)"],
  [9152, "Whipped Cream (01040201)", "Jumlah Sampel - Salmonella"],
  [9153, "Whole Maize (Corn) Meal (060306)", "Salmonella (/25 g)"],
  [
    9154,
    "Whole Maize (Corn) Meal (060306)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9155,
    "Whole Maize (Corn) Meal (060306)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    9156,
    "Whole Maize (Corn) Meal (060306)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    9157,
    "Whole Maize (Corn) Meal (060306)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    9158,
    "Whole Maize (Corn) Meal (060306)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [
    9159,
    "Whole Maize (Corn) Meal (060306)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}1000",
    "\x{2264}10",
  ],
  [9160, "Wijen (120201A9)", "Salmonella (/25 g)"],
  [9161, "Wijen (120201A9)", "Jumlah Sampel - Salmonella"],
  [
    9162,
    "Wijen (120201A9)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9163,
    "Wijen (120201A9)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9164,
    "Wijen (120201A9)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9165,
    "Wijen (120201A9)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9166,
    "Wijen (120201A9)",
    "Bacillus cereus (koloni/g)",
    "\x{2264}100000",
    "\x{2264}10000",
  ],
  [
    9167,
    "Wijen (120201A9)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9168,
    "Wijen (120201A9)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9169,
    "Wijen (120201A9)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9170,
    "Wijen (120201A9)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [
    9171,
    "Wijen (120201A9)",
    "Clostridium pefringens (koloni/g)",
    "\x{2264}10000",
    "\x{2264}1000",
  ],
  [9172, "Wortel Beku (0402020107)", "Salmonella (/25 g)"],
  [9173, "Wortel Beku (0402020107)", "Jumlah Sampel - Salmonella"],
  [
    9174,
    "Wortel Beku (0402020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9175,
    "Wortel Beku (0402020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9176,
    "Wortel Beku (0402020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9177,
    "Wortel Beku (0402020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [
    9178,
    "Wortel Beku (0402020107)",
    "Listeria monocytogenes (koloni/g)",
    "",
    "<100",
  ],
  [9179, "Yogurt (010201A6)", "Salmonella (/25 ml)"],
  [9180, "Yogurt (010201A6)", "Jumlah Sampel - Salmonella"],
  [
    9181,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Salmonella (negatif/25 g)",
  ],
  [
    9182,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    9183,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Salmonella (/25 g)",
  ],
  [
    9184,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [9185, "Yogurt Berperisa/Rasa (010702)", "Salmonella (/25 ml)"],
  [
    9186,
    "Yogurt Berperisa/Rasa (010702)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9187,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Salmonella (/25 ml)",
  ],
  [
    9188,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Jumlah Sampel - Salmonella",
  ],
  [
    9189,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Salmonella (negatif/25 g)",
  ],
  [
    9190,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [
    9191,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Salmonella (/25 g)",
  ],
  [
    9192,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Jumlah Sampel - Salmonella",
    "\x{2265}",
  ],
  [9193, "Yogurt Plain Bubuk (010201B1)", "Salmonella (/25 ml)"],
  [
    9194,
    "Yogurt Plain Bubuk (010201B1)",
    "Jumlah Sampel - Salmonella",
  ],
];
# END FRAGMENT id=data-idn_bpom_cemaran_mikroba_pangan


# BEGIN FRAGMENT id=meta-idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan varname=meta_idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan/meta.yaml
# src-revision: c422671fcd2b83d86e4f559c3f2cf4d1f0646f50 (Mon Oct 31 22:07:23 2022 +0700)
# generate-date: Mon Oct 31 15:23:03 2022 UTC
# generated-by: update-fragments-in-perl-module
our $meta_idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan = {
  "fields" => {
    category => {
      "filterable_regex" => "Yes",
      "pos" => 1,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Category",
      "summary.alt.lang.id" => "Kategori",
      "unique" => "Yes",
    },
    characteristic => {
      "filterable_regex" => "Yes",
      "pos" => 2,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Characteristic",
      "summary.alt.lang.id" => "Karakteristik",
      "unique" => "Yes",
    },
    id => {
      "filterable_regex" => "Yes",
      "pos" => 0,
      "schema" => "uint*",
      "sortable" => "Yes",
      "summary" => "ID",
      "summary.alt.lang.id" => "ID",
      "unique" => "Yes",
    },
    lower_limit => {
      "filterable_regex" => "Yes",
      "pos" => 4,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Lower limit",
      "summary.alt.lang.id" => "Batas bawah",
      "unique" => "Yes",
    },
    upper_limit => {
      "filterable_regex" => "Yes",
      "pos" => 3,
      "schema" => "str*",
      "sortable" => "Yes",
      "summary" => "Upper limit",
      "summary.alt.lang.id" => "Batas atas",
      "unique" => "Yes",
    },
  },
  "pk" => "id",
  "summary" => "Additives in BPOM processed food division",
  "summary.alt.lang.id_ID" => "Bahan tambahan pangan di BPOM pangan olahan",
};
# END FRAGMENT id=meta-idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan

# BEGIN FRAGMENT id=data-idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan varname=data_idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan
# note: This fragment's content is generated by a script. Do not edit manually!
# src-file: /home/u1/repos/gudangdata/bin/../table/idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan/data.csv
# src-revision: c422671fcd2b83d86e4f559c3f2cf4d1f0646f50 (Mon Oct 31 22:07:23 2022 +0700)
# generate-date: Mon Oct 31 15:23:03 2022 UTC
# generated-by: update-fragments-in-perl-module
our $data_idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan = [
  [1, "- (0401020206)", "Arsen (As) (ppm atau mg/kg)", "=0.001"],
  [
    2,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    3,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Kadmium (Cd)(mg/kg)",
    "<0.1",
  ],
  [
    4,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    5,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    6,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    7,
    "Cumi-Cumi / Kerang / Ikan / ... Beku dengan Penambahan Bahan Lain (09020130)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    8,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Kadar minyak nabati (%)",
    "",
    "=20",
  ],
  [
    9,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Arsen (As) (ppm atau mg/kg)",
    "= 0.15",
  ],
  [
    10,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    14,
    "(Saus Teremulsi) untuk Saus Mayo (12060107)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [15, "Abon Daging (08020213)", "Bau, rasa dan warna"],
  [16, "Abon Daging (08020213)", "Kadar air (%)", "=7"],
  [
    17,
    "Abon Daging (08020213)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    18,
    "Abon Daging (08020213)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    19,
    "Abon Daging (08020213)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    20,
    "Abon Daging (08020213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    21,
    "Abon Daging (08020213)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    22,
    "Abon Daging (08020213)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [23, "Abon Ikan (0902040304)", "As (ppm atau mg/kg)", "=0.25"],
  [24, "Abon Ikan (0902040304)", "Cd (ppm atau mg/kg)", "=0.1"],
  [25, "Abon Ikan (0902040304)", "Hg (ppm atau mg/kg)", "=0.5"],
  [
    26,
    "Abon Ikan (0902040304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    27,
    "Abon Ikan (0902040304)",
    "Sn (dalam kaleng) (mg/kg)",
    "=250",
  ],
  [28, "Abon Ikan (0902040304)", "Pb (ppm atau mg/kg)", "=0.2"],
  [
    29,
    "Abon Udang (0902040307)",
    "Angka Lempeng Total (30oC, 72 jam) (koloni/g) ",
    "=500000",
  ],
  [30, "Abon Udang (0902040307)", "Arsen (As) (mg/kg) ", "=0.25"],
  [31, "Abon Udang (0902040307)", "Kadmium (Cd) (mg/kg) ", "=0.1"],
  [32, "Abon Udang (0902040307)", "Raksa (Hg) (mg/kg) ", "=0.5"],
  [33, "Abon Udang (0902040307)", "Timah (Sn) (mg/kg) ", "=40"],
  [
    34,
    "Abon Udang (0902040307)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [35, "Abon Udang (0902040307)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    36,
    "Acar (Sweet Pickle) (0402020322)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    37,
    "Acar (Sweet Pickle) (0402020322)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    38,
    "Acar (Sweet Pickle) (0402020322)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    39,
    "Acar (Sweet Pickle) (0402020322)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    40,
    "Acar (Sweet Pickle) (0402020322)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    41,
    "Acar (Sweet Pickle) (0402020322)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    42,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    43,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    44,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    45,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    46,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    47,
    "Acar (Sweet Pickle)...Steril (0402020319)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    48,
    "Acar Bawang Putih (0402020306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    49,
    "Acar Bawang Putih (0402020306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    50,
    "Acar Bawang Putih (0402020306)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    51,
    "Acar Bawang Putih (0402020306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    52,
    "Acar Bawang Putih (0402020306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    53,
    "Acar Cabe (0402020308)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    54,
    "Acar Cabe (0402020308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [55, "Acar Cabe (0402020308)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    56,
    "Acar Cabe (0402020308)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    57,
    "Acar Cabe (0402020308)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    58,
    "Acar Cabe (0402020308)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    59,
    "Acar Jahe (0402020307)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    60,
    "Acar Jahe (0402020307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [61, "Acar Jahe (0402020307)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    62,
    "Acar Jahe (0402020307)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    63,
    "Acar Jahe (0402020307)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    64,
    "Acar Jahe (0402020307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    65,
    "Acar Jamur (0402020304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    66,
    "Acar Jamur (0402020304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [67, "Acar Jamur (0402020304)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    68,
    "Acar Jamur (0402020304)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    69,
    "Acar Jamur (0402020304)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    70,
    "Acar Jamur (0402020304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    71,
    "Acar Lobak (0402020309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    72,
    "Acar Lobak (0402020309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [73, "Acar Lobak (0402020309)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    74,
    "Acar Lobak (0402020309)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    75,
    "Acar Lobak (0402020309)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    76,
    "Acar Lobak (0402020309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [77, "Acar Sayur (0402020223)", "Arsen (As) (mg/kg)", "=0.15"],
  [78, "Acar Sayur (0402020223)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [79, "Acar Sayur (0402020223)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    80,
    "Acar Sayur (0402020223)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    81,
    "Acar Sayur (0402020223)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [82, "Acar Sayur (0402020223)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [83, "Acar Sayur (0402020320)", "Arsen (As) (mg/kg) ", "=0.15"],
  [84, "Acar Sayur (0402020320)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [85, "Acar Sayur (0402020320)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    86,
    "Acar Sayur (0402020320)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    87,
    "Acar Sayur (0402020320)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [88, "Acar Sayur (0402020320)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    89,
    "Acar Timun Mentah (0402020305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    90,
    "Acar Timun Mentah (0402020305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    91,
    "Acar Timun Mentah (0402020305)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    92,
    "Acar Timun Mentah (0402020305)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    93,
    "Acar Timun Mentah (0402020305)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    94,
    "Acar Timun Mentah (0402020305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    95,
    "Adas Bubuk (12020105)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    96,
    "Adas Bubuk (12020105)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    97,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    98,
    "Adas, Adas Pedas, Fennel, Jinten Manis (12020104)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    99,
    "Adonan Shortened Bread (07010406)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    100,
    "Adonan Shortened Bread (07010406)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    101,
    "Adonan Shortened Bread (07010406)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    102,
    "Adonan Shortened Bread (07010406)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    103,
    "Adonan Shortened Bread (07010406)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    104,
    "Agar-Agar Kertas (0401020914)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    105,
    "Agar-Agar Kertas (0401020914)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    106,
    "Agar-Agar Kertas (0401020914)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    107,
    "Agar-Agar Kertas (0401020914)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    108,
    "Agar-Agar Kertas (0401020914)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    109,
    "Agar-Agar Kertas (0401020914)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    110,
    "Air Bermineral (1401010204)",
    "ALT awal (30oC, 72 jam) (koloni/ml)",
    "=100",
  ],
  [
    111,
    "Air Bermineral (1401010204)",
    "ALT akhir (30oC, 72 jam) (koloni/ml)",
    "=100000",
  ],
  [112, "Air Bermineral (1401010204)", "APM Koliform/100 ml", "<2"],
  [113, "Air Bermineral (1401010204)", "Salmonella (/100 ml)"],
  [
    114,
    "Air Bermineral (1401010204)",
    "Pseudomonas aeruginosa (/ml)",
  ],
  [
    115,
    "Air Demineral Berkarbonat (1401010216)",
    "Kadar CO2 bebas (Air Demineral) (mg/l)",
    "=5890",
    "=3000",
  ],
  [
    116,
    "Air Demineral Berkarbonat (1401010216)",
    "Bau (Air Demineral)",
  ],
  [
    117,
    "Air Demineral Berkarbonat (1401010216)",
    "Rasa (Air Demineral)",
  ],
  [
    118,
    "Air Demineral Berkarbonat (1401010216)",
    "Warna (unit Pt.Co) (Air Demineral)",
    "=5",
  ],
  [
    119,
    "Air Demineral Berkarbonat (1401010216)",
    "pH (Air Demineral)",
    "=7.5",
    "=5",
  ],
  [
    120,
    "Air Demineral Berkarbonat (1401010216)",
    "Kekeruhan (NTU) (Air Demineral)",
    "=1.5",
  ],
  [
    121,
    "Air Demineral Berkarbonat (1401010216)",
    "Zat yang terlarut (mg/l) (Air Demineral)",
    "=10",
  ],
  [
    122,
    "Air Demineral Berkarbonat (1401010216)",
    "Total organik karbon (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    123,
    "Air Demineral Berkarbonat (1401010216)",
    "Timbal (Pb) (mg/l) (Air Demineral)",
  ],
  [
    124,
    "Air Demineral Berkarbonat (1401010216)",
    "Tembaga (Cu) (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    125,
    "Air Demineral Berkarbonat (1401010216)",
    "Kadmium (Cd) (mg/l) (Air Demineral)",
    "=0.003",
  ],
  [
    126,
    "Air Demineral Berkarbonat (1401010216)",
    "Raksa (Hg) (mg/l) (Air Demineral)",
    "=0.001",
  ],
  [
    127,
    "Air Demineral Berkarbonat (1401010216)",
    "Perak (Ag) (mg/l) (Air Demineral)",
    "=0.025",
  ],
  [
    128,
    "Air Demineral Berkarbonat (1401010216)",
    "Kobalt (Co) (mg/l) (Air Demineral)",
    "=0.01",
  ],
  [
    129,
    "Air Demineral Berkarbonat (1401010216)",
    "Arsen (As) (mg/l) (Air Demineral)",
    "=0.01",
  ],
  [
    130,
    "Air Demineral Berkarbonat (1401010216)",
    "ALT awal (30oC, 72 jam) (koloni/ml) (Air Demineral)",
    "=100",
  ],
  [
    131,
    "Air Demineral Berkarbonat (1401010216)",
    "APM Koliform/100 ml (Air Demineral)",
    "<2",
  ],
  [
    132,
    "Air Demineral Berkarbonat (1401010216)",
    "Salmonella (/100 ml) (Air Demineral)",
  ],
  [
    133,
    "Air Demineral Berkarbonat (1401010216)",
    "Pseudomonas aeruginosa (koloni/ml) (Air Demineral)",
  ],
  [134, "Air Embun (1401010212)", "Bau"],
  [135, "Air Embun (1401010212)", "Rasa"],
  [136, "Air Embun (1401010212)", "Warna (unit Pt.Co) ", "=1"],
  [
    137,
    "Air Embun (1401010212)",
    "Zat yang terlarut (mg/l) ",
    "=5",
  ],
  [138, "Air Embun (1401010212)", "Sulfat (S04) (mg/l) ", "=1"],
  [139, "Air Embun (1401010212)", "Klorida (CI) (mg/l) ", "=1"],
  [
    140,
    "Air Embun (1401010212)",
    "ALT (30oC, 72 jam) (koloni/ml) ",
    "=100",
  ],
  [141, "Air Embun (1401010212)", "APM Koliform (/100 ml) ", "<2"],
  [142, "Air Embun (1401010212)", "Salmonella (/100 ml)"],
  [143, "Air Embun (1401010212)", "Pseudomonas aeruginosa (/ml)"],
  [144, "Air Embun (1401010212)", "pH", "=7.5", "=6"],
  [145, "Air Embun (1401010212)", "Kekeruhan (NTU)", "=0.5"],
  [
    146,
    "Air Embun (1401010212)",
    "Nitrat dihitung sebagai (NO3) (mg/l)",
    "=0.5",
  ],
  [
    147,
    "Air Embun (1401010212)",
    "Nitrit dihitung sebagai (NO2) (mg/l)",
    "=0.005",
  ],
  [148, "Air Embun (1401010212)", "Amonia (NH3) (mg/l)", "=1.5"],
  [149, "Air Embun (1401010212)", "Fluorida (F) (mg/l) ", "=0.5"],
  [150, "Air Embun (1401010212)", "Sianida (CN) (mg/l)", "=0.01"],
  [151, "Air Embun (1401010212)", "Besi (Fe) (mg/l)", "=0.05"],
  [152, "Air Embun (1401010212)", "Mangan (Mn) (mg/l)", "=0.02"],
  [
    153,
    "Air Embun (1401010212)",
    "Klor Bebas (Cl2) (mg/l)",
    "=0.05",
  ],
  [154, "Air Embun (1401010212)", "Kromium (Cr) (mg/l)", "=0.02"],
  [155, "Air Embun (1401010212)", "Barium (Ba) (mg/l)", "=0.02"],
  [156, "Air Embun (1401010212)", "Boron (B) (mg/l)", "=0.02"],
  [157, "Air Embun (1401010212)", "Selenium (Se) (mg/l)", "=0.01"],
  [158, "Air Embun (1401010212)", "Arsen (As) (mg/l)", "=0.01"],
  [159, "Air Embun (1401010212)", "Kadmium (Cd) (mg/l)", "=0.003"],
  [160, "Air Embun (1401010212)", "Raksa (Hg) (mg/l)", "=0.001"],
  [161, "Air Embun (1401010212)", "Timbal (Pb) (mg/l)"],
  [162, "Air Embun (1401010212)", "Tembaga (Cu) (mg/l)", "=0.01"],
  [163, "Air Embun (1401010212)", "Aluminium (Al) (mg/l)", "=0.01"],
  [
    164,
    "Air Mineral Alami (1401010105)",
    "Nitrat (NO3) (mg/l)",
    "=45",
  ],
  [
    165,
    "Air Mineral Alami (1401010105)",
    "Flourida (F) (mg/l)",
    "=1",
  ],
  [
    166,
    "Air Mineral Alami (1401010105)",
    "Sulfat (SO4) (mg/l)",
    "=200",
  ],
  [
    167,
    "Air Mineral Alami (1401010105)",
    "Total plate count awal (koloni/ml)",
    "=100",
  ],
  [
    168,
    "Air Mineral Alami (1401010105)",
    "Total plate count akhir (koloni/ml)",
    "=100000",
  ],
  [
    169,
    "Air Mineral Alami (1401010105)",
    "Bakteri bentuk coli (APM/250 ml)",
  ],
  [
    170,
    "Air Mineral Alami (1401010105)",
    "E. Coli (Koloni/250 ml)",
  ],
  [
    171,
    "Air Mineral Alami (1401010105)",
    "Steptococcus (koloni/250 ml)",
  ],
  [
    172,
    "Air Mineral Alami (1401010105)",
    "C. Perfringens (koloni/50 ml)",
  ],
  [
    173,
    "Air Mineral Alami (1401010105)",
    "Pseudomonas aeruginosa (koloni/ml)",
  ],
  [
    174,
    "Air Mineral Alami (1401010105)",
    "Barium (Ba) (mg/l)",
    "=1",
  ],
  [
    175,
    "Air Mineral Alami (1401010105)",
    "Borate (Bo) (mg/l)",
    "=5",
  ],
  [
    176,
    "Air Mineral Alami (1401010105)",
    "Kadmium (Cd) (mg/l)",
    "=0.005",
  ],
  [
    177,
    "Air Mineral Alami (1401010105)",
    "Cromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    178,
    "Air Mineral Alami (1401010105)",
    "Nitrit (NO2) (mg/l)",
    "=0.005",
  ],
  [
    179,
    "Air Mineral Alami (1401010105)",
    "Sianida (CN) (mg/l)",
    "=0.07",
  ],
  [
    180,
    "Air Mineral Alami (1401010105)",
    "Antimon (Sb) (mg/l)",
    "=0.005",
  ],
  [
    181,
    "Air Mineral Alami (1401010105)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    182,
    "Air Mineral Alami (1401010105)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    183,
    "Air Mineral Alami (1401010105)",
    "Timbal (Pb) (mg/l)",
    "=0.01",
  ],
  [
    184,
    "Air Mineral Alami (1401010105)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    185,
    "Air Mineral Alami (1401010105)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    186,
    "Air Mineral Alami (1401010105)",
    "Nikel (Ni) (mg/l)",
    "=0.02",
  ],
  [
    187,
    "Air Mineral Alami (1401010105)",
    "Selenium (Se) (mg/l)",
    "=0.05",
  ],
  [
    188,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami dengan kandungan mineral sangat rendah : kadar komponen anorganik dengan residu kering (mg/l)",
    "=50",
  ],
  [
    189,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami dengan kandungan mineral rendah : kadar komponen anorganik dengan residu kering (mg/l)",
    "=500",
  ],
  [
    190,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami dengan kandungan mineral tinggi : kadar komponen anorganik dengan residu kering (mg/l)",
    "=1500",
  ],
  [
    191,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung bikarbonat : kadar bikarbonat (mg/l)",
    "",
    ">600",
  ],
  [
    192,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung kalsium : kadar kalsium (mg/l)",
    "",
    ">200",
  ],
  [
    193,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung klorida : kadar klorida (mg/l) ",
    "",
    ">200",
  ],
  [
    194,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung fluorida : kadar fluorida (mg/l)",
    "",
    ">1",
  ],
  [
    195,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung besi : kadar besi valensi dua (mg/l)",
    "",
    ">1",
  ],
  [
    196,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung magnesium : kadar magnesium (mg/l)",
    "",
    ">50",
  ],
  [
    197,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung natrium : kadar natrium (mg/l)",
    "",
    ">200",
  ],
  [
    198,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami mengandung sulfat :kadar sulfat (mg/l)",
    ">50",
  ],
  [
    199,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami untuk diet rendah natrium : kadar natrium (mg/l)",
    "=20",
  ],
  [
    200,
    "Air Mineral Alami (1401010105)",
    "Air mineral alami asam : kadar karbondioksida (mg/l)",
    "=250",
  ],
  [
    201,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Air mineral alami mengandung magnesium: kadar magnesium (mg/l)",
    "",
    "=50",
  ],
  [
    202,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Air mineral alami mengandung natrium: kadar natrium (mg/l)",
    "",
    "=200",
  ],
  [
    203,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Air mineral alami mengandung sulfat : kadar sulfat (mg/l)",
    "",
    "=50",
  ],
  [
    204,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Air mineral alami untuk diet rendah natrium : kadar natrium (mg/l)",
    "=20",
  ],
  [
    205,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Air mineral alami asam : kadar karbondioksida (mg/l)",
    "=250",
  ],
  [
    206,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Total plate count awal (koloni/ml)",
    "=100",
  ],
  [
    207,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Total plate count akhir (koloni/ml)",
    "=100000",
  ],
  [
    208,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Bakteri bentuk coli (APM/100 ml)",
    "=0",
  ],
  [
    209,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    210,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Kadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    211,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    212,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Timbal (Pb) (mg/l)",
    "=0.01",
  ],
  [
    213,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "E. Coli (Koloni/250 ml)",
    "=0",
  ],
  [
    214,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Streptococcus (koloni/250 ml)",
    "=0",
  ],
  [
    215,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "C. Perfringens (koloni/50 ml)",
    "=0",
  ],
  [
    216,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Pseudomonas aeruginosa (koloni/ml)",
    "=0",
  ],
  [
    217,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Nitrat (NO3) (mg/l)",
    "=45",
  ],
  [
    218,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Nitrit (NO2) (mg/l)",
    "=0.005",
  ],
  [
    219,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Flourida (F) (mg/l)",
    "=1",
  ],
  [
    220,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Sianida (CN) (mg/l)",
    "=0.07",
  ],
  [
    221,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Sulfat (SO4) (mg/l)",
    "=200",
  ],
  [
    222,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Antimon (Sb) (mg/l)",
    "=0.005",
  ],
  [
    223,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Barium (Ba) (mg/l)",
    "=1",
  ],
  [
    224,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Borate (Bo) (mg/l)",
    "=5",
  ],
  [
    225,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Cromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    226,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    227,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    228,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Selenium (Se) (mg/l)",
    "=0.05",
  ],
  [
    229,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Nikel (Ni) (mg/l)",
    "=0.02",
  ],
  [
    230,
    "Air Mineral Alami Dikarbonasi (Carbonated Natural Mineral Water) (1401010104)",
    "Karbondioksida (CO2)",
  ],
  [
    231,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Air mineral alami dengan kandungan mineral rendah: kadar komponen anorganik dengan residu kering (mg/l)",
    "=500",
  ],
  [
    232,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Air mineral alami dengan kandungan mineral sangat rendah: kadar komponen anorganik dengan residu kering (mg/l)",
    "=50",
  ],
  [
    233,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Air mineral alami dengan kandungan mineral tinggi: kadar komponen anorganik dengan residu kering (mg/l)",
    "=1500",
  ],
  [
    234,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Air mineral alami mengandung bikarbonat : kadar bikarbonat (mg/l)",
    "=600",
  ],
  [
    235,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Total plate count awal (koloni/ml)",
    "=100",
  ],
  [
    236,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Total plate count akhir (koloni/ml)",
    "=100000",
  ],
  [
    237,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Bakteri bentuk coli (APM/250 ml)",
    "=0",
  ],
  [
    238,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    239,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Kadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    240,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    241,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Timah (Sn) (mg/l)",
    "=40",
  ],
  [
    242,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Timbal (Pb) (mg/l)",
    "=0.01",
  ],
  [
    243,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "E. Coli (APM/250 ml)",
    "=0",
  ],
  [
    244,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Steptococcus (koloni/250 ml)",
    "=0",
  ],
  [
    245,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "C. Perfringens (koloni/50 ml)",
    "=0",
  ],
  [
    246,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Pseudomonas aeruginosa (koloni/ml)",
    "=0",
  ],
  [
    247,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Nitrat (NO3) (mg/l)",
    "=45",
  ],
  [
    248,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Nitrit (NO2) (mg/l)",
    "=0.005",
  ],
  [
    249,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Flourida (F) (mg/l)",
    "=1",
  ],
  [
    250,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Sianida (CN) (mg/l)",
    "=0.07",
  ],
  [
    251,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Sulfat (SO4) (mg/l)",
    "=200",
  ],
  [
    252,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Antimon (Sb) (mg/l)",
    "=0.005",
  ],
  [
    253,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Barium (Ba) (mg/l)",
    "=1",
  ],
  [
    254,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Borate (Bo) (mg/l)",
    "=5",
  ],
  [
    255,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Cromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    256,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    257,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    258,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Nikel (Ni) (mg/l)",
    "=0.02",
  ],
  [
    259,
    "Air Mineral Alami Terkarbonasi Secara Alami (Naturally Carbonated Natural Mineral Water) (1401010101)",
    "Selenium (Se) (mg/l)",
    "=0.05",
  ],
  [
    260,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Air mineral alami mengandung magnesium : kadar magnesium (mg/l)",
    "",
    ">50",
  ],
  [
    261,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Air mineral alami mengandung natrium : kadar natrium (mg/l)",
    "",
    ">200",
  ],
  [
    262,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Air mineral alami mengandung sulfat : kadar sulfat (mg/l)",
    "",
    ">50",
  ],
  [
    263,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Air mineral alami asam: kadar karbondioksida (mg/l)",
    "=250",
  ],
  [
    264,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Total plate count awal (koloni/ml)",
    "=100",
  ],
  [
    265,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Total plate count akhir (koloni/ml)",
    "=100000",
  ],
  [
    266,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Bakteri bentuk coli (APM/250 ml)",
    "=0",
  ],
  [
    267,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    268,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Kadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    269,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    270,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Timbal (Pb) (mg/l)",
    "=0.01",
  ],
  [
    271,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Air mineral alami asam: kadar karbondioksida (mg/l)",
    "=250",
  ],
  [
    272,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "E. Coli (APM/250 ml)",
    "=0",
  ],
  [
    273,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Steptococcus (koloni/250 ml)",
    "=0",
  ],
  [
    274,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "C. Perfringens (koloni/50 ml)",
    "=0",
  ],
  [
    275,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Pseudomonas aeruginosa (koloni/ml)",
    "=0",
  ],
  [
    276,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Nitrat (NO3) (mg/l)",
    "=45",
  ],
  [
    277,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Nitrit (NO2) (mg/l)",
    "=0.005",
  ],
  [
    278,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Flourida (F) (mg/l)",
    "=1",
  ],
  [
    279,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Sianida (CN) (mg/l)",
    "=0.07",
  ],
  [
    280,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Sulfat (SO4) (mg/l)",
    "=200",
  ],
  [
    281,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Antimon (Sb) (mg/l)",
    "=0.005",
  ],
  [
    282,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Barium (Ba) (mg/l)",
    "=1",
  ],
  [
    283,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Borate (Bo) (mg/l)",
    "=5",
  ],
  [
    284,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Cromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    285,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    286,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    287,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Nikel (Ni) (mg/l)",
    "=0.02",
  ],
  [
    288,
    "Air Mineral Alami yang Didekarbonasi Penuh atau Sebagian (1401010102)",
    "Selenium (Se) (mg/l)",
    "=0.05",
  ],
  [
    289,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Air mineral alami mengandung kalsium:kadar kalsium (mg/l)",
    "",
    ">200",
  ],
  [
    290,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Air mineral alami mengandung klorida:kadar klorida (mg/l)",
    "",
    ">200",
  ],
  [
    291,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Air mineral alami mengandung fluorida:kadar fluorida (mg/l)",
    "",
    ">1",
  ],
  [
    292,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Air mineral alami mengandung besi:kadar besi valensi dua (mg/l)",
    "",
    ">1",
  ],
  [
    293,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Air mineral alami asam:kadar karbondioksida (mg/l)",
    "=250",
  ],
  [
    294,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Total plate count awal (koloni/ml)",
    "=100",
  ],
  [
    295,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Total plate count akhir (koloni/ml)",
    "=100000",
  ],
  [
    296,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Bakteri bentuk coli (APM/250 ml)",
    "=0",
  ],
  [
    297,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "E. Coli (APM/250 ml)",
    "=0",
  ],
  [
    298,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Steptococcus (koloni/250 ml)",
    "=0",
  ],
  [
    299,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "C. Perfringens (koloni/50 ml)",
    "=0",
  ],
  [
    300,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Pseudomonas aeruginosa (koloni/ml)",
    "=0",
  ],
  [
    301,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Nitrat (NO3) (mg/l)",
    "=45",
  ],
  [
    302,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Nitrit (NO2) (mg/l)",
    "=0.005",
  ],
  [
    303,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Flourida (F) (mg/l)",
    "=1",
  ],
  [
    304,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Sianida (CN) (mg/l)",
    "=0.07",
  ],
  [
    305,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Sulfat (SO4) (mg/l)",
    "=200",
  ],
  [
    306,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Antimon (Sb) (mg/l)",
    "=0.005",
  ],
  [
    307,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    308,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Barium (Ba) (mg/l)",
    "=1",
  ],
  [
    309,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Borate (Bo) (mg/l)",
    "=5",
  ],
  [
    310,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Cadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    311,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Cromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    312,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    313,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Timbal (Pb) (mg/l)",
    "=0.01",
  ],
  [
    314,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    315,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    316,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Nikel (Ni) (mg/l)",
    "=0.02",
  ],
  [
    317,
    "Air Mineral Alami yang Diperkaya (1401010103)",
    "Selenium (Se) (mg/l)",
    "=0.05",
  ],
  [
    318,
    "Air Mineral Berkarbonat (1401010215)",
    "Kadar CO2 bebas (Air Mineral) (mg/l)",
    "=5890",
    "=3000",
  ],
  [
    319,
    "Air Mineral Berkarbonat (1401010215)",
    "Bau (Air Mineral)",
  ],
  [
    320,
    "Air Mineral Berkarbonat (1401010215)",
    "Rasa (Air Mineral)",
  ],
  [
    321,
    "Air Mineral Berkarbonat (1401010215)",
    "Warna (Air Mineral) (unit Pt.Co)",
    "=5",
  ],
  [
    322,
    "Air Mineral Berkarbonat (1401010215)",
    "pH (Air Mineral)",
    "=8.5",
    "=4",
  ],
  [
    323,
    "Air Mineral Berkarbonat (1401010215)",
    "Kekeruhan (Air Mineral) (NTU)",
    "=1.5",
  ],
  [
    324,
    "Air Mineral Berkarbonat (1401010215)",
    "Zat yang terlarut (Air Mineral) (mg/l)",
    "=500",
  ],
  [
    325,
    "Air Mineral Berkarbonat (1401010215)",
    "Zat organik (Air Mineral) (Angka KMn04) (mg/l)",
    "=1",
  ],
  [
    326,
    "Air Mineral Berkarbonat (1401010215)",
    "Nitrat dihitung sebagai (NO3) (Air Mineral) (mg/l)",
    "=44",
  ],
  [
    327,
    "Air Mineral Berkarbonat (1401010215)",
    "Nitrit dihitung sebagai (NO2) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    328,
    "Air Mineral Berkarbonat (1401010215)",
    "Amonium (NH4) (Air Mineral) (mg/l)",
    "=0.15",
  ],
  [
    329,
    "Air Mineral Berkarbonat (1401010215)",
    "Sulfat (S04) (Air Mineral) (mg/l)",
    "=200",
  ],
  [
    330,
    "Air Mineral Berkarbonat (1401010215)",
    "Klorida (CI) (Air Mineral) (mg/l)",
    "=250",
  ],
  [
    331,
    "Air Mineral Berkarbonat (1401010215)",
    "Fluorida (F) (Air Mineral) (mg/l)",
    "=1",
  ],
  [
    332,
    "Air Mineral Berkarbonat (1401010215)",
    "Sianida (CN) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    333,
    "Air Mineral Berkarbonat (1401010215)",
    "Besi (Fe) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    334,
    "Air Mineral Berkarbonat (1401010215)",
    "Mangan (Mn) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    335,
    "Air Mineral Berkarbonat (1401010215)",
    "Klor Bebas (Cl2) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    336,
    "Air Mineral Berkarbonat (1401010215)",
    "Kromium (Cr) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    337,
    "Air Mineral Berkarbonat (1401010215)",
    "Barium (Ba) (Air Mineral) (mg/l)",
    "=0.7",
  ],
  [
    338,
    "Air Mineral Berkarbonat (1401010215)",
    "Boron (B) (Air Mineral) (mg/l)",
    "=2.4",
  ],
  [
    339,
    "Air Mineral Berkarbonat (1401010215)",
    "Selenium (Se) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    340,
    "Air Mineral Berkarbonat (1401010215)",
    "Timbal (Pb) (Air Mineral) (mg/l)",
  ],
  [
    341,
    "Air Mineral Berkarbonat (1401010215)",
    "Tembaga (Cu) (Air Mineral) (mg/l)",
    "=0.5",
  ],
  [
    342,
    "Air Mineral Berkarbonat (1401010215)",
    "Kadmium (Cd) (Air Mineral) (mg/l)",
    "=0.003",
  ],
  [
    343,
    "Air Mineral Berkarbonat (1401010215)",
    "Raksa (Hg) (Air Mineral) (mg/l)",
    "=0.001",
  ],
  [
    344,
    "Air Mineral Berkarbonat (1401010215)",
    "Arsen (As) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    345,
    "Air Mineral Berkarbonat (1401010215)",
    "ALT awal (30oC, 72 jam) (Air Mineral) (koloni/ml)",
    "=100",
  ],
  [
    346,
    "Air Mineral Berkarbonat (1401010215)",
    "Koliform (Air Mineral) (koloni/250 ml)",
  ],
  [
    347,
    "Air Mineral Berkarbonat (1401010215)",
    "Pseudomonas aeruginosa (Air Mineral) (koloni/250 ml)",
  ],
  [
    348,
    "Air Minum Bervitamin (1401010207)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/ml)",
    "=200",
  ],
  [
    349,
    "Air Minum Bervitamin (1401010207)",
    "Staphylococcus aureus (koloni/ml)",
    "=0",
  ],
  [
    350,
    "Air Minum Bervitamin (1401010207)",
    "Kapang Khamir (koloni/ml)",
    "=100",
  ],
  [
    351,
    "Air Minum Bervitamin (1401010207)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    352,
    "Air Minum Bervitamin (1401010207)",
    "Kadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    353,
    "Air Minum Bervitamin (1401010207)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [
    354,
    "Air Minum Bervitamin (1401010207)",
    "Timah (Sn) (mg/l)",
    "=40",
  ],
  [
    355,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Bau (Air Demineral)",
  ],
  [
    356,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Rasa (Air Demineral)",
  ],
  [
    357,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Warna (unit Pt.Co) (Air Demineral)",
    "=5",
  ],
  [
    358,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "pH (Air Demineral)",
    "=7.5",
    "=5",
  ],
  [
    359,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Kekeruhan (NTU) (Air Demineral)",
    "=1.5",
  ],
  [
    360,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Zat yang terlarut (mg/l) (Air Demineral)",
    "=10",
  ],
  [
    361,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Total organik karbon (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    362,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Tembaga (Cu) (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    363,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Arsen (As) (mg/l) (Air Demineral)",
    "=0.01",
  ],
  [
    364,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Kadmium (Cd) (mg/l) (Air Demineral)",
    "=0.003",
  ],
  [
    365,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Raksa (Hg) (mg/l) (Air Demineral)",
    "=0.001",
  ],
  [
    366,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Timbal (Pb) (mg/l) (Air Demineral)",
  ],
  [
    367,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Perak (Ag) (mg/l) (Air Demineral) ",
    "=0.025",
  ],
  [
    368,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Kobalt (Co) (mg/l) (Air Demineral) ",
    "=0.01",
  ],
  [
    369,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "ALT awal (30oC, 72 jam) (koloni/ml) (Air Demineral) ",
    "=100",
  ],
  [
    370,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "ALT akhir (30oC, 72 jam) (koloni/ml) (Air Demineral) ",
    "=100000",
  ],
  [
    371,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "APM Koliform/100 ml (Air Demineral) ",
    "<2",
  ],
  [
    372,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Salmonella (/100 ml) (Air Demineral)",
  ],
  [
    373,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Pseudomonas aeruginosa (koloni/ml) (Air Demineral)",
  ],
  [
    374,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Kadar O2 terlarut di pabrik (mg/l) (Air Demineral)",
    "",
    "=40",
  ],
  [
    375,
    "Air Minum Dalam Kemasan (Air Demineral Beroksigen) (1401010213)",
    "Kadar O2 terlarut di pasaran (mg/l) (Air Demineral)",
    "",
    "=20",
  ],
  [
    376,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Bau (Air Demineral)",
  ],
  [
    377,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Rasa (Air Demineral)",
  ],
  [
    378,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Warna (unit Pt.Co) (Air Demineral)",
    "=5",
  ],
  [
    379,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "pH (Air Demineral)",
    "=7.5",
    "=5",
  ],
  [
    380,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Kekeruhan (NTU) (Air Demineral)",
    "=1.5",
  ],
  [
    381,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Zat yang terlarut (mg/l) (Air Demineral)",
    "=10",
  ],
  [
    382,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Total organik karbon (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    383,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Tembaga (Cu) (mg/l) (Air Demineral)",
    "=0.5",
  ],
  [
    384,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Arsen (As) (mg/l) (Air Demineral)",
    "=0.01",
  ],
  [
    385,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Kadmium (Cd) (mg/l) (Air Demineral)",
    "=0.003",
  ],
  [
    386,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Raksa (Hg) (mg/l) (Air Demineral)",
    "=0.001",
  ],
  [
    387,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Timbal (Pb) (mg/l) (Air Demineral)",
  ],
  [
    388,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Perak (Ag) (mg/l) (Air Demineral) ",
    "=0.025",
  ],
  [
    389,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Kobalt (Co) (mg/l) (Air Demineral) ",
    "=0.01",
  ],
  [
    390,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "ALT awal (30oC, 72 jam) (koloni/ml) (Air Demineral) ",
    "=100",
  ],
  [
    391,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "APM Koliform/100 ml (Air Demineral) ",
    "<2",
  ],
  [
    392,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Salmonella (/100 ml) (Air Demineral)",
  ],
  [
    393,
    "Air minum dalam kemasan (Air Demineral) (1401010209)",
    "Pseudomonas aeruginosa (koloni/ml) (Air Demineral)",
  ],
  [
    394,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Warna (Air Mineral) (unit Pt.Co)",
    "=5",
  ],
  [
    395,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "pH (Air Mineral)",
    "=8.5",
    "=6",
  ],
  [
    396,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Kekeruhan (Air Mineral) (NTU)",
    "=1.5",
  ],
  [
    397,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Zat yang terlarut (Air Mineral) (mg/l)",
    "=500",
  ],
  [
    398,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Zat organik (Air Mineral) (Angka KMn04) (mg/l)",
    "=1",
  ],
  [
    399,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Nitrat dihitung sebagai (NO3) (Air Mineral) (mg/l)",
    "=45",
  ],
  [
    400,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Nitrit dihitung sebagai (NO2) (Air Mineral) (mg/l)",
    "=0.005",
  ],
  [
    401,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Amonium (NH4) (Air Mineral) (mg/l)",
    "=0.15",
  ],
  [
    402,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Sulfat (S04) (Air Mineral) (mg/l)",
    "=200",
  ],
  [
    403,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Klorida (CI) (Air Mineral) (mg/l)",
    "=250",
  ],
  [
    404,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Fluorida (F) (Air Mineral) (mg/l)",
    "=1",
  ],
  [
    405,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Sianida (CN) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    406,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Besi (Fe) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    407,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Mangan (Mn) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    408,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Klor Bebas (Cl2) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    409,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Kromium (Cr) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    410,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Barium (Ba) (Air Mineral) (mg/l)",
    "=0.7",
  ],
  [
    411,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Boron (B) (Air Mineral) (mg/l)",
    "=0.3",
  ],
  [
    412,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Selenium (Se) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    413,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "ALT awal (30oC, 72 jam) (Air Mineral) (koloni/ml)",
    "=100",
  ],
  [
    414,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "APM Koliform (Air Mineral) (/100 ml)",
    "<2",
  ],
  [
    415,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Arsen (As) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    416,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Kadmium (Cd) (Air Mineral) (mg/l)",
    "=0.003",
  ],
  [
    417,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Raksa (Hg) (Air Mineral) (mg/l)",
    "=0.001",
  ],
  [
    418,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Timbal (Pb) (Air Mineral) (mg/l)",
    "=0.005",
  ],
  [
    419,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Tembaga (Cu) (Air Mineral) (mg/l)",
    "=0.5",
  ],
  [
    420,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Salmonella (Air Mineral) (/100 ml)",
  ],
  [
    421,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Pseudomonas aeruginosa (Air Mineral) (/ml)",
  ],
  [
    422,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Bau (Air Mineral)",
  ],
  [
    423,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Rasa (Air Mineral)",
  ],
  [
    424,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Kadar O2 terlarut di pabrik (mg/l) ",
    "",
    "=40",
  ],
  [
    425,
    "Air Minum Dalam Kemasan (Air Mineral Beroksigen) (1401010206)",
    "Kadar O2 terlarut di pasaran (mg/l) ",
    "",
    "=20",
  ],
  [
    426,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Warna (Air Mineral) (unit Pt.Co)",
    "=5",
  ],
  [
    427,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "pH (Air Mineral)",
    "=8.5",
    "=6",
  ],
  [
    428,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Kekeruhan (Air Mineral) (NTU)",
    "=1.5",
  ],
  [
    429,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Zat yang terlarut (Air Mineral) (mg/l)",
    "=500",
  ],
  [
    430,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Zat organik (Air Mineral) (Angka KMn04) (mg/l)",
    "=1",
  ],
  [
    431,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Nitrat dihitung sebagai (NO3) (Air Mineral) (mg/l)",
    "=44",
  ],
  [
    432,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Nitrit dihitung sebagai (NO2) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    433,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Amonium (NH4) (Air Mineral) (mg/l)",
    "=0.15",
  ],
  [
    434,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Sulfat (S04) (Air Mineral) (mg/l)",
    "=200",
  ],
  [
    435,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Klorida (CI) (Air Mineral) (mg/l)",
    "=250",
  ],
  [
    436,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Fluorida (F) (Air Mineral) (mg/l)",
    "=1",
  ],
  [
    437,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Sianida (CN) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    438,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Besi (Fe) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    439,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Mangan (Mn) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    440,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Klor Bebas (Cl2) (Air Mineral) (mg/l)",
    "=0.1",
  ],
  [
    441,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Kromium (Cr) (Air Mineral) (mg/l)",
    "=0.05",
  ],
  [
    442,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Barium (Ba) (Air Mineral) (mg/l)",
    "=0.7",
  ],
  [
    443,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Boron (B) (Air Mineral) (mg/l)",
    "=2.4",
  ],
  [
    444,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Selenium (Se) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    445,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "ALT awal (30oC, 72 jam) (Air Mineral) (koloni/ml)",
    "=100",
  ],
  [
    446,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Coliform (Air Mineral) (koloni/250ml)",
  ],
  [
    447,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Arsen (As) (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    448,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Kadmium (Cd) (Air Mineral) (mg/l)",
    "=0.003",
  ],
  [
    449,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Raksa (Hg) (Air Mineral) (mg/l)",
    "=0.001",
  ],
  [
    450,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Timbal (Pb) (Air Mineral) (mg/l)",
  ],
  [
    451,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Tembaga (Cu) (Air Mineral) (mg/l)",
    "=0.5",
  ],
  [
    452,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Pseudomonas aeruginosa (Air Mineral) (koloni/250ml)",
  ],
  [
    453,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Bau (Air Mineral)",
  ],
  [
    454,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Rasa (Air Mineral)",
  ],
  [
    455,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Bromat (Air Mineral) (mg/l)",
    "=0.01",
  ],
  [
    456,
    "Air Minum Dalam Kemasan (Air Mineral) (1401010211)",
    "Perak (Ag) (mg/l)",
    "=0.025",
  ],
  [
    457,
    "Air Minum pH Tinggi (1401010214)",
    "Warna (unit Pt.Co)",
    "=5",
  ],
  [458, "Air Minum pH Tinggi (1401010214)", "pH", "=9.5", ">8.6"],
  [
    459,
    "Air Minum pH Tinggi (1401010214)",
    "Kekeruhan (NTU)",
    "=1.5",
  ],
  [
    460,
    "Air Minum pH Tinggi (1401010214)",
    "Zat yang terlarut (mg/l)",
    "=500",
  ],
  [
    461,
    "Air Minum pH Tinggi (1401010214)",
    "Zat organik (Angka KMn04) (mg/l)",
    "=1",
  ],
  [
    462,
    "Air Minum pH Tinggi (1401010214)",
    "Nitrat dihitung sebagai (NO3) (mg/l)",
    "=44",
  ],
  [
    463,
    "Air Minum pH Tinggi (1401010214)",
    "Nitrit dihitung sebagai (NO2) (mg/l)",
    "=0.1",
  ],
  [
    464,
    "Air Minum pH Tinggi (1401010214)",
    "Amonium (NH4) (mg/l)",
    "=0.15",
  ],
  [
    465,
    "Air Minum pH Tinggi (1401010214)",
    "Sulfat (S04) (mg/l)",
    "=200",
  ],
  [
    466,
    "Air Minum pH Tinggi (1401010214)",
    "Klorida (CI) (mg/l)",
    "=250",
  ],
  [
    467,
    "Air Minum pH Tinggi (1401010214)",
    "Fluorida (F) (mg/l)",
    "=1",
  ],
  [
    468,
    "Air Minum pH Tinggi (1401010214)",
    "Sianida (CN) (mg/l)",
    "=0.05",
  ],
  [
    469,
    "Air Minum pH Tinggi (1401010214)",
    "Besi (Fe) (mg/l)",
    "=0.1",
  ],
  [
    470,
    "Air Minum pH Tinggi (1401010214)",
    "Mangan (Mn) (mg/l)",
    "=0.05",
  ],
  [
    471,
    "Air Minum pH Tinggi (1401010214)",
    "Klor Bebas (Cl2) (mg/l)",
    "=0.1",
  ],
  [
    472,
    "Air Minum pH Tinggi (1401010214)",
    "Kromium (Cr) (mg/l)",
    "=0.05",
  ],
  [
    473,
    "Air Minum pH Tinggi (1401010214)",
    "Barium (Ba) (mg/l)",
    "=0.7",
  ],
  [
    474,
    "Air Minum pH Tinggi (1401010214)",
    "Boron (B) (mg/l)",
    "=2.4",
  ],
  [
    475,
    "Air Minum pH Tinggi (1401010214)",
    "Selenium (Se) (mg/l)",
    "=0.01",
  ],
  [
    476,
    "Air Minum pH Tinggi (1401010214)",
    "ALT awal (30oC, 72 jam) (koloni/ml)",
    "=100",
  ],
  [
    477,
    "Air Minum pH Tinggi (1401010214)",
    "ALT akhir (30oC, 72 jam) (koloni/ml)",
    "=100000",
  ],
  [
    478,
    "Air Minum pH Tinggi (1401010214)",
    "Koliform (Koloni/250 ml)",
  ],
  [
    479,
    "Air Minum pH Tinggi (1401010214)",
    "Pseudomonas aeruginosa (Koloni/250 ml)",
  ],
  [
    480,
    "Air Minum pH Tinggi (1401010214)",
    "Arsen (As) (mg/l)",
    "=0.01",
  ],
  [
    481,
    "Air Minum pH Tinggi (1401010214)",
    "Kadmium (Cd) (mg/l)",
    "=0.003",
  ],
  [
    482,
    "Air Minum pH Tinggi (1401010214)",
    "Raksa (Hg) (mg/l)",
    "=0.001",
  ],
  [483, "Air Minum pH Tinggi (1401010214)", "Timbal (Pb) (mg/l)"],
  [
    484,
    "Air Minum pH Tinggi (1401010214)",
    "Tembaga (Cu) (mg/l)",
    "=0.5",
  ],
  [
    485,
    "Air Minum pH Tinggi (1401010214)",
    "Bromat (mg/L) (Jika dilakukan desinfeksi dengan proses ozonisasi)",
    "=0.01",
  ],
  [
    486,
    "Air Minum pH Tinggi (1401010214)",
    "Perak (Ag) (mg/l) (Jika dilakukan desinfeksi dengan ion perak)",
    "=0.025",
  ],
  [
    487,
    "Air Minum pH Tinggi (1401010214)",
    "Kadar karbon dioksida (CO2) bebas (mg/L) (Jika dilakukan penambahan CO2)",
    "=5890",
    "=3000",
  ],
  [
    488,
    "Air Minum pH Tinggi (1401010214)",
    "Kadar oksigen (O2) terlarut awal (mg/L) (Jika dilakukan penambahan O2)",
    "",
    "=40",
  ],
  [
    489,
    "Air Minum pH Tinggi (1401010214)",
    "Kadar oksigen (O2) terlarut akhir (mg/L) (Jika dilakukan penambahan O2)",
    "",
    "=20",
  ],
  [490, "Air Soda (1401010205)", "Arsen (As) (mg/kg)", "=0.01"],
  [491, "Air Soda (1401010205)", "Cadmium (Cd) (mg/kg)", "=0.003"],
  [492, "Air Soda (1401010205)", "Raksa (Hg) (mg/kg)", "=0.001"],
  [
    493,
    "Air Soda (1401010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [494, "Air Soda (1401010205)", "Timbal (Pb) (mg/kg)", "=0.005"],
  [
    495,
    "Air Soda (1401010205)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=250",
  ],
  [
    496,
    "Air Soda (1401010205)",
    "Karbondioksida (mg/L)",
    "",
    "=5890",
  ],
  [497, "Akar Chicory (12020198)", "Arsen (As) (mg/kg)", "=0.15"],
  [498, "Akar Chicory (12020198)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [499, "Akar Chicory (12020198)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    500,
    "Akar Chicory (12020198)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [501, "Akar Chicory (12020198)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    502,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    503,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    504,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    505,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    506,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    507,
    "Akar/Umbi/Polong-polongan Dalam Kemasan (0402020417)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [508, "Ale (14020103)", "Arsen (mg/kg)", "=0.1"],
  [509, "Ale (14020103)", "Kadmium (mg/kg)", "=0.2"],
  [510, "Ale (14020103)", "Merkuri (mg/kg)", "=0.03"],
  [
    511,
    "Ale (14020103)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    512,
    "Ale (14020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [513, "Ale (14020103)", "Timbal (mg/kg)", "=0.2"],
  [
    514,
    "Allspice (12020109)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    515,
    "Allspice (12020109)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [516, "Analog keju (010605)", "Arsen (As) (mg/kg) ", "=0.1"],
  [517, "Analog keju (010605)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [518, "Analog keju (010605)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    519,
    "Analog keju (010605)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    520,
    "Analog keju (010605)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    521,
    "Analog keju (010605)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    522,
    "Analog keju (010605)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    523,
    "Analog keju (010605)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    524,
    "Andaliman (12020173)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    525,
    "Andaliman (12020173)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    526,
    "Anggur (Grape Wine) (140203)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    527,
    "Anggur (Grape Wine) (140203)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    528,
    "Anggur (Grape Wine) (140203)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    529,
    "Anggur (Grape Wine) (140203)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    530,
    "Anggur (Grape Wine) (140203)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    531,
    "Anggur (Grape Wine) (140203)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    532,
    "Anggur (Grape Wine) (140203)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    533,
    "Anggur (Grape Wine) (140203)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [534, "Anggur Beras (14020402)", "Kadar etanol (%)", "=24", "=7"],
  [
    535,
    "Anggur Beras (14020402)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [536, "Anggur Beras (14020402)", "Arsen (mg/kg)", "=0.1"],
  [537, "Anggur Beras (14020402)", "Kadmium (mg/kg)", "=0.2"],
  [538, "Anggur Beras (14020402)", "Merkuri (mg/kg)", "=0.03"],
  [
    539,
    "Anggur Beras (14020402)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    540,
    "Anggur Beras (14020402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [541, "Anggur Beras (14020402)", "Timbal (mg/kg)", "=0.2"],
  [
    542,
    "Anggur Beras Ketan (14020403)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    543,
    "Anggur Beras Ketan (14020403)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [544, "Anggur Beras Ketan (14020403)", "Arsen (mg/kg)", "=0.1"],
  [545, "Anggur Beras Ketan (14020403)", "Kadmium (mg/kg)", "=0.2"],
  [
    546,
    "Anggur Beras Ketan (14020403)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    547,
    "Anggur Beras Ketan (14020403)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    548,
    "Anggur Beras Ketan (14020403)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [549, "Anggur Beras Ketan (14020403)", "Timbal (mg/kg)", "=0.2"],
  [
    550,
    "Anggur Brem Bali (14020404)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    551,
    "Anggur Brem Bali (14020404)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [552, "Anggur Brem Bali (14020404)", "Arsen (mg/kg)", "=0.1"],
  [553, "Anggur Brem Bali (14020404)", "Kadmium (mg/kg)", "=0.2"],
  [554, "Anggur Brem Bali (14020404)", "Merkuri (mg/kg)", "=0.03"],
  [
    555,
    "Anggur Brem Bali (14020404)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    556,
    "Anggur Brem Bali (14020404)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [557, "Anggur Brem Bali (14020404)", "Timbal (mg/kg)", "=0.2"],
  [558, "Anggur Buah (14020401)", "Kadar etanol (%)", "=24", "=7"],
  [
    559,
    "Anggur Buah (14020401)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
  ],
  [560, "Anggur Buah (14020401)", "Arsen (mg/kg)", "=0.1"],
  [561, "Anggur Buah (14020401)", "Kadmium (mg/kg)", "=0.2"],
  [562, "Anggur Buah (14020401)", "Merkuri (mg/kg)", "=0.03"],
  [
    563,
    "Anggur Buah (14020401)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    564,
    "Anggur Buah (14020401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [565, "Anggur Buah (14020401)", "Timbal (mg/kg)", "=0.2"],
  [
    566,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    567,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    568,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    569,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    570,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    571,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    572,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    573,
    "Anggur Fortifikasi, Anggur Liqueur dan Anggur Manis (1402030301)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [
    574,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    575,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Kadar metanol dihitung terhadap volume produk (%) (v/v)",
    "=0.01",
  ],
  [
    576,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    577,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    578,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    579,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    580,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    581,
    "Anggur Mengandung bahan pangan lain (antara lain : Ginseng/kolesom/temulawak) (14020708)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    582,
    "Anggur Mengandung Temulawak (14020706)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    583,
    "Anggur Mengandung Temulawak (14020706)",
    "Kadar metanol dihitung terhadap volume produk (%) (v/v) ",
    "=0.01",
  ],
  [
    584,
    "Anggur Mengandung Temulawak (14020706)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    585,
    "Anggur Mengandung Temulawak (14020706)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    586,
    "Anggur Mengandung Temulawak (14020706)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    587,
    "Anggur Mengandung Temulawak (14020706)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    588,
    "Anggur Mengandung Temulawak (14020706)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    589,
    "Anggur Mengandung Temulawak (14020706)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    590,
    "Anggur Rendah Alkohol (14020702)",
    "Kadar etanol (reduced alcohol wine) (% v/v)",
    "=6.5",
    "=1.2",
  ],
  [
    591,
    "Anggur Rendah Alkohol (14020702)",
    "Kadar etanol (low alcohol wine) (% v/v)",
    "=1.2",
  ],
  [
    592,
    "Anggur Rendah Alkohol (14020702)",
    "Kadar metanol dihitung terhadap volume produk (% v/v) ",
    "=0.01",
  ],
  [
    593,
    "Anggur Rendah Alkohol (14020702)",
    "Kadar metanol dihitung terhadap etanol (%) ",
    "=0.1",
  ],
  [
    594,
    "Anggur Rendah Alkohol (14020702)",
    "Kadar asam yang mudah menguap (sebagai asam asetat) (g/100 ml)",
    "=0.2",
  ],
  [
    595,
    "Anggur Rendah Alkohol (14020702)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    596,
    "Anggur Rendah Alkohol (14020702)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    597,
    "Anggur Rendah Alkohol (14020702)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    598,
    "Anggur Rendah Alkohol (14020702)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    599,
    "Anggur Rendah Alkohol (14020702)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    600,
    "Anggur Rendah Alkohol (14020702)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    601,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    602,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    603,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    604,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    605,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    606,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    607,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    608,
    "Anggur Sayur (Vegetable Wine) (14020405)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    609,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    610,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    611,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Kadar karbondioksida pada suhu 20\xB0C (g/100 ml) ",
    "",
    "=0.3",
  ],
  [
    612,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    613,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    614,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    615,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    616,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    617,
    "Anggur Sparkling dan Semi Sparkling (1402030201)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [
    618,
    "Anggur Tonikum Kinina (14020407)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    619,
    "Anggur Tonikum Kinina (14020407)",
    "Kadar kinina (sebagai Kinina Hidroklorida) (g/l)",
    "=2.5",
    "=0.6",
  ],
  [
    620,
    "Anggur Tonikum Kinina (14020407)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    621,
    "Anggur Tonikum Kinina (14020407)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    622,
    "Anggur Tonikum Kinina (14020407)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    623,
    "Anggur Tonikum Kinina (14020407)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    624,
    "Anggur Tonikum Kinina (14020407)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    625,
    "Anggur Tonikum Kinina (14020407)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    626,
    "Anggur Tonikum Kinina (14020407)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [627, "Apem (07010503)", "Arsen (As) (mg/kg)", "=0.5"],
  [628, "Apem (07010503)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [629, "Apem (07010503)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [630, "Apem (07010503)", "Timah (Sn) (mg/kg)", "=40"],
  [631, "Apem (07010503)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [632, "Arak (14020610)", "Kadar etanol (% v/v)", "", "=30"],
  [
    633,
    "Arak (14020610)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [634, "Arak (14020610)", "Arsen (mg/kg)", "=0.1"],
  [635, "Arak (14020610)", "Kadmium (mg/kg)", "=0.2"],
  [636, "Arak (14020610)", "Merkuri (mg/kg)", "=0.03"],
  [
    637,
    "Arak (14020610)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    638,
    "Arak (14020610)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [639, "Arak (14020610)", "Timbal (mg/kg)", "=0.2"],
  [
    640,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    641,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Kadar metanol dihitung terhadap volume produk (%) (v/v)",
    "=0.01",
  ],
  [
    642,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    643,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    644,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    645,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    646,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    647,
    "Arak Anggur Mengandung Ginseng (14020707)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    648,
    "Arak Masak (Angciu) (120303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    649,
    "Arak Masak (Angciu) (120303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    650,
    "Arak Masak (Angciu) (120303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    651,
    "Arak Masak (Angciu) (120303)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    652,
    "Arak Masak (Angciu) (120303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    653,
    "Asam Glugur (12020106)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    654,
    "Asam Glugur (12020106)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    655,
    "Asam Jawa (12020107)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    656,
    "Asam Jawa (12020107)",
    "Cadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    657,
    "Asam Jawa (12020107)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    658,
    "Asam Jawa (12020107)",
    "Timah (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    659,
    "Asam Jawa (12020107)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    660,
    "Asam Jawa (12020107)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    661,
    "Asam Jawa (12020107)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    662,
    "Asam Kandis (12020108)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    663,
    "Asam Kandis (12020108)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [664, "Asam Sunti (12020199)", "Arsen (As) (mg/kg)", "=0.15"],
  [665, "Asam Sunti (12020199)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [666, "Asam Sunti (12020199)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    667,
    "Asam Sunti (12020199)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [668, "Asam Sunti (12020199)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    669,
    "Asam Sunti (12020199)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    670,
    "Asam Sunti (12020199)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    671,
    "Asinan Buah (0401020302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    672,
    "Asinan Buah (0401020302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    673,
    "Asinan Buah (0401020302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    674,
    "Asinan Buah (0401020302)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    675,
    "Asinan Buah (0401020302)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    676,
    "Asinan Buah (0401020302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [677, "Asinan Jahe (0402020323)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    678,
    "Asinan Jahe (0402020323)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    679,
    "Asinan Jahe (0402020323)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    680,
    "Asinan Jahe (0402020323)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    681,
    "Asinan Jahe (0402020323)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [682, "Asinan Jahe (0402020323)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    683,
    "Asinan Jahe (12020110)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    684,
    "Asinan Jahe (12020110)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    685,
    "Asparagus Dalam Kemasan (0402020405)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    686,
    "Asparagus Dalam Kemasan (0402020405)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    687,
    "Asparagus Dalam Kemasan (0402020405)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    688,
    "Asparagus Dalam Kemasan (0402020405)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    689,
    "Asparagus Dalam Kemasan (0402020405)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    690,
    "Asparagus Dalam Kemasan (0402020405)",
    "Batang panjang (long shoots) : terdiri dari tunas dan batangnya dengan panjang antara",
    "=18",
    ">15",
  ],
  [
    691,
    "Asparagus Dalam Kemasan (0402020405)",
    "Batang atau potongan (shoots or spears) : terdiri dari tunas dan batangnya dengan panjang antara",
    "=15",
    ">10.5",
  ],
  [
    692,
    "Asparagus Dalam Kemasan (0402020405)",
    "Pucuk tunas (tips or points) : terdiri dari pucuk dan batangnya dengan panjang antara",
    "=10.5",
    ">4",
  ],
  [693, "Aspic Ikan (09030103)", "As (ppm atau mg/kg)", "=0.25"],
  [694, "Aspic Ikan (09030103)", "Cd (ppm atau mg/kg)", "=0.1"],
  [695, "Aspic Ikan (09030103)", "Hg (ppm atau mg/kg", "=0.5"],
  [
    696,
    "Aspic Ikan (09030103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    697,
    "Aspic Ikan (09030103)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [698, "Aspic Ikan (09030103)", "Pb (ppm atau mg/kg)", "=0.2"],
  [
    699,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    700,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    701,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    702,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    703,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    704,
    "Ayam Cordon Bleu (Chicken Cordon Bleu) (08020308)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    705,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    706,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    707,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    708,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    709,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    710,
    "Ayam Goreng (Fried Chicken) (08020303)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    711,
    "Ayam Karage (Chicken karage) (08020309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    712,
    "Ayam Karage (Chicken karage) (08020309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    713,
    "Ayam Karage (Chicken karage) (08020309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    714,
    "Ayam Karage (Chicken karage) (08020309)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    715,
    "Ayam Karage (Chicken karage) (08020309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    716,
    "Ayam Karage (Chicken karage) (08020309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    717,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    718,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    719,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    720,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    721,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    722,
    "Ayam Katsu (Chicken Katsu) (08020301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    723,
    "Ayam Pop-Corn Beku (08020306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    724,
    "Ayam Pop-Corn Beku (08020306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    725,
    "Ayam Pop-Corn Beku (08020306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    726,
    "Ayam Pop-Corn Beku (08020306)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    727,
    "Ayam Pop-Corn Beku (08020306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    728,
    "Ayam Pop-Corn Beku (08020306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    729,
    "Bacon (0802010101)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    730,
    "Bacon (0802010101)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    731,
    "Bacon (0802010101)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    732,
    "Bacon (0802010101)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    733,
    "Bacon (0802010101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    734,
    "Bacon (0802010101)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    735,
    "Bacon Sapi (0802010102)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    736,
    "Bacon Sapi (0802010102)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    737,
    "Bacon Sapi (0802010102)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    738,
    "Bacon Sapi (0802010102)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    739,
    "Bacon Sapi (0802010102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    740,
    "Bacon Sapi (0802010102)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [741, "Bagel (07010302)", "Arsen (As) (mg/kg)", "=0.5"],
  [742, "Bagel (07010302)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [743, "Bagel (07010302)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [744, "Bagel (07010302)", "Timah (Sn) (mg/kg)", "=40"],
  [745, "Bagel (07010302)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    746,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    747,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    748,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    749,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    750,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    751,
    "Bahan Pelapis Dari Kakao Manis dan Lemak Nabati (05010411)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    752,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    753,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    754,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    755,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    756,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    757,
    "Bahan pengisi roti berbasis cokelat (050405)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    758,
    "Bahan pengisi roti berbasis selain cokelat dan kacang (050406)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    759,
    "Bahan pengisi roti berbasis selain cokelat dan kacang (050406)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    760,
    "Bahan pengisi roti berbasis selain cokelat dan kacang (050406)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    761,
    "Bahan pengisi roti berbasis selain cokelat dan kacang (050406)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    762,
    "Bahan pengisi roti berbasis selain cokelat dan kacang (050406)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    763,
    "Bahan Tambahan Pangan (99)",
    "Kalsium alginat (Calcium alginate)",
  ],
  [
    764,
    "Bahan Tambahan Pangan (99)",
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
  ],
  [
    765,
    "Bahan Tambahan Pangan (99)",
    "Kalsium karbonat (Calcium carbonate)",
  ],
  [
    766,
    "Bahan Tambahan Pangan (99)",
    "Trikalsium fosfat (Tricalcium orthophosphate)",
  ],
  [
    767,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    768,
    "Bahan Tambahan Pangan (99)",
    "Selulosa bubuk (Powdered cellulose)",
  ],
  [
    769,
    "Bahan Tambahan Pangan (99)",
    "Natrium karbonat (Sodium carbonate)",
  ],
  [
    770,
    "Bahan Tambahan Pangan (99)",
    "Magnesium karbonat (Magnesium carbonate)",
  ],
  [
    771,
    "Bahan Tambahan Pangan (99)",
    "Magnesium oksida (Magnesium oxide)",
  ],
  [
    772,
    "Bahan Tambahan Pangan (99)",
    "Natrium besi (II) sianida (Sodium ferrocyanide)",
  ],
  [
    773,
    "Bahan Tambahan Pangan (99)",
    "Kalium besi (II) sianida (Potassium ferrocyanide)",
  ],
  [
    774,
    "Bahan Tambahan Pangan (99)",
    "Kalsium besi (II) sianida (Calcium ferrocyanide)",
  ],
  [
    775,
    "Bahan Tambahan Pangan (99)",
    "Silikon dioksida halus (Silicon dioxide, amorphous)",
  ],
  [
    776,
    "Bahan Tambahan Pangan (99)",
    "Kalsium silikat (Calcium silicate)",
  ],
  [
    777,
    "Bahan Tambahan Pangan (99)",
    "Natrium aluminosilikat (Sodium aluminosilicate)",
  ],
  [
    778,
    "Bahan Tambahan Pangan (99)",
    "Magnesium silikat (Magnesium silicate)",
  ],
  [
    779,
    "Bahan Tambahan Pangan (99)",
    "Asam askorbat (Ascorbic acid)",
  ],
  [
    780,
    "Bahan Tambahan Pangan (99)",
    "Natrium askorbat (Sodium ascorbate)",
  ],
  [
    781,
    "Bahan Tambahan Pangan (99)",
    "Kalsium askorbat (Calcium ascorbate)",
  ],
  [
    782,
    "Bahan Tambahan Pangan (99)",
    "Kalium askorbat (Potassium ascorbate)",
  ],
  [
    783,
    "Bahan Tambahan Pangan (99)",
    "Askorbil palmitat (Ascorbyl palmitate)",
  ],
  [
    784,
    "Bahan Tambahan Pangan (99)",
    "Askorbil stearat (Ascorbyl stearate)",
  ],
  [
    785,
    "Bahan Tambahan Pangan (99)",
    "d-alfa tokoferol (d-alpha-Tocopherol )",
  ],
  [
    786,
    "Bahan Tambahan Pangan (99)",
    "Tokoferol campuran pekat (Mixed tocopherol concentrate)",
  ],
  [
    787,
    "Bahan Tambahan Pangan (99)",
    "dl-alfa tokoferol (dl-alpha Tocopherol)",
  ],
  [
    788,
    "Bahan Tambahan Pangan (99)",
    "Gama tokoferol (Gamma Tocopherol)",
  ],
  [
    789,
    "Bahan Tambahan Pangan (99)",
    "Propil galat (Propyl gallate)",
  ],
  [
    790,
    "Bahan Tambahan Pangan (99)",
    "Asam eritorbat (Erythorbic acid)",
  ],
  [
    791,
    "Bahan Tambahan Pangan (99)",
    "Natrium eritorbat (Sodium erythorbate)",
  ],
  [
    792,
    "Bahan Tambahan Pangan (99)",
    "Butil hidrokinon tersier/TBHQ (Tertiary butylhydroquinone)",
  ],
  [
    793,
    "Bahan Tambahan Pangan (99)",
    "Butil hidroksi anisol/BHA (Butylated hydroxyanisole)",
  ],
  [
    794,
    "Bahan Tambahan Pangan (99)",
    "Butil hidroksi toluen/BHT (Butylated hydroxytoluene)",
  ],
  [
    795,
    "Bahan Tambahan Pangan (99)",
    "Karbon dioksida (Carbon dioxide)",
  ],
  [
    796,
    "Bahan Tambahan Pangan (99)",
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
  ],
  [
    797,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium sitrat (Trisodium citrate)",
  ],
  [
    798,
    "Bahan Tambahan Pangan (99)",
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
  ],
  [
    799,
    "Bahan Tambahan Pangan (99)",
    "Trikalium sitrat (Tripotassium citrate)",
  ],
  [
    800,
    "Bahan Tambahan Pangan (99)",
    "Mononatrium fosfat (Monosodium orthophosphate)",
  ],
  [
    801,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium fosfat (Disodium orthophosphate)",
  ],
  [
    802,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium fosfat (Trisodium orthophosphate)",
  ],
  [
    803,
    "Bahan Tambahan Pangan (99)",
    "Monokalium fosfat (Monopotassium orthophosphate)",
  ],
  [
    804,
    "Bahan Tambahan Pangan (99)",
    "Dikalium fosfat (Dipotassium orthophosphate)",
  ],
  [
    805,
    "Bahan Tambahan Pangan (99)",
    "Trikalium fosfat (Tripotassium orthophosphate)",
  ],
  [806, "Bahan Tambahan Pangan (99)", "Gelatin (Edible gelatin)"],
  [
    807,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium difosfat (Disodium diphosphate)",
  ],
  [
    808,
    "Bahan Tambahan Pangan (99)",
    "Tetranatrium difosfat (Tetrasodium diphosphate)",
  ],
  [
    809,
    "Bahan Tambahan Pangan (99)",
    "Tetrakalium difosfat (Tetrapotassium diphosphate)",
  ],
  [
    810,
    "Bahan Tambahan Pangan (99)",
    "Dikalsium difosfat (Dicalcium diphosphate)",
  ],
  [
    811,
    "Bahan Tambahan Pangan (99)",
    "Natrium tripolifosfat (Sodium Tripolyphosphate)",
  ],
  [
    812,
    "Bahan Tambahan Pangan (99)",
    "Kalium tripolifosfat (Potassium tripolyphosphate)",
  ],
  [
    813,
    "Bahan Tambahan Pangan (99)",
    "Natrium polifosfat (Sodium polyphosphate)",
  ],
  [
    814,
    "Bahan Tambahan Pangan (99)",
    "Kalium polifosfat (Potassium polyphosphate)",
  ],
  [
    815,
    "Bahan Tambahan Pangan (99)",
    "Kalsium polifosfat (Calcium polyphosphate)",
  ],
  [
    816,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
  ],
  [
    817,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
  ],
  [
    818,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
  ],
  [
    819,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltartaric and fatty acid esters of glycerol)",
  ],
  [
    820,
    "Bahan Tambahan Pangan (99)",
    "Natrium glukonat (Sodium gluconate)",
  ],
  [
    821,
    "Bahan Tambahan Pangan (99)",
    "Karbon dioksida (Carbon dioxide)",
  ],
  [822, "Bahan Tambahan Pangan (99)", "Nitrogen (Nitrogen)"],
  [
    823,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    824,
    "Bahan Tambahan Pangan (99)",
    "Kalium laktat (Potassium lactate)",
  ],
  [
    825,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidrogen malat (Sodium hydrogen malate)",
  ],
  [
    826,
    "Bahan Tambahan Pangan (99)",
    "Natrium malat (Sodium malate)",
  ],
  [827, "Bahan Tambahan Pangan (99)", "Gliserol (Glycerol)"],
  [
    828,
    "Bahan Tambahan Pangan (99)",
    "Polidekstrosa (Polydextroses)",
  ],
  [829, "Bahan Tambahan Pangan (99)", "Triasetin (Triacetin)"],
  [
    830,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol (Propylene glycole)",
  ],
  [831, "Bahan Tambahan Pangan (99)", "Malam (Beeswax)"],
  [
    832,
    "Bahan Tambahan Pangan (99)",
    "Lilin kandelila (Candelilla wax)",
  ],
  [
    833,
    "Bahan Tambahan Pangan (99)",
    "Lilin karnauba (Carnauba wax)",
  ],
  [834, "Bahan Tambahan Pangan (99)", "Syelak (Shellac)"],
  [
    835,
    "Bahan Tambahan Pangan (99)",
    "Lilin mikrokristalin (Microcrystalline wax)",
  ],
  [836, "Bahan Tambahan Pangan (99)", "Sorbitol (Sorbitol)"],
  [
    837,
    "Bahan Tambahan Pangan (99)",
    "Sorbitol Sirup (Sorbitol syrup)",
  ],
  [838, "Bahan Tambahan Pangan (99)", "Manitol (Mannitol)"],
  [
    839,
    "Bahan Tambahan Pangan (99)",
    "Glikosida steviol (Steviol glycosides)",
  ],
  [840, "Bahan Tambahan Pangan (99)", "Laktitol (Lactitol)"],
  [841, "Bahan Tambahan Pangan (99)", "Silitol (Xylitol)"],
  [842, "Bahan Tambahan Pangan (99)", "Eritritol (Erythritol)"],
  [
    843,
    "Bahan Tambahan Pangan (99)",
    "Asesulfam-K (Acesulfame potassium)",
  ],
  [844, "Bahan Tambahan Pangan (99)", "Aspartam (Aspartame)"],
  [
    845,
    "Bahan Tambahan Pangan (99)",
    "Asam siklamat (Cyclamic acid)",
  ],
  [
    846,
    "Bahan Tambahan Pangan (99)",
    "Kalsium siklamat (Calcium cyclamate)",
  ],
  [
    847,
    "Bahan Tambahan Pangan (99)",
    "Natrium siklamat (Sodium cyclamate)",
  ],
  [848, "Bahan Tambahan Pangan (99)", "Sakarin (Saccharin)"],
  [
    849,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sakarin (Calcium saccharin)",
  ],
  [
    850,
    "Bahan Tambahan Pangan (99)",
    "Kalium sakarin (Potassium saccharin)",
  ],
  [
    851,
    "Bahan Tambahan Pangan (99)",
    "Natrium sakarin (Sodium saccharin)",
  ],
  [
    852,
    "Bahan Tambahan Pangan (99)",
    "Sukralosa (Sucralose/Trichlorogalactosucrose)",
  ],
  [853, "Bahan Tambahan Pangan (99)", "Neotam (Neotame)"],
  [
    854,
    "Bahan Tambahan Pangan (99)",
    "Sukrosa asetat isobutirat (Sucrose acetate isobutyrate)",
  ],
  [
    855,
    "Bahan Tambahan Pangan (99)",
    "Trietil sitrat (Triethyl citrate)",
  ],
  [
    856,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol (Propylene glycol)",
  ],
  [
    857,
    "Bahan Tambahan Pangan (99)",
    "Polietilen glikol (Polyethylene glycol)",
  ],
  [
    858,
    "Bahan Tambahan Pangan (99)",
    "Asam alginat (Alginic acid)",
  ],
  [
    859,
    "Bahan Tambahan Pangan (99)",
    "Natrium alginat (Sodium alginate)",
  ],
  [
    860,
    "Bahan Tambahan Pangan (99)",
    "Kalium alginat (Potassium alginate)",
  ],
  [
    861,
    "Bahan Tambahan Pangan (99)",
    "Kalsium alginat (Calcium alginate)",
  ],
  [862, "Bahan Tambahan Pangan (99)", "Agar-agar (Agar)"],
  [863, "Bahan Tambahan Pangan (99)", "Karagen (Carrageenan)"],
  [
    864,
    "Bahan Tambahan Pangan (99)",
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
  ],
  [865, "Bahan Tambahan Pangan (99)", "Gom gelan (Gellan gum)"],
  [866, "Bahan Tambahan Pangan (99)", "Gelatin (Edible gelatin)"],
  [867, "Bahan Tambahan Pangan (99)", "Pektin (Pectins)"],
  [868, "Bahan Tambahan Pangan (99)", "Gom xanthan (Xanthan gum)"],
  [
    869,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    870,
    "Bahan Tambahan Pangan (99)",
    "Etil metil selulosa (Methyl ethyl cellulose)",
  ],
  [
    871,
    "Bahan Tambahan Pangan (99)",
    "Kalsium karbonat (Calcium carbonate)",
  ],
  [872, "Bahan Tambahan Pangan (99)", "Asam asetat (Acetic acid)"],
  [
    873,
    "Bahan Tambahan Pangan (99)",
    "Natrium asetat (Sodium acetate)",
  ],
  [
    874,
    "Bahan Tambahan Pangan (99)",
    "Kalsium asetat (Calcium acetate)",
  ],
  [875, "Bahan Tambahan Pangan (99)", "Asam laktat (Lactic acid)"],
  [876, "Bahan Tambahan Pangan (99)", "Asam malat (Malic acid)"],
  [
    877,
    "Bahan Tambahan Pangan (99)",
    "Asam fumarat (Fumaric acid)",
  ],
  [
    878,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    879,
    "Bahan Tambahan Pangan (99)",
    "Kalium laktat (Potassium lactate)",
  ],
  [
    880,
    "Bahan Tambahan Pangan (99)",
    "Kalsium laktat (Calcium lactate)",
  ],
  [
    881,
    "Bahan Tambahan Pangan (99)",
    "L-amonium laktat (L-ammonium lactate)",
  ],
  [882, "Bahan Tambahan Pangan (99)", "Asam sitrat (Citric acid)"],
  [
    883,
    "Bahan Tambahan Pangan (99)",
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
  ],
  [
    884,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
  ],
  [
    885,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium sitrat (Trisodium citrate)",
  ],
  [
    886,
    "Bahan Tambahan Pangan (99)",
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
  ],
  [
    887,
    "Bahan Tambahan Pangan (99)",
    "Trikalium sitrat (Tripotassium citrate)",
  ],
  [
    888,
    "Bahan Tambahan Pangan (99)",
    "Trikalsium sitrat (Tricalcium citrate)",
  ],
  [
    889,
    "Bahan Tambahan Pangan (99)",
    "Asam tartrat (Tartaric acid)",
  ],
  [
    890,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidrogen tartrat (Potassium hydrogen tartrate)",
  ],
  [
    891,
    "Bahan Tambahan Pangan (99)",
    "Asam fosfat (Orthophosphoric acid)",
  ],
  [
    892,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidrogen malat (Sodium hydrogen malate)",
  ],
  [
    893,
    "Bahan Tambahan Pangan (99)",
    "Natrium malat (Sodium malate)",
  ],
  [
    894,
    "Bahan Tambahan Pangan (99)",
    "Kalsium DL-malat (Calcium DL-malate)",
  ],
  [895, "Bahan Tambahan Pangan (99)", "Asam adipat (Adipic acid)"],
  [
    896,
    "Bahan Tambahan Pangan (99)",
    "Natrium adipat (Sodium adipates)",
  ],
  [
    897,
    "Bahan Tambahan Pangan (99)",
    "Kalium adipat (Potassium adipate)",
  ],
  [
    898,
    "Bahan Tambahan Pangan (99)",
    "Natrium karbonat (Sodium carbonate)",
  ],
  [
    899,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate)",
  ],
  [
    900,
    "Bahan Tambahan Pangan (99)",
    "Kalium karbonat (Potassium carbonate)",
  ],
  [
    901,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate)",
  ],
  [
    902,
    "Bahan Tambahan Pangan (99)",
    "Amonium karbonat (Ammonium carbonate)",
  ],
  [
    903,
    "Bahan Tambahan Pangan (99)",
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate)",
  ],
  [
    904,
    "Bahan Tambahan Pangan (99)",
    "Magnesium karbonat (Magnesium carbonate)",
  ],
  [
    905,
    "Bahan Tambahan Pangan (99)",
    "Asam hidroklorida (Hydrochloric acid)",
  ],
  [
    906,
    "Bahan Tambahan Pangan (99)",
    "Natrium sulfat (Sodium sulphate)",
  ],
  [
    907,
    "Bahan Tambahan Pangan (99)",
    "Kalium sulfat (Potassium sulphate)",
  ],
  [
    908,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    909,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidroksida (Sodium hydroxide)",
  ],
  [
    910,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidroksida (Potassium hydroxide)",
  ],
  [
    911,
    "Bahan Tambahan Pangan (99)",
    "Kalsium hidroksida (Calcium hydroxide)",
  ],
  [
    912,
    "Bahan Tambahan Pangan (99)",
    "Magnesium hidroksida (Magnesium hydroxide)",
  ],
  [
    913,
    "Bahan Tambahan Pangan (99)",
    "Kalsium oksida (Calcium oxide)",
  ],
  [
    914,
    "Bahan Tambahan Pangan (99)",
    "Glukono delta lakton (Glucono delta lactone)",
  ],
  [
    915,
    "Bahan Tambahan Pangan (99)",
    "Kalsium glukonat (Calcium gluconate)",
  ],
  [916, "Bahan Tambahan Pangan (99)", "Asam sorbat (Sorbic acid)"],
  [
    917,
    "Bahan Tambahan Pangan (99)",
    "Natrium sorbat (Sodium sorbate)",
  ],
  [
    918,
    "Bahan Tambahan Pangan (99)",
    "Kalium sorbat (Potassium sorbate)",
  ],
  [
    919,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sorbat (Calcium sorbate)",
  ],
  [
    920,
    "Bahan Tambahan Pangan (99)",
    "Asam benzoate (Benzoic acid)",
  ],
  [
    921,
    "Bahan Tambahan Pangan (99)",
    "Natrium benzoat (Sodium benzoate)",
  ],
  [
    922,
    "Bahan Tambahan Pangan (99)",
    "Kalium benzoat (Potassium benzoate)",
  ],
  [
    923,
    "Bahan Tambahan Pangan (99)",
    "Kalsium benzoat (Calcium benzoate )",
  ],
  [
    924,
    "Bahan Tambahan Pangan (99)",
    "Etil para-hidroksibenzoat (Ethyl para- hydroxybenzoate)",
  ],
  [
    925,
    "Bahan Tambahan Pangan (99)",
    "Metil para-hidroksibenzoat (Methyl para hydroxybenzoate)",
  ],
  [
    926,
    "Bahan Tambahan Pangan (99)",
    "Belerang dioksida (Sulphur dioxide)",
  ],
  [
    927,
    "Bahan Tambahan Pangan (99)",
    "Natrium sulfit (Sodium sulphite )",
  ],
  [
    928,
    "Bahan Tambahan Pangan (99)",
    "Natrium bisulfit (Sodium bisulphate)",
  ],
  [
    929,
    "Bahan Tambahan Pangan (99)",
    "Natrium metabisulfit (Sodium metabisulphite)",
  ],
  [
    930,
    "Bahan Tambahan Pangan (99)",
    "Kalium metabisulfit (Potassium metabisulphite)",
  ],
  [
    931,
    "Bahan Tambahan Pangan (99)",
    "Kalium sulfit (Potassium sulphite)",
  ],
  [
    932,
    "Bahan Tambahan Pangan (99)",
    "Kalsium bisulfit (Calcium bisulphite)",
  ],
  [
    933,
    "Bahan Tambahan Pangan (99)",
    "Kalium bisulfit (Potassium bisulphite)",
  ],
  [934, "Bahan Tambahan Pangan (99)", "Nisin (Nisin)"],
  [
    935,
    "Bahan Tambahan Pangan (99)",
    "Kalium nitrit (Potassium nitrite)",
  ],
  [
    936,
    "Bahan Tambahan Pangan (99)",
    "Natrium nitrit (Sodium nitrite)",
  ],
  [
    937,
    "Bahan Tambahan Pangan (99)",
    "Natrium nitrat (Sodium nitrate)",
  ],
  [
    938,
    "Bahan Tambahan Pangan (99)",
    "Kalium nitrat (Potassium nitrate)",
  ],
  [
    939,
    "Bahan Tambahan Pangan (99)",
    "Asam propionat (Propionic acid)",
  ],
  [
    940,
    "Bahan Tambahan Pangan (99)",
    "Natrium propionat (Sodium propionate)",
  ],
  [
    941,
    "Bahan Tambahan Pangan (99)",
    "Kalsium propionat (Calcium propionate)",
  ],
  [
    942,
    "Bahan Tambahan Pangan (99)",
    "Kalium propionat (Potassium propionate)",
  ],
  [
    943,
    "Bahan Tambahan Pangan (99)",
    "Lisozim hidroklorida (Lysozyme hydrochloride)",
  ],
  [
    944,
    "Bahan Tambahan Pangan (99)",
    "Natrium karbonat (Sodium carbonate)",
  ],
  [
    945,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate)",
  ],
  [
    946,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate)",
  ],
  [
    947,
    "Bahan Tambahan Pangan (99)",
    "Amonium karbonat (Ammonium carbonate)",
  ],
  [
    948,
    "Bahan Tambahan Pangan (99)",
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate)",
  ],
  [
    949,
    "Bahan Tambahan Pangan (99)",
    "Natrium aluminium fosfat (Sodium aluminium phosphates)",
  ],
  [
    950,
    "Bahan Tambahan Pangan (99)",
    "Glukono delta lakton (Glucono delta lactone)",
  ],
  [951, "Bahan Tambahan Pangan (99)", "Dekstrin (Dextrins)"],
  [
    952,
    "Bahan Tambahan Pangan (99)",
    "Pati asetat (Starch acetate)",
  ],
  [
    953,
    "Bahan Tambahan Pangan (99)",
    "Kalsium karbonat (Calcium carbonate)",
  ],
  [954, "Bahan Tambahan Pangan (99)", "Lesitin (Lecithins)"],
  [
    955,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    956,
    "Bahan Tambahan Pangan (99)",
    "Kalsium laktat (Calcium lactate)",
  ],
  [
    957,
    "Bahan Tambahan Pangan (99)",
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
  ],
  [
    958,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
  ],
  [
    959,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium sitrat (Trisodium citrate)",
  ],
  [
    960,
    "Bahan Tambahan Pangan (99)",
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
  ],
  [
    961,
    "Bahan Tambahan Pangan (99)",
    "Trikalium sitrat (Tripotassium citrate)",
  ],
  [
    962,
    "Bahan Tambahan Pangan (99)",
    "Mononatrium fosfat (Monosodium orthophosphate)",
  ],
  [
    963,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium fosfat (Disodium orthophosphate)",
  ],
  [
    964,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium fosfat (Trisodium orthophosphate)",
  ],
  [
    965,
    "Bahan Tambahan Pangan (99)",
    "Monokalium fosfat (Monopotassium orthophosphate)",
  ],
  [
    966,
    "Bahan Tambahan Pangan (99)",
    "Dikalium fosfat (Dipotassium orthophosphate)",
  ],
  [
    967,
    "Bahan Tambahan Pangan (99)",
    "Trikalium fosfat (Tripotassium orthophosphate)",
  ],
  [
    968,
    "Bahan Tambahan Pangan (99)",
    "Asam alginat (Alginic acid)",
  ],
  [
    969,
    "Bahan Tambahan Pangan (99)",
    "Natrium alginat (Sodium alginate)",
  ],
  [
    970,
    "Bahan Tambahan Pangan (99)",
    "Kalium alginat (Potassium alginate)",
  ],
  [
    971,
    "Bahan Tambahan Pangan (99)",
    "Kalsium alginat (Calcium alginate)",
  ],
  [
    972,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol alginat (Propylene glycol alginate)",
  ],
  [973, "Bahan Tambahan Pangan (99)", "Agar-agar (Agar)"],
  [974, "Bahan Tambahan Pangan (99)", "Karagen (Carrageenan)"],
  [
    975,
    "Bahan Tambahan Pangan (99)",
    "Gom kacang lokus (Locust bean gum)",
  ],
  [976, "Bahan Tambahan Pangan (99)", "Gom guar (Guar gum)"],
  [
    977,
    "Bahan Tambahan Pangan (99)",
    "Gom tragakan (Tragacanth gum)",
  ],
  [978, "Bahan Tambahan Pangan (99)", "Gom arab (Arabic gum)"],
  [979, "Bahan Tambahan Pangan (99)", "Gom karaya (Karaya gum)"],
  [980, "Bahan Tambahan Pangan (99)", "Gliserol (Glycerol)"],
  [981, "Bahan Tambahan Pangan (99)", "Gelatin (Edible gelatin)"],
  [
    982,
    "Bahan Tambahan Pangan (99)",
    "Polisorbat 20 (Polyoxyethylene (20) sorbitan monolaurate)",
  ],
  [
    983,
    "Bahan Tambahan Pangan (99)",
    "Polisorbat 40 (Polyoxyethylene (20) Sorbitan Monopalmitate)",
  ],
  [
    984,
    "Bahan Tambahan Pangan (99)",
    "Polisorbat 80 (Polyoxyethylene (20) sorbitan monooleate)",
  ],
  [
    985,
    "Bahan Tambahan Pangan (99)",
    "Polisorbat 60 (Polyoxyethylene (20) sorbitan monostearate)",
  ],
  [
    986,
    "Bahan Tambahan Pangan (99)",
    "Polisorbat 65 (Polyoxyethylene (20) ssorbitan tristearate)",
  ],
  [987, "Bahan Tambahan Pangan (99)", "Pektin (Pectins)"],
  [
    988,
    "Bahan Tambahan Pangan (99)",
    "Ester gliserol resin kayu (Glycerol ester of wood Rosin)",
  ],
  [
    989,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium difosfat (Disodium diphosphate)",
  ],
  [
    990,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium difosfat (Trisodium diphosphate)",
  ],
  [
    991,
    "Bahan Tambahan Pangan (99)",
    "Tetranatrium difosfat (Tetrasodium diphosphate)",
  ],
  [
    992,
    "Bahan Tambahan Pangan (99)",
    "Tetrakalium difosfat (Tetrapotassium diphosphate)",
  ],
  [
    993,
    "Bahan Tambahan Pangan (99)",
    "Dikalsium difosfat (Dicalcium diphosphate)",
  ],
  [
    994,
    "Bahan Tambahan Pangan (99)",
    "Kalsium difosfat (Calcium Dihydrogen Diphosphate)",
  ],
  [
    995,
    "Bahan Tambahan Pangan (99)",
    "Natrium polifosfat (Sodium polyphosphate)",
  ],
  [
    996,
    "Bahan Tambahan Pangan (99)",
    "Kalium polifosfat (Potassium polyphosphate)",
  ],
  [
    997,
    "Bahan Tambahan Pangan (99)",
    "Natrium kalsium polifosfat (Sodium calcium polyphosphate)",
  ],
  [
    998,
    "Bahan Tambahan Pangan (99)",
    "Kalsium polifosfat (Calcium polyphosphates)",
  ],
  [
    999,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    1000,
    "Bahan Tambahan Pangan (99)",
    "Selulosa bubuk (Powdered cellulose)",
  ],
  [
    1001,
    "Bahan Tambahan Pangan (99)",
    "Metil selulosa (Methyl cellulosa)",
  ],
  [
    1002,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil selulosa (Hydroxypropyl cellulose)",
  ],
  [
    1003,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
  ],
  [
    1004,
    "Bahan Tambahan Pangan (99)",
    "Etil metil selulosa (Methyl ethyl cellulose)",
  ],
  [
    1005,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
  ],
  [
    1006,
    "Bahan Tambahan Pangan (99)",
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
  ],
  [
    1007,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
  ],
  [
    1008,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
  ],
  [
    1009,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
  ],
  [
    1010,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltaric and fattya acid esters of glycerol)",
  ],
  [
    1011,
    "Bahan Tambahan Pangan (99)",
    "Ester sukrosa asam lemak (Sucrose esters of fatty acids)",
  ],
  [
    1012,
    "Bahan Tambahan Pangan (99)",
    "Ester poligliserol asam lemak (Polyglycerol esters of fatty acids)",
  ],
  [
    1013,
    "Bahan Tambahan Pangan (99)",
    "Ester poligliserol asam risinoleat terinteresterifikasi (Polyglycerol esters of interesterified ricinoleic acid)",
  ],
  [
    1014,
    "Bahan Tambahan Pangan (99)",
    "Ester propilen glikol asam lemak (Propylene glycol esters of fatty acids)",
  ],
  [
    1015,
    "Bahan Tambahan Pangan (99)",
    "Natrium stearoil-2-laktilat (Sodium stearoyl-2-lactylate)",
  ],
  [
    1016,
    "Bahan Tambahan Pangan (99)",
    "Sorbitan monostearat (Sorbitan monostearat)",
  ],
  [
    1017,
    "Bahan Tambahan Pangan (99)",
    "Sorbitan tristearat (Sorbitan tristearat)",
  ],
  [1018, "Bahan Tambahan Pangan (99)", "Malam (Beeswax)"],
  [
    1019,
    "Bahan Tambahan Pangan (99)",
    "Lilin kandelila (Candelilla wax)",
  ],
  [
    1020,
    "Bahan Tambahan Pangan (99)",
    "Polidekstrosa (Polydextroses)",
  ],
  [
    1021,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi asam (Acid treated starch)",
  ],
  [
    1022,
    "Bahan Tambahan Pangan (99)",
    "Pati pucat (Bleached starch)",
  ],
  [
    1023,
    "Bahan Tambahan Pangan (99)",
    "Pati oksidasi (Oxidized starch)",
  ],
  [
    1024,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi enzim (Enzymed treated starch)",
  ],
  [
    1025,
    "Bahan Tambahan Pangan (99)",
    "Monopati fosfat (Monostarch phosphate)",
  ],
  [
    1026,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat (Distarch phosphate)",
  ],
  [
    1027,
    "Bahan Tambahan Pangan (99)",
    "Fosfat dipati fosfat (Phosphated distarch phosphates)",
  ],
  [
    1028,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
  ],
  [
    1029,
    "Bahan Tambahan Pangan (99)",
    "Pati asetat (Starch acetate)",
  ],
  [
    1030,
    "Bahan Tambahan Pangan (99)",
    "Dipati adipat terasetilasi (Acetylated distarch adipate)",
  ],
  [
    1031,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil pati (Hydroxypropyl starch)",
  ],
  [
    1032,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
  ],
  [
    1033,
    "Bahan Tambahan Pangan (99)",
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
  ],
  [
    1034,
    "Bahan Tambahan Pangan (99)",
    "Asetil pati oksidasi (Acetylated oxidized starch)",
  ],
  [
    1035,
    "Bahan Tambahan Pangan (99)",
    "Natrium kaseinat (Sodium caseinate)",
  ],
  [
    1036,
    "Bahan Tambahan Pangan (99)",
    "Kalsium asetat (Calcium acetate)",
  ],
  [
    1037,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    1038,
    "Bahan Tambahan Pangan (99)",
    "Kalsium laktat (Calcium lactate)",
  ],
  [
    1039,
    "Bahan Tambahan Pangan (99)",
    "Asam alginat (Alginic acid)",
  ],
  [
    1040,
    "Bahan Tambahan Pangan (99)",
    "Natrium alginat (Sodium alginate)",
  ],
  [
    1041,
    "Bahan Tambahan Pangan (99)",
    "Kalium alginat (Potassium alginate)",
  ],
  [
    1042,
    "Bahan Tambahan Pangan (99)",
    "Kalsium alginat (Calcium alginate)",
  ],
  [
    1043,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol alginat (Propylene glycol alginate)",
  ],
  [1044, "Bahan Tambahan Pangan (99)", "Agar-agar (Agar)"],
  [1045, "Bahan Tambahan Pangan (99)", "Karagen (Carrageenan)"],
  [
    1046,
    "Bahan Tambahan Pangan (99)",
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
  ],
  [
    1047,
    "Bahan Tambahan Pangan (99)",
    "Gom kacang lokus (Locust bean gum)",
  ],
  [1048, "Bahan Tambahan Pangan (99)", "Gom guar (Guar gum)"],
  [
    1049,
    "Bahan Tambahan Pangan (99)",
    "Gom tragakan (Tragacanth gum)",
  ],
  [1050, "Bahan Tambahan Pangan (99)", "Gom arab (Arabic gum)"],
  [
    1051,
    "Bahan Tambahan Pangan (99)",
    "Gom xanthan (Xanthan gum)",
  ],
  [1052, "Bahan Tambahan Pangan (99)", "Gom karaya (Karaya gum)"],
  [1053, "Bahan Tambahan Pangan (99)", "Gom tara (Tara gum)"],
  [1054, "Bahan Tambahan Pangan (99)", "Gom gelan (Gellan gum)"],
  [1055, "Bahan Tambahan Pangan (99)", "Gom gatti (Gum ghatti)"],
  [1056, "Bahan Tambahan Pangan (99)", "Gliserol (Glycerol)"],
  [1057, "Bahan Tambahan Pangan (99)", "Gelatin (Edible gelatin)"],
  [1058, "Bahan Tambahan Pangan (99)", "Pektin (Pectins)"],
  [
    1059,
    "Bahan Tambahan Pangan (99)",
    "Ester gliserol resin kayu (Glycerol ester of wood rosin)",
  ],
  [
    1060,
    "Bahan Tambahan Pangan (99)",
    "Alfa-Siklodekstrin (alpha-Cyclodextrin)",
  ],
  [
    1061,
    "Bahan Tambahan Pangan (99)",
    "Gama-Siklodekstrin (gamma-Cyclodextrin)",
  ],
  [
    1062,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    1063,
    "Bahan Tambahan Pangan (99)",
    "Selulosa bubuk (Powdered cellulose)",
  ],
  [
    1064,
    "Bahan Tambahan Pangan (99)",
    "Metil selulosa (Methyl cellulose)",
  ],
  [
    1065,
    "Bahan Tambahan Pangan (99)",
    "Etil selulosa (Ethyl cellulose)",
  ],
  [
    1066,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil selulosa (Hydroxypropyl cellulose)",
  ],
  [
    1067,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
  ],
  [
    1068,
    "Bahan Tambahan Pangan (99)",
    "Etil metil selulosa (Methyl ethyl cellulose)",
  ],
  [
    1069,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
  ],
  [
    1070,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa hidrolisa enzim (Sodium carboxymethyl cellulose, enzymatically hydrolysed)",
  ],
  [
    1071,
    "Bahan Tambahan Pangan (99)",
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
  ],
  [
    1072,
    "Bahan Tambahan Pangan (99)",
    "Kalium klorida (Potassium chloride)",
  ],
  [
    1073,
    "Bahan Tambahan Pangan (99)",
    "Kalsium klorida (Calcium chloride)",
  ],
  [
    1074,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    1075,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidroksida (Potassium hydroxide)",
  ],
  [1076, "Bahan Tambahan Pangan (99)", "Bromelain (Bromelain)"],
  [
    1077,
    "Bahan Tambahan Pangan (99)",
    "Polidekstrosa (Polydextroses)",
  ],
  [1078, "Bahan Tambahan Pangan (99)", "Dekstrin (Dextrins)"],
  [
    1079,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi asam (Acid treated starch)",
  ],
  [
    1080,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi basa (Alkaline treated starch)",
  ],
  [
    1081,
    "Bahan Tambahan Pangan (99)",
    "Pati pucat (Bleached starch)",
  ],
  [
    1082,
    "Bahan Tambahan Pangan (99)",
    "Pati oksidasi (Oxidized starch)",
  ],
  [
    1083,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi enzim (Enzymed treated starch)",
  ],
  [
    1084,
    "Bahan Tambahan Pangan (99)",
    "Monopati fosfat (Monostarch phosphate)",
  ],
  [
    1085,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat (Distarch phosphate)",
  ],
  [
    1086,
    "Bahan Tambahan Pangan (99)",
    "Fosfat dipati fosfat (Phosphated distarch phosphates)",
  ],
  [
    1087,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
  ],
  [
    1088,
    "Bahan Tambahan Pangan (99)",
    "Pati asetat (Starch acetate)",
  ],
  [
    1089,
    "Bahan Tambahan Pangan (99)",
    "Dipati adipat terasetilasi (Acetylated distarch adipate)",
  ],
  [
    1090,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil pati (Hydroxypropyl starch)",
  ],
  [
    1091,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
  ],
  [
    1092,
    "Bahan Tambahan Pangan (99)",
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
  ],
  [
    1093,
    "Bahan Tambahan Pangan (99)",
    "Asetil pati oksidasi (Acetylated oxidized starch)",
  ],
  [
    1094,
    "Bahan Tambahan Pangan (99)",
    "Natrium kaseinat (Sodium caseinate)",
  ],
  [
    1095,
    "Bahan Tambahan Pangan (99)",
    "Kalsium laktat (Calcium lactate)",
  ],
  [
    1096,
    "Bahan Tambahan Pangan (99)",
    "Trikalsium sitrat (Tricalcium citrate)",
  ],
  [
    1097,
    "Bahan Tambahan Pangan (99)",
    "Kalium klorida (Potassium chloride)",
  ],
  [
    1098,
    "Bahan Tambahan Pangan (99)",
    "Kalsium klorida (Calcium chloride)",
  ],
  [
    1099,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    1100,
    "Bahan Tambahan Pangan (99)",
    "Kalsium glukonat (Calcium gluconate)",
  ],
  [
    1101,
    "Bahan Tambahan Pangan (99)",
    "Asam L-glutamat (L-Glutamic acid)",
  ],
  [
    1102,
    "Bahan Tambahan Pangan (99)",
    "Mononatrium L-glutamate (Monosodium L-glutamate)",
  ],
  [
    1103,
    "Bahan Tambahan Pangan (99)",
    "Monokalium L-glutamate (Monopotassium L-glutamate)",
  ],
  [
    1104,
    "Bahan Tambahan Pangan (99)",
    "Kalsium di-L-glutamat (Calsium di-L-glutamate)",
  ],
  [
    1105,
    "Bahan Tambahan Pangan (99)",
    "Asam 5-guanilat (5-Guanylic acid)",
  ],
  [
    1106,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium 5-guanilat (Disodium 5- guanylate)",
  ],
  [
    1107,
    "Bahan Tambahan Pangan (99)",
    "Dikalium 5-guanilat (Dipotassium 5- guanylate)",
  ],
  [
    1108,
    "Bahan Tambahan Pangan (99)",
    "Kalsium 5-guanilat (Calcium 5- guanylate)",
  ],
  [
    1109,
    "Bahan Tambahan Pangan (99)",
    "Asam 5- inosinat (5-Inosinic acid)",
  ],
  [
    1110,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium 5- inosinat (Disodium 5- inosinate)",
  ],
  [
    1111,
    "Bahan Tambahan Pangan (99)",
    "Dikalium 5-inosinat (Dipotassium 5- inosinate)",
  ],
  [
    1112,
    "Bahan Tambahan Pangan (99)",
    "Kalsium 5- inosinat (Calcium 5- inosinate)",
  ],
  [
    1113,
    "Bahan Tambahan Pangan (99)",
    "Kalsium 5- ribonukleotida (Calcium 5- ribonucleotides)",
  ],
  [
    1114,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium 5- ribonukleotida (Disodium 5- ribonucleotides)",
  ],
  [
    1115,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    1116,
    "Bahan Tambahan Pangan (99)",
    "Asam alginat (Alginic acid)",
  ],
  [
    1117,
    "Bahan Tambahan Pangan (99)",
    "Natrium alginat (Sodium alginate)",
  ],
  [
    1118,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol alginat (Propylene glycol alginate)",
  ],
  [1119, "Bahan Tambahan Pangan (99)", "Agar-agar (Agar)"],
  [1120, "Bahan Tambahan Pangan (99)", "Karagen (Carrageenan)"],
  [1121, "Bahan Tambahan Pangan (99)", "Gom guar (Guar gum)"],
  [
    1122,
    "Bahan Tambahan Pangan (99)",
    "Gom tragakan (Tragacanth gum)",
  ],
  [1123, "Bahan Tambahan Pangan (99)", "Gom arab (Arabic gum)"],
  [1124, "Bahan Tambahan Pangan (99)", "Gom karaya (Karaya gum)"],
  [
    1125,
    "Bahan Tambahan Pangan (99)",
    "Ester gliserol resin kayu (Glycerol ester of wood Rosin)",
  ],
  [
    1126,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    1127,
    "Bahan Tambahan Pangan (99)",
    "Selulosa bubuk (Powdered cellulose)",
  ],
  [
    1128,
    "Bahan Tambahan Pangan (99)",
    "Metil selulosa (Methyl cellulose)",
  ],
  [
    1129,
    "Bahan Tambahan Pangan (99)",
    "Etil selulosa (Ethyl cellulose)",
  ],
  [
    1130,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
  ],
  [
    1131,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
  ],
  [
    1132,
    "Bahan Tambahan Pangan (99)",
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
  ],
  [
    1133,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    1134,
    "Bahan Tambahan Pangan (99)",
    "Polidekstrosa (Polydextroses)",
  ],
  [
    1135,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi asam (Acid treated starch)",
  ],
  [
    1136,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi basa (Alkaline treated starch)",
  ],
  [
    1137,
    "Bahan Tambahan Pangan (99)",
    "Pati pucat (Bleached starch)",
  ],
  [
    1138,
    "Bahan Tambahan Pangan (99)",
    "Pati oksidasi (Oxidized starch)",
  ],
  [
    1139,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi enzim (Enzymed treated starch)",
  ],
  [
    1140,
    "Bahan Tambahan Pangan (99)",
    "Monopati fosfat (Monostarch phosphate)",
  ],
  [
    1141,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat (Distarch phosphate)",
  ],
  [
    1142,
    "Bahan Tambahan Pangan (99)",
    "Fosfat dipati fosfat (Phosphated distarch phosphate)",
  ],
  [
    1143,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
  ],
  [
    1144,
    "Bahan Tambahan Pangan (99)",
    "Dipati adipat terasetilasi (Acetylated distarch adipate)",
  ],
  [
    1145,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil pati (Hydroxypropyl starch)",
  ],
  [
    1146,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
  ],
  [
    1147,
    "Bahan Tambahan Pangan (99)",
    "Kalsium karbonat (Calcium carbonate)",
  ],
  [
    1148,
    "Bahan Tambahan Pangan (99)",
    "Kalsium asetat (Calcium acetate)",
  ],
  [
    1149,
    "Bahan Tambahan Pangan (99)",
    "Asam fumarat (Fumaric acid)",
  ],
  [1150, "Bahan Tambahan Pangan (99)", "Lesitin (Lecithins)"],
  [
    1151,
    "Bahan Tambahan Pangan (99)",
    "Natrium laktat (Sodium lactate)",
  ],
  [
    1152,
    "Bahan Tambahan Pangan (99)",
    "Kalsium laktat (Calcium lactate)",
  ],
  [
    1153,
    "Bahan Tambahan Pangan (99)",
    "Natrium dihidrogen sitrat (Sodium dihydrogen citrate)",
  ],
  [
    1154,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium monohidrogen sitrat (Disodium monohydrogen citrate)",
  ],
  [
    1155,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium sitrat (Trisodium citrate)",
  ],
  [
    1156,
    "Bahan Tambahan Pangan (99)",
    "Kalium dihidrogen sitrat (Potassium dihydrogen citrate)",
  ],
  [
    1157,
    "Bahan Tambahan Pangan (99)",
    "Trikalium sitrat (Tripotassium citrate)",
  ],
  [
    1158,
    "Bahan Tambahan Pangan (99)",
    "Trikalsium sitrat (Tricalcium citrate)",
  ],
  [
    1159,
    "Bahan Tambahan Pangan (99)",
    "Mononatrium fosfat (Monosodium orthophosphate)",
  ],
  [
    1160,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium fosfat (Disodium orthophosphate)",
  ],
  [
    1161,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium fosfat (Trisodium orthophosphate)",
  ],
  [
    1162,
    "Bahan Tambahan Pangan (99)",
    "Monokalium fosfat (Monopotassium orthophosphate)",
  ],
  [
    1163,
    "Bahan Tambahan Pangan (99)",
    "Dikalium fosfat (Dipotassium orthophosphate)",
  ],
  [
    1164,
    "Bahan Tambahan Pangan (99)",
    "Trikalium fosfat (Tripotassium orthophosphate)",
  ],
  [
    1165,
    "Bahan Tambahan Pangan (99)",
    "Kalsium fosfat (Calcium phosphates)",
  ],
  [
    1166,
    "Bahan Tambahan Pangan (99)",
    "Monokalsium fosfat (Monocalcium orthophosphate)",
  ],
  [
    1167,
    "Bahan Tambahan Pangan (99)",
    "Dikalsium fosfat (Dicalcium orthophosphate)",
  ],
  [
    1168,
    "Bahan Tambahan Pangan (99)",
    "Trikalsium fosfat (Tricalcium orthophosphate)",
  ],
  [
    1169,
    "Bahan Tambahan Pangan (99)",
    "Asam adipat (Adipic acid)",
  ],
  [
    1170,
    "Bahan Tambahan Pangan (99)",
    "Asam alginat (Alginic acid)",
  ],
  [
    1171,
    "Bahan Tambahan Pangan (99)",
    "Natrium alginat (Sodium alginate)",
  ],
  [
    1172,
    "Bahan Tambahan Pangan (99)",
    "Kalium alginat (Potassium alginate)",
  ],
  [
    1173,
    "Bahan Tambahan Pangan (99)",
    "Kalsium alginat (Calcium alginate)",
  ],
  [
    1174,
    "Bahan Tambahan Pangan (99)",
    "Propilen glikol alginat (Propylene glycol alginate)",
  ],
  [1175, "Bahan Tambahan Pangan (99)", "Agar-agar (Agar)"],
  [1176, "Bahan Tambahan Pangan (99)", "Karagen (Carrageenan)"],
  [
    1177,
    "Bahan Tambahan Pangan (99)",
    "Rumput laut eucheuma olahan (Processed eucheuma seaweed)",
  ],
  [
    1178,
    "Bahan Tambahan Pangan (99)",
    "Gom kacang lokus (Locust bean gum)",
  ],
  [1179, "Bahan Tambahan Pangan (99)", "Gom guar (Guar gum)"],
  [
    1180,
    "Bahan Tambahan Pangan (99)",
    "Gom tragakan (Tragacanth gum)",
  ],
  [1181, "Bahan Tambahan Pangan (99)", "Gom arab (Arabic gum)"],
  [
    1182,
    "Bahan Tambahan Pangan (99)",
    "Gom xanthan (Xanthan gum)",
  ],
  [1183, "Bahan Tambahan Pangan (99)", "Gom karaya (Karaya gum)"],
  [1184, "Bahan Tambahan Pangan (99)", "Gom tara (Tara gum)"],
  [1185, "Bahan Tambahan Pangan (99)", "Gom gelan (Gellan gum)"],
  [1186, "Bahan Tambahan Pangan (99)", "Gom gatti (Gum ghatti)"],
  [1187, "Bahan Tambahan Pangan (99)", "Gliserol (Glycerol)"],
  [1188, "Bahan Tambahan Pangan (99)", "Gelatin (Edible gelatin)"],
  [1189, "Bahan Tambahan Pangan (99)", "Pektin (Pectins)"],
  [
    1190,
    "Bahan Tambahan Pangan (99)",
    "Ester gliserol resin kayu (Glycerol ester of wood rosin)",
  ],
  [
    1191,
    "Bahan Tambahan Pangan (99)",
    "Dinatrium difosfat (Disodium diphosphate)",
  ],
  [
    1192,
    "Bahan Tambahan Pangan (99)",
    "Trinatrium difosfat (Trisodium diphosphate)",
  ],
  [
    1193,
    "Bahan Tambahan Pangan (99)",
    "Tetranatrium difosfat (Tetrasodium diphosphate)",
  ],
  [
    1194,
    "Bahan Tambahan Pangan (99)",
    "Tetrakalium difosfat (Tetrapotassium diphosphate)",
  ],
  [
    1195,
    "Bahan Tambahan Pangan (99)",
    "Dikalsium difosfat (Dicalcium diphosphate)",
  ],
  [
    1196,
    "Bahan Tambahan Pangan (99)",
    "Natrium tripolifosfat (Sodium Tripolyphosphate)",
  ],
  [
    1197,
    "Bahan Tambahan Pangan (99)",
    "Kalium tripolifosfat (Potassium tripolyphosphate)",
  ],
  [
    1198,
    "Bahan Tambahan Pangan (99)",
    "Natrium polifosfat (Sodium polyphosphate)",
  ],
  [
    1199,
    "Bahan Tambahan Pangan (99)",
    "Kalium polifosfat (Potassium polyphosphate)",
  ],
  [
    1200,
    "Bahan Tambahan Pangan (99)",
    "Natrium kalsium polifosfat (Sodium calcium polyphosphate)",
  ],
  [
    1201,
    "Bahan Tambahan Pangan (99)",
    "Kalsium polifosfat (Calcium polyphosphates)",
  ],
  [
    1202,
    "Bahan Tambahan Pangan (99)",
    "Alfa-Siklodekstrin (alpha-Cyclodextrin)",
  ],
  [
    1203,
    "Bahan Tambahan Pangan (99)",
    "Gama-Siklodekstrin (gamma-Cyclodextrin)",
  ],
  [
    1204,
    "Bahan Tambahan Pangan (99)",
    "Selulosa mikrokristalin (Microcrystalline cellulose)",
  ],
  [
    1205,
    "Bahan Tambahan Pangan (99)",
    "Selulosa bubuk (Powdered cellulose)",
  ],
  [
    1206,
    "Bahan Tambahan Pangan (99)",
    "Metil selulosa (Methyl cellulosa)",
  ],
  [
    1207,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil selulosa (Hydroxypropyl cellulose)",
  ],
  [
    1208,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil metil selulosa (Hydroxypropyl methyl cellulose)",
  ],
  [
    1209,
    "Bahan Tambahan Pangan (99)",
    "Etil metil selulosa (Methyl ethyl cellulose)",
  ],
  [
    1210,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa (Sodium carboxymethyl cellulose)",
  ],
  [
    1211,
    "Bahan Tambahan Pangan (99)",
    "Natrium kroskarmelos (Croscarmellose sodium)",
  ],
  [
    1212,
    "Bahan Tambahan Pangan (99)",
    "Natrium karboksimetil selulosa hidrolisa enzim (Sodium carboxymethyl cellulose, enzymatically hydrolysed)",
  ],
  [
    1213,
    "Bahan Tambahan Pangan (99)",
    "Mono dan digliserida asam lemak (Mono- and di-glycerides of fatty acids)",
  ],
  [
    1214,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan asetat dari gliserol (Acetic and fatty acid esters of glycerol)",
  ],
  [
    1215,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan laktat dari gliserol (Lactic and fatty acid esters of glycerol)",
  ],
  [
    1216,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan sitrat dari gliserol (Citric and fatty acid esters of glycerol)",
  ],
  [
    1217,
    "Bahan Tambahan Pangan (99)",
    "Ester asam lemak dan diasetiltartrat dari gliserol (Diacetyltaric and fatty acid esters of glycerol)",
  ],
  [
    1218,
    "Bahan Tambahan Pangan (99)",
    "Ester poligliserol asam risinoleat terinteresterifikasi (Polyglycerol esters of interesterified ricinoleic acid)",
  ],
  [
    1219,
    "Bahan Tambahan Pangan (99)",
    "Natrium karbonat (Sodium carbonate)",
  ],
  [
    1220,
    "Bahan Tambahan Pangan (99)",
    "Natrium hidrogen karbonat (Sodium hydrogen carbonate)",
  ],
  [
    1221,
    "Bahan Tambahan Pangan (99)",
    "Kalium karbonat (Potassium carbonates)",
  ],
  [
    1222,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidrogen karbonat (Potassium hydrogen carbonate)",
  ],
  [
    1223,
    "Bahan Tambahan Pangan (99)",
    "Amonium karbonat (Ammonium carbonate)",
  ],
  [
    1224,
    "Bahan Tambahan Pangan (99)",
    "Amonium hidrogen karbonat (Ammonium hydrogen carbonate)",
  ],
  [
    1225,
    "Bahan Tambahan Pangan (99)",
    "Kalium klorida (Potassium chloride)",
  ],
  [
    1226,
    "Bahan Tambahan Pangan (99)",
    "Kalsium klorida (Calcium chloride)",
  ],
  [
    1227,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    1228,
    "Bahan Tambahan Pangan (99)",
    "Kalium hidroksida (Potassium hydroxide)",
  ],
  [
    1229,
    "Bahan Tambahan Pangan (99)",
    "Kalsium hidroksida (Calcium hydroxide)",
  ],
  [
    1230,
    "Bahan Tambahan Pangan (99)",
    "Magnesium hidroksida (Magnesium hydroxide)",
  ],
  [1231, "Bahan Tambahan Pangan (99)", "Malam (Beeswax)"],
  [1232, "Bahan Tambahan Pangan (99)", "Papain (Papain)"],
  [1233, "Bahan Tambahan Pangan (99)", "Bromelain (Bromelain)"],
  [
    1234,
    "Bahan Tambahan Pangan (99)",
    "Polidekstrosa (Polydextroses)",
  ],
  [1235, "Bahan Tambahan Pangan (99)", "Dekstrin (Dextrins)"],
  [
    1236,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi asam (Acid treated starch)",
  ],
  [
    1237,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi basa (Alkaline treated starch)",
  ],
  [
    1238,
    "Bahan Tambahan Pangan (99)",
    "Pati pucat (Bleached starch)",
  ],
  [
    1239,
    "Bahan Tambahan Pangan (99)",
    "Pati oksidasi (Oxidized starch)",
  ],
  [
    1240,
    "Bahan Tambahan Pangan (99)",
    "Pati modifikasi enzim (Enzymed treated starch)",
  ],
  [
    1241,
    "Bahan Tambahan Pangan (99)",
    "Monopati fosfat Mono (starch phosphate)",
  ],
  [
    1242,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat (Distarch phosphate)",
  ],
  [
    1243,
    "Bahan Tambahan Pangan (99)",
    "Fosfat dipati fosfat (Phosphate distarch phosphates)",
  ],
  [
    1244,
    "Bahan Tambahan Pangan (99)",
    "Dipati fosfat terasetilasi (Acetylated distrarch phosphate)",
  ],
  [
    1245,
    "Bahan Tambahan Pangan (99)",
    "Pati asetat (Starch acetate)",
  ],
  [
    1246,
    "Bahan Tambahan Pangan (99)",
    "Dipati adipat terasetilasi (Acetylated distarch adipate)",
  ],
  [
    1247,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil pati (Hydroxypropyl starch)",
  ],
  [
    1248,
    "Bahan Tambahan Pangan (99)",
    "Hidroksipropil dipati fosfat (Hydroxypropyl distarch phosphate)",
  ],
  [
    1249,
    "Bahan Tambahan Pangan (99)",
    "Pati natrium oktenilsuksinat (Starch sodium octenyl succinate)",
  ],
  [
    1250,
    "Bahan Tambahan Pangan (99)",
    "Asetil pati oksidasi (Acetylated oxidized starch)",
  ],
  [
    1251,
    "Bahan Tambahan Pangan (99)",
    "Natrium kaseinat (Sodium caseinate)",
  ],
  [
    1252,
    "Bahan Tambahan Pangan (99)",
    "Magnesium karbonat (Magnesium carbonate)",
  ],
  [
    1253,
    "Bahan Tambahan Pangan (99)",
    "Magnesium hidroksida (Magnesium hydroxide)",
  ],
  [
    1254,
    "Bahan Tambahan Pangan (99)",
    "Perisa hasil proses panas (Process flavouring)",
  ],
  [
    1255,
    "Bahan Tambahan Pangan (99)",
    "L-Amonium laktat (L-Ammonium lactate)",
  ],
  [
    1256,
    "Bahan Tambahan Pangan (99)",
    "Natrium stearoil-2-laktilat (Sodium stearoyl-2-lactylate)",
  ],
  [
    1257,
    "Bahan Tambahan Pangan (99)",
    "Amonium klorida (Ammonium chloride)",
  ],
  [
    1258,
    "Bahan Tambahan Pangan (99)",
    "Kalsium sulfat (Calcium sulphate)",
  ],
  [
    1259,
    "Bahan Tambahan Pangan (99)",
    "Kalsium oksida (Calcium oxide)",
  ],
  [
    1260,
    "Bahan Tambahan Pangan (99)",
    "a -Amilase dari Aspergillus oryzae, Var (alpha-Amylase from Aspergillus oryzae, var.)",
  ],
  [
    1261,
    "Bahan Tambahan Pangan (99)",
    "Protease dari Aspergillus oryzae, Var. (Protease from Aspergillus oryzae, var)",
  ],
  [1262, "Bahan Tambahan Pangan (99)", "Papain (Papain)"],
  [1263, "Bahan Tambahan Pangan (99)", "Bromelain (Bromelain)"],
  [
    1264,
    "Bahan Tambahan Pangan (99)",
    "Kurkumin CI. No. 75300 (Curcumin)",
  ],
  [
    1265,
    "Bahan Tambahan Pangan (99)",
    "Riboflavin (sintetik) (Riboflavin, synthetic)",
  ],
  [
    1266,
    "Bahan Tambahan Pangan (99)",
    "Riboflavin 5- natrium fosfat (Riboflavin 5-phosphate sodium)",
  ],
  [
    1267,
    "Bahan Tambahan Pangan (99)",
    "Karmin CI. No. 75470 (Carmines)",
  ],
  [
    1268,
    "Bahan Tambahan Pangan (99)",
    "Ekstrak cochineal No. 75470 (Cochineal extract)",
  ],
  [
    1269,
    "Bahan Tambahan Pangan (99)",
    "Klorofil dan klorofilin tembaga kompleks CI. No. 75810 (Chlorophylls and chlorophyllins, copper complexes)",
  ],
  [
    1270,
    "Bahan Tambahan Pangan (99)",
    "Karamel I (Caramel I - plain)",
  ],
  [
    1271,
    "Bahan Tambahan Pangan (99)",
    "Karamel III amonia proses (Caramel III - ammonia process)",
  ],
  [
    1272,
    "Bahan Tambahan Pangan (99)",
    "Karamel IV amonia sulfit proses (Caramel IV - sulphite ammonia process)",
  ],
  [
    1273,
    "Bahan Tambahan Pangan (99)",
    "Karbon tanaman CI. 77266 (Vegetable carbon)",
  ],
  [
    1274,
    "Bahan Tambahan Pangan (99)",
    "Beta-karoten (sayuran) CI. No. 75130 (Carotenes, beta(vegetable))",
  ],
  [
    1275,
    "Bahan Tambahan Pangan (99)",
    "Ekstrak anato CI. No. 75120 (berbasis bixin) (Annatto extracts, bixin based)",
  ],
  [
    1276,
    "Bahan Tambahan Pangan (99)",
    "Beta-karoten (sintetik) CI. No. 40800 (beta-Carotenes, synthetic)",
  ],
  [
    1277,
    "Bahan Tambahan Pangan (99)",
    "Beta-karoten dari Blakeslea trispora (beta-Carotenes (Blakeslea trispora))",
  ],
  [
    1278,
    "Bahan Tambahan Pangan (99)",
    "Beta-apo-8-karotenal CI. No. 40820 (beta-Apo-8-Carotenal)",
  ],
  [
    1279,
    "Bahan Tambahan Pangan (99)",
    "Etil ester dari beta-apo-8asam karotenoat CI. No. 40825 (beta-apo-8-Carotenoic acid ethyl ester)",
  ],
  [1280, "Bahan Tambahan Pangan (99)", "Merah bit (Beet red)"],
  [
    1281,
    "Bahan Tambahan Pangan (99)",
    "Antosianin (Anthocyanins)",
  ],
  [
    1282,
    "Bahan Tambahan Pangan (99)",
    "Titanium dioksida CI. No. 77891 (Titanium dioxide)",
  ],
  [
    1283,
    "Bahan Tambahan Pangan (99)",
    "Tartrazin CI. No. 19140 (Tartrazine)",
  ],
  [
    1284,
    "Bahan Tambahan Pangan (99)",
    "Kuning kuinolin CI. No. 47005 Quinoline yellow",
  ],
  [
    1285,
    "Bahan Tambahan Pangan (99)",
    "Kuning FCF CI. No. 15985 Sunset yellow FCF",
  ],
  [
    1286,
    "Bahan Tambahan Pangan (99)",
    "Karmoisin CI. No. 14720 (carmoisine)",
  ],
  [
    1287,
    "Bahan Tambahan Pangan (99)",
    "Ponceau 4R CI. No. 16255 (Ponceau 4R)",
  ],
  [
    1288,
    "Bahan Tambahan Pangan (99)",
    "Eritrosin CI. No. 45430 (Erythrosine)",
  ],
  [
    1289,
    "Bahan Tambahan Pangan (99)",
    "Merah allura CI. No. 16035 (Allura red)",
  ],
  [
    1290,
    "Bahan Tambahan Pangan (99)",
    "Indigotin CI. No. 73015 (Indigotine)",
  ],
  [
    1291,
    "Bahan Tambahan Pangan (99)",
    "Biru berlian FCF CI No. 42090 (Brilliant blue FCF)",
  ],
  [
    1292,
    "Bahan Tambahan Pangan (99)",
    "Hijau FCF CI. No. 42053 (Fast green FCF)",
  ],
  [
    1293,
    "Bahan Tambahan Pangan (99)",
    "Coklat HT CI. No. 20285 (Brown HT)",
  ],
  [
    1294,
    "Bahan Tambahan Pangan (99)",
    "Kalsium dinatrium etilen diamin tetra asetat (Calcium disodium ethylene diamine tetra acetate)",
  ],
  [
    1295,
    "Bahan Tambahan Pangan (99)",
    "Isopropil sitrat (Isopropyl citrates)",
  ],
  [
    1296,
    "Bahan Tambahan Pangan (99)",
    "Natrium glukonat (Sodium gluconate)",
  ],
  [
    1297,
    "Bahan Tambahan Pangan (99)",
    "Kalium glukonat (Potassium gluconate)",
  ],
  [1298, "Bahan Tambahan Pangan (99)", "Lutein"],
  [
    1299,
    "Bahan Tambahan Pangan (99)",
    "Hemiselulase dari Aspergillus niger",
  ],
  [
    1300,
    "Bahan Tambahan Pangan (99)",
    "Xylanase dari Aspergillus niger",
  ],
  [1301, "Bahan Tambahan Pangan (99)", "Besi (II) Glukonat"],
  [
    1302,
    "Bahan Tambahan Pangan (99)",
    "Glukosa oksidase dari Aspergillus niger",
  ],
  [
    1303,
    "Bahan Tambahan Pangan (99)",
    "Perisa Artifisial (Artificial flavour)",
  ],
  [
    1304,
    "Bahan Tambahan Pangan (99)",
    "Perisa Identik Alami (Natural Identical Flavour)",
  ],
  [
    1305,
    "Bahan Tambahan Pangan (99)",
    "Perisa Alami (Natural Flavour)",
  ],
  [
    1306,
    "Bahan Tambahan Pangan (99)",
    "Klorofil tembaga kompleks CI. No. 75810 (Chlorophylls, Copper Complexes)",
  ],
  [
    1307,
    "Bahan Tambahan Pangan (99)",
    "Klorofil CI. No. 75810 (Chlorophyll)",
  ],
  [
    1308,
    "Bahan Tambahan Pangan (99)",
    "Amonium Fosfatidat (Ammonium Phosphatide)",
  ],
  [
    1309,
    "Bahan Tambahan Pangan (99)",
    "Natrium Hidrogen Sulfat (Sodium Hydrogen Sulphate)",
  ],
  [
    1310,
    "Bahan Tambahan Pangan (99)",
    "Ekstrak Ragi (Yeast Extract)",
  ],
  [
    1311,
    "Bahan Tambahan Pangan (99)",
    "Minyak Atsiri Paprika (Paprika Oleoresin)",
  ],
  [1312, "Bahan Tambahan Pangan (99)", "Karamel II"],
  [
    1313,
    "Bahan Tambahan Pangan (99)",
    "Karmoisin CI. No. 14720 (Azorubine (carmoisine))",
  ],
  [1314, "Bahan Tambahan Pangan (99)", "Ekstrak Quillaila"],
  [
    1315,
    "Bahan Tambahan Pangan (99)",
    "Xylanase dari Aspergillus niger",
  ],
  [
    1316,
    "Bahan Tambahan Pangan (99)",
    "Trietil sitrat (Triethyl citrate)",
  ],
  [
    1317,
    "Bahan Tambahan Pangan (99)",
    "Ekstrak Luo Han Guo (berasal dari buah Siraitia grosvenorii) atau Monk Fruit Extract",
  ],
  [
    1318,
    "Bahan Tambahan Pangan (99)",
    "Ekstrak Rosemari (Rosemary Extract)",
  ],
  [
    1319,
    "Bahu Babi Curing Matang (08020204)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1320,
    "Bahu Babi Curing Matang (08020204)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1321,
    "Bahu Babi Curing Matang (08020204)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1322,
    "Bahu Babi Curing Matang (08020204)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1323,
    "Bahu Babi Curing Matang (08020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1324,
    "Bahu Babi Curing Matang (08020204)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1325,
    "Bahu Sapi Curing Matang (08020205)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1326,
    "Bahu Sapi Curing Matang (08020205)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1327,
    "Bahu Sapi Curing Matang (08020205)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1328,
    "Bahu Sapi Curing Matang (08020205)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1329,
    "Bahu Sapi Curing Matang (08020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1330,
    "Bahu Sapi Curing Matang (08020205)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [1331, "Bakpao/Pao (07010502)", "Arsen (As) (mg/kg)", "=0.5"],
  [1332, "Bakpao/Pao (07010502)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [1333, "Bakpao/Pao (07010502)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [1334, "Bakpao/Pao (07010502)", "Timah (Sn) (mg/kg)", "=40"],
  [1335, "Bakpao/Pao (07010502)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [1336, "Bakpia (07020210)", "Arsen (As) (mg/kg) ", "=0.5"],
  [1337, "Bakpia (07020210)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [1338, "Bakpia (07020210)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [
    1339,
    "Bakpia (07020210)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1340,
    "Bakpia (07020210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [1341, "Bakpia (07020210)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    1342,
    "Bakso Campur dan Batagor (1675)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1343,
    "Bakso Campur dan Batagor (1675)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1344,
    "Bakso Campur dan Batagor (1675)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1345,
    "Bakso Campur dan Batagor (1675)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1346,
    "Bakso Campur dan Batagor (1675)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1347,
    "Bakso Campur dan Batagor (1675)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [1348, "Bakso Daging (08030211)", "Kadar daging (%)", "", "=45"],
  [
    1349,
    "Bakso Daging (08030211)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1350,
    "Bakso Daging (08030211)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1351,
    "Bakso Daging (08030211)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1352,
    "Bakso Daging (08030211)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1353,
    "Bakso Daging (08030211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1354,
    "Bakso Daging (08030211)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1355,
    "Bakso Daging (08030244)",
    "kandungan daging (%)",
    "",
    "=45",
  ],
  [1356, "Bakso Daging (08030244)", "Kadar protein", "", "=11"],
  [1357, "Bakso Daging (08030244)", "Kadar lemak", "=10"],
  [
    1358,
    "Bakso Daging (08030244)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1359,
    "Bakso Daging (08030244)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1360,
    "Bakso Daging (08030244)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1361,
    "Bakso Daging (08030244)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1362,
    "Bakso Daging (08030244)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1363,
    "Bakso Daging (08030244)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1364,
    "Bakso Daging Kering (08030212)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1365,
    "Bakso Daging Kering (08030212)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1366,
    "Bakso Daging Kering (08030212)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1367,
    "Bakso Daging Kering (08030212)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1368,
    "Bakso Daging Kering (08030212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1369,
    "Bakso Daging Kering (08030212)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1370,
    "Bakso Daging Kombinasi (08030230)",
    "kandungan daging (%)",
    "",
    "=20",
  ],
  [
    1371,
    "Bakso Daging Kombinasi (08030230)",
    "Kadar protein (%)",
    "",
    "=8",
  ],
  [
    1372,
    "Bakso Daging Kombinasi (08030230)",
    "Kadar lemak (%)",
    "=10",
  ],
  [
    1373,
    "Bakso Daging Kombinasi (08030230)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1374,
    "Bakso Daging Kombinasi (08030230)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1375,
    "Bakso Daging Kombinasi (08030230)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1376,
    "Bakso Daging Kombinasi (08030230)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1377,
    "Bakso Daging Kombinasi (08030230)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1378,
    "Bakso Daging Kombinasi (08030230)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1379,
    "Bakso Daging Mentah (08010209)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1380,
    "Bakso Daging Mentah (08010209)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1381,
    "Bakso Daging Mentah (08010209)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1382,
    "Bakso Daging Mentah (08010209)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1383,
    "Bakso Daging Mentah (08010209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1384,
    "Bakso Daging Mentah (08010209)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1385,
    "Bakso Goreng (08030318)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1386,
    "Bakso Goreng (08030318)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1387,
    "Bakso Goreng (08030318)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1388,
    "Bakso Goreng (08030318)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1389,
    "Bakso Goreng (08030318)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1390,
    "Bakso Goreng (08030318)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1391,
    "Bakso Goreng (08030318)",
    "Kandungan daging (%)",
    "",
    "=45",
  ],
  [1392, "Bakso Goreng (08030318)", "Kadar protein (%)", "", "=11"],
  [1393, "Bakso Goreng (08030318)", "Kadar lemak (%)", "=10"],
  [
    1394,
    "Bakso Goreng Kombinasi (08030319)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1395,
    "Bakso Goreng Kombinasi (08030319)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1396,
    "Bakso Goreng Kombinasi (08030319)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1397,
    "Bakso Goreng Kombinasi (08030319)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1398,
    "Bakso Goreng Kombinasi (08030319)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1399,
    "Bakso Goreng Kombinasi (08030319)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1400,
    "Bakso Goreng Kombinasi (08030319)",
    "Kandungan daging (%)",
    "",
    "=20",
  ],
  [
    1401,
    "Bakso Goreng Kombinasi (08030319)",
    "Kadar protein (%)",
    "",
    "=8",
  ],
  [
    1402,
    "Bakso Goreng Kombinasi (08030319)",
    "Kadar lemak (%)",
    "=10",
  ],
  [1403, "Bakso Ikan (0902040107)", "Arsen (As) (mg/kg)", "=0.25"],
  [1404, "Bakso Ikan (0902040107)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [1405, "Bakso Ikan (0902040107)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [1406, "Bakso Ikan (0902040107)", "Timah (Sn) (mg/kg)", "=40"],
  [1407, "Bakso Ikan (0902040107)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    1408,
    "Bakso Ikan (0902040107)",
    "Kandungan lumatan daging ikan atau surimi (%)",
    "",
    "=40",
  ],
  [
    1409,
    "Bakso Ikan Beku (09020133)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    1410,
    "Bakso Ikan Beku (09020133)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    1411,
    "Bakso Ikan Beku (09020133)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    1412,
    "Bakso Ikan Beku (09020133)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    1413,
    "Bakso Ikan Beku (09020133)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    1414,
    "Bakso Ikan Beku (09020133)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1415,
    "Bakso Ikan Beku (09020133)",
    "Kandungan lumatan daging ikan atau surimi (%)",
    "",
    "=40",
  ],
  [
    1416,
    "Bakso Ikan Kering (0902040108)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1417,
    "Bakso Ikan Kering (0902040108)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    1418,
    "Bakso Ikan Kering (0902040108)",
    "Hg (ppm atau mg/kg",
    "=0.5",
  ],
  [
    1419,
    "Bakso Ikan Kering (0902040108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1420,
    "Bakso Ikan Kering (0902040108)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    1421,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Kandungan lumatan daging ikan atau surimi (%) (untuk bakso ikan kering)",
    "=40",
  ],
  [
    1422,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Kandungan lumatan daging moluska/ krustase/ ekinodermata (%) (untuk bakso moluska/ krustase/ ekinodermata kering)",
    "=30",
  ],
  [
    1423,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    1424,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Kadmium (Cd)(mg/kg)",
    "=0.10",
  ],
  [
    1425,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Merkuri (Hg) (mg/kg)",
    "=0.50",
  ],
  [
    1426,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1427,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    1428,
    "Bakso Ikan/Moluska/Krustase/Ekinodermata (Kering) (0902040310)",
    "Timbal (Pb) (mg/kg)",
    "=0.20",
  ],
  [
    1429,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    1430,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    1431,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    1432,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    1433,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    1434,
    "Bakso Udang / Bakso Cumi (0902040205)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1435,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    1436,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    1437,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    1438,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    1439,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    1440,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1441,
    "Bakwan Ikan (Rebus Atau Kukus) (0902040124)",
    "Kandungan daging ikan atau surimi (%)",
    "",
    "=10",
  ],
  [1442, "Bandeng Isi (0902040125)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    1443,
    "Bandeng Isi (0902040125)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    1444,
    "Bandeng Isi (0902040125)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    1445,
    "Bandeng Isi (0902040125)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    1446,
    "Bandeng Isi (0902040125)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [1447, "Bandeng Isi (0902040125)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    1448,
    "Bandeng Presto (0902040105)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1449,
    "Bandeng Presto (0902040105)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    1450,
    "Bandeng Presto (0902040105)",
    "Hg (ppm atau mg/kg",
    "=0.5",
  ],
  [
    1451,
    "Bandeng Presto (0902040105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1452,
    "Bandeng Presto (0902040105)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    1453,
    "Bars Buah (0401020815)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1454,
    "Bars Buah (0401020815)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1455,
    "Bars Buah (0401020815)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1456,
    "Bars Buah (0401020815)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1457,
    "Bars Buah (0401020815)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [1458, "Basilla (12020112)", "Kadar air (%)", "=9"],
  [
    1459,
    "Basilla (12020112)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.3",
  ],
  [
    1460,
    "Basilla (12020112)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1461,
    "Basilla (12020112)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1462,
    "Basilla (12020112)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1463,
    "Basilla (12020112)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    1464,
    "Basilla (12020112)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1465,
    "Bawang Batak/Lokio (12020116)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1466,
    "Bawang Batak/Lokio (12020116)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1467,
    "Bawang Batak/Lokio (12020116)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1468,
    "Bawang Batak/Lokio (12020116)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1469,
    "Bawang Batak/Lokio (12020116)",
    "Timbal (ppm atau mg/kg) ",
    "=1",
  ],
  [
    1470,
    "Bawang Daun (12020117)",
    "Arsen (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    1471,
    "Bawang Daun (12020117)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    1472,
    "Bawang Daun (12020117)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1473,
    "Bawang Daun (12020117)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1474,
    "Bawang Daun (12020117)",
    "Timbal (ppm atau mg/kg) ",
    "=1",
  ],
  [
    1475,
    "Bawang Goreng (12020195)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1476,
    "Bawang Goreng (12020195)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1477,
    "Bawang Goreng (12020195)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1478,
    "Bawang Goreng (12020195)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    1479,
    "Bawang Goreng (12020195)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1480,
    "Bawang Goreng (12020195)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1481,
    "Bawang Goreng (12020195)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [1482, "Bawang Hitam (12020211)", "Kadar Air (%)", "=50"],
  [
    1483,
    "Bawang Hitam (12020211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1484,
    "Bawang Hitam (12020211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1485,
    "Bawang Hitam (12020211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1486,
    "Bawang Hitam (12020211)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1487,
    "Bawang Hitam (12020211)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    1488,
    "Bawang Hitam (12020211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1489,
    "Bawang Merah (Shallot) (12020115)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1490,
    "Bawang Merah (Shallot) (12020115)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1491,
    "Bawang Merah (Shallot) (12020115)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1492,
    "Bawang Merah (Shallot) (12020115)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1493,
    "Bawang Merah (Shallot) (12020115)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    1494,
    "Bawang Merah (Shallot) (12020115)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1495,
    "Bawang Merah (Shallot) (12020115)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1496,
    "Bawang Putih (12020114)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1497,
    "Bawang Putih (12020114)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1498,
    "Bawang Putih (12020114)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1499,
    "Bawang Putih (12020114)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1500,
    "Bawang Putih (12020114)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1501,
    "Bawang Putih (12020114)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    1502,
    "Bawang Putih (12020114)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1503,
    "Bawang Putih (12020114)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [1504, "Bay Leaves (12020113)", "Kadar air (%)", "=7"],
  [
    1505,
    "Bay Leaves (12020113)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    1506,
    "Bay Leaves (12020113)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1507,
    "Bay Leaves (12020113)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1508,
    "Bay Leaves (12020113)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1509,
    "Bay Leaves (12020113)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    1510,
    "Bay Leaves (12020113)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [1511, "Bayam Beku (0402020106)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    1512,
    "Bayam Beku (0402020106)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1513,
    "Bayam Beku (0402020106)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1514,
    "Bayam Beku (0402020106)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1515,
    "Bayam Beku (0402020106)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [1516, "Bayam Beku (0402020106)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [1517, "Beras Diperkaya (060106)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    1518,
    "Beras Diperkaya (060106)",
    "Cadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [1519, "Beras Diperkaya (060106)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    1520,
    "Beras Diperkaya (060106)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1521,
    "Beras Diperkaya (060106)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    1522,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1523,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1524,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1525,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1526,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1527,
    "Berbagai Tipe Produk Pikel Daging Oriental : Daging Pikel Miso (Miso- Zuke), Daging Pikel Koji (Koji-Zuke), dan Daging Pikel Kecap (Shoyu-Zuke). (0802010107)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [1528, "Bergamot (120201A1)", "Arsen (As) (mg/kg)", "=0.15"],
  [1529, "Bergamot (120201A1)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [1530, "Bergamot (120201A1)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    1531,
    "Bergamot (120201A1)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [1532, "Bergamot (120201A1)", "Timbal (Pb) (mg/kg)", "=1"],
  [1533, "Bihun (06040301)", "Kadar air (%)", "=13"],
  [1534, "Bihun (06040301)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    1535,
    "Bihun (06040301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1536,
    "Bihun (06040301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1537,
    "Bihun (06040301)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    1538,
    "Bihun (06040301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1539,
    "Bihun Instan (06040305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    1540,
    "Bihun Instan (06040305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1541,
    "Bihun Instan (06040305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1542,
    "Bihun Instan (06040305)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    1543,
    "Bihun Instan (06040305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [1544, "Bihun Instan (06040305)", "Kadar air (%)", "=13"],
  [1545, "Bihun Lainnya (06040317)", "Kadar air (%)", "=13"],
  [
    1546,
    "Bihun Lainnya (06040317)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    1547,
    "Bihun Lainnya (06040317)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1548,
    "Bihun Lainnya (06040317)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1549,
    "Bihun Lainnya (06040317)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1550,
    "Bihun Lainnya (06040317)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1551,
    "Biji Bunga Matahari (0402020208)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    1552,
    "Biji Bunga Matahari (0402020208)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1553,
    "Biji Bunga Matahari (0402020208)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1554,
    "Biji Bunga Matahari (0402020208)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1555,
    "Biji Bunga Matahari (0402020208)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    1556,
    "Biji Bunga Matahari (0402020208)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    1557,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1558,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1559,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1560,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1561,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    1562,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Merkuri (Hg) (ppm atau mg/kg) (Khusus untuk Kakao Bubuk)",
    "=0.03",
  ],
  [
    1563,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Kadmium (Cd) (ppm atau mg/kg) (Khusus untuk Kakao Bubuk)",
    "=0.85",
  ],
  [
    1564,
    "Biji cokelat yang disangrai atau roasting (05010121)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1565,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1566,
    "Biji Dill (Dill Seed), Adas Manis, Adas Sowa, Adas Cina, Ender (12020128)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1567,
    "Biji Jagung Beku (0402020109)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    1568,
    "Biji Jagung Beku (0402020109)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1569,
    "Biji Jagung Beku (0402020109)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1570,
    "Biji Jagung Beku (0402020109)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1571,
    "Biji Jagung Beku (0402020109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1572,
    "Biji Jagung Beku (0402020109)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    1573,
    "Biji Jagung Beku (0402020109)",
    "Aflatoksin B1 (ppb)",
    "=15",
  ],
  [
    1574,
    "Biji Jagung Beku (0402020109)",
    "Aflatoksin total (ppb)",
    "=20",
  ],
  [
    1575,
    "Biji Kapulaga (12020149)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    1576,
    "Biji Kapulaga (12020149)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1577,
    "Biji Kapulaga (12020149)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1578,
    "Biji Kapulaga (12020149)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1579,
    "Biji Kapulaga (12020149)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1580,
    "Biji Kapulaga (12020149)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    1581,
    "Biji Kapulaga (12020149)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1582,
    "Biji Kapulaga (12020149)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1583,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    1584,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1585,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1586,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1587,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1588,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    1589,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1590,
    "Biji Kapulaga (Cardamom) Amomum (12020152)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1591,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Kadar air (%)",
    "=12",
  ],
  [
    1592,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    1593,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    1594,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1595,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1596,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    1597,
    "Biji Kopi yang Disangrai atau Roasting (14010515)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [1598, "Biji Saga (0402020209)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    1599,
    "Biji Saga (0402020209)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1600,
    "Biji Saga (0402020209)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1601,
    "Biji Saga (0402020209)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1602,
    "Biji Saga (0402020209)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [1603, "Biji Saga (0402020209)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    1604,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1605,
    "Biji Sawi Bubuk atau Biji Mustard Bubuk (12020120)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1606,
    "Biji Sawi/Biji Mustard (12020119)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1607,
    "Biji Sawi/Biji Mustard (12020119)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1608,
    "Biji Selasih (0402020224)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    1609,
    "Biji Selasih (0402020224)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    1610,
    "Biji Selasih (0402020224)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1611,
    "Biji Selasih (0402020224)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1612,
    "Biji Selasih (0402020224)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1613,
    "Biji Selasih (0402020224)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1614,
    "Biji Seledri (12020118)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1615,
    "Biji Seledri (12020118)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [1616, "Biji Wijen (0402020210)", "Kadar air (%)", "=10"],
  [1617, "Biji Wijen (0402020210)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    1618,
    "Biji Wijen (0402020210)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1619,
    "Biji Wijen (0402020210)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1620,
    "Biji Wijen (0402020210)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1621,
    "Biji Wijen (0402020210)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [1622, "Biji Wijen (0402020210)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    1623,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1624,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1625,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1626,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    1627,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1628,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1629,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1630,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (0402020225)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    1631,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1632,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    1633,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1634,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1635,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1636,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    1637,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1638,
    "Biji-bijian dan Kacang-kacangan Lainnya (non serealia) (Roasting, Sangrai, Panggang, dll) (Khusus Registrasi Ulang) (0402020232)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1639,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    1640,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Cadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1641,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1642,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1643,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1644,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    1645,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    1646,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    1647,
    "Biji-Bijian dan Kacang-Kacangan Utuh (Serealia) (060101)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    1648,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    1649,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1650,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1651,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1652,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1653,
    "Biji-Bijian Utuh, Patahan, atau Serpihan, Termasuk Beras dengan Pemanasan dan/atau Penambahan Bahan Lain (060121)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [1654, "Bika Ambon (07020118)", "Arsen (As) (mg/kg)", "=0.5"],
  [1655, "Bika Ambon (07020118)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [1656, "Bika Ambon (07020118)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [1657, "Bika Ambon (07020118)", "Timah (Sn) (mg/kg)", "=40"],
  [1658, "Bika Ambon (07020118)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [1659, "Bir (14020101)", "Kadar etanol (%)", "=8", "=0.5"],
  [
    1660,
    "Bir (14020101)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [1661, "Bir (14020101)", "Arsen (ppm atau mg/L)", "=0.1"],
  [1662, "Bir (14020101)", "Kadmium (ppm atau mg/L)", "=0.2"],
  [1663, "Bir (14020101)", "Merkuri (ppm atau mg/L)", "=0.03"],
  [
    1664,
    "Bir (14020101)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    1665,
    "Bir (14020101)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [1666, "Bir (14020101)", "Timbal (ppm atau mg/L)", "=0.2"],
  [
    1667,
    "Bir Hitam (Stout) (14020102)",
    "Kadar etanol (%)",
    "=8",
    "=2",
  ],
  [
    1668,
    "Bir Hitam (Stout) (14020102)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
  ],
  [
    1669,
    "Bir Hitam (Stout) (14020102)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    1670,
    "Bir Hitam (Stout) (14020102)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    1671,
    "Bir Hitam (Stout) (14020102)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    1672,
    "Bir Hitam (Stout) (14020102)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    1673,
    "Bir Hitam (Stout) (14020102)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    1674,
    "Bir Hitam (Stout) (14020102)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [1675, "Birch Beer (1401040112)", "Kandungan (Brix)", "=14"],
  [
    1676,
    "Birch Beer (1401040112)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1677,
    "Birch Beer (1401040112)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    1678,
    "Birch Beer (1401040112)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    1679,
    "Birch Beer (1401040112)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1680,
    "Birch Beer (1401040112)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1681,
    "Birch Beer (1401040112)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [1682, "Biskuit (07010301)", "Arsen (As) (mg/kg)", "=0.5"],
  [1683, "Biskuit (07010301)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [1684, "Biskuit (07010301)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    1685,
    "Biskuit (07010301)",
    "Timah (Sn) (mg/kg) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [1686, "Biskuit (07010301)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    1687,
    "Biskuit (07010301)",
    "Timah (Sn) (mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [1688, "Biskuit (07020139)", "Kadar air (%) ", "=5"],
  [1689, "Biskuit (07020139)", "Arsen (As) (mg/kg) ", "=0.5"],
  [1690, "Biskuit (07020139)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [1691, "Biskuit (07020139)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [
    1692,
    "Biskuit (07020139)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1693,
    "Biskuit (07020139)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [1694, "Biskuit (07020139)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    1695,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    1696,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    1697,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1698,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    1699,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    1700,
    "Biskuit (Manis) atau Kukis Atau Sweet Crackers (07020107)",
    "Kadar air (%)",
    "=5",
  ],
  [
    1701,
    "Biskuit Bar Sereal Isi (07020130)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    1702,
    "Biskuit Bar Sereal Isi (07020130)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    1703,
    "Biskuit Bar Sereal Isi (07020130)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1704,
    "Biskuit Bar Sereal Isi (07020130)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    1705,
    "Biskuit Bar Sereal Isi (07020130)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [1706, "Biskuit Colek (07020127)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    1707,
    "Biskuit Colek (07020127)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [1708, "Biskuit Colek (07020127)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [1709, "Biskuit Colek (07020127)", "Timah (Sn) (mg/kg)", "=40"],
  [1710, "Biskuit Colek (07020127)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    1711,
    "Biskuit Diet Diabetes (130305)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    1712,
    "Biskuit Diet Diabetes (130305)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    1713,
    "Biskuit Diet Diabetes (130305)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    1714,
    "Biskuit Diet Diabetes (130305)",
    "Sn yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1715,
    "Biskuit Diet Diabetes (130305)",
    "Sn yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    1716,
    "Biskuit Diet Diabetes (130305)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    1717,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    1718,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    1719,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1720,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    1721,
    "Biskuit Lapis/Biskuit Sandwich (07020128)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [1722, "Biskuit Marie (07020108)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    1723,
    "Biskuit Marie (07020108)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [1724, "Biskuit Marie (07020108)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [1725, "Biskuit Marie (07020108)", "Timah (Sn) (mg/kg)", "=40"],
  [1726, "Biskuit Marie (07020108)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [1727, "Biskuit Marie (07020108)", "Kadar air (%)", "=5"],
  [
    1728,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    1729,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    1730,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1731,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    1732,
    "Biskuit Marie Salut / Biskuit Salut (07020109)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    1733,
    "Biskuit non terigu (07020132)",
    "Arsen (As) (mg/kg) ",
    "=0.5",
  ],
  [
    1734,
    "Biskuit non terigu (07020132)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    1735,
    "Biskuit non terigu (07020132)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    1736,
    "Biskuit non terigu (07020132)",
    "Timah (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1737,
    "Biskuit non terigu (07020132)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [1738, "Biskuit non terigu (07020132)", "Kadar air (%) ", "<5"],
  [
    1739,
    "Boerewors (08010202)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    1740,
    "Boerewors (08010202)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    1741,
    "Boerewors (08010202)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    1742,
    "Boerewors (08010202)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1743,
    "Boerewors (08010202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1744,
    "Boerewors (08010202)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [1745, "Bolu Emprit (07020215)", "Arsen (As) (mg/kg) ", "=0.5"],
  [1746, "Bolu Emprit (07020215)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [
    1747,
    "Bolu Emprit (07020215)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    1748,
    "Bolu Emprit (07020215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [1749, "Bolu Emprit (07020215)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [1750, "Bolu Kukus (07010504)", "Arsen (As) (mg/kg)", "=0.5"],
  [1751, "Bolu Kukus (07010504)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [1752, "Bolu Kukus (07010504)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [1753, "Bolu Kukus (07010504)", "Timah (Sn) (mg/kg)", "=40"],
  [1754, "Bolu Kukus (07010504)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [1755, "Bolu Kukus (07020138)", "Arsen (As) (mg/kg) ", "=0.5"],
  [1756, "Bolu Kukus (07020138)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [1757, "Bolu Kukus (07020138)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [1758, "Bolu Kukus (07020138)", "Timah (Sn) (mg/kg)", "=40"],
  [1759, "Bolu Kukus (07020138)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [
    1760,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    1761,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    1762,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1763,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    1764,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1765,
    "Bonbon Cokelat/Permen Isi Cokelat (05010403)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [1766, "Brandy (14020602)", "Kadar etanol (%)", "", "=36"],
  [
    1767,
    "Brandy (14020602)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [1768, "Brandy (14020602)", "Arsen (mg/kg)", "=0.1"],
  [1769, "Brandy (14020602)", "Kadmium (mg/kg)", "=0.2"],
  [1770, "Brandy (14020602)", "Merkuri (mg/kg)", "=0.03"],
  [
    1771,
    "Brandy (14020602)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    1772,
    "Brandy (14020602)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [1773, "Brandy (14020602)", "Timbal (mg/kg)", "=0.2"],
  [
    1774,
    "Brandy (14020602)",
    "Lama proses pematangan dalam tong kayu yang ukurannya tidak lebih dari 1000 L (tahun)",
    "",
    "=1",
  ],
  [1775, "Brandy Buah (14020603)", "Kadar etanol (%)", "", "=36"],
  [
    1776,
    "Brandy Buah (14020603)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [1777, "Brandy Buah (14020603)", "Arsen (mg/kg)", "=0.1"],
  [1778, "Brandy Buah (14020603)", "Kadmium (mg/kg)", "=0.2"],
  [1779, "Brandy Buah (14020603)", "Merkuri (mg/kg)", "=0.03"],
  [
    1780,
    "Brandy Buah (14020603)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    1781,
    "Brandy Buah (14020603)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [1782, "Brandy Buah (14020603)", "Timbal (mg/kg)", "=0.2"],
  [
    1783,
    "Brawn and Head Cheese (08030203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    1784,
    "Brawn and Head Cheese (08030203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1785,
    "Brawn and Head Cheese (08030203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1786,
    "Brawn and Head Cheese (08030203)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1787,
    "Brawn and Head Cheese (08030203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1788,
    "Brawn and Head Cheese (08030203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [1789, "Bread Stick (0701010114)", "Arsen (As) (mg/kg) ", "=0.5"],
  [
    1790,
    "Bread Stick (0701010114)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    1791,
    "Bread Stick (0701010114)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [1792, "Bread Stick (0701010114)", "Timah (Sn) (mg/kg) ", "=40"],
  [
    1793,
    "Bread Stick (0701010114)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [1794, "Brem (060509)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [1795, "Brem (060509)", "Kadmium (Cd) (ppm atau mg/kg)", "=0.05"],
  [1796, "Brem (060509)", "Merkuri (Hg) (ppm atau mg/kg)", "=0.03"],
  [
    1797,
    "Brem (060509)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [1798, "Brem (060509)", "Timbal (Pb) (ppm atau mg/kg)", "=0.25"],
  [
    1799,
    "Brokoli Beku (0402020104)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    1800,
    "Brokoli Beku (0402020104)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1801,
    "Brokoli Beku (0402020104)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1802,
    "Brokoli Beku (0402020104)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1803,
    "Brokoli Beku (0402020104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1804,
    "Brokoli Beku (0402020104)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [1805, "Brownies (07020131)", "Arsen (As) (mg/kg) ", "=0.5"],
  [1806, "Brownies (07020131)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [1807, "Brownies (07020131)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [1808, "Brownies (07020131)", "Timah (Sn) (mg/kg)", "=40"],
  [1809, "Brownies (07020131)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    1810,
    "Brussel Sprout Beku (0402020105)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    1811,
    "Brussel Sprout Beku (0402020105)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    1812,
    "Brussel Sprout Beku (0402020105)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    1813,
    "Brussel Sprout Beku (0402020105)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1814,
    "Brussel Sprout Beku (0402020105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1815,
    "Brussel Sprout Beku (0402020105)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    1816,
    "Buah Asin (0401020301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1817,
    "Buah Asin (0401020301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1818,
    "Buah Asin (0401020301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1819,
    "Buah Asin (0401020301)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1820,
    "Buah Asin (0401020301)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1821,
    "Buah Asin (0401020301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1822,
    "Buah Beku (04010201)",
    "total padatan cairan (buah beku dalam gula kering (%))",
    "=35.00",
    "=18",
  ],
  [
    1823,
    "Buah Beku (04010201)",
    "total padatan cairan (buah beku dalam sirup (%))",
    "=30.00",
    "=15",
  ],
  [
    1824,
    "Buah Beku (0401020101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1825,
    "Buah Beku (0401020101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1826,
    "Buah Beku (0401020101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1827,
    "Buah Beku (0401020101)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1828,
    "Buah Beku (0401020101)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1829,
    "Buah Beku (0401020101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1830,
    "Buah beku dalam gula kering (0401020102)",
    "Total padatan cairan yang diperoleh dari contoh yang dicairkan (thawing) dan dihancurkan yang diukur dengan refraktometer pada suhu 20oC",
    "=35.00",
    "=18",
  ],
  [
    1831,
    "Buah beku dalam gula kering (0401020102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1832,
    "Buah beku dalam gula kering (0401020102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1833,
    "Buah beku dalam gula kering (0401020102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1834,
    "Buah beku dalam gula kering (0401020102)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1835,
    "Buah beku dalam gula kering (0401020102)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1836,
    "Buah beku dalam gula kering (0401020102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1837,
    "Buah beku dalam sirup (0401020103)",
    "Total padatan dari cairan yang diperoleh dari contoh yang dicairkan (thawing) dan dihancurkan yang diukur dengan refraktometer pada suhu 20oC",
    "=30.00",
    "=15",
  ],
  [
    1838,
    "Buah beku dalam sirup (0401020103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1839,
    "Buah beku dalam sirup (0401020103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1840,
    "Buah beku dalam sirup (0401020103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1841,
    "Buah beku dalam sirup (0401020103)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1842,
    "Buah beku dalam sirup (0401020103)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1843,
    "Buah beku dalam sirup (0401020103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1844,
    "Buah Bergula atau Buah Bersalut Gula (0401020701)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1845,
    "Buah Bergula atau Buah Bersalut Gula (0401020701)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1846,
    "Buah Bergula atau Buah Bersalut Gula (0401020701)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1847,
    "Buah Bergula atau Buah Bersalut Gula (0401020701)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1848,
    "Buah Bergula atau Buah Bersalut Gula (0401020701)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1849,
    "Buah Bergula (0401020704)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1850,
    "Buah Bergula (0401020704)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    1851,
    "Buah Bergula (0401020704)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1852,
    "Buah Bergula (0401020704)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1853,
    "Buah Bergula (0401020704)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/Kg)",
    "=40",
  ],
  [
    1854,
    "Buah Bergula (0401020704)",
    "Timbal (Pb) (mg/kg)",
    "=0.20",
  ],
  [
    1855,
    "Buah Berkristal (0401020702)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1856,
    "Buah Berkristal (0401020702)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1857,
    "Buah Berkristal (0401020702)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1858,
    "Buah Berkristal (0401020702)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1859,
    "Buah Berkristal (0401020702)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1860,
    "Buah Bersalut (0401020705)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1861,
    "Buah Bersalut (0401020705)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    1862,
    "Buah Bersalut (0401020705)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1863,
    "Buah Bersalut (0401020705)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1864,
    "Buah Bersalut (0401020705)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    1865,
    "Buah Bersalut (0401020705)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1866,
    "Buah Dalam Kaleng (0401020401)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1867,
    "Buah Dalam Kaleng (0401020401)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1868,
    "Buah Dalam Kaleng (0401020401)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1869,
    "Buah Dalam Kaleng (0401020401)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1870,
    "Buah Dalam Kaleng (0401020401)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1871,
    "Buah Dalam Kaleng (0401020401)",
    "Bobot Tuntas (%)",
    "",
    "=40",
  ],
  [
    1872,
    "Buah Dalam Kaleng (0401020401)",
    "Rongga Kosong (headspace) pada kaleng (% v/v)",
    "=10.00",
  ],
  [
    1873,
    "Buah dalam Kemasan (0401020404)",
    "Bobot tuntas (%)",
    "",
    "=40",
  ],
  [
    1874,
    "Buah dalam Kemasan (0401020404)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1875,
    "Buah dalam Kemasan (0401020404)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1876,
    "Buah dalam Kemasan (0401020404)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1877,
    "Buah dalam Kemasan (0401020404)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1878,
    "Buah dalam Kemasan (0401020404)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1879,
    "Buah dalam Kemasan (0401020404)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1880,
    "Buah Goreng Beku (0401020104)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1881,
    "Buah Goreng Beku (0401020104)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1882,
    "Buah Goreng Beku (0401020104)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1883,
    "Buah Goreng Beku (0401020104)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    1884,
    "Buah Goreng Beku (0401020104)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    1885,
    "Buah Goreng Beku (0401020104)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1886,
    "Buah Kering (0401020201)",
    "Kadar air buah kering yang tidak di sulfurisasi (%)",
    "=20.00",
  ],
  [
    1887,
    "Buah Kering (0401020201)",
    "Kadar air buah kering dengan sulfurisasi (%)",
    "=25.00",
  ],
  [
    1888,
    "Buah Kering (0401020201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1889,
    "Buah Kering (0401020201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1890,
    "Buah Kering (0401020201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1891,
    "Buah Kering (0401020201)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1892,
    "Buah Kering (0401020201)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1893,
    "Buah Kering (0401020201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1894,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1895,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1896,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1897,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1898,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1899,
    "Buah Kering (Freeze Dried) (0401020208)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1900,
    "Buah Kering Asin (0401020203)",
    "Kadar air buah kering yang tidak di sulfurisasi (%)",
    "=20.00",
  ],
  [
    1901,
    "Buah Kering Asin (0401020203)",
    "Kadar air buah kering dengan sulfurisasi (%)",
    "=25.00",
  ],
  [
    1902,
    "Buah Kering Asin (0401020203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1903,
    "Buah Kering Asin (0401020203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1904,
    "Buah Kering Asin (0401020203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1905,
    "Buah Kering Asin (0401020203)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1906,
    "Buah Kering Asin (0401020203)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1907,
    "Buah Kering Asin (0401020203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1908,
    "Buah Kering Campur (0401020202)",
    "Kadar air buah kering yang tidak di sulfurisasi (%)",
    "=20.00",
  ],
  [
    1909,
    "Buah Kering Campur (0401020202)",
    "Kadar air buah kering dengan sulfurisasi (%)",
    "=25.00",
  ],
  [
    1910,
    "Buah Kering Campur (0401020202)",
    "Kandungan buah kering (%)",
    "",
    "=70",
  ],
  [
    1911,
    "Buah Kering Campur (0401020202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1912,
    "Buah Kering Campur (0401020202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1913,
    "Buah Kering Campur (0401020202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1914,
    "Buah Kering Campur (0401020202)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1915,
    "Buah Kering Campur (0401020202)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1916,
    "Buah Kering Campur (0401020202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1917,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1918,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1919,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1920,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    1921,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    1922,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1923,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Kandungan buah kering untuk Buah Kering Campur (%)",
    "",
    "=50",
  ],
  [
    1924,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Kadar air untuk kelapa parut kering (%)",
    "=3",
  ],
  [
    1925,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Kadar air untuk santan bubuk (%)",
    "=5",
  ],
  [
    1926,
    "Buah Kering dengan Penambahan Bahan Lain (0401020207)",
    "Kadar lemak kelapa untuk santan bubuk dihitung setelah rekonstitusi (%)",
    "",
    "=5",
  ],
  [
    1927,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1928,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1929,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1930,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1931,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    1932,
    "Bubuk Agar (Agar-Agar Tepung/Tepung Agar-Agar) (0401020913)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1933,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1934,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1935,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    1936,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    1937,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    1938,
    "Bubuk Asam Jawa/Tamarin (0401020813)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    1939,
    "Bubuk Buttermilk (01050111)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    1940,
    "Bubuk Buttermilk (01050111)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    1941,
    "Bubuk Buttermilk (01050111)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    1942,
    "Bubuk Buttermilk (01050111)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1943,
    "Bubuk Buttermilk (01050111)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    1944,
    "Bubuk Buttermilk (01050111)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    1945,
    "Bubuk Buttermilk (01050111)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    1946,
    "Bubuk Buttermilk (01050204)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    1947,
    "Bubuk Buttermilk (01050204)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    1948,
    "Bubuk Buttermilk (01050204)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1949,
    "Bubuk Buttermilk (01050204)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    1950,
    "Bubuk Buttermilk (01050204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    1951,
    "Bubuk Buttermilk (01050204)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1952,
    "Bubuk Buttermilk (01050204)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    1953,
    "Bubuk Buttermilk (01050204)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    1954,
    "Bubuk Buttermilk (01050204)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1955,
    "Bubuk Buttermilk (01050204)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    1956,
    "Bubuk Buttermilk (01050204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    1957,
    "Bubuk Buttermilk (01050204)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1958,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Kandungan kakao (total cocoa solids) dihitung sebagai berat kering",
    "",
    "=20",
  ],
  [
    1959,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    1960,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    1961,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1962,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    1963,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1964,
    "Bubuk Minuman Cokelat (Drinking Chocolate) (05010115)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    1965,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Kandungan kakao (total cocoa solids) dihitung sebagai berat kering (%)",
    "",
    "=10",
  ],
  [
    1966,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    1967,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    1968,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    1969,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    1970,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1971,
    "Bubuk Minuman Kakao (Drinking Cocoa Mixes) (05010114)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    1972,
    "Bubuk Ngohyang (12020203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    1973,
    "Bubuk Ngohyang (12020203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    1974,
    "Bubuk Ngohyang (12020203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    1975,
    "Bubuk Ngohyang (12020203)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    1976,
    "Bubuk Ngohyang (12020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1977,
    "Bubuk Ngohyang (12020203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    1978,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    1979,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    1980,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1981,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    1982,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    1983,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1984,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Kandungan padatan susu dan atau turunannya (%) ",
    "",
    "=5",
  ],
  [
    1985,
    "Bubuk Puding Butterscotch/Puding Susu (010711)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    1986,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    1987,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    1988,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    1989,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    1990,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    1991,
    "Bubuk Puding Rasa/Berperisa (0401020918)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    1992,
    "Bubuk Whey (01080201)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    1993,
    "Bubuk Whey (01080201)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    1994,
    "Bubuk Whey (01080201)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1995,
    "Bubuk Whey (01080201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    1996,
    "Bubuk Whey (01080201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    1997,
    "Bubuk Whey (01080201)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    1998,
    "Bubuk Whey (01080201)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    1999,
    "Bubuk Whey Permeate (01080203)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    2000,
    "Bubuk Whey Permeate (01080203)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2001,
    "Bubuk Whey Permeate (01080203)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    2002,
    "Bubuk Whey Permeate (01080203)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2003,
    "Bubuk Whey Permeate (01080203)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    2004,
    "Bubuk Whey Permeate (01080203)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    2005,
    "Bubuk Whey Permeate (01080203)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    2006,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    2007,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    2008,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2009,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2010,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2011,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2012,
    "Bubuk Whey yang Telah Didemineralisasi (01080202)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    2013,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2014,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Kadmium (Cd) (mg/kg)",
    "=0.50",
  ],
  [
    2015,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2016,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2017,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2018,
    "Bubuk/Blok/Kubus/Pasta Ekstrak Ayam/Sapi/Udang/Keju (12020221)",
    "Timbal (Pb) (mg/kg)",
    "=1.00",
  ],
  [
    2019,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2020,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2021,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2022,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2023,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2024,
    "Bubur (Pulp) Horseadish (0402020604)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    2025,
    "Bubur (Pulp) Kentang (0402020603)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2026,
    "Bubur (Pulp) Kentang (0402020603)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2027,
    "Bubur (Pulp) Kentang (0402020603)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2028,
    "Bubur (Pulp) Kentang (0402020603)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2029,
    "Bubur (Pulp) Kentang (0402020603)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2030,
    "Bubur (Pulp) Kentang (0402020603)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    2031,
    "Bubur (Pulp) Sayur (0402020616)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2032,
    "Bubur (Pulp) Sayur (0402020616)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    2033,
    "Bubur (Pulp) Sayur (0402020616)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2034,
    "Bubur (Pulp) Sayur (0402020616)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2035,
    "Bubur (Pulp) Sayur (0402020616)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    2036,
    "Bubur (Pulp) Sayur (0402020616)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2037,
    "Bubur (Pulp) Tomat (0402020602)",
    "Bobot Jenis (20 oC)",
    "",
    "=1.05",
  ],
  [
    2038,
    "Bubur (Pulp) Tomat (0402020602)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2039,
    "Bubur (Pulp) Tomat (0402020602)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2040,
    "Bubur (Pulp) Tomat (0402020602)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2041,
    "Bubur (Pulp) Tomat (0402020602)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2042,
    "Bubur (Pulp) Tomat (0402020602)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2043,
    "Bubur (Pulp) Tomat (0402020602)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    2044,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    2045,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2046,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2047,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2048,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2049,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Jika Pasta Tomat : Total Padatan (%)",
    "=25",
  ],
  [
    2050,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Jika Bubur Tomat (Pulp) : Bobot jenis (specific gravity) (20oC)",
    "",
    "=1.05",
  ],
  [
    2051,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Aflatoksin B1 (hanya berlaku jika bahan baku dari kacang tanah) (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    2052,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2053,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kaleng (0402020613)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    2054,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2055,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2056,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2057,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2058,
    "Bubur (Pulp), Saus, dan Pasta Sayur, Kacang, dan Biji-Bijian dalam Kemasan (0402020614)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2059,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Total padatan (%)",
    "",
    "=12",
  ],
  [
    2060,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2061,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2062,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2063,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    2064,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    2065,
    "Bubur Buah (Fruit Pulp) (0401020801)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [2066, "Bubur Cabe (12020123)", "Kandungan cabe (%)", "", "=15"],
  [
    2067,
    "Bubur Cabe (12020123)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2068,
    "Bubur Cabe (12020123)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2069,
    "Bubur Cabe (12020123)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2070,
    "Bubur Cabe (12020123)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2071,
    "Bubur Cabe (12020123)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2072,
    "Bubur Cabe (12020123)",
    "Timah (Sn) (ppm atau mg/kg) yang dikemas dalam kaleng",
    "=250",
  ],
  [
    2073,
    "Bubur Cabe (12020123)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2074,
    "Bubur Cabe (12020123)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [2075, "Bubur Instan (060119)", "Kadar air (%)", "=14"],
  [2076, "Bubur Instan (060119)", "Arsen (As) (mg/kg)", "=0.1"],
  [2077, "Bubur Instan (060119)", "Cadmium (Cd) (mg/kg)", "=0.05"],
  [2078, "Bubur Instan (060119)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    2079,
    "Bubur Instan (060119)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2080,
    "Bubur Instan (060119)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2081, "Bubur Instan (060119)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    2082,
    "Bubur Instan (06040313)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2083,
    "Bubur Instan (06040313)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2084,
    "Bubur Instan (06040313)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2085,
    "Bubur Instan (06040313)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2086,
    "Bubur Instan (06040313)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    2087,
    "Bubur Instan (06040313)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2088,
    "Bubur Jahe (12020139)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2089,
    "Bubur Jahe (12020139)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2090,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2091,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2092,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2093,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Timah pangan olahan yang tidak dikemas dalam kaleng (Sn) (mg/kg)",
    "=40",
  ],
  [
    2094,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2095,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2096,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2097,
    "Bubur Kacang ..... Bubuk / Instan (0402020226)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    2098,
    "Bubur Serealia Instan (06040312)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2099,
    "Bubur Serealia Instan (06040312)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2100,
    "Bubur Serealia Instan (06040312)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2101,
    "Bubur Serealia Instan (06040312)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2102,
    "Bubur Serealia Instan (06040312)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    2103,
    "Bubur Serealia Instan (06040312)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2104,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2105,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2106,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2107,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    2108,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2109,
    "Bubur Siap Saji Dalam Kemasan (06040315)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2110,
    "Bumbu Ekstrak Cumi (12020216)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2111,
    "Bumbu Ekstrak Cumi (12020216)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2112,
    "Bumbu Ekstrak Cumi (12020216)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2113,
    "Bumbu Ekstrak Cumi (12020216)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    2114,
    "Bumbu Ekstrak Cumi (12020216)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2115,
    "Bumbu Ekstrak Cumi (12020216)",
    "Timbal (Pb) (mg/kg)",
    "=1.0",
  ],
  [2116, "Bumbu Ekstrak Cumi (12020216)", "Kadar air (%)", "=4"],
  [
    2117,
    "Bumbu Ekstrak Cumi (12020216)",
    "Kadar cumi (%)",
    "",
    "=15",
  ],
  [
    2118,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Kadar air (%)",
    "=4",
  ],
  [
    2119,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Kadar protein (%)",
    "",
    "=6",
  ],
  [
    2120,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2121,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2122,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2123,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2124,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2125,
    "Bumbu Ekstrak Daging Ayam (12020214)",
    "Timbal (Pb) (mg/kg)",
    "=1.0",
  ],
  [
    2126,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Kadar air (%)",
    "=4",
  ],
  [
    2127,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Kadar Protein (%)",
    "",
    "=6",
  ],
  [
    2128,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2129,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2130,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2131,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2132,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2133,
    "Bumbu Ekstrak Daging Ayam (12050207)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2134,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2135,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Kadmium (Cd) (mg/kg)",
    "=0.50",
  ],
  [
    2136,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2137,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2138,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2139,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Kadar air (%)",
    "=4",
  ],
  [
    2140,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Kadar protein (%)",
    "",
    "=7",
  ],
  [
    2141,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2142,
    "Bumbu Ekstrak Daging Sapi (12020212)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2143,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Kadar air (%)",
    "=4",
  ],
  [
    2144,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Kadar Protein (%)",
    "",
    "=7",
  ],
  [
    2145,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2146,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2147,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2148,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2149,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2150,
    "Bumbu Ekstrak Daging Sapi (12050205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2151,
    "Bumbu Ekstrak Udang (12020215)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2152,
    "Bumbu Ekstrak Udang (12020215)",
    "Kadmium (Cd) (mg/kg)",
    "=0.50",
  ],
  [
    2153,
    "Bumbu Ekstrak Udang (12020215)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2154,
    "Bumbu Ekstrak Udang (12020215)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    2155,
    "Bumbu Ekstrak Udang (12020215)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    2156,
    "Bumbu Ekstrak Udang (12020215)",
    "Timbal (Pb) (mg/kg)",
    "=1.0",
  ],
  [2157, "Bumbu Ekstrak Udang (12020215)", "Kadar air (%)", "=4"],
  [
    2158,
    "Bumbu Ekstrak Udang (12020215)",
    "Kadar udang (%)",
    "",
    "=15",
  ],
  [2159, "Bumbu Kacang (12060227)", "Arsen (As) (mg/kg)", "=0.15"],
  [2160, "Bumbu Kacang (12060227)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [2161, "Bumbu Kacang (12060227)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [2162, "Bumbu Kacang (12060227)", "Timah (Sn) (mg/kg)", "=40"],
  [2163, "Bumbu Kacang (12060227)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2164,
    "Bumbu Kacang (12060227)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2165,
    "Bumbu Kacang (12060227)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    2166,
    "Bumbu Kacang (12060227)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    2167,
    "Bumbu Lainnya (Basah) (12050210)",
    "Arsen (mg/kg)",
    "=0.15",
  ],
  [
    2168,
    "Bumbu Lainnya (Basah) (12050210)",
    "Kadmium (mg/kg)",
    "=0.5",
  ],
  [
    2169,
    "Bumbu Lainnya (Basah) (12050210)",
    "Merkuri (mg/kg)",
    "=0.05",
  ],
  [
    2170,
    "Bumbu Lainnya (Basah) (12050210)",
    "Timah (mg/kg)",
    "=40",
  ],
  [
    2171,
    "Bumbu Lainnya (Basah) (12050210)",
    "Timbal (mg/kg)",
    "=1",
  ],
  [
    2172,
    "Bumbu Lainnya (Kering) (12050211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2173,
    "Bumbu Lainnya (Kering) (12050211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2174,
    "Bumbu Lainnya (Kering) (12050211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2175,
    "Bumbu Lainnya (Kering) (12050211)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2176,
    "Bumbu Lainnya (Kering) (12050211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2177,
    "Bumbu Lainnya (Kering) (12050211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2178,
    "Bumbu Mi Instan (12020208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2179,
    "Bumbu Mi Instan (12020208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2180,
    "Bumbu Mi Instan (12020208)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2181,
    "Bumbu Mi Instan (12020208)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2182,
    "Bumbu Mi Instan (12020208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2183,
    "Bumbu Mi Instan (12020208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2184,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2185,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2186,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2187,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2188,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2189,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2190,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12020217)",
    "Kadar air (%)",
    "=12.5",
  ],
  [
    2191,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Kadar Air (%)",
    "=12.5",
  ],
  [
    2192,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2193,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2194,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2195,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Timah (Sn) Pangan olahan yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2196,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    2197,
    "Bumbu Pasta Ekstrak Daging (Misalnya Bumbu Pasta Ekstrak Daging Sapi dan Daging Ayam) (12050209)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2198,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2199,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2200,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2201,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2202,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2203,
    "Bumbu Penguat Rasa dan Garam (12050212)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2204,
    "Bumbu Rasa Ayam (12020220)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2205,
    "Bumbu Rasa Ayam (12020220)",
    "Kadmium (Cd) (mg/kg)",
    "=0.50",
  ],
  [
    2206,
    "Bumbu Rasa Ayam (12020220)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2207,
    "Bumbu Rasa Ayam (12020220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2208,
    "Bumbu Rasa Ayam (12020220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    2209,
    "Bumbu Rasa Ayam (12020220)",
    "Timbal (Pb) (mg/kg)",
    "=1.00",
  ],
  [
    2210,
    "Bumbu Rasa Ayam (12050208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2211,
    "Bumbu Rasa Ayam (12050208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2212,
    "Bumbu Rasa Ayam (12050208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2213,
    "Bumbu Rasa Ayam (12050208)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2214,
    "Bumbu Rasa Ayam (12050208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2215,
    "Bumbu Rasa Ayam (12050208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2216,
    "Bumbu Rasa Ikan (12020218)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2217,
    "Bumbu Rasa Ikan (12020218)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2218,
    "Bumbu Rasa Ikan (12020218)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2219,
    "Bumbu Rasa Ikan (12020218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2220,
    "Bumbu Rasa Ikan (12020218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2221,
    "Bumbu Rasa Ikan (12020218)",
    "Timbal (Pb) (mg/kg)",
    "=1.00",
  ],
  [
    2222,
    "Bumbu Rasa Ikan (12050215)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2223,
    "Bumbu Rasa Ikan (12050215)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2224,
    "Bumbu Rasa Ikan (12050215)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2225,
    "Bumbu Rasa Ikan (12050215)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2226,
    "Bumbu Rasa Ikan (12050215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2227, "Bumbu Rasa Ikan (12050215)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2228,
    "Bumbu Rasa Sapi (12020213)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2229,
    "Bumbu Rasa Sapi (12020213)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2230,
    "Bumbu Rasa Sapi (12020213)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2231,
    "Bumbu Rasa Sapi (12020213)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2232,
    "Bumbu Rasa Sapi (12020213)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [2233, "Bumbu Rasa Sapi (12020213)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2234,
    "Bumbu Rasa Sapi (12050206)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2235,
    "Bumbu Rasa Sapi (12050206)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2236,
    "Bumbu Rasa Sapi (12050206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2237,
    "Bumbu Rasa Sapi (12050206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2238,
    "Bumbu Rasa Sapi (12050206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2239,
    "Bumbu Rasa Sapi (12050206)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2240,
    "Bumbu Rasa Udang (12020219)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2241,
    "Bumbu Rasa Udang (12020219)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2242,
    "Bumbu Rasa Udang (12020219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2243,
    "Bumbu Rasa Udang (12020219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2244,
    "Bumbu Rasa Udang (12020219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2245,
    "Bumbu Rasa Udang (12020219)",
    "Timbal (Pb) (mg/kg)",
    "=1.00",
  ],
  [
    2246,
    "Bumbu Rasa Udang (12050216)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2247,
    "Bumbu Rasa Udang (12050216)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2248,
    "Bumbu Rasa Udang (12050216)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2249,
    "Bumbu Rasa Udang (12050216)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2250,
    "Bumbu Rasa Udang (12050216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2251,
    "Bumbu Rasa Udang (12050216)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2252,
    "Bumbu Siap Pakai (12020205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2253,
    "Bumbu Siap Pakai (12020205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2254,
    "Bumbu Siap Pakai (12020205)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2255,
    "Bumbu Siap Pakai (12020205)",
    "Timah (Sn) pangan olahan dalam kemasan kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2256,
    "Bumbu Siap Pakai (12020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2257,
    "Bumbu Siap Pakai (12020205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2258,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2259,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2260,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2261,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Timah (Sn) pangan olahan dalam kemasan kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2262,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2263,
    "Bumbu Siap Pakai (Steril) (12020209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [2264, "Bun Kukus (07010505)", "Arsen (As) (mg/kg)", "=0.5"],
  [2265, "Bun Kukus (07010505)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [2266, "Bun Kukus (07010505)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [2267, "Bun Kukus (07010505)", "Timah (Sn) (mg/kg)", "=40"],
  [2268, "Bun Kukus (07010505)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    2269,
    "Buncis Beku (0402020102)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    2270,
    "Buncis Beku (0402020102)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    2271,
    "Buncis Beku (0402020102)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    2272,
    "Buncis Beku (0402020102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2273,
    "Buncis Beku (0402020102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2274,
    "Buncis Beku (0402020102)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    2275,
    "Buncis Dalam Kemasan (0402020409)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2276,
    "Buncis Dalam Kemasan (0402020409)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2277,
    "Buncis Dalam Kemasan (0402020409)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2278,
    "Buncis Dalam Kemasan (0402020409)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2279,
    "Buncis Dalam Kemasan (0402020409)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    2280,
    "Burger Daging (08030320)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2281,
    "Burger Daging (08030320)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2282,
    "Burger Daging (08030320)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2283,
    "Burger Daging (08030320)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2284,
    "Burger Daging (08030320)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2285,
    "Burger Daging (08030320)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [2286, "Burger Ikan (0902040130)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    2287,
    "Burger Ikan (0902040130)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    2288,
    "Burger Ikan (0902040130)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    2289,
    "Burger Ikan (0902040130)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2290,
    "Burger Ikan (0902040130)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [2291, "Burger Ikan (0902040130)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    2292,
    "Burger Ikan (0902040130)",
    "Kandungan lumatan daging ikan (%)",
    "",
    "=30",
  ],
  [
    2293,
    "Buttermilk (Plain) (0101010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2294,
    "Buttermilk (Plain) (0101010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    2295,
    "Buttermilk (Plain) (0101010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2296,
    "Buttermilk (Plain) (0101010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    2297,
    "Buttermilk (Plain) (0101010201)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    2298,
    "Buttermilk (Plain) (0101010201)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    2299,
    "Buttermilk (Plain) (0101010201)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    2300,
    "Buttermilk cair (01010301)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    2301,
    "Buttermilk cair (01010301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2302,
    "Buttermilk cair (01010301)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    2303,
    "Buttermilk cair (01010301)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    2304,
    "Buttermilk cair (01010301)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    2305,
    "Buttermilk cair (01010301)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    2306,
    "Buttermilk cair (01010301)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [2307, "Butterscotch (05020204)", "Arsen (As) (mg/kg)", "=1"],
  [2308, "Butterscotch (05020204)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [2309, "Butterscotch (05020204)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    2310,
    "Butterscotch (05020204)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2311,
    "Butterscotch (05020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2312, "Butterscotch (05020204)", "Timbal (Pb) (mg/kg)", "=1"],
  [2313, "Cabe Bubuk (12020124)", "Kadar air (%)", "=12"],
  [
    2314,
    "Cabe Bubuk (12020124)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2315,
    "Cabe Bubuk (12020124)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2316,
    "Cabe Bubuk (12020124)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2317,
    "Cabe Bubuk (12020124)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2318,
    "Cabe Bubuk (12020124)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2319,
    "Cabe Bubuk (12020124)",
    "Timah (Sn) (ppm atau mg/kg) yang dikemas dalam kaleng",
    "=250",
  ],
  [
    2320,
    "Cabe Bubuk (12020124)",
    "Aflatoksin B1 (ppb atau mcg/kg",
    "=15",
  ],
  [
    2321,
    "Cabe Bubuk (12020124)",
    "Aflatoksin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    2322,
    "Cabe Jawa (12020121)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2323,
    "Cabe Jawa (12020121)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2324,
    "Cabe Kering (0402020202)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    2325,
    "Cabe Kering (0402020202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    2326,
    "Cabe Kering (0402020202)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    2327,
    "Cabe Kering (0402020202)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2328,
    "Cabe Kering (0402020202)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    2329,
    "Cabe Kering (0402020202)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    2330,
    "Cabe Merah Segar (12020122)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2331,
    "Cabe Merah Segar (12020122)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2332,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2333,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2334,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2335,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2336,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2337,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2338,
    "Campuran kakao-gula (cocoa-sugar mixtures) (05010117)",
    "Kadar Air (%)",
    "=5",
  ],
  [
    2339,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2340,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2341,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2342,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2343,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2344,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2345,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Kadar lemak makan (%)",
    "",
    "=80",
  ],
  [
    2346,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020103)",
    "Kadar Air (%)",
    "=18",
  ],
  [
    2347,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Kadar lemak (%)",
    "",
    "=80",
  ],
  [
    2348,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Kadar air (%)",
    "=18",
  ],
  [
    2349,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2350,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2351,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2352,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2353,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2354,
    "Campuran Margarin dan Mentega (Blends of butter and margarine) (02020206)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2355,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Kandungan lemak makan (%) ",
    "",
    "=80",
  ],
  [
    2356,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Kadar air (%) ",
    "=18",
  ],
  [
    2357,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Vitamin A yang ditambahkan (IU/100 g)",
    "=3500",
    "=2500",
  ],
  [
    2358,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Vitamin D yang ditambahkan (IU/100 g)",
    "=350",
    "=250",
  ],
  [
    2359,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2360,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2361,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2362,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2363,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2364,
    "Campuran Margarin Meja dan Mentega (02020208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2365,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    2366,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    2367,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    2368,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2369,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    2370,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    2371,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Kadar Lemak Susu (%)",
    "",
    "=26",
  ],
  [
    2372,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Kadar Air (%)",
    "=5",
  ],
  [
    2373,
    "Campuran Susu dan Krim Bubuk (Plain) (01050110)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    2374,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    2375,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    2376,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2377,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    2378,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    2379,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2380,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "aflatoksin M1 (mcg/kg)/ ppb",
    "=5",
  ],
  [
    2381,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "kadar lemak susu (%)",
    "",
    "=26",
  ],
  [
    2382,
    "Campuran Susu dan Krim Bubuk (Plain) (01050201)",
    "kadar air (%)",
    "=5",
  ],
  [
    2383,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    2384,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2385,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    2386,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2387,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    2388,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    2389,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01010414)",
    "Aflatoksin M1 (ppb atau mcg/Kg)",
    "=0.50",
  ],
  [
    2390,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    2391,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    2392,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2393,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    2394,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    2395,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    2396,
    "Campuran Susu dan Krim Bubuk Berperisa atau (dengan) Rasa (01050202)",
    "aflatoksin M1 (mcg/kg)/ ppb",
    "=5",
  ],
  [
    2397,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2398,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2399,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2400,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    2401,
    "Campuran Untuk Saus, Gravies, dan Dressing (120603)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2402, "Carob Coatings (05010504)", "Arsen (As) (mg/kg)", "=1"],
  [
    2403,
    "Carob Coatings (05010504)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2404,
    "Carob Coatings (05010504)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2405,
    "Carob Coatings (05010504)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2406,
    "Carob Coatings (05010504)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2407, "Carob Coatings (05010504)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2408,
    "Cengkeh (12020126)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2409,
    "Cengkeh (12020126)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [2410, "Cengkeh Bubuk (12020127)", "Kadar air (%)", "=12"],
  [
    2411,
    "Cengkeh Bubuk (12020127)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=15",
  ],
  [
    2412,
    "Cengkeh Bubuk (12020127)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2413,
    "Cengkeh Bubuk (12020127)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2414,
    "Cengkeh Bubuk (12020127)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2415,
    "Cengkeh Bubuk (12020127)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2416,
    "Cengkeh Bubuk (12020127)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2417,
    "Cengkeh Bubuk (12020127)",
    "Timah (Sn) (ppm atau mg/kg) pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng ",
    "=250",
  ],
  [
    2418,
    "Cengkeh Bubuk (12020127)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    2419,
    "Cengkeh Bubuk (12020127)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    2420,
    "Chesnut Dalam Kaleng (0402020412)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    2421,
    "Chesnut Dalam Kaleng (0402020412)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    2422,
    "Chesnut Dalam Kaleng (0402020412)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    2423,
    "Chesnut Dalam Kaleng (0402020412)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2424,
    "Chesnut Dalam Kaleng (0402020412)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [2425, "Chesnut Dalam Kaleng (0402020412)", "Bobot Tuntas (%)"],
  [
    2426,
    "Chicken Strip Beku (08020307)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2427,
    "Chicken Strip Beku (08020307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2428,
    "Chicken Strip Beku (08020307)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2429,
    "Chicken Strip Beku (08020307)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2430,
    "Chicken Strip Beku (08020307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2431,
    "Chicken Strip Beku (08020307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [2432, "Chorizos (0803010302)", "As (mg/kg)", "=0.25"],
  [2433, "Chorizos (0803010302)", "Cd (mg/kg)", "=0.05"],
  [2434, "Chorizos (0803010302)", "Hg (mg/kg)", "=0.03"],
  [
    2435,
    "Chorizos (0803010302)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2436,
    "Chorizos (0803010302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2437, "Chorizos (0803010302)", "Pb (mg/kg) ", "=0.5"],
  [
    2438,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Total padatan terlarut (%)",
    "=50.00",
  ],
  [
    2439,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2440,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2441,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2442,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    2443,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    2444,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    2445,
    "Chutney Mangga (Mango Chutney) (0401020601)",
    "Kandungan buah mangga (%)",
    "",
    "=40",
  ],
  [
    2446,
    "Cider atau Anggur Apel (14020201)",
    "Kadar etanol (%)",
    "=8.5",
  ],
  [
    2447,
    "Cider atau Anggur Apel (14020201)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    2448,
    "Cider atau Anggur Apel (14020201)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    2449,
    "Cider atau Anggur Apel (14020201)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    2450,
    "Cider atau Anggur Apel (14020201)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    2451,
    "Cider atau Anggur Apel (14020201)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    2452,
    "Cider atau Anggur Apel (14020201)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    2453,
    "Cider atau Anggur Apel (14020201)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [
    2454,
    "Cincau Hijau (0401020905)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    2455,
    "Cincau Hijau (0401020905)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    2456,
    "Cincau Hijau (0401020905)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    2457,
    "Cincau Hijau (0401020905)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2458,
    "Cincau Hijau (0401020905)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2459,
    "Cincau Hijau (0401020905)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    2460,
    "Cincau Hitam (0401020906)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    2461,
    "Cincau Hitam (0401020906)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    2462,
    "Cincau Hitam (0401020906)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    2463,
    "Cincau Hitam (0401020906)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2464,
    "Cincau Hitam (0401020906)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2465,
    "Cincau Hitam (0401020906)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    2466,
    "Cireng Seafood (0902040306)",
    "Arsen (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2467,
    "Cireng Seafood (0902040306)",
    "Kadmium (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2468,
    "Cireng Seafood (0902040306)",
    "Merkuri (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2469,
    "Cireng Seafood (0902040306)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2470,
    "Cireng Seafood (0902040306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2471,
    "Cireng Seafood (0902040306)",
    "Timbal (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    2472,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [2473, "Coating) (05010505)", "Arsen (As) (mg/kg)", "=1"],
  [
    2474,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [2475, "Coating) (05010505)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    2476,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [2477, "Coating) (05010505)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    2478,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [
    2479,
    "Coating) (05010505)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2480,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [
    2481,
    "Coating) (05010505)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2482,
    "Coating Dari Lembaga Gandum Bebas Lemak (Deffated Wheat Germ",
  ],
  [2483, "Coating) (05010505)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2484,
    "Cocoa Butter Equivalent (05010501)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2485,
    "Cocoa Butter Equivalent (05010501)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2486,
    "Cocoa Butter Equivalent (05010501)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2487,
    "Cocoa Butter Equivalent (05010501)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2488,
    "Cocoa Butter Equivalent (05010501)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2489,
    "Cocoa Butter Equivalent (05010501)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2490, "Cognac (14020604)", "Kadar etanol (% v/v)", "", "=40"],
  [
    2491,
    "Cognac (14020604)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [2492, "Cognac (14020604)", "Arsen (mg/kg)", "=0.1"],
  [2493, "Cognac (14020604)", "Kadmium (mg/kg)", "=0.2"],
  [2494, "Cognac (14020604)", "Merkuri (mg/kg)", "=0.03"],
  [
    2495,
    "Cognac (14020604)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    2496,
    "Cognac (14020604)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2497, "Cognac (14020604)", "Timbal (mg/kg)", "=0.2"],
  [2498, "Cokelat (05010401)", "Arsen (As) (mg/kg)", "=1"],
  [2499, "Cokelat (05010401)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [2500, "Cokelat (05010401)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    2501,
    "Cokelat (05010401)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2502,
    "Cokelat (05010401)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2503, "Cokelat (05010401)", "Timbal (Pb) (mg/kg)", "=1"],
  [2504, "Cokelat Aerasi (05010420)", "Arsen (As) (mg/kg)", "=1"],
  [
    2505,
    "Cokelat Aerasi (05010420)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2506,
    "Cokelat Aerasi (05010420)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2507,
    "Cokelat Aerasi (05010420)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2508,
    "Cokelat Aerasi (05010420)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2509, "Cokelat Aerasi (05010420)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2510,
    "Cokelat Berperisa (05010419)",
    "Kopi cokelat mengandung bubuk kopi sangrai (%)",
    "",
    "=1.5",
  ],
  [
    2511,
    "Cokelat Berperisa (05010419)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2512,
    "Cokelat Berperisa (05010419)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2513,
    "Cokelat Berperisa (05010419)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2514,
    "Cokelat Berperisa (05010419)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2515,
    "Cokelat Berperisa (05010419)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2516,
    "Cokelat Berperisa (05010419)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2517, "Cokelat Bubuk (05010119)", "Arsen (As) (mg/kg)", "=1"],
  [
    2518,
    "Cokelat Bubuk (05010119)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2519,
    "Cokelat Bubuk (05010119)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2520,
    "Cokelat Bubuk (05010119)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2521,
    "Cokelat Bubuk (05010119)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2522, "Cokelat Bubuk (05010119)", "Kakao bubuk (%)", "", "=32"],
  [2523, "Cokelat Bubuk (05010119)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2524,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2525,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2526,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2527,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2528,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2529,
    "Cokelat Compound Butir/Cokelat Paduan Butir (05010506)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2530,
    "Cokelat Drop atau Chip (05010407)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2531,
    "Cokelat Drop atau Chip (05010407)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2532,
    "Cokelat Drop atau Chip (05010407)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2533,
    "Cokelat Drop atau Chip (05010407)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2534,
    "Cokelat Drop atau Chip (05010407)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2535,
    "Cokelat Drop atau Chip (05010407)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2536,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2537,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2538,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2539,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2540,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2541,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2542,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Padatan kakao (%)",
    "",
    "=35",
  ],
  [
    2543,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Lemak kakao (%)",
    "",
    "=18",
  ],
  [
    2544,
    "Cokelat Hitam (dark chocolate, semisweet chocolate, bittersweet chocolate) / Cokelat Hitam Isi ... (05010423)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=14",
  ],
  [
    2545,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Padatan kakao (%)",
    "",
    "=35",
  ],
  [
    2546,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Lemak kakao (%)",
    "",
    "=31",
  ],
  [
    2547,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=2.5",
  ],
  [
    2548,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2549,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2550,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2551,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2552,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2553,
    "Cokelat Hitam Kovertur (Dark Chocolate Couverture) / Cokelat Hitam Kovertur Isi ... (05010425)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2554,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Padatan kakao (%)",
    "",
    "=30",
  ],
  [
    2555,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Lemak kakao (%)",
    "",
    "=18",
  ],
  [
    2556,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=12",
  ],
  [
    2557,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2558,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2559,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2560,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2561,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2562,
    "Cokelat Hitam Manis (Sweet Chocolate) / Cokelat Hitam Manis Isi ... (05010424)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2563, "Cokelat Imitasi (05010510)", "Arsen (As) (mg/kg)", "=1"],
  [
    2564,
    "Cokelat Imitasi (05010510)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2565,
    "Cokelat Imitasi (05010510)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2566,
    "Cokelat Imitasi (05010510)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2567,
    "Cokelat Imitasi (05010510)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2568, "Cokelat Imitasi (05010510)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2569,
    "Cokelat Instan (05010112)",
    "Kandungan lemak kakao (%)",
    "=8",
  ],
  [2570, "Cokelat Instan (05010112)", "Kadar air (%)", "=5"],
  [2571, "Cokelat Instan (05010112)", "Arsen (As) (mg/kg)", "=1"],
  [
    2572,
    "Cokelat Instan (05010112)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2573,
    "Cokelat Instan (05010112)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2574,
    "Cokelat Instan (05010112)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    2575,
    "Cokelat Instan (05010112)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2576, "Cokelat Instan (05010112)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2577,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Komponen cokelat untuk pelapisan dari berat total produk akhir (%)",
    "",
    "=40",
  ],
  [
    2578,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2579,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2580,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2581,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2582,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2583,
    "Cokelat Isi (Filled Chocolate) (05010413)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2584,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2585,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2586,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2587,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2588,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2589,
    "Cokelat Isi (Filled Chocolate) (05010431)",
    "Komponen cokelat untuk pelapisan (%)",
    "",
    "=25",
  ],
  [
    2590,
    "Cokelat Komposit (05010422)",
    "Kandungan cokelat (%)",
    "",
    "=60",
  ],
  [2591, "Cokelat Komposit (05010422)", "Arsen (As) (mg/kg)", "=1"],
  [
    2592,
    "Cokelat Komposit (05010422)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2593,
    "Cokelat Komposit (05010422)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2594,
    "Cokelat Komposit (05010422)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2595,
    "Cokelat Komposit (05010422)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2596,
    "Cokelat Komposit (05010422)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2597, "Cokelat Krim (05010409)", "Arsen (As) (mg/kg)", "=1"],
  [2598, "Cokelat Krim (05010409)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    2599,
    "Cokelat Krim (05010409)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2600,
    "Cokelat Krim (05010409)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2601,
    "Cokelat Krim (05010409)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2602, "Cokelat Krim (05010409)", "Timbal (Pb) (mg/kg)", "=1"],
  [2603, "Cokelat Laminasi (05010421)", "Arsen (As) (mg/kg)", "=1"],
  [
    2604,
    "Cokelat Laminasi (05010421)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2605,
    "Cokelat Laminasi (05010421)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2606,
    "Cokelat Laminasi (05010421)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2607,
    "Cokelat Laminasi (05010421)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2608,
    "Cokelat Laminasi (05010421)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2609,
    "Cokelat Manis (05010410)",
    "Kadar cokelat liquor (%)",
    "",
    "=15",
  ],
  [2610, "Cokelat Manis (05010410)", "Arsen (As) (mg/kg)", "=1"],
  [
    2611,
    "Cokelat Manis (05010410)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2612,
    "Cokelat Manis (05010410)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2613,
    "Cokelat Manis (05010410)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2614,
    "Cokelat Manis (05010410)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2615, "Cokelat Manis (05010410)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2616,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Padatan kakao (dihitung dari basis berat kering) (%)",
    "",
    "=13",
  ],
  [
    2617,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2618,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2619,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2620,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2621,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2622,
    "Cokelat Paduan / Cokelat Compound Hitam (dark compound chocolate) / Cokelat Compound Hitam Isi ... (05010511)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2623,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Padatan kakao (dihitung dari basis berat kering) (%)",
    "",
    "=7",
  ],
  [
    2624,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2625,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2626,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2627,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2628,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2629,
    "Cokelat Paduan / Cokelat Compound Hitam Manis (Sweet Dark Compound Chocolate) / Cokelat Compound Hitam Manis Isi ... (05010512)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2630,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Padatan susu (%) (dihitung dari basis berat kering)",
    "",
    "=14",
  ],
  [
    2631,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2632,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2633,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2634,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2635,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2636,
    "Cokelat Paduan / Cokelat Compound Putih (White Compound Chocolate) / Cokelat Compound Putih Isi ... (05010515)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2637,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Padatan susu (%) (dihitung dari basis berat kering)",
    "",
    "=5",
  ],
  [
    2638,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2639,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2640,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2641,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2642,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2643,
    "Cokelat Paduan / Cokelat Compound Putih Manis (Sweet White Compound Chocolate) / Cokelat Compound Putih Manis Isi ... (05010516)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2644,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Padatan kakao (dihitung dari basis berat kering) (%)",
    "",
    "=5",
  ],
  [
    2645,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Padatan susu (dihitung dari basis berat kering) (%)",
    "",
    "=9",
  ],
  [
    2646,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2647,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2648,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2649,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2650,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2651,
    "Cokelat Paduan / Cokelat Compound Susu (Milk Compound Chocolate) / Cokelat Compound Susu Isi ... (05010513)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2652,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Padatan kakao (%) (dihitung dari basis berat kering)",
    "",
    "=5",
  ],
  [
    2653,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Padatan susu (%) (dihitung dari basis berat kering)",
    "",
    "=5",
  ],
  [
    2654,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2655,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2656,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2657,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2658,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2659,
    "Cokelat Paduan / Cokelat Compound Susu Manis (Sweet Milk Compound Chocolate) / Cokelat Compound Susu Manis Isi ... (05010514)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2660,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Padatan kakao (dihitung dari basis berat kering) (%)",
    "",
    "=20",
  ],
  [
    2661,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2662,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2663,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2664,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2665,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2666,
    "Cokelat Paduan/Cokelat Compound Hitam Pahit (bitter dark compound chocolate) / Cokelat Compound Hitam Pahit Isi ... (05010508)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2667, "Cokelat Pasta (05010301)", "Kadar air (%)", "=2"],
  [2668, "Cokelat Pasta (05010301)", "Kadar lemak (%)", "", "=25"],
  [2669, "Cokelat Pasta (05010301)", "Arsen (As) (mg/kg)", "=1"],
  [
    2670,
    "Cokelat Pasta (05010301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2671,
    "Cokelat Pasta (05010301)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2672,
    "Cokelat Pasta (05010301)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2673,
    "Cokelat Pasta (05010301)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2674, "Cokelat Pasta (05010301)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2675,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2676,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2677,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2678,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2679,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2680,
    "Cokelat Pasta (berbasis air) (05010305)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2681,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2682,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2683,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2684,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2685,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2686,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2687,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Kadar air (%)",
    "=2",
  ],
  [
    2688,
    "Cokelat Pasta (berbasis minyak) (05010304)",
    "Kadar lemak (%)",
    "",
    "=25",
  ],
  [
    2689,
    "Cokelat Putih (05010406)",
    "Kadar lemak kakao (%)",
    "",
    "=20",
  ],
  [
    2690,
    "Cokelat Putih (05010406)",
    "Kadar lemak susu (%)",
    "",
    "=3.5",
  ],
  [2691, "Cokelat Putih (05010406)", "Arsen (As) (mg/kg)", "=1"],
  [
    2692,
    "Cokelat Putih (05010406)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2693,
    "Cokelat Putih (05010406)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2694,
    "Cokelat Putih (05010406)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2695,
    "Cokelat Putih (05010406)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2696, "Cokelat Putih (05010406)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2697,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2698,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2699,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2700,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2701,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2702,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2703,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Lemak kakao (%)",
    "",
    "=20",
  ],
  [
    2704,
    "Cokelat Putih (white chocolate) / Cokelat Putih Isi ... (05010429)",
    "Padatan susu (%)",
    "",
    "=14",
  ],
  [
    2705,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Lemak kakao (%)",
    "",
    "=20",
  ],
  [
    2706,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Padatan susu (%)",
    "",
    "=14",
  ],
  [
    2707,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Total Lemak (%)",
    "",
    "=25",
  ],
  [
    2708,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2709,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2710,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2711,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2712,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2713,
    "Cokelat Putih Kovertur (White Chocolate Couverture) / Cokelat Putih Kovertur Isi ... (05010427)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2714,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2715,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2716,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2717,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2718,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2719,
    "Cokelat Semi-Manis atau Cokelat Pahit-Manis atau Cokelat Hitam (05010412)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [2720, "Cokelat Serpih (05010417)", "Arsen (As) (mg/kg)", "=1"],
  [
    2721,
    "Cokelat Serpih (05010417)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2722,
    "Cokelat Serpih (05010417)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2723,
    "Cokelat Serpih (05010417)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2724,
    "Cokelat Serpih (05010417)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2725, "Cokelat Serpih (05010417)", "Timbal (Pb) (mg/kg)", "=1"],
  [2726, "Cokelat Susu (05010408)", "Kadar air (%)", "=1.5"],
  [2727, "Cokelat Susu (05010408)", "Arsen (As) (mg/kg)", "=1"],
  [2728, "Cokelat Susu (05010408)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    2729,
    "Cokelat Susu (05010408)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2730,
    "Cokelat Susu (05010408)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2731,
    "Cokelat Susu (05010408)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [2732, "Cokelat Susu (05010408)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    2733,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2734,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2735,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2736,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2737,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2738,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Padatan kakao (%)",
    "",
    "=25",
  ],
  [
    2739,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=2.5",
  ],
  [
    2740,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Padatan susu (%)",
    "",
    "=12",
  ],
  [
    2741,
    "Cokelat Susu (milk chocolate) / Cokelat Susu Isi ... (05010430)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2742,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Padatan kakao (%)",
    "",
    "=25",
  ],
  [
    2743,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Lemak kakao (%)",
    "",
    "=15",
  ],
  [
    2744,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=2.5",
  ],
  [
    2745,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Padatan susu (%)",
    "",
    "=12",
  ],
  [
    2746,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Total Lemak (%)",
    "",
    "=31",
  ],
  [
    2747,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2748,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2749,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2750,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2751,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2752,
    "Cokelat Susu Kovertur (Milk Chocolate Couverture) / Cokelat Susu Kovertur Isi ... (05010426)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2753,
    "Cokelat Susu Serpih (05010418)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2754,
    "Cokelat Susu Serpih (05010418)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2755,
    "Cokelat Susu Serpih (05010418)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2756,
    "Cokelat Susu Serpih (05010418)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2757,
    "Cokelat Susu Serpih (05010418)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2758,
    "Cokelat Susu Serpih (05010418)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2759,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    2760,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    2761,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    2762,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    2763,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    2764,
    "Cokelat Tawar (Unsweetened Chocolate) (05010414)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    2765,
    "Cold Pressed Oils (02010203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2766,
    "Cold Pressed Oils (02010203)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2767,
    "Cold Pressed Oils (02010203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2768,
    "Cold Pressed Oils (02010203)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2769,
    "Cold Pressed Oils (02010203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2770,
    "Cold Pressed Oils (02010203)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    2771,
    "Cone untuk Es Krim (07020213)",
    "Arsen (As) (mg/kg) ",
    "=0.5",
  ],
  [
    2772,
    "Cone untuk Es Krim (07020213)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    2773,
    "Cone untuk Es Krim (07020213)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    2774,
    "Cone untuk Es Krim (07020213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2775,
    "Cone untuk Es Krim (07020213)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [
    2776,
    "Cordials (1401040203)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2777,
    "Cordials (1401040203)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    2778,
    "Cordials (1401040203)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    2779,
    "Cordials (1401040203)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    2780,
    "Cordials (1401040203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2781,
    "Cordials (1401040203)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [2782, "Crepes (07020142)", "Arsen (As) (mg/kg)", "=0.5"],
  [2783, "Crepes (07020142)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [2784, "Crepes (07020142)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [2785, "Crepes (07020142)", "Timah (Sn) (mg/kg)", "=40"],
  [2786, "Crepes (07020142)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [2787, "Crouton (07010401)", "Arsen (As) (mg/kg)", "=0.5"],
  [2788, "Crouton (07010401)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [2789, "Crouton (07010401)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [2790, "Crouton (07010401)", "Timah (Sn) (mg/kg)", "=40"],
  [2791, "Crouton (07010401)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [2792, "Crush (1401040202)", "Kandungan buah (%)", "=5", "=3"],
  [2793, "Crush (1401040202)", "Arsen (ppm atau mg/kg) ", "=0.05"],
  [
    2794,
    "Crush (1401040202)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    2795,
    "Crush (1401040202)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    2796,
    "Crush (1401040202)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    2797,
    "Crush (1401040202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2798, "Crush (1401040202)", "Timbal (ppm atau mg/kg) ", "=0.05"],
  [
    2799,
    "Cuka Fermentasi, Vinegar (120301)",
    "Total asam (g/100ml)",
    "",
    "=4",
  ],
  [
    2800,
    "Cuka Fermentasi, Vinegar (120301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2801,
    "Cuka Fermentasi, Vinegar (120301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2802,
    "Cuka Fermentasi, Vinegar (120301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2803,
    "Cuka Fermentasi, Vinegar (120301)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2804,
    "Cuka Fermentasi, Vinegar (120301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2805,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Kadar asam asetat (% v/b)",
    "",
    "=12.5",
  ],
  [
    2806,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2807,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2808,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2809,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    2810,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2811,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Dapur) (120304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2812,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Kadar asam asetat (%)",
    "=12.5",
    "=4",
  ],
  [
    2813,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    2814,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2815,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2816,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    2817,
    "Cuka Hasil Pengenceran Asam Asetat Glasial (Cuka Meja) (120302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    2818,
    "Cumi dan Sotong Kering (09020534)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    2819,
    "Cumi dan Sotong Kering (09020534)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    2820,
    "Cumi dan Sotong Kering (09020534)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    2821,
    "Cumi dan Sotong Kering (09020534)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    2822,
    "Cumi dan Sotong Kering (09020534)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    2823,
    "Cumi dan Sotong Kering (09020534)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2824,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Angka Lempeng Total (koloni/g)",
    "=50000",
  ],
  [
    2825,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    2826,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    2827,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    2828,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    2829,
    "Cumi-Cumi / Kerang / Ikan / ... Beku (09020121)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2830,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    2831,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    2832,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    2833,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    2834,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    2835,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    2836,
    "Cumi-cumi Dalam Kemasan (090416)",
    "Bobot Tuntas (%)",
    "",
    "=50",
  ],
  [
    2837,
    "Custard (100402)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2838,
    "Custard (100402)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    2839,
    "Custard (100402)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2840,
    "Custard (100402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2841,
    "Custard (100402)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2842,
    "Custard Beku (100403)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2843,
    "Custard Beku (100403)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    2844,
    "Custard Beku (100403)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2845,
    "Custard Beku (100403)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2846,
    "Custard Beku (100403)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2847,
    "Dadih (0101010202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    2848,
    "Dadih (0101010202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    2849,
    "Dadih (0101010202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2850,
    "Dadih (0101010202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    2851,
    "Dadih (0101010202)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    2852,
    "Dadih (0101010202)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [2853, "Dadih (0101010202)", "Aflatoksin M1 (ppb)", "=0.5"],
  [2854, "Dadih (0102A0)", "Arsen (As) (mg/kg)", "=0.1"],
  [2855, "Dadih (0102A0)", "Kadmium (Cd)(mg/kg)", "=0.05"],
  [2856, "Dadih (0102A0)", "Merkuri (Hg) (mg/kg)", "=0.02"],
  [
    2857,
    "Dadih (0102A0)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    2858,
    "Dadih (0102A0)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [2859, "Dadih (0102A0)", "Timbal (Pb) (mg/kg)", "=0.02"],
  [2860, "Dadih (0102A0)", "Aflatoksin M1 (mcg/kg)", "=0.05"],
  [
    2861,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2862,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2863,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2864,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2865,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2866,
    "Daging (Ayam, Bebek, Unggas lainnya) yang Dimarinasi (0802010106)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2867,
    "Daging Asap (0802010108)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2868,
    "Daging Asap (0802010108)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2869,
    "Daging Asap (0802010108)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2870,
    "Daging Asap (0802010108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2871,
    "Daging Asap (0802010108)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2872,
    "Daging Asap (0802010108)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2873,
    "Daging Ayam Yang Dikalengkan (08020206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2874,
    "Daging Ayam Yang Dikalengkan (08020206)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2875,
    "Daging Ayam Yang Dikalengkan (08020206)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2876,
    "Daging Ayam Yang Dikalengkan (08020206)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2877,
    "Daging Ayam Yang Dikalengkan (08020206)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2878,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2879,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2880,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2881,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2882,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2883,
    "Daging Ayam yang Dimarinasi (0802010112)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2884,
    "Daging Babi Asin Kering (0802010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2885,
    "Daging Babi Asin Kering (0802010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2886,
    "Daging Babi Asin Kering (0802010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2887,
    "Daging Babi Asin Kering (0802010201)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2888,
    "Daging Babi Asin Kering (0802010201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2889,
    "Daging Babi Asin Kering (0802010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2890,
    "Daging Cangkuk (0802010303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2891,
    "Daging Cangkuk (0802010303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2892,
    "Daging Cangkuk (0802010303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2893,
    "Daging Cangkuk (0802010303)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2894,
    "Daging Cangkuk (0802010303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2895,
    "Daging Cangkuk (0802010303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2896,
    "Daging Cincang (08010205)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2897,
    "Daging Cincang (08010205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2898,
    "Daging Cincang (08010205)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2899,
    "Daging Cincang (08010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2900,
    "Daging Cincang (08010205)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    2901,
    "Daging Cincang (08010205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2902,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Kadar Daging (%)",
    "",
    "=30",
  ],
  [
    2903,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2904,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2905,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2906,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2907,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2908,
    "Daging Cincang Olahan Berbumbu (08030233)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2909,
    "Daging dalam Kaleng (08020226)",
    "Kandungan daging (meat content) (%)",
    "",
    "=60",
  ],
  [
    2910,
    "Daging dalam Kaleng (08020226)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2911,
    "Daging dalam Kaleng (08020226)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2912,
    "Daging dalam Kaleng (08020226)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2913,
    "Daging dalam Kaleng (08020226)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2914,
    "Daging dalam Kaleng (08020226)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2915,
    "Daging dalam Kaleng (08020226)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2916,
    "Daging Dalam Kaleng (Tanpa Kuah) (08020211)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2917,
    "Daging Dalam Kaleng (Tanpa Kuah) (08020211)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2918,
    "Daging Dalam Kaleng (Tanpa Kuah) (08020211)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2919,
    "Daging Dalam Kaleng (Tanpa Kuah) (08020211)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2920,
    "Daging Dalam Kaleng (Tanpa Kuah) (08020211)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2921,
    "Daging Giling (08010206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2922,
    "Daging Giling (08010206)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2923,
    "Daging Giling (08010206)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2924,
    "Daging Giling (08010206)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2925,
    "Daging Giling (08010206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2926,
    "Daging Giling (08010206)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2927,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2928,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2929,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2930,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2931,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2932,
    "Daging Halus Olahan Berbumbu (08030240)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2933,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2934,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2935,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2936,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2937,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2938,
    "Daging Halus Olahan Berbumbu (Beku) (08030325)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2939,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    2940,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    2941,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Raksa (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    2942,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    2943,
    "Daging Kepiting Rebus Beku (0902040202)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    2944,
    "Daging Kornet Mentah (0802010104)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2945,
    "Daging Kornet Mentah (0802010104)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2946,
    "Daging Kornet Mentah (0802010104)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2947,
    "Daging Kornet Mentah (0802010104)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2948,
    "Daging Kornet Mentah (0802010104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2949,
    "Daging Kornet Mentah (0802010104)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2950,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2951,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2952,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2953,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2954,
    "Daging Kuah Dalam Kemasan (08020210)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2955,
    "Daging Kuring Cacahan Matang (08030204)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2956,
    "Daging Kuring Cacahan Matang (08030204)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2957,
    "Daging Kuring Cacahan Matang (08030204)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2958,
    "Daging Kuring Cacahan Matang (08030204)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2959,
    "Daging Kuring Cacahan Matang (08030204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2960,
    "Daging Kuring Cacahan Matang (08030204)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2961,
    "Daging Luncheon Matang (08030207)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2962,
    "Daging Luncheon Matang (08030207)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2963,
    "Daging Luncheon Matang (08030207)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2964,
    "Daging Luncheon Matang (08030207)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2965,
    "Daging Luncheon Matang (08030207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2966,
    "Daging Luncheon Matang (08030207)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2967,
    "Daging Luncheon Matang dalam Kaleng (08030225)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2968,
    "Daging Luncheon Matang dalam Kaleng (08030225)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2969,
    "Daging Luncheon Matang dalam Kaleng (08030225)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2970,
    "Daging Luncheon Matang dalam Kaleng (08030225)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2971,
    "Daging Luncheon Matang dalam Kaleng (08030225)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2972,
    "Daging Marinasi (0802010111)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    2973,
    "Daging Marinasi (0802010111)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    2974,
    "Daging Marinasi (0802010111)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    2975,
    "Daging Marinasi (0802010111)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2976,
    "Daging Marinasi (0802010111)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    2977,
    "Daging Marinasi (0802010111)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    2978,
    "Daging Marinasi (Beku) (08020310)",
    "As (mg/kg)",
    "=0.25",
  ],
  [
    2979,
    "Daging Marinasi (Beku) (08020310)",
    "Cd (mg/kg)",
    "=0.05",
  ],
  [
    2980,
    "Daging Marinasi (Beku) (08020310)",
    "Hg (mg/kg)",
    "=0.03",
  ],
  [
    2981,
    "Daging Marinasi (Beku) (08020310)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    2982,
    "Daging Marinasi (Beku) (08020310)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [2983, "Daging Marinasi (Beku) (08020310)", "Pb (mg/kg)", "=0.5"],
  [
    2984,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2985,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2986,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2987,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2988,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2989,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2990,
    "Daging Murni Giling Tanpa Lemak (08010207)",
    "Total Lemak (%) ",
    "=7",
  ],
  [
    2991,
    "Daging Olahan Berbumbu (08020225)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    2992,
    "Daging Olahan Berbumbu (08020225)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    2993,
    "Daging Olahan Berbumbu (08020225)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    2994,
    "Daging Olahan Berbumbu (08020225)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    2995,
    "Daging Olahan Berbumbu (08020225)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    2996,
    "Daging Olahan Berbumbu (08020225)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    2997,
    "Daging Olahan Berbumbu Beku (08020313)",
    "As (mg/kg)",
    "=0.25",
  ],
  [
    2998,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Cd (mg/kg)",
    "=0.05",
  ],
  [
    2999,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Hg (mg/kg)",
    "=0.03",
  ],
  [
    3000,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3001,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3002,
    "Daging Olahan Berbumbu Beku (08020313)",
    "Pb (mg/kg)",
    "=0.5",
  ],
  [
    3003,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3004,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3005,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3006,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3007,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3008,
    "Daging Olahan Berbumbu Siap Makan (Rendang Daging, Semur Daging, dll) (08020228)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3009,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Kadar air (%)",
    "=10",
  ],
  [
    3010,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3011,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3012,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3013,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3014,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3015,
    "Daging Olahan Khas Indonesia Berbentuk Potongan (08020208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3016,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3017,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3018,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3019,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3020,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3021,
    "Daging Paha Babi Kuring Matang (0802010206)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3022,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3023,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3024,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3025,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3026,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3027,
    "Daging Paha Babi Kuring Matang (08020201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3028,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3029,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3030,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3031,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3032,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3033,
    "Daging Paha Babi Kuring Mentah (0802010205)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3034,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    3035,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    3036,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    3037,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Timah (Sn) (mg/kg) ",
    "=250",
  ],
  [
    3038,
    "Daging Rajungan Dalam Kaleng (090405)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    3039,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Angka Lempeng Total (30oC, 72 jam) (koloni/g) ",
    "=500000",
  ],
  [
    3040,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    3041,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    3042,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Raksa (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    3043,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    3044,
    "Daging Rajungan Rebus Dingin (0902040201)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    3045,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3046,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3047,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3048,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3049,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3050,
    "Daging Sapi Kering (Dried Beef) (0802010203)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3051,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3052,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3053,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3054,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3055,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3056,
    "Daging Sapi yang Difermentasi Dalam Wadah Keramik (Potted Beef) (0802010301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3057,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3058,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3059,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3060,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3061,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3062,
    "Daging Sapi yang Dimarinasi (0802010105)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3063,
    "Daging Sei (0802010110)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3064,
    "Daging Sei (0802010110)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3065,
    "Daging Sei (0802010110)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3066,
    "Daging Sei (0802010110)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3067,
    "Daging Sei (0802010110)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3068,
    "Daging Sei (0802010110)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3069,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    3070,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3071,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3072,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3073,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3074,
    "Daun Jeruk Purut (Kaffir lime) (12020196)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    3075,
    "Daun Ketumbar (12020162)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3076,
    "Daun Ketumbar (12020162)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3077,
    "Daun Ketumbar (12020162)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3078,
    "Daun Ketumbar (12020162)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3079,
    "Daun Ketumbar (12020162)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    3080,
    "Daun Pandan (12020197)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    3081,
    "Daun Pandan (12020197)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3082,
    "Daun Pandan (12020197)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3083,
    "Daun Pandan (12020197)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3084,
    "Daun Pandan (12020197)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3085,
    "Daun Pandan (12020197)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    3086,
    "Daun Peterseli (120201A2)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3087,
    "Daun Peterseli (120201A2)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3088,
    "Daun Peterseli (120201A2)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3089,
    "Daun Peterseli (120201A2)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3090, "Daun Peterseli (120201A2)", "Timbal (Pb) (mg/kg)", "=1"],
  [3091, "Daun Sembung (120201A3)", "Arsen (As) (mg/kg)", "=0.15"],
  [3092, "Daun Sembung (120201A3)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    3093,
    "Daun Sembung (120201A3)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3094,
    "Daun Sembung (120201A3)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3095, "Daun Sembung (120201A3)", "Timbal (Pb) (mg/kg)", "=1"],
  [3096, "Daun Suji (120201A4)", "Arsen (As) (mg/kg)", "=0.15"],
  [3097, "Daun Suji (120201A4)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [3098, "Daun Suji (120201A4)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    3099,
    "Daun Suji (120201A4)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3100, "Daun Suji (120201A4)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3101,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    3102,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3103,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Merkuri (Hg)(mg/kg)",
    "=0.05",
  ],
  [
    3104,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3105,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3106,
    "Debu Kakao (Cocoa Dust) (05010105)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    3107,
    "Degermed Maize (Corn) Grits (060311)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    3108,
    "Degermed Maize (Corn) Grits (060311)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3109,
    "Degermed Maize (Corn) Grits (060311)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3110,
    "Degermed Maize (Corn) Grits (060311)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3111,
    "Degermed Maize (Corn) Grits (060311)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3112,
    "Degermed Maize (Corn) Grits (060311)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    3113,
    "Degermed Maize (Corn) Grits (060311)",
    "Aflatoksin B1 (ppb) ",
    "=15",
  ],
  [
    3114,
    "Degermed Maize (Corn) Grits (060311)",
    "Aflatoksin Total (ppb) ",
    "=20",
  ],
  [
    3115,
    "Degermed Maize (Corn) Grits (060311)",
    "Kadar Air (%)",
    "=15",
  ],
  [
    3116,
    "Degermed Maize (Corn) Grits (060311)",
    "Kehalusan (lolos ayakan 9 mesh) (%) ",
    "",
    "=95",
  ],
  [
    3117,
    "Degermed Maize (Corn) Grits (060311)",
    "Kehalusan (lolos ayakan 24 mesh) (%)",
    "",
    "=20",
  ],
  [
    3118,
    "Degermed Maize (Corn) Meal (060307)",
    "Kadar Air (%)",
    "=15",
  ],
  [
    3119,
    "Degermed Maize (Corn) Meal (060307)",
    "Kehalusan - lolos ayakan 0.85 mm (%)",
    "",
    "=95",
  ],
  [
    3120,
    "Degermed Maize (Corn) Meal (060307)",
    "Kehalusan - lolos ayakan 24 mesh (%)",
    "",
    "=45",
  ],
  [
    3121,
    "Degermed Maize (Corn) Meal (060307)",
    "Kehalusan - lolos ayakan 65 mesh (%)",
    "",
    "=25",
  ],
  [
    3122,
    "Degermed Maize (Corn) Meal (060307)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    3123,
    "Degermed Maize (Corn) Meal (060307)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    3124,
    "Degermed Maize (Corn) Meal (060307)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    3125,
    "Degermed Maize (Corn) Meal (060307)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    3126,
    "Degermed Maize (Corn) Meal (060307)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    3127,
    "Degermed Maize (Corn) Meal (060307)",
    "Aflatoksin B1 (mcg/kg)",
    "=15",
  ],
  [
    3128,
    "Degermed Maize (Corn) Meal (060307)",
    "Aflatoksin Total (mcg/kg)",
    "=20",
  ],
  [
    3129,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    3130,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3131,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3132,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3133,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3134,
    "Dekorasi (Misalnya Untuk Bakery) dan Topping (Non-Buah) (050407)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [3135, "Dekstrin (06020206)", "Arsen (As) ( mg/kg )", "=0.1"],
  [3136, "Dekstrin (06020206)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [3137, "Dekstrin (06020206)", "Merkuri (Hg) ( mg/kg )", "=0.03"],
  [
    3138,
    "Dekstrin (06020206)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [3139, "Dekstrin (06020206)", "Timbal (Pb) ( mg/kg )", "=0.25"],
  [3140, "Dekstrosa Anhidrat (11010101)", "D-glukosa (%)", "=99.5"],
  [
    3141,
    "Dekstrosa Anhidrat (11010101)",
    "Kadar total padatan (%)",
    "=98",
  ],
  [
    3142,
    "Dekstrosa Anhidrat (11010101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    3143,
    "Dekstrosa Anhidrat (11010101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3144,
    "Dekstrosa Anhidrat (11010101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3145,
    "Dekstrosa Anhidrat (11010101)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3146,
    "Dekstrosa Anhidrat (11010101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3147,
    "Dekstrosa Monohidrat (11010102)",
    "D-glukosa (%)",
    "=99.5",
  ],
  [
    3148,
    "Dekstrosa Monohidrat (11010102)",
    "Kadar total padatan (%)",
    "=90",
  ],
  [
    3149,
    "Dekstrosa Monohidrat (11010102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    3150,
    "Dekstrosa Monohidrat (11010102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3151,
    "Dekstrosa Monohidrat (11010102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3152,
    "Dekstrosa Monohidrat (11010102)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3153,
    "Dekstrosa Monohidrat (11010102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3154,
    "Dektrosa Serbuk (Icing Dextrose) (11010202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    3155,
    "Dektrosa Serbuk (Icing Dextrose) (11010202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3156,
    "Dektrosa Serbuk (Icing Dextrose) (11010202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3157,
    "Dektrosa Serbuk (Icing Dextrose) (11010202)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3158,
    "Dektrosa Serbuk (Icing Dextrose) (11010202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3159,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3160,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3161,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3162,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3163,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3164,
    "Dendeng Daging (dengan perlakuan panas) (08030242)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3165,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Kadar air (%) ",
    "=10",
  ],
  [
    3166,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3167,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3168,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3169,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3170,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3171,
    "Dendeng Daging (tanpa perlakuan panas) (0802010207)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3172,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Kadar air (%)",
    "=10",
  ],
  [
    3173,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3174,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3175,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3176,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3177,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3178,
    "Dendeng Daging dengan Perlakuan Panas (08020222)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [3179, "Dendeng Ikan (09020528)", "Arsen (As) (mg/kg)", "=0.25"],
  [3180, "Dendeng Ikan (09020528)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [3181, "Dendeng Ikan (09020528)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [
    3182,
    "Dendeng Ikan (09020528)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    3183,
    "Dendeng Ikan (09020528)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [3184, "Dendeng Ikan (09020528)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [3185, "Dimsum Ikan (0902040126)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    3186,
    "Dimsum Ikan (0902040126)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    3187,
    "Dimsum Ikan (0902040126)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    3188,
    "Dimsum Ikan (0902040126)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    3189,
    "Dimsum Ikan (0902040126)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [3190, "Dimsum Ikan (0902040126)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    3191,
    "Dimsum Ikan (0902040126)",
    "Kandungan lumatan daging ikan dan/atau surimi, cacahan",
  ],
  [3192, "dan/atau potongan daging ikan (%)", "", "=30"],
  [
    3193,
    "Dimsum Udang (0902040213)",
    "Kandungan udang (%)",
    "",
    "=30",
  ],
  [
    3194,
    "Dimsum Udang (0902040213)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    3195,
    "Dimsum Udang (0902040213)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    3196,
    "Dimsum Udang (0902040213)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    3197,
    "Dimsum Udang (0902040213)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    3198,
    "Dimsum Udang (0902040213)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    3199,
    "Dimsum Udang (0902040213)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    3200,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3201,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3202,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3203,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3204,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3205,
    "DMM (Desinewed Minced Meat) (08010215)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3206,
    "Dodol atau Lempok Buah (0401021208)",
    "Kadar air (%)",
    "=20",
  ],
  [
    3207,
    "Dodol atau Lempok Buah (0401021208)",
    "Kadar gula (sebagai sukrosa) (%)",
    "",
    "=35",
  ],
  [
    3208,
    "Dodol atau Lempok Buah (0401021208)",
    "Kadar serat kasar (%)",
    "=2.5",
  ],
  [
    3209,
    "Dodol atau Lempok Buah (0401021208)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    3210,
    "Dodol atau Lempok Buah (0401021208)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    3211,
    "Dodol atau Lempok Buah (0401021208)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    3212,
    "Dodol atau Lempok Buah (0401021208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3213,
    "Dodol atau Lempok Buah (0401021208)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    3214,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3215,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    3216,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3217,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    3218,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    3219,
    "Dodol Rumput Laut/Dodol berbahan dasar sayur atau kacang-kacangan lainnya (0402020810)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [3220, "Dodol/Jenang/Gelamai (060701)", "Kadar air (%)", "=20"],
  [
    3221,
    "Dodol/Jenang/Gelamai (060701)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3222,
    "Dodol/Jenang/Gelamai (060701)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3223,
    "Dodol/Jenang/Gelamai (060701)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3224,
    "Dodol/Jenang/Gelamai (060701)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    3225,
    "Dodol/Jenang/Gelamai (060701)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3226,
    "Dodol/Jenang/Gelamai (060701)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [3227, "Doenjang (12090102)", "Arsen (As) (mg/kg)", "=0.15"],
  [3228, "Doenjang (12090102)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [3229, "Doenjang (12090102)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [3230, "Doenjang (12090102)", "Timah (Sn) (mg/kg)", "=40"],
  [3231, "Doenjang (12090102)", "Timbal (Pb) (mg/kg)", "=1"],
  [3232, "Donat (07020205)", "Arsen (As) (mg/kg)", "=0.5"],
  [3233, "Donat (07020205)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [3234, "Donat (07020205)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [3235, "Donat (07020205)", "Timah (Sn) (mg/kg)", "=40"],
  [3236, "Donat (07020205)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    3237,
    "Dou chi (06080601)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3238,
    "Dou chi (06080601)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3239,
    "Dou chi (06080601)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3240,
    "Dou chi (06080601)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3241,
    "Dou chi (06080601)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [3242, "Doujiang (12090101)", "Arsen (As) (mg/kg)", "=0.15"],
  [3243, "Doujiang (12090101)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [3244, "Doujiang (12090101)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [3245, "Doujiang (12090101)", "Timah (Sn) (mg/kg)", "=40"],
  [3246, "Doujiang (12090101)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3247,
    "Dripping atau Edible Tallow (02010306)",
    "Bilangan penyabunan mg KOH/g",
    "=202",
    "=190",
  ],
  [
    3248,
    "Dripping atau Edible Tallow (02010306)",
    "Bilangan iod Wijs",
    "=53",
    "=40",
  ],
  [
    3249,
    "Dripping atau Edible Tallow (02010306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3250,
    "Dripping atau Edible Tallow (02010306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3251,
    "Dripping atau Edible Tallow (02010306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3252,
    "Dripping atau Edible Tallow (02010306)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3253,
    "Dripping atau Edible Tallow (02010306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3254,
    "Dripping atau Edible Tallow (02010306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3255,
    "Dsaudan (100306)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3256,
    "Dsaudan (100306)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    3257,
    "Dsaudan (100306)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3258,
    "Dsaudan (100306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3259,
    "Dsaudan (100306)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [3260, "Dulce de leche (010705)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    3261,
    "Dulce de leche (010705)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3262,
    "Dulce de leche (010705)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    3263,
    "Dulce de leche (010705)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3264,
    "Dulce de leche (010705)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [3265, "Dulce de leche (010705)", "Timbal (Pb) (mg/kg)", "=0.02"],
  [
    3266,
    "Dulce de leche (010705)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [3267, "Ebi Bubuk (09020529)", "Arsen (As) (mg/kg)", "=0.25"],
  [3268, "Ebi Bubuk (09020529)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [3269, "Ebi Bubuk (09020529)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [
    3270,
    "Ebi Bubuk (09020529)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    3271,
    "Ebi Bubuk (09020529)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [3272, "Ebi Bubuk (09020529)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    3273,
    "Ebi Katsu (08030316)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3274,
    "Ebi Katsu (08030316)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3275,
    "Ebi Katsu (08030316)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3276,
    "Ebi Katsu (08030316)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3277,
    "Ebi Katsu (08030316)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3278,
    "Ebi Katsu (08030316)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [3279, "Egg Roll (07020126)", "Arsen (As) (mg/kg)", "=0.5"],
  [3280, "Egg Roll (07020126)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [3281, "Egg Roll (07020126)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [3282, "Egg Roll (07020126)", "Timah (Sn) (mg/kg)", "=40"],
  [3283, "Egg Roll (07020126)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [3284, "Egg Roll (07020126)", "Kadar Telur (%)", "", "=35"],
  [
    3285,
    "Ekado/ Moneybag (08030324)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3286,
    "Ekado/ Moneybag (08030324)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3287,
    "Ekado/ Moneybag (08030324)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3288,
    "Ekado/ Moneybag (08030324)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3289,
    "Ekado/ Moneybag (08030324)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3290,
    "Ekado/ Moneybag (08030324)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3291,
    "Eko Tukir (060730)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3292,
    "Eko Tukir (060730)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3293,
    "Eko Tukir (060730)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3294,
    "Eko Tukir (060730)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3295,
    "Eko Tukir (060730)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    3296,
    "Eko Tukir (060730)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3297,
    "Eko Tukir (060730)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3298,
    "Eko Tukir (060730)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3299,
    "Ekstrak Aloe (0402020605)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3300,
    "Ekstrak Aloe (0402020605)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3301,
    "Ekstrak Aloe (0402020605)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3302,
    "Ekstrak Aloe (0402020605)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3303,
    "Ekstrak Aloe (0402020605)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3304,
    "Ekstrak Aloe (0402020605)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3305,
    "Empek-Empek Palembang (0902040113)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    3306,
    "Empek-Empek Palembang (0902040113)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    3307,
    "Empek-Empek Palembang (0902040113)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    3308,
    "Empek-Empek Palembang (0902040113)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    3309,
    "Empek-Empek Palembang (0902040113)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [3310, "Emping Beras (060109)", "Kadar air (%)", "=14"],
  [3311, "Emping Beras (060109)", "Arsen (As) (mg/kg)", "=0.1"],
  [3312, "Emping Beras (060109)", "Cadmium (Cd) (mg/kg)", "=0.05"],
  [3313, "Emping Beras (060109)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    3314,
    "Emping Beras (060109)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3315,
    "Emping Beras (060109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3316, "Emping Beras (060109)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    3317,
    "Emping Jengkol (0402020213)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3318,
    "Emping Jengkol (0402020213)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3319,
    "Emping Jengkol (0402020213)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3320,
    "Emping Jengkol (0402020213)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    3321,
    "Emping Jengkol (0402020213)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    3322,
    "Emping Jengkol (0402020213)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [3323, "Emping Melinjo (0402020212)", "Kadar air (%)", "=12"],
  [
    3324,
    "Emping Melinjo (0402020212)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3325,
    "Emping Melinjo (0402020212)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3326,
    "Emping Melinjo (0402020212)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3327,
    "Emping Melinjo (0402020212)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    3328,
    "Emping Melinjo (0402020212)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    3329,
    "Emping Melinjo (0402020212)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    3330,
    "Emping Melinjo Goreng (150130)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3331,
    "Emping Melinjo Goreng (150130)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3332,
    "Emping Melinjo Goreng (150130)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3333,
    "Emping Melinjo Goreng (150130)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3334,
    "Emping Melinjo Goreng (150130)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3335,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Kadar air (%)",
    "=3.5",
  ],
  [
    3336,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    3337,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3338,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3339,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3340,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3341,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    3342,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    3343,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Aflatoksin total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    3344,
    "Enting-Enting Kacang Gepuk (05020304)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    3345,
    "Es Batu Untuk Konsumsi (0316)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    3346,
    "Es Batu Untuk Konsumsi (0316)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3347,
    "Es Batu Untuk Konsumsi (0316)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3348,
    "Es Batu Untuk Konsumsi (0316)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    3349,
    "Es Batu Untuk Konsumsi (0316)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3350,
    "Es Buah (Fruit Ice) (0302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3351,
    "Es Buah (Fruit Ice) (0302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3352,
    "Es Buah (Fruit Ice) (0302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3353,
    "Es Buah (Fruit Ice) (0302)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3354,
    "Es Buah (Fruit Ice) (0302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3355,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3356,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3357,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3358,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3359,
    "Es Jepit atau Es Serut atau Es Gusruk/Gosrok (0304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [3360, "Es Krim (010701)", "Arsen (As) (mg/kg) ", "=0.1"],
  [3361, "Es Krim (010701)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [3362, "Es Krim (010701)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    3363,
    "Es Krim (010701)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3364,
    "Es Krim (010701)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3365, "Es Krim (010701)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [3366, "Es Krim (010701)", "Kadar lemak total (%)", "", "=5"],
  [3367, "Es Krim (010701)", "Total padatan (%)", "", "=31"],
  [
    3368,
    "Es Krim (010701)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [3369, "Es Krim (010701)", "Total padatan susu (%)", "", "=5"],
  [
    3370,
    "Es Krim Modifikasi (010719)",
    "Kadar protein (%) ",
    "",
    "=2.7",
  ],
  [
    3371,
    "Es Krim Modifikasi (010719)",
    "Kadar lemak total (%) ",
    "",
    "=5",
  ],
  [
    3372,
    "Es Krim Modifikasi (010719)",
    "Total padatan (%) ",
    "",
    "=31",
  ],
  [
    3373,
    "Es Krim Modifikasi (010719)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    3374,
    "Es Krim Modifikasi (010719)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3375,
    "Es Krim Modifikasi (010719)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    3376,
    "Es Krim Modifikasi (010719)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3377,
    "Es Krim Modifikasi (010719)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3378,
    "Es Krim Modifikasi (010719)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    3379,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    3380,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3381,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    3382,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3383,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3384,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    3385,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Kadar Protein Susu (%)",
    "",
    "=2.7",
  ],
  [
    3386,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Kadar lemak susu (%)",
    "",
    "=5",
  ],
  [
    3387,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Total padatan (%)",
    "",
    "=31",
  ],
  [
    3388,
    "Es Krim Susu (Dairy Ice Cream) (010720)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [3389, "Es Kue (0308)", "Arsen (As) (ppm atau mg/kg)", "=0.20"],
  [3390, "Es Kue (0308)", "Kadmium (Cd) (ppm atau mg/kg)", "=0.01"],
  [3391, "Es Kue (0308)", "Merkuri (Hg) (ppm atau mg/kg)", "=0.03"],
  [3392, "Es Kue (0308)", "Timah (Sn) (ppm atau mg/kg)", "=40.00"],
  [3393, "Es Kue (0308)", "Timbal (Pb) (ppm atau mg/kg)", "=0.15"],
  [3394, "Es Lilin (0307)", "Arsen (As) (ppm atau mg/kg)", "=0.2"],
  [
    3395,
    "Es Lilin (0307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3396,
    "Es Lilin (0307)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [3397, "Es Lilin (0307)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [
    3398,
    "Es Lilin (0307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3399,
    "Es Lilin Goyang (0306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3400,
    "Es Lilin Goyang (0306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3401,
    "Es Lilin Goyang (0306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3402,
    "Es Lilin Goyang (0306)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3403,
    "Es Lilin Goyang (0306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [3404, "Es Loli (0314)", "Arsen (As) (ppm atau mg/kg)", "=0.20"],
  [
    3405,
    "Es Loli (0314)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3406,
    "Es Loli (0314)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [3407, "Es Loli (0314)", "Timah (Sn) (ppm atau mg/kg)", "=40.00"],
  [3408, "Es Loli (0314)", "Timbal (Pb) (ppm atau mg/kg)", "=0.15"],
  [3409, "Es Mambo (0303)", "Arsen (As) (ppm atau mg/kg)", "=0.2"],
  [
    3410,
    "Es Mambo (0303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3411,
    "Es Mambo (0303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [3412, "Es Mambo (0303)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [
    3413,
    "Es Mambo (0303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3414,
    "Es Mengandung Susu (010717)",
    "Kadar Lemak Susu (%)",
    "<2",
    "=0.5",
  ],
  [
    3415,
    "Es Mengandung Susu (010717)",
    "Total Padatan Susu Bukan Lemak (%)",
    "",
    "=1.1",
  ],
  [
    3416,
    "Es Mengandung Susu (010717)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    3417,
    "Es Mengandung Susu (010717)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3418,
    "Es Mengandung Susu (010717)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    3419,
    "Es Mengandung Susu (010717)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3420,
    "Es Mengandung Susu (010717)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    3421,
    "Es Mengandung Susu (0320)",
    "Arsen (As) (mg/kg)",
    "=0.20",
  ],
  [
    3422,
    "Es Mengandung Susu (0320)",
    "Kadmium (Cd)(mg/kg)",
    "=0.01",
  ],
  [
    3423,
    "Es Mengandung Susu (0320)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3424,
    "Es Mengandung Susu (0320)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    3425,
    "Es Mengandung Susu (0320)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    3426,
    "Es Mengandung Susu (0320)",
    "Timbal (Pb) (mg/kg)",
    "=0.15",
  ],
  [
    3427,
    "Es Mengandung Susu (0320)",
    "Kadar Protein Susu (%)",
    "<1",
    "=0.3",
  ],
  [
    3428,
    "Es Pelangi (0312)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    3429,
    "Es Pelangi (0312)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3430,
    "Es Pelangi (0312)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3431,
    "Es Pelangi (0312)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    3432,
    "Es Pelangi (0312)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [3433, "Es Puter (0305)", "Arsen (As) (ppm atau mg/kg)", "=0.2"],
  [
    3434,
    "Es Puter (0305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3435,
    "Es Puter (0305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [3436, "Es Puter (0305)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [
    3437,
    "Es Puter (0305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [3438, "Es Rasa Susu (0318)", "Kadar protein susu (%)", "<0.3"],
  [
    3439,
    "Es Rasa Susu (0318)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    3440,
    "Es Rasa Susu (0318)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3441,
    "Es Rasa Susu (0318)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3442,
    "Es Rasa Susu (0318)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    3443,
    "Es Rasa Susu (0318)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3444,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    3445,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3446,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3447,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    3448,
    "Es Stik (Ice Stick) atau Es Loli (0311)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [3449, "Es Susu (010703)", "Arsen (As) (mg/kg) ", "=0.1"],
  [3450, "Es Susu (010703)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [3451, "Es Susu (010703)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    3452,
    "Es Susu (010703)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3453,
    "Es Susu (010703)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [3454, "Es Susu (010703)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [3455, "Es Susu (010703)", "Kadar Protein Susu (%)", "", "=1"],
  [
    3456,
    "Es Susu (010703)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [3457, "Es Tebak (0313)", "Arsen (As) (ppm atau mg/kg)", "=0.20"],
  [
    3458,
    "Es Tebak (0313)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3459,
    "Es Tebak (0313)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [3460, "Es Tebak (0313)", "Timah (Sn)(ppm atau mg/kg)", "=40.00"],
  [
    3461,
    "Es Tebak (0313)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3462,
    "Extra Virgin Olive Oil (02010236)",
    "asam lemak bebas sebagai asam oleat (g/100g)",
    "=0.8",
  ],
  [
    3463,
    "Extra Virgin Olive Oil (02010236)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3464,
    "Extra Virgin Olive Oil (02010236)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3465,
    "Extra Virgin Olive Oil (02010236)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3466,
    "Extra Virgin Olive Oil (02010236)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3467,
    "Extra Virgin Olive Oil (02010236)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3468,
    "Extra Virgin Olive Oil (02010236)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3469,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    3470,
    "Fenugreek Bubuk, Kelabat Bubuk, Kelabet Bubuk, Klabat Bubuk (12020134)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    3471,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    3472,
    "Fenugreek, Kelabat, Kelabet, Klabat (12020133)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    3473,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    3474,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    3475,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    3476,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3477,
    "Fermentasi Buah (termasuk sari buah fermentasi) (0401021004)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3478,
    "Fish Kasu-zuke (09030202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3479,
    "Fish Kasu-zuke (09030202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3480,
    "Fish Kasu-zuke (09030202)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3481,
    "Fish Kasu-zuke (09030202)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3482,
    "Fish Kasu-zuke (09030202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3483,
    "Fish Kasu-zuke (09030202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3484,
    "Fish Koji-zuke (09030201)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3485,
    "Fish Koji-zuke (09030201)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [3486, "Fish Koji-zuke (09030201)", "Hg (ppm atau mg/kg", "=0.5"],
  [
    3487,
    "Fish Koji-zuke (09030201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3488,
    "Fish Koji-zuke (09030201)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3489,
    "Fish Koji-zuke (09030201)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3490,
    "Fish Miso-zuke (09030203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3491,
    "Fish Miso-zuke (09030203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3492,
    "Fish Miso-zuke (09030203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3493,
    "Fish Miso-zuke (09030203)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3494,
    "Fish Miso-zuke (09030203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3495,
    "Fish Miso-zuke (09030203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3496,
    "Fish Shoyu-zuke (09030204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3497,
    "Fish Shoyu-zuke (09030204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3498,
    "Fish Shoyu-zuke (09030204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3499,
    "Fish Shoyu-zuke (09030204)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3500,
    "Fish Shoyu-zuke (09030204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3501,
    "Fish Shoyu-zuke (09030204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3502,
    "Fish Su-zuke (09030205)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3503,
    "Fish Su-zuke (09030205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3504,
    "Fish Su-zuke (09030205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3505,
    "Fish Su-zuke (09030205)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3506,
    "Fish Su-zuke (09030205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3507,
    "Fish Su-zuke (09030205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3508,
    "Fish Tsukudani (09030104)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3509,
    "Fish Tsukudani (09030104)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [3510, "Fish Tsukudani (09030104)", "Hg (ppm atau mg/kg", "=0.5"],
  [
    3511,
    "Fish Tsukudani (09030104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3512,
    "Fish Tsukudani (09030104)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3513,
    "Fish Tsukudani (09030104)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3514,
    "Foie Gras and Pates (08020227)",
    "Kadar daging",
    "",
    "=70",
  ],
  [
    3515,
    "Foie Gras and Pates (08020227)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3516,
    "Foie Gras and Pates (08020227)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3517,
    "Foie Gras and Pates (08020227)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3518,
    "Foie Gras and Pates (08030202)",
    "Kadar daging (%) ",
    "",
    "=70",
  ],
  [
    3519,
    "Foie Gras and Pates (08030202)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    3520,
    "Foie Gras and Pates (08030202)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    3521,
    "Foie Gras and Pates (08030202)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    3522,
    "Foie Gras and Pates (08030202)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    3523,
    "Foie Gras and Pates (08030202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    3524,
    "Foie Gras and Pates (08030202)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    3525,
    "Formula Bayi Bubuk (13010101)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3526,
    "Formula Bayi Bubuk (13010101)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3527,
    "Formula Bayi Bubuk (13010101)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3528,
    "Formula Bayi Bubuk (13010101)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3529,
    "Formula Bayi Bubuk (13010101)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3530,
    "Formula Bayi Bubuk (13010101)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [3531, "Formula Bayi Bubuk (13010101)", "Pestisida"],
  [
    3532,
    "Formula Bayi Cair (13010102)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3533,
    "Formula Bayi Cair (13010102)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3534,
    "Formula Bayi Cair (13010102)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3535,
    "Formula Bayi Cair (13010102)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3536,
    "Formula Bayi Cair (13010102)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3537,
    "Formula Bayi Cair (13010102)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [3538, "Formula Bayi Cair (13010102)", "Pestisida"],
  [
    3539,
    "Formula Bayi Cair (1308)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3540,
    "Formula Bayi Cair (1308)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3541,
    "Formula Bayi Cair (1308)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3542,
    "Formula Bayi Cair (1308)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3543,
    "Formula Bayi Cair (1308)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3544,
    "Formula Bayi Cair (1308)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    3545,
    "Formula Bayi Cair (1308)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    3546,
    "Formula Bayi Cair (1308)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    3547,
    "Formula Bayi Cair (1308)",
    "Protein susu non hidrolisat (g/100 kkal) ",
    "",
    "=2",
  ],
  [
    3548,
    "Formula Bayi Cair (1308)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    3549,
    "Formula Bayi Cair (1308)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    3550,
    "Formula Bayi Cair (1308)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    3551,
    "Formula Bayi Cair (1308)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    3552,
    "Formula Bayi Cair (1308)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    3553,
    "Formula Bayi Cair (1308)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%) ",
    "=30",
  ],
  [
    3554,
    "Formula Bayi Cair (1308)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml)",
    "=2",
  ],
  [
    3555,
    "Formula Bayi Cair (1308)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    3556,
    "Formula Bayi Cair (1308)",
    "Penambahan Fruktosa (%)",
    "=Negatif",
  ],
  [
    3557,
    "Formula Bayi Cair (1308)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    3558,
    "Formula Bayi Cair (1308)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3559,
    "Formula Bayi Padat (1307)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3560,
    "Formula Bayi Padat (1307)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3561,
    "Formula Bayi Padat (1307)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3562,
    "Formula Bayi Padat (1307)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3563,
    "Formula Bayi Padat (1307)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3564,
    "Formula Bayi Padat (1307)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    3565,
    "Formula Bayi Padat (1307)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    3566,
    "Formula Bayi Padat (1307)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    3567,
    "Formula Bayi Padat (1307)",
    "Protein susu non hidrolisat (g/100 kkal) ",
    "",
    "=2",
  ],
  [
    3568,
    "Formula Bayi Padat (1307)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    3569,
    "Formula Bayi Padat (1307)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    3570,
    "Formula Bayi Padat (1307)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    3571,
    "Formula Bayi Padat (1307)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    3572,
    "Formula Bayi Padat (1307)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    3573,
    "Formula Bayi Padat (1307)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%) ",
    "=30",
  ],
  [
    3574,
    "Formula Bayi Padat (1307)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml)",
    "=2",
  ],
  [
    3575,
    "Formula Bayi Padat (1307)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    3576,
    "Formula Bayi Padat (1307)",
    "Penambahan Fruktosa (%)",
    "=Negatif",
  ],
  [
    3577,
    "Formula Bayi Padat (1307)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    3578,
    "Formula Bayi Padat (1307)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3579,
    "Formula Khusus Untuk Anak (1381)",
    "Arsen (As) mg/kg (siap konsumsi)",
    "=0.02",
  ],
  [
    3580,
    "Formula Khusus Untuk Anak (1381)",
    "Timbal (Pb) mg/kg (siap konsumsi)",
    "=0.02",
  ],
  [
    3581,
    "Formula Khusus Untuk Anak (1381)",
    "Merkuri (Hg) mg/kg (siap konsumsi)",
    "=0.01",
  ],
  [
    3582,
    "Formula Khusus Untuk Anak (1381)",
    "Kadmium (Cd) mg/kg (siap konsumsi)",
    "=0.01",
  ],
  [
    3583,
    "Formula Khusus Untuk Anak (1381)",
    "Timah (Sn) mg/kg (siap konsumsi)",
    "=10",
  ],
  [
    3584,
    "Formula Lanjutan Bubuk (13010201)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3585,
    "Formula Lanjutan Bubuk (13010201)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3586,
    "Formula Lanjutan Bubuk (13010201)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3587,
    "Formula Lanjutan Bubuk (13010201)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3588,
    "Formula Lanjutan Bubuk (13010201)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3589,
    "Formula Lanjutan Bubuk (13010201)",
    "Aflatoksin M1 (jika berbasis susu) (ppb)",
    "=0.5",
  ],
  [
    3590,
    "Formula Lanjutan Cair (13010202)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3591,
    "Formula Lanjutan Cair (13010202)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3592,
    "Formula Lanjutan Cair (13010202)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3593,
    "Formula Lanjutan Cair (13010202)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3594,
    "Formula Lanjutan Cair (13010202)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3595,
    "Formula Lanjutan Cair (13010202)",
    "Aflatoksin M1 (jika berbasis susu) (ppb)",
    "=0.5",
  ],
  [
    3596,
    "Formula Lanjutan Cair (1310)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3597,
    "Formula Lanjutan Cair (1310)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3598,
    "Formula Lanjutan Cair (1310)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3599,
    "Formula Lanjutan Cair (1310)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3600,
    "Formula Lanjutan Cair (1310)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3601,
    "Formula Lanjutan Cair (1310)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3602,
    "Formula Lanjutan Cair (1310)",
    "Kadar Protein, bahan dasar susu sapi (g/100 kkal)",
    "=3.5",
    "=1.82",
  ],
  [
    3603,
    "Formula Lanjutan Cair (1310)",
    "Kadar Protein, bahan dasar kedelai (g/100 kkal)",
    "=3.5",
    "=2.25",
  ],
  [
    3604,
    "Formula Lanjutan Padat (1309)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3605,
    "Formula Lanjutan Padat (1309)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3606,
    "Formula Lanjutan Padat (1309)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3607,
    "Formula Lanjutan Padat (1309)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3608,
    "Formula Lanjutan Padat (1309)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3609,
    "Formula Lanjutan Padat (1309)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3610,
    "Formula Lanjutan Padat (1309)",
    "Kadar Protein, bahan dasar susu sapi (g/100 kkal)",
    "=3.5",
    "=1.82",
  ],
  [
    3611,
    "Formula Lanjutan Padat (1309)",
    "Kadar Protein, bahan dasar kedelai (g/100 kkal)",
    "=3.5",
    "=2.25",
  ],
  [
    3612,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3613,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3614,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3615,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3616,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3617,
    "Formula Pertumbuhan Bubuk (13010401)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    3618,
    "Formula Pertumbuhan Cair (13010402)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    3619,
    "Formula Pertumbuhan Cair (13010402)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3620,
    "Formula Pertumbuhan Cair (13010402)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3621,
    "Formula Pertumbuhan Cair (13010402)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    3622,
    "Formula Pertumbuhan Cair (13010402)",
    "Timah (Sn) (ppm atau mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=10",
  ],
  [
    3623,
    "Formula Pertumbuhan Cair (13010402)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    3624,
    "Formula Pertumbuhan Cair (1312)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3625,
    "Formula Pertumbuhan Cair (1312)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3626,
    "Formula Pertumbuhan Cair (1312)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3627,
    "Formula Pertumbuhan Cair (1312)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3628,
    "Formula Pertumbuhan Cair (1312)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3629,
    "Formula Pertumbuhan Cair (1312)",
    "Protein susu (g/100 kkal)",
    "=5.5",
    "=3",
  ],
  [
    3630,
    "Formula Pertumbuhan Cair (1312)",
    "Isolat protein kedelai (g/100 kkal)",
    "=5.8",
    "=3.2",
  ],
  [
    3631,
    "Formula Pertumbuhan Cair (1312)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3632,
    "Formula Pertumbuhan Padat (1311)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    3633,
    "Formula Pertumbuhan Padat (1311)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3634,
    "Formula Pertumbuhan Padat (1311)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3635,
    "Formula Pertumbuhan Padat (1311)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=10",
  ],
  [
    3636,
    "Formula Pertumbuhan Padat (1311)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    3637,
    "Formula Pertumbuhan Padat (1311)",
    "Protein susu (g/100 kkal)",
    "=5.5",
    "=3",
  ],
  [
    3638,
    "Formula Pertumbuhan Padat (1311)",
    "Isolat protein kedelai (g/100 kkal)",
    "=5.8",
    "=3.2",
  ],
  [
    3639,
    "Formula Pertumbuhan Padat (1311)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3640,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3641,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3642,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3643,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3644,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3645,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    3646,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    3647,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    3648,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Protein susu non hidrolisat (g/100 kkal) ",
    "",
    "=2",
  ],
  [
    3649,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    3650,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    3651,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    3652,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    3653,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    3654,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%) ",
    "=30",
  ],
  [
    3655,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml)",
    "=2",
  ],
  [
    3656,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    3657,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Penambahan Fruktosa (%)",
    "=Negatif",
  ],
  [
    3658,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    3659,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Bawah 1500 daltons (%)",
    "",
    "=95",
  ],
  [
    3660,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Atas 6000 daltons (%)",
    "=0.5",
  ],
  [
    3661,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Bawah 1000 daltons (%)",
    "",
    "=89",
  ],
  [
    3662,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Untuk Formula Asam Amino, Berat Molekul Di Atas 300 daltons (%)",
    "=Negatif",
  ],
  [
    3663,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Cair (1342)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3664,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3665,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3666,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3667,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3668,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3669,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    3670,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    3671,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    3672,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Protein susu non hidrolisat (g/100 kkal) ",
    "",
    "=2",
  ],
  [
    3673,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    3674,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    3675,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    3676,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    3677,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    3678,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%) ",
    "=30",
  ],
  [
    3679,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml)",
    "=2",
  ],
  [
    3680,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    3681,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Penambahan Fruktosa (%)",
    "=Negatif",
  ],
  [
    3682,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    3683,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Bawah 1500 daltons (%)",
    "",
    "=95",
  ],
  [
    3684,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Atas 6000 daltons (%)",
    "=0.5",
  ],
  [
    3685,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Untuk Formula Terhidrolisat Ekstensif, Berat Molekul Di Bawah 1000 daltons (%)",
    "",
    "=89",
  ],
  [
    3686,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Untuk Formula Asam Amino, Berat Molekul Di Atas 300 daltons (%)",
    "=Negatif",
  ],
  [
    3687,
    "Formula Untuk Keperluan Medis Khusus Bayi Dengan Alergi Protein Susu Sapi Padat (1341)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3688,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3689,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3690,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3691,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3692,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3693,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Cair (1340)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.03",
  ],
  [
    3694,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3695,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3696,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3697,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3698,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3699,
    "Formula Untuk Keperluan Medis Khusus Bayi Prematur Padat (1339)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/kg)",
    "=0.03",
  ],
  [
    3700,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3701,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3702,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3703,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3704,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3705,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Cair (1356)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3706,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3707,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3708,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3709,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3710,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3711,
    "Formula Untuk Keperluan Medis Khusus Untuk Bayi Dengan Kejang Intraktabel (Epilepsi) Padat (1355)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3712,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3713,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3714,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3715,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3716,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3717,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Protein susu (g/100 kkal)",
    "=5.5",
    "=3",
  ],
  [
    3718,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Isolat protein kedelai (g/100 kkal)",
    "=5.8",
    "=3.2",
  ],
  [
    3719,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Osmolalitas produk siap konsumsi (mOsm/kg)",
    "=430",
  ],
  [
    3720,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Cair (1346)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3721,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3722,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3723,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3724,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3725,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    3726,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Protein susu (g/100 kkal)",
    "=5.5",
    "=3",
  ],
  [
    3727,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Isolat protein kedelai (g/100 kkal)",
    "=5.8",
    "=3.2",
  ],
  [
    3728,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Osmolalitas produk siap konsumsi (mOsm/kg)",
    "=430",
  ],
  [
    3729,
    "Formula Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Anak Beresiko Gagal Tumbuh, Gizi Kurang, Atau Gizi Buruk Padat (1345)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3730,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3731,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3732,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3733,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3734,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3735,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3736,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Cair (1350)",
    "fenilalanin",
  ],
  [
    3737,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3738,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3739,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3740,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3741,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3742,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3743,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Fenilketonuria Padat (1349)",
    "fenilalanin",
  ],
  [
    3744,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3745,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3746,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3747,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3748,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3749,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3750,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Cair (1348)",
    "Leusin",
  ],
  [
    3751,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3752,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3753,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3754,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3755,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3756,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3757,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Isovaleric Acedemia Padat (1347)",
    "Leusin",
  ],
  [
    3758,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3759,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3760,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3761,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3762,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3763,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3764,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "valin",
  ],
  [
    3765,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "leusin",
  ],
  [
    3766,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1354)",
    "isoleusin",
  ],
  [
    3767,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3768,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3769,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3770,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3771,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3772,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3773,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "isoleusin",
  ],
  [
    3774,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "leusin",
  ],
  [
    3775,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1353)",
    "valin",
  ],
  [
    3776,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3777,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3778,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3779,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3780,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3781,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3782,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "fenilalanin",
  ],
  [
    3783,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1352)",
    "Tirosin",
  ],
  [
    3784,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    3785,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3786,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3787,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    3788,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    3789,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    3790,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "fenilalanin",
  ],
  [
    3791,
    "Formula Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1351)",
    "Tirosin",
  ],
  [
    3792,
    "French Dressing (12060104)",
    "Kadar lemak total (%)",
    "",
    "=35",
  ],
  [
    3793,
    "French Dressing (12060104)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3794,
    "French Dressing (12060104)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    3795,
    "French Dressing (12060104)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3796,
    "French Dressing (12060104)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3797,
    "French Dressing (12060104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3798,
    "French Dressing (12060104)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [3799, "Frosting (050402)", "Arsen (As) (mg/kg)", "=1"],
  [3800, "Frosting (050402)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [3801, "Frosting (050402)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    3802,
    "Frosting (050402)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3803,
    "Frosting (050402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3804, "Frosting (050402)", "Timbal (Pb) (mg/kg)", "=1"],
  [3805, "Fruktosa (11010103)", "D-glukosa (%)", "=95"],
  [
    3806,
    "Fruktosa (11010103)",
    "Kadar total padatan (%)",
    "",
    "=0.5",
  ],
  [
    3807,
    "Fruktosa (11010103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    3808,
    "Fruktosa (11010103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3809,
    "Fruktosa (11010103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3810,
    "Fruktosa (11010103)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3811,
    "Fruktosa (11010103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [3812, "Fudge (05020203)", "Arsen (As) (mg/kg)", "=1"],
  [3813, "Fudge (05020203)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [3814, "Fudge (05020203)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    3815,
    "Fudge (05020203)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3816,
    "Fudge (05020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3817, "Fudge (05020203)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3818,
    "Fuli Bubuk (12020136)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    3819,
    "Fuli Bubuk (12020136)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    3820,
    "Fuli Kering (12020135)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    3821,
    "Fuli Kering (12020135)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [3822, "Furikake (12020206)", "Arsen (mg/kg) ", "=0.15"],
  [3823, "Furikake (12020206)", "Kadmium (mg/kg) ", "=0.5"],
  [3824, "Furikake (12020206)", "Merkuri (mg/kg) ", "=0.05"],
  [3825, "Furikake (12020206)", "Timah (mg/kg) ", "=40"],
  [3826, "Furikake (12020206)", "Timbal (mg/kg) ", "=1"],
  [
    3827,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Kadar air (%) ",
    "=15",
  ],
  [
    3828,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Kehalusan : lolos ayakan 8 mesh (%) ",
    "",
    ">40",
  ],
  [
    3829,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Kehalusan : lolos ayakan 20 mesh (%) ",
    "<50",
  ],
  [
    3830,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    3831,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Cadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3832,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3833,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3834,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3835,
    "Gandum Hancur (Crushed Wheat) (060112)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    3836,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Kadar air (%) ",
    "=15",
  ],
  [
    3837,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Kehalusan : lolos ayakan 8 mesh (%) ",
    "",
    "=90",
  ],
  [
    3838,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Kehalusan : lolos ayakan 20 mesh (%) ",
    "=20",
  ],
  [
    3839,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    3840,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Cadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    3841,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3842,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3843,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3844,
    "Gandum Patah (Cracked Wheat) (060111)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    3845,
    "Garam Berbumbu (12010110)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3846,
    "Garam Berbumbu (12010110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3847,
    "Garam Berbumbu (12010110)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3848,
    "Garam Berbumbu (12010110)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    3849,
    "Garam Berbumbu (12010110)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [3850, "Garam Berbumbu (12010110)", "Timbal (Pb) (mg/kg)", "=1"],
  [3851, "Garam Berbumbu (12010110)", "Kadar NaCl (%)", "", "=50"],
  [
    3852,
    "Garam Berbumbu (12010110)",
    "Kadar iodium dihitung sebagai KIO3 (mg/kg)",
    "",
    "=15.95",
  ],
  [3853, "Garam Cair (12010108)", "Kadar NaCl (%) ", "", "=23"],
  [3854, "Garam Cair (12010108)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [3855, "Garam Cair (12010108)", "Timbal (Pb) (mg/kg)", "=1"],
  [3856, "Garam Cair (12010108)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [3857, "Garam Cair (12010108)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    3858,
    "Garam Campuran (12010106)",
    "Kandungan NaCl (%)",
    "",
    "=50",
  ],
  [
    3859,
    "Garam Campuran (12010106)",
    "Yodium sebagai kalium iodat (mg/kg adbk)",
    "=15.95",
  ],
  [
    3860,
    "Garam Campuran (12010106)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3861,
    "Garam Campuran (12010106)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [3862, "Garam Campuran (12010106)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3863,
    "Garam Campuran (12010106)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [3864, "Garam Campuran (12010106)", "Timah (Sn) (mg/kg)", "=40"],
  [3865, "Garam Diet (12010112)", "Arsen (As) (mg/kg)", "=0.15"],
  [3866, "Garam Diet (12010112)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [3867, "Garam Diet (12010112)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [3868, "Garam Diet (12010112)", "Timah (Sn) (mg/kg)", "=40"],
  [3869, "Garam Diet (12010112)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3870,
    "Garam Diet (12010112)",
    "Kadar Iodium dihitung sebagai KIO3 (mg/kg)",
    "",
    "=30",
  ],
  [
    3871,
    "Garam Diet (12010112)",
    "Kadar klorida (KCl) (atas dasar bahan kering) (%)",
    "=40",
  ],
  [
    3872,
    "Garam Diet (12010112)",
    "Kadar NaCl (atas dasar bahan kering) (%)",
    "=60",
  ],
  [3873, "Garam Gurih (12010107)", "NaCl (%)", "", "=87"],
  [
    3874,
    "Garam Gurih (12010107)",
    "Penyedap rasa dihitung sebagai mononatrium L-glutamat (%)",
    "=12",
    "=9",
  ],
  [
    3875,
    "Garam Gurih (12010107)",
    "Yodium, dihitung sebagai kalium Iodat (KIO3) (mg/kg)",
    "=80",
    "=30",
  ],
  [3876, "Garam Gurih (12010107)", "Arsen (As) (mg/kg)", "=0.15"],
  [3877, "Garam Gurih (12010107)", "Tembaga (Cu) (mg/kg)", "=10"],
  [3878, "Garam Gurih (12010107)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [3879, "Garam Gurih (12010107)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    3880,
    "Garam Industri Aneka Pangan (12010111)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3881,
    "Garam Industri Aneka Pangan (12010111)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3882,
    "Garam Industri Aneka Pangan (12010111)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3883,
    "Garam Industri Aneka Pangan (12010111)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    3884,
    "Garam Industri Aneka Pangan (12010111)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    3885,
    "Garam Industri Aneka Pangan (12010111)",
    "Kadar NaCl (basis kering) (%)",
    "",
    "=97",
  ],
  [
    3886,
    "Garam Industri Aneka Pangan (12010111)",
    "Kadar Iodium dihitung sebagai KIO3 (mg/kg)",
    "",
    "=30",
  ],
  [
    3887,
    "Garam Konsumsi Beriodium (12010103)",
    "Kadar air (H2O) (% b/b)",
    "=7",
  ],
  [
    3888,
    "Garam Konsumsi Beriodium (12010103)",
    "Kadar NaCl (natrium klorida) dihitung dari jumlah klorida (Cl) (b/b) adbk (%)",
    "",
    "=94",
  ],
  [
    3889,
    "Garam Konsumsi Beriodium (12010103)",
    "Yodium dihitung sebagai Kalium Iodidat (KIO3) adbk (mg/kg)",
    "",
    "=30",
  ],
  [
    3890,
    "Garam Konsumsi Beriodium (12010103)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3891,
    "Garam Konsumsi Beriodium (12010103)",
    "Merkuri (Hg) (mg/kg)",
    "=0.1",
  ],
  [
    3892,
    "Garam Konsumsi Beriodium (12010103)",
    "Timbal (Pb) (mg/kg)",
    "=10",
  ],
  [
    3893,
    "Garam Konsumsi Beriodium (12010103)",
    "Kadmium (Cd) (mg/kg) *",
    "=0.5",
  ],
  [
    3894,
    "Garam Konsumsi Beriodium (12010103)",
    "Bagian yang tidak larut dalam air (b/b) adbk (%) *",
    "=0.5",
  ],
  [
    3895,
    "Garam Konsumsi Beriodium (12010103)",
    "Tembaga (Cu) (mg/kg) *",
    "=10",
  ],
  [
    3896,
    "Garam Kurang Natrium (12010109)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3897,
    "Garam Kurang Natrium (12010109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3898,
    "Garam Kurang Natrium (12010109)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3899,
    "Garam Kurang Natrium (12010109)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3900,
    "Garam Kurang Natrium (12010109)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3901,
    "Garam Kurang Natrium (12010109)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    3902,
    "Garam Kurang Natrium (12010109)",
    "Kadar natrium klorida (NaCl) (g/100g)",
    "=25",
  ],
  [
    3903,
    "Garam Kurang Natrium (12010109)",
    "Kadar iodium sebagai KIO3 (mg/kg)",
    "",
    "=30",
  ],
  [
    3904,
    "Garam Kurang Natrium (12010109)",
    "Komponen lain yang dapat digunakan adalah garam kalium; garam kalsium; garam magnesium; garam amonium; atau campurannya.",
  ],
  [3905, "Genever (14020611)", "Kadar etanol (% v/v)", "", "=30"],
  [
    3906,
    "Genever (14020611)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [3907, "Genever (14020611)", "Arsen (mg/kg)", "=0.1"],
  [3908, "Genever (14020611)", "Kadmium (mg/kg)", "=0.2"],
  [3909, "Genever (14020611)", "Merkuri (mg/kg)", "=0.03"],
  [
    3910,
    "Genever (14020611)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    3911,
    "Genever (14020611)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3912, "Genever (14020611)", "Timbal (mg/kg)", "=0.2"],
  [3913, "Geplak (0401021210)", "Kadar air (%)", "=14"],
  [
    3914,
    "Geplak (0401021210)",
    "Kadar gula (sebagai sakarosa) (%)",
    "",
    "=68",
  ],
  [3915, "Geplak (0401021210)", "Kadar serat kasar (%)", "=2.5"],
  [3916, "Geplak (0401021210)", "Arsen (As) (mg/kg) ", "=0.15"],
  [3917, "Geplak (0401021210)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [3918, "Geplak (0401021210)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    3919,
    "Geplak (0401021210)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    3920,
    "Geplak (0401021210)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [3921, "Geplak (0401021210)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [3922, "Getas (150307)", "Arsen (As) (ppm atau mg/kg)", "=0.25"],
  [
    3923,
    "Getas (150307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [3924, "Getas (150307)", "Raksa (Hg) (ppm atau mg/kg)", "=0.03"],
  [
    3925,
    "Getas (150307)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [3926, "Getas (150307)", "Timbal (Pb) (ppm atau mg/kg)", "=0.25"],
  [
    3927,
    "Getuk Singkong (0402020803)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    3928,
    "Getuk Singkong (0402020803)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3929,
    "Getuk Singkong (0402020803)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3930,
    "Getuk Singkong (0402020803)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    3931,
    "Getuk Singkong (0402020803)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [3932, "Ghee (02010102)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    3933,
    "Ghee (02010102)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    3934,
    "Ghee (02010102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3935,
    "Ghee (02010102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3936,
    "Ghee (02010102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3937, "Ghee (02010102)", "Timbal (Pb) (mg/kg)", "=0.1"],
  [3938, "Ghee (02010102)", "Kadar air (%)", "=0.1"],
  [
    3939,
    "Ghee (02010102)",
    "Kadar asam lemak bebas (sebagai asam oleat) (%)",
    "=0.4",
  ],
  [3940, "Gin (14020607)", "Kadar etanol (%)", "", "=37.5"],
  [
    3941,
    "Gin (14020607)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [3942, "Gin (14020607)", "Arsen (mg/kg)", "=0.1"],
  [3943, "Gin (14020607)", "Kadmium (mg/kg)", "=0.2"],
  [3944, "Gin (14020607)", "Merkuri (mg/kg)", "=0.03"],
  [
    3945,
    "Gin (14020607)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    3946,
    "Gin (14020607)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [3947, "Gin (14020607)", "Timbal (mg/kg)", "=0.2"],
  [3948, "Ginger Ale (1401040109)", "Kandungan (Brix)", "=14"],
  [
    3949,
    "Ginger Ale (1401040109)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3950,
    "Ginger Ale (1401040109)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3951,
    "Ginger Ale (1401040109)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    3952,
    "Ginger Ale (1401040109)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    3953,
    "Ginger Ale (1401040109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    3954,
    "Ginger Ale (1401040109)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    3955,
    "Glukosa (11010306)",
    "Gula pereduksi (sebagao dektrosa anhidrat) (%)",
    "",
    "=70",
  ],
  [3956, "Glukosa (11010306)", "Arsen (As) (ppm atau mg/kg)", "=1"],
  [
    3957,
    "Glukosa (11010306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3958,
    "Glukosa (11010306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3959,
    "Glukosa (11010306)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3960,
    "Glukosa (11010306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [3961, "Gochujang (0402020709)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    3962,
    "Gochujang (0402020709)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    3963,
    "Gochujang (0402020709)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    3964,
    "Gochujang (0402020709)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    3965,
    "Gochujang (0402020709)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [3966, "Gochujang (0402020709)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    3967,
    "Gochujang (Saus Fermentasi) (12060226)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    3968,
    "Gochujang (Saus Fermentasi) (12060226)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    3969,
    "Gochujang (Saus Fermentasi) (12060226)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    3970,
    "Gochujang (Saus Fermentasi) (12060226)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    3971,
    "Gochujang (Saus Fermentasi) (12060226)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [3972, "Granola (060317)", "Arsen (As) (mg/kg)", "=0.1"],
  [3973, "Granola (060317)", "Kadmium (Cd)(mg/kg)", "=0.05"],
  [3974, "Granola (060317)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    3975,
    "Granola (060317)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    3976,
    "Granola (060317)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [3977, "Granola (060317)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    3978,
    "Gula Aren (110201)",
    "Kadar gula (sebagai sakarosa)(%)",
    "",
    "=77",
  ],
  [3979, "Gula Aren (110201)", "Kadar air (%)", "=10"],
  [3980, "Gula Aren (110201)", "Arsen (As) (ppm atau mg/kg)", "=1"],
  [
    3981,
    "Gula Aren (110201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3982,
    "Gula Aren (110201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3983,
    "Gula Aren (110201)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3984,
    "Gula Aren (110201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [3985, "Gula Aren Cair (110409)", "Arsen (As) (mg/kg)", "=1"],
  [3986, "Gula Aren Cair (110409)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [
    3987,
    "Gula Aren Cair (110409)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    3988,
    "Gula Aren Cair (110409)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg)",
    "=250",
  ],
  [
    3989,
    "Gula Aren Cair (110409)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [3990, "Gula Aren Cair (110409)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [3991, "Gula Batu (110406)", "Arsen (As) (ppm atau mg/kg)", "=1"],
  [
    3992,
    "Gula Batu (110406)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    3993,
    "Gula Batu (110406)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    3994,
    "Gula Batu (110406)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg)",
    "=250",
  ],
  [
    3995,
    "Gula Batu (110406)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    3996,
    "Gula Batu (110406)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    3997,
    "Gula Coklat Sukrosa (110206)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    3998,
    "Gula Coklat Sukrosa (110206)",
    "Kadmium (Cd)(mg/kg)",
    "=0.2",
  ],
  [
    3999,
    "Gula Coklat Sukrosa (110206)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4000,
    "Gula Coklat Sukrosa (110206)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4001,
    "Gula Coklat Sukrosa (110206)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    4002,
    "Gula Coklat Sukrosa (110206)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [4003, "Gula Hias (110408)", "Arsen (As) (mg/kg)", "=1"],
  [4004, "Gula Hias (110408)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [4005, "Gula Hias (110408)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    4006,
    "Gula Hias (110408)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4007,
    "Gula Hias (110408)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [4008, "Gula Hias (110408)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    4009,
    "Gula Invert (110303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4010,
    "Gula Invert (110303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4011,
    "Gula Invert (110303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4012,
    "Gula Invert (110303)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4013,
    "Gula Invert (110303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4014,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    4015,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4016,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4017,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4018,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4019,
    "Gula Kapas (Cotton Candy)/Arumanis (05020211)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4020,
    "Gula Kastor (11010310)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4021,
    "Gula Kastor (11010310)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4022,
    "Gula Kastor (11010310)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4023,
    "Gula Kastor (11010310)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4024,
    "Gula Kastor (11010310)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4025,
    "Gula Kelapa (110204)",
    "Kadar gula (sebagai sakarosa)(%)",
    "",
    "=77",
  ],
  [
    4026,
    "Gula Kelapa (110204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4027,
    "Gula Kelapa (110204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4028,
    "Gula Kelapa (110204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4029,
    "Gula Kelapa (110204)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4030,
    "Gula Kelapa (110204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4031,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Warna Kristal (CT)",
    "=7.5",
    "=4",
  ],
  [
    4032,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Warna Larutan (ICUMSA) (IU)",
    "=200",
    "=81",
  ],
  [
    4033,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Besar Jenis Butir (mm)",
    "=1.2",
    "=0.8",
  ],
  [
    4034,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Susut Pengeringan (b/b) (%)",
    "=0.1",
  ],
  [
    4035,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Polarisasi (\xB0Z, 20\xB0C) (\"Z\")",
    "",
    "=99.6",
  ],
  [
    4036,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Abu Konduktiviti (b/b) (%)",
    "=0.1",
  ],
  [
    4037,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Belerang Dioksida (SO2) (mg/kg)",
    "=30",
  ],
  [
    4038,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    4039,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Tembaga (Cu) (mg/kg)",
    "=2",
  ],
  [
    4040,
    "Gula Kristal Putih (GKP1) (11010502)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4041,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Warna Kristal (CT)",
    "=10",
    "=7.6",
  ],
  [
    4042,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Warna Larutan (ICUMSA) (IU)",
    "=300",
    "=201",
  ],
  [
    4043,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Besar Jenis Butir (mm)",
    "=1.2",
    "=0.8",
  ],
  [
    4044,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Susut Pengeringan (b/b) (%)",
    "=0.1",
  ],
  [
    4045,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Polarisasi (\xB0Z, 20\xB0C) (Z)",
    "",
    "=99.5",
  ],
  [
    4046,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Abu Konduktiviti (b/b) (%)",
    "=0.15",
  ],
  [
    4047,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Belerang Dioksida (SO2) (mg/kg)",
    "=30",
  ],
  [
    4048,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    4049,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Tembaga (Cu) (mg/kg)",
    "=2",
  ],
  [
    4050,
    "Gula Kristal Putih (GKP2) (11010503)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4051,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Nilai polarisasi (Z)",
    "",
    "=99.5",
  ],
  [
    4052,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "ALT (30oC, 72 jam) (koloni/g)",
    "=3000",
  ],
  [
    4053,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Koliform (APM/g)",
    "<3",
  ],
  [
    4054,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Kapang dan khamir (koloni/g)",
    "=100",
  ],
  [
    4055,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4056,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4057,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4058,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4059,
    "Gula Kristal Putih atau Gula Pasir (11010501)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    4060,
    "Gula Merah Lunak (11010302)",
    "Kadar gula invert (%)",
    "",
    "=88",
  ],
  [
    4061,
    "Gula Merah Lunak (11010302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4062,
    "Gula Merah Lunak (11010302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4063,
    "Gula Merah Lunak (11010302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4064,
    "Gula Merah Lunak (11010302)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4065,
    "Gula Merah Lunak (11010302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4066,
    "Gula Merah Tebu/Saka (110203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4067,
    "Gula Merah Tebu/Saka (110203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4068,
    "Gula Merah Tebu/Saka (110203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4069,
    "Gula Merah Tebu/Saka (110203)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4070,
    "Gula Merah Tebu/Saka (110203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4071,
    "Gula Palma (110202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4072,
    "Gula Palma (110202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4073,
    "Gula Palma (110202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4074,
    "Gula Palma (110202)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4075,
    "Gula Palma (110202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4076,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    4077,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    4078,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4079,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4080,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4081,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4082,
    "Gula Palma Serbuk (Gula Semut) (110207)",
    "Kadar air (%)",
    "= 3",
  ],
  [
    4083,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4084,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4085,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4086,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4087,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4088,
    "Gula Pasir dengan Pemanis Buatan (110601)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    4089,
    "Gula Pasir Mentah (11010305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4090,
    "Gula Pasir Mentah (11010305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4091,
    "Gula Pasir Mentah (11010305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4092,
    "Gula Pasir Mentah (11010305)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4093,
    "Gula Pasir Mentah (11010305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4094,
    "Gula Semut (110205)",
    "Kadar gula (sebagai sakarosa)(%)",
    "",
    "=80",
  ],
  [
    4095,
    "Gula Semut (110205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4096,
    "Gula Semut (110205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4097,
    "Gula Semut (110205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4098,
    "Gula Semut (110205)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4099,
    "Gula Semut (110205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4100,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4101,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4102,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4103,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    4104,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4105,
    "Gula Serbuk (Icing Sugar) / Tepung Gula / Gula Halus (11010201)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [4106, "Gula Sukrosa Cair (110307)", "Arsen (As) (mg/kg)", "=1"],
  [
    4107,
    "Gula Sukrosa Cair (110307)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    4108,
    "Gula Sukrosa Cair (110307)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4109,
    "Gula Sukrosa Cair (110307)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4110,
    "Gula Sukrosa Cair (110307)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4111,
    "Gula Sukrosa Cair (110307)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4112,
    "Gula Sukrosa Cair (110307)",
    "Kadar sukrosa (% \xBA Brix)",
    "",
    "=65",
  ],
  [4113, "Gula Tebu Mentah (11010311)", "Arsen (As) (mg/kg)", "=1"],
  [
    4114,
    "Gula Tebu Mentah (11010311)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    4115,
    "Gula Tebu Mentah (11010311)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4116,
    "Gula Tebu Mentah (11010311)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4117,
    "Gula Tebu Mentah (11010311)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4118,
    "Gula Tebu Mentah (11010311)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [4119, "Gulali (05020213)", "Arsen (As) (mg/kg)", "=1"],
  [4120, "Gulali (05020213)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [4121, "Gulali (05020213)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    4122,
    "Gulali (05020213)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4123,
    "Gulali (05020213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4124, "Gulali (05020213)", "Timbal (Pb) (mg/kg)", "=1"],
  [4125, "Gulali (05020302)", "Arsen (As) (mg/kg)", "=1"],
  [4126, "Gulali (05020302)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [4127, "Gulali (05020302)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    4128,
    "Gulali (05020302)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4129,
    "Gulali (05020302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4130, "Gulali (05020302)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    4131,
    "Gyoza (08030304)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4132,
    "Gyoza (08030304)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4133,
    "Gyoza (08030304)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4134,
    "Gyoza (08030304)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4135,
    "Gyoza (08030304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4136,
    "Gyoza (08030304)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [4137, "Gyoza (08030304)", "Kandungan daging (%)", "", "=15"],
  [
    4138,
    "Half and Half (01040102)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    4139,
    "Half and Half (01040102)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    4140,
    "Half and Half (01040102)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    4141,
    "Half and Half (01040102)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    4142,
    "Half and Half (01040102)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    4143,
    "Half and Half (01040102)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    4144,
    "Half and Half (01040102)",
    "Aflatoksin M1 (mcg/kg) ",
    "=0.5",
  ],
  [
    4145,
    "Half and Half (01040102)",
    "Kadar lemak susu (%)",
    "=34",
    "=18",
  ],
  [4146, "Half and Half (01040102)", "Krim susu (%)", "", "=10.5"],
  [
    4147,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Krim Susu (%)",
    "",
    "=10.5",
  ],
  [
    4148,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    4149,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    4150,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    4151,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    4152,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    4153,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    4154,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    4155,
    "Half and Half (Steril Komersial / Tetrapak) (01040103)",
    "Kadar lemak susu (%)",
    "=34",
    "=18",
  ],
  [
    4156,
    "Halidan (100305)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4157,
    "Halidan (100305)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    4158,
    "Halidan (100305)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4159,
    "Halidan (100305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4160,
    "Halidan (100305)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4161,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4162,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4163,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4164,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4165,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4166,
    "Ham Sapi (Daging Paha Sapi Kuring) Matang (08020203)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    4167,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4168,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4169,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4170,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4171,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4172,
    "Ham Tipe Prosciutto (Italian Style Ham) (0802010204)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    4173,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    4174,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4175,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4176,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4177,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4178,
    "Hasil Olah Gula (Butiran, dll) (05020105)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4179,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4180,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4181,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4182,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    4183,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    4184,
    "Hasil Olah Iles-iles Dalam Bentuk Jeli (0402020612)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4185,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4186,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4187,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4188,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4189,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4190,
    "Hasil Olahan Sawit - Pengganti Santan (020303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4191,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4192,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4193,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4194,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4195,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4196,
    "Herba dan Rempah yang Diproses dengan Pemasakan, Fermentasi dan atau Penambahan Bahan Tambahan Pangan (120201B3)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4197,
    "Human Milk Fortifier (HMF) Cair (1344)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    4198,
    "Human Milk Fortifier (HMF) Cair (1344)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    4199,
    "Human Milk Fortifier (HMF) Cair (1344)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    4200,
    "Human Milk Fortifier (HMF) Cair (1344)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    4201,
    "Human Milk Fortifier (HMF) Cair (1344)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    4202,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    4203,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    4204,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    4205,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    4206,
    "Human Milk Fortifier (HMF) Padat (1343)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=10",
  ],
  [
    4207,
    "Hydrolised Vegetable Protein (HVP) (121003)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4208,
    "Hydrolised Vegetable Protein (HVP) (121003)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4209,
    "Hydrolised Vegetable Protein (HVP) (121003)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4210,
    "Hydrolised Vegetable Protein (HVP) (121003)",
    "Timah (mg/kg)",
    "=40",
  ],
  [
    4211,
    "Hydrolised Vegetable Protein (HVP) (121003)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [4212, "Icing (050401)", "Arsen (As) (mg/kg)", "=1"],
  [4213, "Icing (050401)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [4214, "Icing (050401)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    4215,
    "Icing (050401)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4216,
    "Icing (050401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4217, "Icing (050401)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    4218,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=10",
  ],
  [
    4219,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4220,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4221,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4222,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4223,
    "Ikan / Cumi-Cumi / Kerang / ... Analog dalam Kaleng (0902040121)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [4224, "Ikan Asap (09020501)", "As (ppm atau mg/kg) ", "=0.25"],
  [4225, "Ikan Asap (09020501)", "Cd (ppm atau mg/kg) ", "=0.1"],
  [4226, "Ikan Asap (09020501)", "Hg (ppm atau mg/kg) ", "=0.5"],
  [
    4227,
    "Ikan Asap (09020501)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4228,
    "Ikan Asap (09020501)",
    "Sn (dalam kaleng) (ppm atau mg/kg) ",
    "=250",
  ],
  [4229, "Ikan Asap (09020501)", "Pb (ppm atau mg/kg) ", "=0.2"],
  [
    4230,
    "Ikan Asin Jambal Roti (09020530)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4231,
    "Ikan Asin Jambal Roti (09020530)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4232,
    "Ikan Asin Jambal Roti (09020530)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4233,
    "Ikan Asin Jambal Roti (09020530)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4234,
    "Ikan Asin Jambal Roti (09020530)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4235,
    "Ikan Asin Jambal Roti (09020530)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4236,
    "Ikan Asin Kering (09020503)",
    "Organoleptik Nilai Minimal (Angka 1-9)",
    "",
    "=7",
  ],
  [4237, "Ikan Asin Kering (09020503)", "Kadar air (%)", "=40"],
  [
    4238,
    "Ikan Asin Kering (09020503)",
    "Kadar garam (%) (b/b)",
    "=20",
  ],
  [
    4239,
    "Ikan Asin Kering (09020503)",
    "Kadar abu tak larut dalam asam (%) (b/b)",
    "=0.3",
  ],
  [
    4240,
    "Ikan Asin Kering (09020503)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4241,
    "Ikan Asin Kering (09020503)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4242,
    "Ikan Asin Kering (09020503)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4243,
    "Ikan Asin Kering (09020503)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4244,
    "Ikan Asin Kering (09020503)",
    "Sn (dalam kaleng) (ppm atau mg/kg)",
    "=250",
  ],
  [
    4245,
    "Ikan Asin Kering (09020503)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4246,
    "Ikan Dalam Kemasan (090418)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4247,
    "Ikan Dalam Kemasan (090418)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4248,
    "Ikan Dalam Kemasan (090418)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4249,
    "Ikan Dalam Kemasan (090418)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4250,
    "Ikan Dalam Kemasan (090418)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4251,
    "Ikan Dalam Kemasan (090418)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4252,
    "Ikan Dalam Kemasan (090418)",
    "Bobot Tuntas (%)",
    "",
    "=50",
  ],
  [
    4253,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4254,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4255,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4256,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4257,
    "Ikan dan Produk Ikan Kukus atau Rebus (0902040101)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4258,
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi) (090413)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4259,
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi) (090413)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4260,
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi) (090413)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4261,
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi) (090413)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4262,
    "Ikan dan Produk Perikanan (Termasuk Moluska, Krustase, dan Ekinodermata) dalam Kemasan (Sterilisasi) (090413)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [4263, "Ikan Kalengan (090401)", "Arsen (As) (mg/kg)", "=0.25"],
  [4264, "Ikan Kalengan (090401)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [4265, "Ikan Kalengan (090401)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [4266, "Ikan Kalengan (090401)", "Timah (Sn) (mg/kg)", "=250"],
  [4267, "Ikan Kalengan (090401)", "Timbal (Pb) mg/kg", "=0.2"],
  [4268, "Ikan Kering (09020524)", "As (ppm atau mg/kg)", "=0.25"],
  [4269, "Ikan Kering (09020524)", "Cd (ppm atau mg/kg)", "=0.1"],
  [4270, "Ikan Kering (09020524)", "Hg (ppm atau mg/kg)", "=0.5"],
  [
    4271,
    "Ikan Kering (09020524)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4272,
    "Ikan Kering (09020524)",
    "Sn (dalam kaleng) (ppm atau mg/kg)",
    "=250",
  ],
  [4273, "Ikan Kering (09020524)", "Pb (ppm atau mg/kg)", "=0.2"],
  [
    4274,
    "Ikan Panggang (0902040305)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4275,
    "Ikan Panggang (0902040305)",
    "Cd (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    4276,
    "Ikan Panggang (0902040305)",
    "Hg (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    4277,
    "Ikan Panggang (0902040305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4278,
    "Ikan Panggang (0902040305)",
    "Sn (dalam kaleng) (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4279,
    "Ikan Panggang (0902040305)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [4280, "Ikan Peda (09020531)", "Arsen (As) (mg/kg)", "=0.25"],
  [4281, "Ikan Peda (09020531)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [4282, "Ikan Peda (09020531)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [
    4283,
    "Ikan Peda (09020531)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4284,
    "Ikan Peda (09020531)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [4285, "Ikan Peda (09020531)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    4286,
    "Ikan Pindang Garam (0902040104)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4287,
    "Ikan Pindang Garam (0902040104)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4288,
    "Ikan Pindang Garam (0902040104)",
    "Hg (ppm atau mg/kg",
    "=0.5",
  ],
  [
    4289,
    "Ikan Pindang Garam (0902040104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4290,
    "Ikan Pindang Garam (0902040104)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [4291, "Ikan Renyah (0902040314)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    4292,
    "Ikan Renyah (0902040314)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    4293,
    "Ikan Renyah (0902040314)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    4294,
    "Ikan Renyah (0902040314)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4295,
    "Ikan Renyah (0902040314)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [4296, "Ikan Renyah (0902040314)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    4297,
    "Ikan Teri Asin Kering (09020504)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4298,
    "Ikan Teri Asin Kering (09020504)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4299,
    "Ikan Teri Asin Kering (09020504)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4300,
    "Ikan Teri Asin Kering (09020504)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4301,
    "Ikan Teri Asin Kering (09020504)",
    "Sn (dalam kaleng) (ppm atau mg/kg)",
    "=250",
  ],
  [
    4302,
    "Ikan Teri Asin Kering (09020504)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [4303, "Ikura (09030307)", "Arsen (As) (mg/kg)", "=0.25"],
  [4304, "Ikura (09030307)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [4305, "Ikura (09030307)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [4306, "Ikura (09030307)", "Timah (Sn) (mg/kg)", "=40"],
  [4307, "Ikura (09030307)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    4308,
    "Jagung Berondong (150119)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4309,
    "Jagung Berondong (150119)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4310,
    "Jagung Berondong (150119)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4311,
    "Jagung Berondong (150119)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4312,
    "Jagung Berondong (150119)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4313,
    "Jagung Berondong (150119)",
    "Aflatoksin B1 (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    4314,
    "Jagung Berondong (150119)",
    "Aflatoksin Total (ppb atau mcg/Kg)",
    "=20",
  ],
  [
    4315,
    "Jagung Bertongkol Beku (0402020110)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4316,
    "Jagung Bertongkol Beku (0402020110)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4317,
    "Jagung Bertongkol Beku (0402020110)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4318,
    "Jagung Bertongkol Beku (0402020110)",
    "Timah (Sn) untuk produk yang diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4319,
    "Jagung Bertongkol Beku (0402020110)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4320,
    "Jagung Bertongkol Beku (0402020110)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    4321,
    "Jagung Bertongkol Beku (0402020110)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4322,
    "Jagung Bertongkol Beku (0402020110)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4323,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4324,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4325,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4326,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    4327,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    4328,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    4329,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Bobot Tuntas (%)",
  ],
  [
    4330,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4331,
    "Jagung Manis Dalam Kemasan (0402020403)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4332,
    "Jagung Marning (150120)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4333,
    "Jagung Marning (150120)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4334,
    "Jagung Marning (150120)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4335,
    "Jagung Marning (150120)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4336,
    "Jagung Marning (150120)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4337,
    "Jagung Marning (150120)",
    "Aflatoksin B1 (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    4338,
    "Jagung Marning (150120)",
    "Aflatoksin Total (ppb atau mcg/Kg)",
    "=20",
  ],
  [4339, "Jagung Pipil (060113)", "Arsen (As) (mg/kg)", "=0.1"],
  [4340, "Jagung Pipil (060113)", "Cadmium (Cd) (mg/kg)", "=0.05"],
  [4341, "Jagung Pipil (060113)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    4342,
    "Jagung Pipil (060113)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4343,
    "Jagung Pipil (060113)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4344, "Jagung Pipil (060113)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    4345,
    "Jagung Pipil (060113)",
    "Aflatoksin B1 (ppb atau mcg/Kg) ",
    "=15",
  ],
  [
    4346,
    "Jagung Pipil (060113)",
    "Aflatoksin Total (ppb atau mcg/Kg) ",
    "=20",
  ],
  [4347, "Jagung Pipil (060113)", "Kadar Air (%)", "=15.5"],
  [4348, "Jahe Bubuk (12020140)", "Kadar air (%)", "=13"],
  [
    4349,
    "Jahe Bubuk (12020140)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    4350,
    "Jahe Bubuk (12020140)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4351,
    "Jahe Bubuk (12020140)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4352,
    "Jahe Bubuk (12020140)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4353,
    "Jahe Bubuk (12020140)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4354, "Jahe Bubuk (12020140)", "Timbal (ppm atau mg/kg)", "=1"],
  [
    4355,
    "Jahe Bubuk (12020140)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4356,
    "Jahe Bubuk (12020140)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4357,
    "Jahe Kering (12020138)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    4358,
    "Jahe Kering (12020138)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    4359,
    "Jahe Kristalisasi (0402020609)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4360,
    "Jahe Kristalisasi (0402020609)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4361,
    "Jahe Kristalisasi (0402020609)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4362,
    "Jahe Kristalisasi (0402020609)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4363,
    "Jahe Kristalisasi (0402020609)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4364,
    "Jahe Kristalisasi (0402020609)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4365,
    "Jahe Segar (12020137)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4366,
    "Jahe Segar (12020137)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4367,
    "Jamur Asin (0402020303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4368,
    "Jamur Asin (0402020303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4369,
    "Jamur Asin (0402020303)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4370,
    "Jamur Asin (0402020303)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4371,
    "Jamur Asin (0402020303)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4372,
    "Jamur Asin (0402020303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4373,
    "Jamur Beku (0402020108)",
    "Jamur iris kering, ketebalan irisan (mm)",
    "=4",
    "=1",
  ],
  [
    4374,
    "Jamur Beku (0402020108)",
    "Jamur kering yang dikeringkan dengan pengering beku; kadar air (%)",
    "=6",
  ],
  [
    4375,
    "Jamur Beku (0402020108)",
    "Jamur kering yang dikeringkan dengan cara lain; kadar air (%)",
    "=12",
  ],
  [
    4376,
    "Jamur Beku (0402020108)",
    "Jamur Shitake kering; kadar air (%)",
    "=13",
  ],
  [4377, "Jamur Beku (0402020108)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    4378,
    "Jamur Beku (0402020108)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4379,
    "Jamur Beku (0402020108)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4380,
    "Jamur Beku (0402020108)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4381,
    "Jamur Beku (0402020108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4382, "Jamur Beku (0402020108)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    4383,
    "Jamur Dalam Kemasan (0402020404)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4384,
    "Jamur Dalam Kemasan (0402020404)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4385,
    "Jamur Dalam Kemasan (0402020404)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4386,
    "Jamur Dalam Kemasan (0402020404)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4387,
    "Jamur Dalam Kemasan (0402020404)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [4388, "Jamur Dalam Kemasan (0402020404)", "Bobot Tuntas (%)"],
  [
    4389,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4390,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4391,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4392,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4393,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4394,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4395,
    "Jamur Dalam Minyak Zaitun atau Jamur Dalam Minyak Nabati Lain (0402020301)",
    "Kadar garam (%) (Jika produk jamur diasinkan)",
    "=1",
  ],
  [
    4396,
    "Jamur Fermentasi (0402020704)",
    "Kadar asam laktat sebagai hasil fermentasi (%)",
    "=1",
  ],
  [
    4397,
    "Jamur Fermentasi (0402020704)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4398,
    "Jamur Fermentasi (0402020704)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4399,
    "Jamur Fermentasi (0402020704)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4400,
    "Jamur Fermentasi (0402020704)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4401,
    "Jamur Fermentasi (0402020704)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4402,
    "Jamur Fermentasi (0402020704)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4403,
    "Jamur Kering (0402020203)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4404,
    "Jamur Kering (0402020203)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4405,
    "Jamur Kering (0402020203)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4406,
    "Jamur Kering (0402020203)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4407,
    "Jamur Kering (0402020203)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4408,
    "Jamur Kering (0402020203)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    4409,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4410,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4411,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4412,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Timah (Sn) (mg/kg) untuk pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng",
    "=250",
  ],
  [
    4413,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4414,
    "Jantung Artichoke yang Diasinkan (0402020310)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [4415, "Jeli Agar (0401020903)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    4416,
    "Jeli Agar (0401020903)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4417,
    "Jeli Agar (0401020903)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4418,
    "Jeli Agar (0401020903)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4419,
    "Jeli Agar (0401020903)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4420, "Jeli Agar (0401020903)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    4421,
    "Jeli Agar Bubuk (0401020917)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4422,
    "Jeli Agar Bubuk (0401020917)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4423,
    "Jeli Agar Bubuk (0401020917)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    4424,
    "Jeli Agar Bubuk (0401020917)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    4425,
    "Jeli Agar Bubuk (0401020917)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4426,
    "Jeli Agar Bubuk (0401020917)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4427,
    "Jeli Buah (0401020502)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1.00",
  ],
  [
    4428,
    "Jeli Buah (0401020502)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    4429,
    "Jeli Buah (0401020502)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4430,
    "Jeli Buah (0401020502)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    4431,
    "Jeli Buah (0401020502)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    4432,
    "Jeli Buah (0401020502)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.40",
  ],
  [
    4433,
    "Jem Buah atau Selai Buah (0401020501)",
    "Kandungan buah (%)",
    "",
    "=35",
  ],
  [
    4434,
    "Jem Buah atau Selai Buah (0401020501)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1.00",
  ],
  [
    4435,
    "Jem Buah atau Selai Buah (0401020501)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    4436,
    "Jem Buah atau Selai Buah (0401020501)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4437,
    "Jem Buah atau Selai Buah (0401020501)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    4438,
    "Jem Buah atau Selai Buah (0401020501)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    4439,
    "Jem Buah atau Selai Buah (0401020501)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.40",
  ],
  [
    4440,
    "Jerky (0802010202)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4441,
    "Jerky (0802010202)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4442,
    "Jerky (0802010202)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4443,
    "Jerky (0802010202)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4444,
    "Jerky (0802010202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4445,
    "Jerky (0802010202)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [4446, "Jintan Bubuk (12020142)", "Kadar air (%)", "=10"],
  [
    4447,
    "Jintan Bubuk (12020142)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    4448,
    "Jintan Bubuk (12020142)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4449,
    "Jintan Bubuk (12020142)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4450,
    "Jintan Bubuk (12020142)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4451,
    "Jintan Bubuk (12020142)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4452,
    "Jintan Bubuk (12020142)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4453,
    "Jintan Bubuk (12020142)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4454,
    "Jintan Bubuk (12020142)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4455, "Jintan Hitam (12020144)", "Kadar air (%)", "=12"],
  [
    4456,
    "Jintan Hitam (12020144)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.5",
  ],
  [
    4457,
    "Jintan Hitam (12020144)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4458,
    "Jintan Hitam (12020144)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4459,
    "Jintan Hitam (12020144)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4460,
    "Jintan Hitam (12020144)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4461,
    "Jintan Hitam (12020144)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4462,
    "Jintan Hitam (12020144)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4463,
    "Jintan Hitam (12020144)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4464, "Jintan Hitam Bubuk (12020145)", "Kadar air (%)", "=12"],
  [
    4465,
    "Jintan Hitam Bubuk (12020145)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.5",
  ],
  [
    4466,
    "Jintan Hitam Bubuk (12020145)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4467,
    "Jintan Hitam Bubuk (12020145)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4468,
    "Jintan Hitam Bubuk (12020145)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4469,
    "Jintan Hitam Bubuk (12020145)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4470,
    "Jintan Hitam Bubuk (12020145)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4471,
    "Jintan Hitam Bubuk (12020145)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4472,
    "Jintan Hitam Bubuk (12020145)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4473, "Jintan Manis (12020143)", "Kadar air (%)", "=7"],
  [
    4474,
    "Jintan Manis (12020143)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    4475,
    "Jintan Manis (12020143)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4476,
    "Jintan Manis (12020143)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4477,
    "Jintan Manis (12020143)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4478,
    "Jintan Manis (12020143)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4479,
    "Jintan Manis (12020143)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4480,
    "Jintan Manis (12020143)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4481,
    "Jintan Manis (12020143)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4482, "Jintan Putih Bubuk (12020147)", "Kadar air (%)", "=12"],
  [
    4483,
    "Jintan Putih Bubuk (12020147)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=2",
  ],
  [
    4484,
    "Jintan Putih Bubuk (12020147)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4485,
    "Jintan Putih Bubuk (12020147)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4486,
    "Jintan Putih Bubuk (12020147)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4487,
    "Jintan Putih Bubuk (12020147)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4488,
    "Jintan Putih Bubuk (12020147)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4489,
    "Jintan Putih Bubuk (12020147)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4490,
    "Jintan Putih Bubuk (12020147)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4491, "Jintan Putih, Cumin (12020146)", "Kadar air (%)", "=12"],
  [
    4492,
    "Jintan Putih, Cumin (12020146)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=2",
  ],
  [
    4493,
    "Jintan Putih, Cumin (12020146)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4494,
    "Jintan Putih, Cumin (12020146)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4495,
    "Jintan Putih, Cumin (12020146)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4496,
    "Jintan Putih, Cumin (12020146)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4497,
    "Jintan Putih, Cumin (12020146)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4498,
    "Jintan Putih, Cumin (12020146)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4499,
    "Jintan Putih, Cumin (12020146)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4500, "Jintan/Caraway (12020141)", "Kadar air (%)", "=10"],
  [
    4501,
    "Jintan/Caraway (12020141)",
    "Kadar minyak atsiri (% v/b)",
    "=3",
  ],
  [
    4502,
    "Jintan/Caraway (12020141)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4503,
    "Jintan/Caraway (12020141)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4504,
    "Jintan/Caraway (12020141)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4505,
    "Jintan/Caraway (12020141)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4506,
    "Jintan/Caraway (12020141)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4507,
    "Jintan/Caraway (12020141)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4508,
    "Jintan/Caraway (12020141)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4509, "Jipang Beras (150122)", "Kadar air (%)", "=8"],
  [
    4510,
    "Jipang Beras (150122)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4511,
    "Jipang Beras (150122)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4512,
    "Jipang Beras (150122)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4513,
    "Jipang Beras (150122)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4514,
    "Jipang Beras (150122)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4515,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4516,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4517,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4518,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4519,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4520,
    "Jipang Berbahan Dasar Kentang, Umbi, Serealia, Tepung atau Pati (150134)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4521,
    "Jipang Jagung (150121)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4522,
    "Jipang Jagung (150121)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4523,
    "Jipang Jagung (150121)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4524,
    "Jipang Jagung (150121)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4525,
    "Jipang Jagung (150121)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4526,
    "Jipang Jagung (150121)",
    "Aflatoksin B1 (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    4527,
    "Jipang Jagung (150121)",
    "Aflatoksin Total (ppb atau mcg/Kg)",
    "=20",
  ],
  [4528, "Jipang Jagung (150121)", "Kadar air (%)", "=7"],
  [4529, "Jipang Melinjo (150138)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    4530,
    "Jipang Melinjo (150138)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4531,
    "Jipang Melinjo (150138)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4532,
    "Jipang Melinjo (150138)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4533,
    "Jipang Melinjo (150138)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [4534, "Jipang Melinjo (150138)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [4535, "Jipang Melinjo (150138)", "Kadar air (%)", "=8"],
  [4536, "Jipang/Kipang Kacang (150210)", "Kadar air (%)", "=7"],
  [
    4537,
    "Jipang/Kipang Kacang (150210)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4538,
    "Jipang/Kipang Kacang (150210)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4539,
    "Jipang/Kipang Kacang (150210)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4540,
    "Jipang/Kipang Kacang (150210)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4541,
    "Jipang/Kipang Kacang (150210)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4542,
    "Jipang/Kipang Kacang (150210)",
    "Aflatoksin B1 (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    4543,
    "Jipang/Kipang Kacang (150210)",
    "Aflatoksin Total (ppb atau mcg/Kg)",
    "=20",
  ],
  [
    4544,
    "Jongkong Kelapa Muda (060710)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4545,
    "Jongkong Kelapa Muda (060710)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4546,
    "Jongkong Kelapa Muda (060710)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4547,
    "Jongkong Kelapa Muda (060710)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    4548,
    "Jongkong Kelapa Muda (060710)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4549,
    "Jongkong Kelapa Muda (060710)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4550,
    "Juadah Kering/Mayang Papan (060713)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4551,
    "Juadah Kering/Mayang Papan (060713)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4552,
    "Juadah Kering/Mayang Papan (060713)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4553,
    "Juadah Kering/Mayang Papan (060713)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    4554,
    "Juadah Kering/Mayang Papan (060713)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4555,
    "Juadah Kering/Mayang Papan (060713)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [4556, "Junket (010704)", "Arsen (As) (mg/kg) ", "=0.1"],
  [4557, "Junket (010704)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [4558, "Junket (010704)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    4559,
    "Junket (010704)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4560,
    "Junket (010704)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [4561, "Junket (010704)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    4562,
    "Junket (010704)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    4563,
    "Kacang Alas (Biji Sengon) (150222)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4564,
    "Kacang Alas (Biji Sengon) (150222)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4565,
    "Kacang Alas (Biji Sengon) (150222)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4566,
    "Kacang Alas (Biji Sengon) (150222)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4567,
    "Kacang Alas (Biji Sengon) (150222)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4568,
    "Kacang Alas (Biji Sengon) (150222)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4569,
    "Kacang Alas (Biji Sengon) (150222)",
    "Aflatoksin Total (sebagai bahan baku) (ppb)",
    "=15",
  ],
  [
    4570,
    "Kacang Alas (Biji Sengon) (150222)",
    "Aflatoksin Total (dalam bentuk produk siap konsumsi) (ppb)",
    "=10",
  ],
  [4571, "Kacang Atom Lainnya (150216)", "Kadar Air (%)", "=3"],
  [
    4572,
    "Kacang Atom Lainnya (150216)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4573,
    "Kacang Atom Lainnya (150216)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4574,
    "Kacang Atom Lainnya (150216)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4575,
    "Kacang Atom Lainnya (150216)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4576,
    "Kacang Atom Lainnya (150216)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4577,
    "Kacang Atom Lainnya (150216)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4578,
    "Kacang Atom Lainnya (150216)",
    "Aflatoksin Total (sebagai bahan baku) (ppb)",
    "=15",
  ],
  [
    4579,
    "Kacang Atom Lainnya (150216)",
    "Aflatoksin Total (dalam bentuk produk siap konsumsi) (ppb)",
    "=10",
  ],
  [
    4580,
    "Kacang Atom/Sukro (150207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4581,
    "Kacang Atom/Sukro (150207)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4582,
    "Kacang Atom/Sukro (150207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4583,
    "Kacang Atom/Sukro (150207)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4584,
    "Kacang Atom/Sukro (150207)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4585,
    "Kacang Atom/Sukro (150207)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4586,
    "Kacang Atom/Sukro (150207)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4587, "Kacang Atom/Sukro (150207)", "Kadar air (%)", "=3"],
  [4588, "Kacang Bersalut (150220)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    4589,
    "Kacang Bersalut (150220)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4590,
    "Kacang Bersalut (150220)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4591,
    "Kacang Bersalut (150220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4592,
    "Kacang Bersalut (150220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4593,
    "Kacang Bersalut (150220)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4594,
    "Kacang Bersalut (150220)",
    "Aflatoksin B1 (ppb atau \xB5g/kg)",
    "=15",
  ],
  [
    4595,
    "Kacang Bersalut (150220)",
    "Aflatoksin total (ppb atau \xB5g/kg)",
    "=20",
  ],
  [
    4596,
    "Kacang Bogor (150213)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4597,
    "Kacang Bogor (150213)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4598,
    "Kacang Bogor (150213)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4599,
    "Kacang Bogor (150213)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4600,
    "Kacang Bogor (150213)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4601,
    "Kacang Bogor (150213)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4602,
    "Kacang Garing/Kacang Kulit (150201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4603,
    "Kacang Garing/Kacang Kulit (150201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4604,
    "Kacang Garing/Kacang Kulit (150201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4605,
    "Kacang Garing/Kacang Kulit (150201)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4606,
    "Kacang Garing/Kacang Kulit (150201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4607,
    "Kacang Garing/Kacang Kulit (150201)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4608,
    "Kacang Garing/Kacang Kulit (150201)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4609,
    "Kacang Garing/Kacang Kulit (150201)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4610,
    "Kacang Garing/Kacang Kulit (150201)",
    "Kadar air (%)",
    "=3",
  ],
  [
    4611,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Bobot Tuntas (%)",
  ],
  [
    4612,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4613,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4614,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4615,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4616,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4617,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    4618,
    "Kacang Ginko Dalam Kemasan (0402020416)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [4619, "Kacang Goreng (150221)", "Arsen (As) (mg/kg)", "=0.25"],
  [4620, "Kacang Goreng (150221)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [4621, "Kacang Goreng (150221)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    4622,
    "Kacang Goreng (150221)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4623,
    "Kacang Goreng (150221)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [4624, "Kacang Goreng (150221)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    4625,
    "Kacang Goreng (150221)",
    "Aflatoksin B1 (ppb atau \xB5g/kg)",
    "=15",
  ],
  [
    4626,
    "Kacang Goreng (150221)",
    "Aflatoksin total (ppb atau \xB5g/kg)",
    "=20",
  ],
  [
    4627,
    "Kacang Goreng Lainnya (150218)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4628,
    "Kacang Goreng Lainnya (150218)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4629,
    "Kacang Goreng Lainnya (150218)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4630,
    "Kacang Goreng Lainnya (150218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4631,
    "Kacang Goreng Lainnya (150218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4632,
    "Kacang Goreng Lainnya (150218)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4633,
    "Kacang Goreng Lainnya (150218)",
    "Aflatoksin B1 (ppb atau \xB5g/kg)",
    "=15",
  ],
  [
    4634,
    "Kacang Goreng Lainnya (150218)",
    "Aflatoksin total (ppb atau \xB5g/kg)",
    "=20",
  ],
  [4635, "Kacang Goyang (150209)", "Kadar air (%)", "=5"],
  [
    4636,
    "Kacang Goyang (150209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4637,
    "Kacang Goyang (150209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4638,
    "Kacang Goyang (150209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4639,
    "Kacang Goyang (150209)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4640,
    "Kacang Goyang (150209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4641,
    "Kacang Goyang (150209)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4642,
    "Kacang Goyang (150209)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4643,
    "Kacang Goyang (150209)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4644,
    "Kacang Kapri (150211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4645,
    "Kacang Kapri (150211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4646,
    "Kacang Kapri (150211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4647,
    "Kacang Kapri (150211)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4648,
    "Kacang Kapri (150211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4649,
    "Kacang Kapri (150211)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4650,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4651,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4652,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4653,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4654,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    4655,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Bobot Tuntas (%)",
  ],
  [
    4656,
    "Kacang Kapri (Green Peas) Dalam Kemasan (0402020408)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4657,
    "Kacang Kapri Beku (0402020103)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4658,
    "Kacang Kapri Beku (0402020103)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4659,
    "Kacang Kapri Beku (0402020103)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4660,
    "Kacang Kapri Beku (0402020103)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4661,
    "Kacang Kapri Beku (0402020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4662,
    "Kacang Kapri Beku (0402020103)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    4663,
    "Kacang Kapri Beku (0402020103)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4664,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (beans) (%)",
    "=15",
  ],
  [
    4665,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (lentils) (%)",
    "=15",
  ],
  [
    4666,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (peas) (%)",
    "=15",
  ],
  [
    4667,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (chick peas) (%)",
    "=14",
  ],
  [
    4668,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (kacang tanah) (%)",
    "=15",
  ],
  [
    4669,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    4670,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    4671,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4672,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4673,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    4674,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    4675,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Kadar air (cow peas) (%)",
    "=15",
  ],
  [
    4676,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4677,
    "Kacang Kering dan Polong Kacang Kering (0402020207)",
    "Batas kadar air bila tanpa kulit menjadi ... (%) (diatas batas kadar air semula)",
    "=2",
  ],
  [
    4678,
    "Kacang Koro (150212)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4679,
    "Kacang Koro (150212)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4680,
    "Kacang Koro (150212)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4681,
    "Kacang Koro (150212)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4682,
    "Kacang Koro (150212)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4683,
    "Kacang Koro (150212)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [4684, "Kacang Mede (150205)", "Kadar air (%)", "=6"],
  [
    4685,
    "Kacang Mede (150205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4686,
    "Kacang Mede (150205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4687,
    "Kacang Mede (150205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4688,
    "Kacang Mede (150205)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4689,
    "Kacang Mede (150205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4690,
    "Kacang Mede (150205)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4691,
    "Kacang Panggang (150204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4692,
    "Kacang Panggang (150204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4693,
    "Kacang Panggang (150204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4694,
    "Kacang Panggang (150204)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4695,
    "Kacang Panggang (150204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4696,
    "Kacang Panggang (150204)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4697,
    "Kacang Panggang (150204)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4698,
    "Kacang Panggang (150204)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4699,
    "Kacang Panggang Lainnya (150219)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    4700,
    "Kacang Panggang Lainnya (150219)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4701,
    "Kacang Panggang Lainnya (150219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4702,
    "Kacang Panggang Lainnya (150219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    4703,
    "Kacang Panggang Lainnya (150219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    4704,
    "Kacang Panggang Lainnya (150219)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    4705,
    "Kacang Panggang Lainnya (150219)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    4706,
    "Kacang Pistacio (150214)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4707,
    "Kacang Pistacio (150214)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4708,
    "Kacang Pistacio (150214)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    4709,
    "Kacang Pistacio (150214)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4710,
    "Kacang Pistacio (150214)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    4711,
    "Kacang Pistacio (150214)",
    "Aflatoksin Total (ppb atau mcg/kg) ",
    "=10",
  ],
  [4712, "Kacang Sangrai (150217)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    4713,
    "Kacang Sangrai (150217)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4714,
    "Kacang Sangrai (150217)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    4715,
    "Kacang Sangrai (150217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    4716,
    "Kacang Sangrai (150217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [4717, "Kacang Sangrai (150217)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [4718, "Kacang Sangrai (150217)", "Kadar air (%)", "=3"],
  [
    4719,
    "Kacang Sangrai (150217)",
    "Aflatoksin B1 (ppb atau \xB5g/kg)",
    "=15",
  ],
  [
    4720,
    "Kacang Sangrai (150217)",
    "Aflatoksin total (ppb atau \xB5g/kg)",
    "=20",
  ],
  [
    4721,
    "Kacang Telur (150208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4722,
    "Kacang Telur (150208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4723,
    "Kacang Telur (150208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4724,
    "Kacang Telur (150208)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4725,
    "Kacang Telur (150208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4726,
    "Kacang Telur (150208)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4727,
    "Kacang Telur (150208)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4728, "Kakao Bubuk (05010101)", "Kadar air (b/b) (%)", "=5"],
  [
    4729,
    "Kakao Bubuk (05010101)",
    "Kadar lemak (b/b) (%)",
    "",
    "=10",
  ],
  [
    4730,
    "Kakao Bubuk (05010101)",
    "Kehalusan (lolos ayakan 200 mesh) (%)",
    "",
    "=99.5",
  ],
  [
    4731,
    "Kakao Bubuk (05010101)",
    "Kulit (shell) dihitung dari alkali free nib (b/b) (%)",
    "=1.75",
  ],
  [
    4732,
    "Kakao Bubuk (05010101)",
    "ALT (30oC, 72 jam) (koloni/g)",
    "=5000",
  ],
  [
    4733,
    "Kakao Bubuk (05010101)",
    "Bakteri bentuk coli (APM/g)",
    "<3",
  ],
  [4734, "Kakao Bubuk (05010101)", "Salmonella sp. (/25 g)"],
  [4735, "Kakao Bubuk (05010101)", "Kapang (koloni/g)", "=50"],
  [4736, "Kakao Bubuk (05010101)", "Arsen (As) (mg/kg)", "=1"],
  [4737, "Kakao Bubuk (05010101)", "Cadmium (Cd) (mg/kg)", "=0.85"],
  [
    4738,
    "Kakao Bubuk (05010101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4739,
    "Kakao Bubuk (05010101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [4740, "Kakao Bubuk (05010101)", "Merkuri (Hg) (mg/kg)"],
  [4741, "Kakao Bubuk (05010101)", "Timbal (Pb) (mg/kg)", "=1"],
  [4742, "Kakao Bubuk (05010101)", "Escherichia Coli (/g)"],
  [4743, "Kakao Bubuk (05010101)", "Khamir (koloni/g)", "=50"],
  [
    4744,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Kandungan lemak kakao (%)",
    "=22",
  ],
  [
    4745,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    4746,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Cadmium (Cd) (mg/kg)",
    "=0.85",
  ],
  [
    4747,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Raksa (Hg) (mg/kg)",
  ],
  [
    4748,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4749,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4750,
    "Kakao Bubuk Untuk Sarapan (Breakfast Cocoa) (05010102)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [4751, "Kakao Instan (05010118)", "Arsen (As) (mg/kg)", "=1"],
  [4752, "Kakao Instan (05010118)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    4753,
    "Kakao Instan (05010118)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4754,
    "Kakao Instan (05010118)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [4755, "Kakao Instan (05010118)", "Timbal (Pb) (mg/kg)", "=1"],
  [4756, "Kakao Instan (05010118)", "Kadar Air (%)", "=5"],
  [
    4757,
    "Kakao Instan (05010118)",
    "Kandungan kakao (total cocoa solids) dihitung sebagai berat kering (%)",
    "",
    "=10",
  ],
  [
    4758,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    4759,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4760,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4761,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    4762,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4763,
    "Kakao Massa (Cocoa liquor) (05010120)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4764,
    "Kaldu dan Konsome (12050102)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    4765,
    "Kaldu dan Konsome (12050102)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    4766,
    "Kaldu dan Konsome (12050102)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4767,
    "Kaldu dan Konsome (12050102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4768,
    "Kaldu dan Konsome (12050102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    4769,
    "Kaldu dan Konsome (12050102)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    4770,
    "Kaldu dan Konsome (12050102)",
    "Nitrogen total untuk kaldu daging unggas (mg/l)",
    "",
    "=100",
  ],
  [
    4771,
    "Kaldu dan Konsome (12050102)",
    "Nitrogen total untuk konsome daging sapi (mg/l)",
    "",
    "=160",
  ],
  [
    4772,
    "Kaldu dan Konsome (12050102)",
    "Nitrogen total untuk kaldu daging lainnya (mg/l)",
    "",
    "=350",
  ],
  [
    4773,
    "Kaldu dan Konsome (12050102)",
    "Nitrogen amino untuk kaldu daging lainnya (mg/l)",
    "",
    "=210",
  ],
  [
    4774,
    "Kaldu dan Konsome (12050102)",
    "Natrium klorida (g/l)",
    "=12.5",
  ],
  [
    4775,
    "Kaldu dan Konsome (12050102)",
    "Lemak untuk kaldu daging berlemak (g/l)",
    "",
    "=3",
  ],
  [
    4776,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4777,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4778,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4779,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4780,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4781,
    "Kaldu dan Konsome Produk Perikanan (Seperti Kaldu Udang, Kaldu Ikan, dll) (12050103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4782,
    "Kamaboko (0902040106)",
    "Angka Lempeng Total (30oC, 72 jam) (koloni/g)",
    "=500000",
  ],
  [4783, "Kamaboko (0902040106)", "Arsen (As) (mg/kg)", "=0.25"],
  [4784, "Kamaboko (0902040106)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [4785, "Kamaboko (0902040106)", "Raksa (Hg) (mg/kg) ", "=0.5"],
  [
    4786,
    "Kamaboko (0902040106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4787,
    "Kamaboko (0902040106)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [4788, "Kamaboko (0902040106)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [4789, "Kampyo (0402020221)", "Arsen (As) (mg/kg)", "=0.15"],
  [4790, "Kampyo (0402020221)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [4791, "Kampyo (0402020221)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    4792,
    "Kampyo (0402020221)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    4793,
    "Kampyo (0402020221)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [4794, "Kampyo (0402020221)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    4795,
    "Kapucino (1401040245)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4796,
    "Kapucino (1401040245)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    4797,
    "Kapucino (1401040245)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    4798,
    "Kapucino (1401040245)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4799,
    "Kapucino (1401040245)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    4800,
    "Kapucino (1401040245)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    4801,
    "Kapucino (1401040245)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4802,
    "Kapulaga (12020148)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [4803, "Kapulaga (12020148)", "Arsen (ppm atau mg/kg)", "=0.15"],
  [4804, "Kapulaga (12020148)", "Kadmium (ppm atau mg/kg)", "=0.5"],
  [
    4805,
    "Kapulaga (12020148)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4806,
    "Kapulaga (12020148)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4807, "Kapulaga (12020148)", "Timbal (ppm atau mg/kg)", "=1"],
  [
    4808,
    "Kapulaga (12020148)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4809,
    "Kapulaga (12020148)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4810, "Kapulaga (12020148)", "Timbal (ppm atau mg/kg)", "=7"],
  [
    4811,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Kadar air (%)",
    "=14",
  ],
  [
    4812,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    4813,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4814,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4815,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4816,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4817,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4818,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4819,
    "Kapulaga (Cardamom) Amomum (12020151)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4820,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Kadar air (%)",
    "=14",
  ],
  [
    4821,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    4822,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4823,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4824,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4825,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4826,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4827,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4828,
    "Kapulaga (Cardamom) Amomum Bubuk (12020154)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4829, "Kapulaga Bubuk (12020153)", "Kadar air (%)", "=14"],
  [
    4830,
    "Kapulaga Bubuk (12020153)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    4831,
    "Kapulaga Bubuk (12020153)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4832,
    "Kapulaga Bubuk (12020153)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4833,
    "Kapulaga Bubuk (12020153)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4834,
    "Kapulaga Bubuk (12020153)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4835,
    "Kapulaga Bubuk (12020153)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    4836,
    "Kapulaga Bubuk (12020153)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4837,
    "Kapulaga Bubuk (12020153)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4838, "Kapulaga Lokal (12020150)", "Kadar air (%)", "=12"],
  [
    4839,
    "Kapulaga Lokal (12020150)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=3",
  ],
  [
    4840,
    "Kapulaga Lokal (12020150)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4841,
    "Kapulaga Lokal (12020150)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4842,
    "Kapulaga Lokal (12020150)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4843,
    "Kapulaga Lokal (12020150)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4844,
    "Kapulaga Lokal (12020150)",
    "Timbal (ppm atau mg/kg) ",
    "=1",
  ],
  [
    4845,
    "Kapulaga Lokal (12020150)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4846,
    "Kapulaga Lokal (12020150)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [4847, "Kastengel (07020135)", "Kadar air (%)", "=10"],
  [
    4848,
    "Kastengel (07020135)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.5",
  ],
  [4849, "Kastengel (07020135)", "Kadmium (Cd)", "=0.2"],
  [
    4850,
    "Kastengel (07020135)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4851,
    "Kastengel (07020135)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4852,
    "Kastengel (07020135)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4853,
    "Kastengel (07020135)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4854,
    "Katrisolo (060729)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4855,
    "Katrisolo (060729)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4856,
    "Katrisolo (060729)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4857,
    "Katrisolo (060729)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    4858,
    "Katrisolo (060729)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4859,
    "Kayu Manis (12020155)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.5",
  ],
  [
    4860,
    "Kayu Manis (12020155)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4861,
    "Kayu Manis (12020155)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4862,
    "Kayu Manis (12020155)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4863,
    "Kayu Manis (12020155)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4864, "Kayu Manis (12020155)", "Timbal (ppm atau mg/kg)", "=1"],
  [
    4865,
    "Kayu Manis (12020155)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4866,
    "Kayu Manis (12020155)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [4867, "Kayu Manis Bubuk (12020156)", "Kadar air (%)", "=12"],
  [
    4868,
    "Kayu Manis Bubuk (12020156)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.5",
  ],
  [
    4869,
    "Kayu Manis Bubuk (12020156)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    4870,
    "Kayu Manis Bubuk (12020156)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    4871,
    "Kayu Manis Bubuk (12020156)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4872,
    "Kayu Manis Bubuk (12020156)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    4873,
    "Kayu Manis Bubuk (12020156)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    4874,
    "Kayu Manis Bubuk (12020156)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    4875,
    "Kayu Manis Bubuk (12020156)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    4876,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    4877,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    4878,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    4879,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    4880,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4881,
    "Kebab/Roti Isi Daging/Tortilla Isi Daging (1669)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    4882,
    "Kecap Asin (Salty Soy Sauce) (1209020302)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4883,
    "Kecap Asin (Salty Soy Sauce) (1209020302)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4884,
    "Kecap Asin (Salty Soy Sauce) (1209020302)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4885,
    "Kecap Asin (Salty Soy Sauce) (1209020302)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4886,
    "Kecap Asin (Salty Soy Sauce) (1209020302)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [4887, "Kecap Bumbu (1209020306)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    4888,
    "Kecap Bumbu (1209020306)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4889,
    "Kecap Bumbu (1209020306)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4890,
    "Kecap Bumbu (1209020306)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4891,
    "Kecap Bumbu (1209020306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4892, "Kecap Bumbu (1209020306)", "Timbal (Pb) (mg/kg)", "=1"],
  [4893, "Kecap Ikan (12060401)", "Arsen (As) (mg/kg)", "=0.15"],
  [4894, "Kecap Ikan (12060401)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [4895, "Kecap Ikan (12060401)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [4896, "Kecap Ikan (12060401)", "Timah (Sn) (mg/kg)", "=40"],
  [4897, "Kecap Ikan (12060401)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    4898,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Arsen (mg/kg)",
    "=0.15",
  ],
  [
    4899,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Kadmium (mg/kg)",
    "=0.5",
  ],
  [
    4900,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Merkuri (mg/kg)",
    "=0.05",
  ],
  [
    4901,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Timah (mg/kg)",
    "=40",
  ],
  [
    4902,
    "Kecap Inggeris, Saus Worchester (12060218)",
    "Timbal (mg/kg)",
    "=1",
  ],
  [
    4903,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Kadar Protein (N x 6.25) (%)",
    "",
    "=4",
  ],
  [
    4904,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4905,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4906,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4907,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4908,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4909,
    "Kecap Kedelai Asin (Salty Soy Sauce) (1209020101)",
    "Bau dan Rasa",
  ],
  [
    4910,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Kadar Protein (N x 6.25) (%)",
    "",
    "=4",
  ],
  [
    4911,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4912,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4913,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4914,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4915,
    "Kecap Kedelai Asin Non Fermentasi/Hidrolisat (1209020201)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4916,
    "Kecap Kedelai Manis (Sweet Soy Sauce) (1209020301)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4917,
    "Kecap Kedelai Manis (Sweet Soy Sauce) (1209020301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4918,
    "Kecap Kedelai Manis (Sweet Soy Sauce) (1209020301)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4919,
    "Kecap Kedelai Manis (Sweet Soy Sauce) (1209020301)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4920,
    "Kecap Kedelai Manis (Sweet Soy Sauce) (1209020301)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [4921, "Kecap Kelapa (12060219)", "Arsen (As) (mg/kg)", "=0.15"],
  [4922, "Kecap Kelapa (12060219)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [4923, "Kecap Kelapa (12060219)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [4924, "Kecap Kelapa (12060219)", "Timah (Sn) (mg/kg)", "=40"],
  [4925, "Kecap Kelapa (12060219)", "Timbal (Pb) (mg/kg)", "=1"],
  [4926, "Kecap Pedas (1209020305)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    4927,
    "Kecap Pedas (1209020305)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4928,
    "Kecap Pedas (1209020305)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4929,
    "Kecap Pedas (1209020305)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4930,
    "Kecap Pedas (1209020305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [4931, "Kecap Pedas (1209020305)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    4932,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Kadar air (%)",
    "=7",
  ],
  [
    4933,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Kadar NaCl (%)",
    "=36",
    "=32",
  ],
  [
    4934,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4935,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4936,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4937,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4938,
    "Kecap yang Dikeringkan/Bubuk Kecap (Fermented Soy Sauce Powder) (1209020303)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4939,
    "Kecimpring (150114)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4940,
    "Kecimpring (150114)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4941,
    "Kecimpring (150114)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4942,
    "Kecimpring (150114)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    4943,
    "Kecimpring (150114)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4944,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    4945,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    4946,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    4947,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    4948,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    4949,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    4950,
    "Kecombrang/Sambuang/Kincong/Honje (12020176)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    4951,
    "Keecho/Heecho (08030317)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    4952,
    "Keecho/Heecho (08030317)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4953,
    "Keecho/Heecho (08030317)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    4954,
    "Keecho/Heecho (08030317)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4955,
    "Keecho/Heecho (08030317)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4956,
    "Keecho/Heecho (08030317)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [4957, "Kefir (010201A9)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    4958,
    "Kefir (010201A9)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    4959,
    "Kefir (010201A9)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    4960,
    "Kefir (010201A9)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    4961,
    "Kefir (010201A9)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    4962,
    "Kefir (010201A9)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [4963, "Kefir (010201A9)", "Aflatoksin M1 (mcg/kg) ", "=0.5"],
  [
    4964,
    "Kefir (010201A9)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [4965, "Kefir (010201A9)", "Kadar asam laktat (%) ", "", "=0.6"],
  [
    4966,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    4967,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    4968,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    4969,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    4970,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    4971,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    4972,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    4973,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    4974,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Kadar asam laktat (%)",
    "",
    "=0.6",
  ],
  [
    4975,
    "Kefir (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010207)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    4976,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    4977,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    4978,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    4979,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    4980,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    4981,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    4982,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    4983,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    4984,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Kadar asam laktat (%)",
    "",
    "=0.6",
  ],
  [
    4985,
    "Kefir (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010107)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    4986,
    "Kefir Berperisa/rasa (010718)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=4.6",
  ],
  [
    4987,
    "Kefir Berperisa/rasa (010718)",
    "Kadar asam laktat (%)",
    "",
    "=0.6",
  ],
  [
    4988,
    "Kefir Berperisa/rasa (010718)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    4989,
    "Kefir Berperisa/rasa (010718)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    4990,
    "Kefir Berperisa/rasa (010718)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    4991,
    "Kefir Berperisa/rasa (010718)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    4992,
    "Kefir Berperisa/rasa (010718)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    4993,
    "Kefir Berperisa/rasa (010718)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    4994,
    "Kefir Berperisa/rasa (010718)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    4995,
    "Kefir Berperisa/rasa (010718)",
    "Kadar Protein Susu (%)",
    "",
    "=1.6",
  ],
  [4996, "Keik (Cake) (07020102)", "Arsen (As) (mg/kg)", "=0.5"],
  [4997, "Keik (Cake) (07020102)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [4998, "Keik (Cake) (07020102)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [4999, "Keik (Cake) (07020102)", "Timah (Sn) (mg/kg)", "=40"],
  [5000, "Keik (Cake) (07020102)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    5001,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    5002,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    5003,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5004,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    5005,
    "Keik (Cake), Kukis (Cookies) dan Pai (Pie) (07020101)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    5006,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5007,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5008,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5009,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5010,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5011,
    "Keik Kakao/Bungkil Kakao (05010109)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5012,
    "Keik Keju (Cheese Cake) (07020104)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    5013,
    "Keik Keju (Cheese Cake) (07020104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    5014,
    "Keik Keju (Cheese Cake) (07020104)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5015,
    "Keik Keju (Cheese Cake) (07020104)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    5016,
    "Keik Keju (Cheese Cake) (07020104)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    5017,
    "Keik Mentega (Butter Cake) (07020103)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    5018,
    "Keik Mentega (Butter Cake) (07020103)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    5019,
    "Keik Mentega (Butter Cake) (07020103)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5020,
    "Keik Mentega (Butter Cake) (07020103)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    5021,
    "Keik Mentega (Butter Cake) (07020103)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    5022,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    5023,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    5024,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5025,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    5026,
    "Keik Pound (Pound Cake Atau Quatre Quarts) (07020105)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    5027,
    "Keju Amerika (American Cheese) (0106040102)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5028,
    "Keju Amerika (American Cheese) (0106040102)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5029,
    "Keju Amerika (American Cheese) (0106040102)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5030,
    "Keju Amerika (American Cheese) (0106040102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5031,
    "Keju Amerika (American Cheese) (0106040102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5032,
    "Keju Amerika (American Cheese) (0106040102)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5033,
    "Keju Amerika (American Cheese) (0106040102)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5034,
    "Keju Amerika (American Cheese) (0106040102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5035,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5036,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5037,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5038,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5039,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5040,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5041,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5042,
    "Keju Bata (Brick Cheese) (0106020102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5043, "Keju Bath (0106020111)", "Arsen (As) (mg/kg)", "=0.1"],
  [5044, "Keju Bath (0106020111)", "Kadmium (Cd)(mg/kg)", "=0.05"],
  [5045, "Keju Bath (0106020111)", "Merkuri (Hg) (mg/kg)", "=0.02"],
  [
    5046,
    "Keju Bath (0106020111)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5047,
    "Keju Bath (0106020111)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [5048, "Keju Bath (0106020111)", "Timbal (Pb) (mg/kg)", "=0.02"],
  [
    5049,
    "Keju Bath (0106020111)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5050, "Keju Bath (010602A5)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5051, "Keju Bath (010602A5)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [5052, "Keju Bath (010602A5)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    5053,
    "Keju Bath (010602A5)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5054,
    "Keju Bath (010602A5)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5055, "Keju Bath (010602A5)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5056,
    "Keju Bath (010602A5)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5057,
    "Keju Bath (010602A5)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5058,
    "Keju Biru (Blue cheese) (0106020101)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5059,
    "Keju Biru (Blue cheese) (0106020101)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5060,
    "Keju Biru (Blue cheese) (0106020101)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5061,
    "Keju Biru (Blue cheese) (0106020101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5062,
    "Keju Biru (Blue cheese) (0106020101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5063,
    "Keju Biru (Blue cheese) (0106020101)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5064,
    "Keju Biru (Blue cheese) (0106020101)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5065,
    "Keju Biru (Blue cheese) (0106020101)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5066,
    "Keju Bocconcini (01060104)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5067,
    "Keju Bocconcini (01060104)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5068,
    "Keju Bocconcini (01060104)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5069,
    "Keju Bocconcini (01060104)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5070,
    "Keju Bocconcini (01060104)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5071,
    "Keju Bocconcini (01060104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5072,
    "Keju Bocconcini (01060104)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5073,
    "Keju Bocconcini (01060104)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5074, "Keju Bondard (0106020112)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    5075,
    "Keju Bondard (0106020112)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    5076,
    "Keju Bondard (0106020112)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5077,
    "Keju Bondard (0106020112)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5078,
    "Keju Bondard (0106020112)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5079,
    "Keju Bondard (0106020112)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5080,
    "Keju Bondard (0106020112)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5081, "Keju Bondard (010602A6)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5082,
    "Keju Bondard (010602A6)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5083,
    "Keju Bondard (010602A6)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5084,
    "Keju Bondard (010602A6)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5085,
    "Keju Bondard (010602A6)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5086,
    "Keju Bondard (010602A6)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5087,
    "Keju Bondard (010602A6)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5088,
    "Keju Bondard (010602A6)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5089, "Keju Bougon (0106020113)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    5090,
    "Keju Bougon (0106020113)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    5091,
    "Keju Bougon (0106020113)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5092,
    "Keju Bougon (0106020113)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5093,
    "Keju Bougon (0106020113)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5094,
    "Keju Bougon (0106020113)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5095,
    "Keju Bougon (0106020113)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5096, "Keju Bougon (010602A7)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5097,
    "Keju Bougon (010602A7)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5098,
    "Keju Bougon (010602A7)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5099,
    "Keju Bougon (010602A7)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5100,
    "Keju Bougon (010602A7)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5101, "Keju Bougon (010602A7)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5102,
    "Keju Bougon (010602A7)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5103,
    "Keju Bougon (010602A7)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5104,
    "Keju Bouquet des moines (0106020114)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5105,
    "Keju Bouquet des moines (0106020114)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    5106,
    "Keju Bouquet des moines (0106020114)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5107,
    "Keju Bouquet des moines (0106020114)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5108,
    "Keju Bouquet des moines (0106020114)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5109,
    "Keju Bouquet des moines (0106020114)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5110,
    "Keju Bouquet des moines (0106020114)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5111,
    "Keju Bouquet des moines (010602A8)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5112,
    "Keju Bouquet des moines (010602A8)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5113,
    "Keju Bouquet des moines (010602A8)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5114,
    "Keju Bouquet des moines (010602A8)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5115,
    "Keju Bouquet des moines (010602A8)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5116,
    "Keju Bouquet des moines (010602A8)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5117,
    "Keju Bouquet des moines (010602A8)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5118,
    "Keju Bouquet des moines (010602A8)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5119,
    "Keju Boursault (010602A9)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5120,
    "Keju Boursault (010602A9)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5121,
    "Keju Boursault (010602A9)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5122,
    "Keju Boursault (010602A9)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5123,
    "Keju Boursault (010602A9)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5124,
    "Keju Boursault (010602A9)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5125,
    "Keju Boursault (010602A9)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5126,
    "Keju Boursault (010602A9)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5127, "Keju Brie (0106020105)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5128,
    "Keju Brie (0106020105)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5129,
    "Keju Brie (0106020105)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5130,
    "Keju Brie (0106020105)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5131,
    "Keju Brie (0106020105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5132, "Keju Brie (0106020105)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5133,
    "Keju Brie (0106020105)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5134,
    "Keju Brie (0106020105)",
    "Lemak susu dihitung terhadap bahan kering (%) ",
    "",
    "=40",
  ],
  [
    5135,
    "Keju Brie (0106020105)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5136,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5137,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5138,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5139,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5140,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5141,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5142,
    "Keju Bubuk (Untuk Rekonstitusi Contohnya Dalam Pembuatan Saus Keju) (01060203)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5143,
    "Keju Camembert (0106020110)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5144,
    "Keju Camembert (0106020110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5145,
    "Keju Camembert (0106020110)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5146,
    "Keju Camembert (0106020110)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5147,
    "Keju Camembert (0106020110)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5148,
    "Keju Camembert (0106020110)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5149,
    "Keju Camembert (0106020110)",
    "Kadar Lemak Susu Dihitung Terhadap Bahan Kering (%)",
    "",
    "=30",
  ],
  [
    5150,
    "Keju Camembert (0106020110)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    5151,
    "Keju Camembert (010602A4)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5152,
    "Keju Camembert (010602A4)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5153,
    "Keju Camembert (010602A4)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5154,
    "Keju Camembert (010602A4)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5155,
    "Keju Camembert (010602A4)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5156,
    "Keju Camembert (010602A4)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5157,
    "Keju Camembert (010602A4)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5158,
    "Keju Camembert (010602A4)",
    "Lemak susu dihitung terhadap bahan kering (%)",
    "",
    "=30",
  ],
  [
    5159,
    "Keju Camembert (010602A4)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5160, "Keju Cheddar (0106020109)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    5161,
    "Keju Cheddar (0106020109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5162,
    "Keju Cheddar (0106020109)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5163,
    "Keju Cheddar (0106020109)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5164,
    "Keju Cheddar (0106020109)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5165,
    "Keju Cheddar (0106020109)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5166,
    "Keju Cheddar (0106020109)",
    "Kadar Lemak Susu Dihitung Terhadap Bahan Kering (%)",
    "",
    "=22",
  ],
  [
    5167,
    "Keju Cheddar (0106020109)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [5168, "Keju Cheddar (010602A1)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5169,
    "Keju Cheddar (010602A1)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5170,
    "Keju Cheddar (010602A1)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5171,
    "Keju Cheddar (010602A1)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5172,
    "Keju Cheddar (010602A1)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5173,
    "Keju Cheddar (010602A1)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5174,
    "Keju Cheddar (010602A1)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5175,
    "Keju Cheddar (010602A1)",
    "Lemak susu dihitung terhadap bahan kering (%)",
    "",
    "=22",
  ],
  [
    5176,
    "Keju Cheddar (010602A1)",
    "Aflatoxin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5177,
    "Keju Cheddar Olahan (010604A1)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5178,
    "Keju Cheddar Olahan (010604A1)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5179,
    "Keju Cheddar Olahan (010604A1)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5180,
    "Keju Cheddar Olahan (010604A1)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5181,
    "Keju Cheddar Olahan (010604A1)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5182,
    "Keju Cheddar Olahan (010604A1)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5183,
    "Keju Cheddar Olahan (010604A1)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5184,
    "Keju Cheddar Olahan (010604A1)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5185,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5186,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5187,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5188,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5189,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5190,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5191,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5192,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Padatan susu bukan lemak (%)",
    "",
    "=18",
  ],
  [
    5193,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5194,
    "Keju Cottage (Cottage Cheese) (01060101)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5195,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5196,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5197,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5198,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5199,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5200,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5201,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5202,
    "Keju Cottage yang ditambah krim (Creamed Cottage Cheese) (01060106)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [5203, "Keju Edam (0106020108)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5204,
    "Keju Edam (0106020108)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5205,
    "Keju Edam (0106020108)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5206,
    "Keju Edam (0106020108)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5207,
    "Keju Edam (0106020108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5208, "Keju Edam (0106020108)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5209,
    "Keju Edam (0106020108)",
    "Lemak Susu dihitung terhadap bahan kering (%) ",
    "",
    "=30",
  ],
  [
    5210,
    "Keju Edam (0106020108)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5211,
    "Keju Edam (0106020108)",
    "Aflatoksin M1 (ppb atau mcg/kg) ",
    "=0.5",
  ],
  [5212, "Keju Edam (010602A3)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5213, "Keju Edam (010602A3)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [5214, "Keju Edam (010602A3)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    5215,
    "Keju Edam (010602A3)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5216,
    "Keju Edam (010602A3)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5217, "Keju Edam (010602A3)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5218,
    "Keju Edam (010602A3)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5219,
    "Keju Edam (010602A3)",
    "Lemak susu dihitung terhadap bahan kering (%)",
    "",
    "=30",
  ],
  [
    5220,
    "Keju Edam (010602A3)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [5221, "Keju Gouda (0106020103)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5222,
    "Keju Gouda (0106020103)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5223,
    "Keju Gouda (0106020103)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5224,
    "Keju Gouda (0106020103)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5225,
    "Keju Gouda (0106020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5226,
    "Keju Gouda (0106020103)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5227,
    "Keju Gouda (0106020103)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5228,
    "Keju Gouda (0106020103)",
    "Lemak susu dihitung terhadap bahan kering (%) ",
    "",
    "=30",
  ],
  [
    5229,
    "Keju Gouda (0106020103)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5230,
    "Keju Haloumy (010607)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5231,
    "Keju Haloumy (010607)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5232, "Keju Haloumy (010607)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5233, "Keju Haloumy (010607)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [5234, "Keju Haloumy (010607)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [5235, "Keju Haloumy (010607)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5236,
    "Keju Haloumy (0106A3)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5237,
    "Keju Havarti (0106020104)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5238,
    "Keju Havarti (0106020104)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5239,
    "Keju Havarti (0106020104)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5240,
    "Keju Havarti (0106020104)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5241,
    "Keju Havarti (0106020104)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5242,
    "Keju Havarti (0106020104)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5243,
    "Keju Havarti (0106020104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5244,
    "Keju Havarti (0106020104)",
    "Lemak susu dihitung terhadap bahan kering (%) ",
    "",
    "=30",
  ],
  [
    5245,
    "Keju Havarti (0106020104)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5246,
    "Keju Krim (Cream Cheese) (01060102)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5247,
    "Keju Krim (Cream Cheese) (01060102)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5248,
    "Keju Krim (Cream Cheese) (01060102)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5249,
    "Keju Krim (Cream Cheese) (01060102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5250,
    "Keju Krim (Cream Cheese) (01060102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5251,
    "Keju Krim (Cream Cheese) (01060102)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5252,
    "Keju Krim (Cream Cheese) (01060102)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5253,
    "Keju Krim (Cream Cheese) (01060102)",
    "Lemak susu dari total padatan (%)",
    "",
    "=25",
  ],
  [
    5254,
    "Keju Krim (Cream Cheese) (01060102)",
    "Kadar air terhadap bahan tanpa lemak (%)",
    "",
    "=67",
  ],
  [
    5255,
    "Keju Krim (Cream Cheese) (01060102)",
    "Total padatan (%)",
    "",
    "=22",
  ],
  [
    5256,
    "Keju Krim (Cream Cheese) (01060102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5257,
    "Keju Mozzarella (01060103)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5258,
    "Keju Mozzarella (01060103)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5259,
    "Keju Mozzarella (01060103)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5260,
    "Keju Mozzarella (01060103)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5261,
    "Keju Mozzarella (01060103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5262,
    "Keju Mozzarella (01060103)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5263,
    "Keju Mozzarella (01060103)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5264,
    "Keju Mozzarella (01060103)",
    "Lemak susu dihitung terhadap bahan kering (dengan kelembaban tinggi) (%)",
    "",
    "=20",
  ],
  [
    5265,
    "Keju Mozzarella (01060103)",
    "Lemak susu dihitung terhadap bahan kering (dengan kelembaban rendah) (%)",
    "",
    "=18",
  ],
  [
    5266,
    "Keju Mozzarella (01060103)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5267,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5268,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5269,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5270,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5271,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5272,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5273,
    "Keju Neufchatel dan Sayuran Untuk Olesan (0106040201)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [5274, "Keju Olahan (010604A0)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5275, "Keju Olahan (010604A0)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [5276, "Keju Olahan (010604A0)", "Merkuri (Hg) (mg/kg)", "=0.02"],
  [
    5277,
    "Keju Olahan (010604A0)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5278,
    "Keju Olahan (010604A0)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [5279, "Keju Olahan (010604A0)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5280,
    "Keju Olahan (010604A0)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5281,
    "Keju Olahan (010604A0)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5282,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5283,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5284,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5285,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5286,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5287,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5288,
    "Keju Olahan Berperisa, Keju Olahan dengan Tambahan Buah, Sayur dan atau Daging (0106040203)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5289,
    "Keju Olahan Plain (0106040104)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5290,
    "Keju Olahan Plain (0106040104)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    5291,
    "Keju Olahan Plain (0106040104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5292,
    "Keju Olahan Plain (0106040104)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5293,
    "Keju Olahan Plain (0106040104)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5294,
    "Keju Olahan Plain (0106040104)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5295,
    "Keju Olahan Plain (0106040104)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5296,
    "Keju Parmesan (0106020106)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5297,
    "Keju Parmesan (0106020106)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5298,
    "Keju Parmesan (0106020106)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5299,
    "Keju Parmesan (0106020106)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5300,
    "Keju Parmesan (0106020106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5301,
    "Keju Parmesan (0106020106)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5302,
    "Keju Parmesan (0106020106)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5303,
    "Keju Parmesan (0106020106)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [5304, "Keju Peram (010602A0)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5305, "Keju Peram (010602A0)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [5306, "Keju Peram (010602A0)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    5307,
    "Keju Peram (010602A0)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5308,
    "Keju Peram (010602A0)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5309, "Keju Peram (010602A0)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5310,
    "Keju Peram (010602A0)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5311,
    "Keju Peram (010602A0)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5312,
    "Keju Peram Lainnya (0106020115)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5313,
    "Keju Peram Lainnya (0106020115)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    5314,
    "Keju Peram Lainnya (0106020115)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5315,
    "Keju Peram Lainnya (0106020115)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    5316,
    "Keju Peram Lainnya (0106020115)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    5317,
    "Keju Peram Lainnya (0106020115)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5318,
    "Keju Peram Lainnya (0106020115)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    5319,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5320,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5321,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    5322,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5323,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5324,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    5325,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5326,
    "Keju Protein Whey (Misal Keju Ricotta) (010606)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [5327, "Keju Swiss (0106020107)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    5328,
    "Keju Swiss (0106020107)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5329,
    "Keju Swiss (0106020107)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5330,
    "Keju Swiss (0106020107)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5331,
    "Keju Swiss (0106020107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5332,
    "Keju Swiss (0106020107)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5333,
    "Keju Swiss (0106020107)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5334,
    "Keju Swiss (0106020107)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5335,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    5336,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5337,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    5338,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5339,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5340,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5341,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5342,
    "Keju Tanpa Pemeraman (Keju Mentah) (01060105)",
    "Aflatoksin M1 (ppb atau mcg)",
    "=0.5",
  ],
  [5343, "Keju Whey (010603)", "Arsen (As) (mg/kg) ", "=0.1"],
  [5344, "Keju Whey (010603)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [5345, "Keju Whey (010603)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    5346,
    "Keju Whey (010603)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5347,
    "Keju Whey (010603)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5348, "Keju Whey (010603)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    5349,
    "Keju Whey (010603)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    5350,
    "Keju Whey (010603)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5351,
    "Kekicak/Gegicak (060727)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5352,
    "Kekicak/Gegicak (060727)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5353,
    "Kekicak/Gegicak (060727)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5354,
    "Kekicak/Gegicak (060727)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    5355,
    "Kekicak/Gegicak (060727)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5356,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5357,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5358,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5359,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    5360,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    5361,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Kadar air (%)",
    "=3.00",
  ],
  [
    5362,
    "Kelapa Parut Kering dengan Proses Pemanasan/ Oven (0401020205)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    5363,
    "Kelp / Kombu (0402020218)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    5364,
    "Kelp / Kombu (0402020218)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5365,
    "Kelp / Kombu (0402020218)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5366,
    "Kelp / Kombu (0402020218)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5367,
    "Kelp / Kombu (0402020218)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5368,
    "Kelp / Kombu (0402020218)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5369,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Kandungan susu (%)",
    "=5",
  ],
  [
    5370,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5371,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5372,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5373,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5374,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5375,
    "Kembang Gula Isi Susu/Permen Isi Susu (05020104)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5376,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Kadar air (%)",
    "=20",
  ],
  [
    5377,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5378,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5379,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5380,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5381,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5382,
    "Kembang Gula Jeli Agar dan Gelatin (05020210)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5383,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5384,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5385,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5386,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5387,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5388,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5389,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Kadar air (%)",
    "=20",
  ],
  [
    5390,
    "Kembang Gula Jeli Pati (Starch Jelly) (05020209)",
    "Kadar air (%)",
    "=20",
  ],
  [
    5391,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5392,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5393,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5394,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5395,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5396,
    "Kembang Gula Karamel/Permen Karamel (05020202)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5397,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Kadar air (%)",
    "=5",
  ],
  [
    5398,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Kadar gom (%)",
    "",
    "=12",
  ],
  [
    5399,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5400,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5401,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5402,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5403,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5404,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5405,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Kadar air (%)",
    "=5",
  ],
  [
    5406,
    "Kembang Gula Karet/Permen Karet (050301)",
    "Gom",
    "",
    "=12",
  ],
  [
    5407,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "kadar air tidak lebih dari (%)",
    "=3.5",
  ],
  [
    5408,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5409,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5410,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5411,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5412,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5413,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5414,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Kadar air permen lunak (%)",
    "=7.5",
  ],
  [
    5415,
    "Kembang Gula Keras/Permen Keras/Hard Candy/Boiled Sweet (05020101)",
    "Kadar air permen lunak jeli (%)",
    "=20",
  ],
  [
    5416,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5417,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5418,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5419,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5420,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5421,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5422,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Kadar air permen lunak non jeli (%)",
    "=7.5",
  ],
  [
    5423,
    "Kembang Gula Lunak/Permen Lunak (05020201)",
    "Kadar air permen lunak jeli (%)",
    "=20",
  ],
  [
    5424,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Kandungan susu (%)",
    "",
    "=5",
  ],
  [
    5425,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    5426,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5427,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5428,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5429,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5430,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    5431,
    "Kembang Gula Susu/Permen Susu (010708)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    5432,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    5433,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5434,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5435,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5436,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5437,
    "Kembang Gula/Permen Isi lainnya (05020106)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5438,
    "Kembang Tahu (06080201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5439,
    "Kembang Tahu (06080201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5440,
    "Kembang Tahu (06080201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5441,
    "Kembang Tahu (06080201)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    5442,
    "Kembang Tahu (06080201)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5443,
    "Kembang Tahu (06080201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5444,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Bobot Tuntas (%)",
  ],
  [
    5445,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5446,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5447,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5448,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    5449,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5450,
    "Kembang Tahu dalam Kaleng (06080202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5451,
    "Kemiri (12020158)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    5452,
    "Kemiri (12020158)",
    "Cadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    5453,
    "Kemiri (12020158)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    5454,
    "Kemiri (12020158)",
    "Timah (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5455,
    "Kemiri (12020158)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    5456,
    "Kemiri (12020158)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    5457,
    "Kemiri (12020158)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [5458, "Kemiri (12020158)", "Kadar minyak (%)", "", "=60"],
  [5459, "Kemiri (12020158)", "Kadar air ( %)", "=5"],
  [
    5460,
    "Kemiri Dengan Tempurung (12020157)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5461,
    "Kemiri Dengan Tempurung (12020157)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5462,
    "Kemplang (150304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5463,
    "Kemplang (150304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5464,
    "Kemplang (150304)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5465,
    "Kemplang (150304)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5466,
    "Kemplang (150304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5467,
    "Kencur (12020159)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5468,
    "Kencur (12020159)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5469,
    "Kencur (12020159)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [5470, "Kencur (12020159)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [5471, "Kencur (12020159)", "Timbal (Pb) (ppm atau mg/kg)", "=1"],
  [
    5472,
    "Kencur (12020159)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5473,
    "Kencur (12020159)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5474,
    "Kencur Bubuk (12020160)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5475,
    "Kencur Bubuk (12020160)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5476,
    "Kencur Bubuk (12020160)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5477,
    "Kencur Bubuk (12020160)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    5478,
    "Kencur Bubuk (12020160)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    5479,
    "Kencur Bubuk (12020160)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5480,
    "Kencur Bubuk (12020160)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5481,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5482,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5483,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5484,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5485,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5486,
    "Kentang Goreng Beku (Frozen French Fries) (0402020111)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5487,
    "Kentang Kering Serpih (Flakes) (0402020215)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5488,
    "Kentang Kering Serpih (Flakes) (0402020215)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5489,
    "Kentang Kering Serpih (Flakes) (0402020215)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5490,
    "Kentang Kering Serpih (Flakes) (0402020215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5491,
    "Kentang Kering Serpih (Flakes) (0402020215)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5492,
    "Keping Jagung (Corn Flake) (060302)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5493,
    "Keping Jagung (Corn Flake) (060302)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5494,
    "Keping Jagung (Corn Flake) (060302)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5495,
    "Keping Jagung (Corn Flake) (060302)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5496,
    "Keping Jagung (Corn Flake) (060302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5497,
    "Keping Jagung (Corn Flake) (060302)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    5498,
    "Keping Jagung (Corn Flake) (060302)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5499,
    "Keping Jagung (Corn Flake) (060302)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5500,
    "Kerang Dalam Kaleng (090404)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    5501,
    "Kerang Dalam Kaleng (090404)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    5502,
    "Kerang Dalam Kaleng (090404)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    5503,
    "Kerang Dalam Kaleng (090404)",
    "Timah (Sn) (mg/kg)",
    "=250",
  ],
  [
    5504,
    "Kerang Dalam Kaleng (090404)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    5505,
    "Keripik Apel (0401021201)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5506,
    "Keripik Apel (0401021201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5507,
    "Keripik Apel (0401021201)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5508,
    "Keripik Apel (0401021201)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    5509,
    "Keripik Apel (0401021201)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    5510,
    "Keripik Apel (0401021201)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5511,
    "Keripik Bayam (0402020801)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5512,
    "Keripik Bayam (0402020801)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5513,
    "Keripik Bayam (0402020801)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5514,
    "Keripik Bayam (0402020801)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5515,
    "Keripik Bayam (0402020801)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5516,
    "Keripik Belut (0902040316)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    5517,
    "Keripik Belut (0902040316)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    5518,
    "Keripik Belut (0902040316)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    5519,
    "Keripik Belut (0902040316)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    5520,
    "Keripik Belut (0902040316)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    5521,
    "Keripik Belut (0902040316)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    5522,
    "Keripik Bonggol Pisang (0402020811)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    5523,
    "Keripik Bonggol Pisang (0402020811)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5524,
    "Keripik Bonggol Pisang (0402020811)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5525,
    "Keripik Bonggol Pisang (0402020811)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    5526,
    "Keripik Bonggol Pisang (0402020811)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    5527,
    "Keripik Bonggol Pisang (0402020811)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    5528,
    "Keripik Buah (0401021211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5529,
    "Keripik Buah (0401021211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5530,
    "Keripik Buah (0401021211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5531,
    "Keripik Buah (0401021211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5532,
    "Keripik Buah (0401021211)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    5533,
    "Keripik Buah (0401021211)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5534,
    "Keripik Buah Simulasi (0401021207)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5535,
    "Keripik Buah Simulasi (0401021207)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5536,
    "Keripik Buah Simulasi (0401021207)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5537,
    "Keripik Buah Simulasi (0401021207)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5538,
    "Keripik Buah Simulasi (0401021207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5539,
    "Keripik Buah Simulasi (0401021207)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [5540, "Keripik Gadung (150102)", "Kadar air (%)", "=6"],
  [
    5541,
    "Keripik Gadung (150102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5542,
    "Keripik Gadung (150102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5543,
    "Keripik Gadung (150102)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5544,
    "Keripik Gadung (150102)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5545,
    "Keripik Gadung (150102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5546,
    "Keripik Ikan (0902040315)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    5547,
    "Keripik Ikan (0902040315)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    5548,
    "Keripik Ikan (0902040315)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    5549,
    "Keripik Ikan (0902040315)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    5550,
    "Keripik Ikan (0902040315)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    5551,
    "Keripik Ikan (0902040315)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    5552,
    "Keripik Jamur Kancing (0402020802)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5553,
    "Keripik Jamur Kancing (0402020802)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5554,
    "Keripik Jamur Kancing (0402020802)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5555,
    "Keripik Jamur Kancing (0402020802)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5556,
    "Keripik Jamur Kancing (0402020802)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [5557, "Keripik Kentang (150101)", "Kadar air (%) (dusty)", "=3"],
  [
    5558,
    "Keripik Kentang (150101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5559,
    "Keripik Kentang (150101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5560,
    "Keripik Kentang (150101)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5561,
    "Keripik Kentang (150101)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5562,
    "Keripik Kentang (150101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5563, "Keripik Kentang (150101)", "Kadar air (%) (salut)", "=7"],
  [
    5564,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5565,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5566,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5567,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5568,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Sn (dalam kaleng) (ppm atau mg/kg)",
    "=250",
  ],
  [
    5569,
    "Keripik Kulit Ikan Goreng (0902040303)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [5570, "Keripik Lainnya (150131)", "Kadar air (%)", "=3"],
  [
    5571,
    "Keripik Lainnya (150131)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5572,
    "Keripik Lainnya (150131)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5573,
    "Keripik Lainnya (150131)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5574,
    "Keripik Lainnya (150131)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5575,
    "Keripik Lainnya (150131)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5576,
    "Keripik Nangka (0401021202)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5577,
    "Keripik Nangka (0401021202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5578,
    "Keripik Nangka (0401021202)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5579,
    "Keripik Nangka (0401021202)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    5580,
    "Keripik Nangka (0401021202)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5581,
    "Keripik Nangka (0401021202)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    5582,
    "Keripik Nenas (0401021203)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5583,
    "Keripik Nenas (0401021203)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5584,
    "Keripik Nenas (0401021203)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5585,
    "Keripik Nenas (0401021203)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5586,
    "Keripik Nenas (0401021203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5587,
    "Keripik Nenas (0401021203)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5588,
    "Keripik Oncom (150110)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5589,
    "Keripik Oncom (150110)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5590,
    "Keripik Oncom (150110)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5591,
    "Keripik Oncom (150110)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5592,
    "Keripik Oncom (150110)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5593,
    "Keripik Paru (08020215)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5594,
    "Keripik Paru (08020215)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.3",
  ],
  [
    5595,
    "Keripik Paru (08020215)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5596,
    "Keripik Paru (08020215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5597,
    "Keripik Paru (08020215)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    5598,
    "Keripik Paru (08020215)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    5599,
    "Keripik Pisang (0401021204)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5600,
    "Keripik Pisang (0401021204)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5601,
    "Keripik Pisang (0401021204)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5602,
    "Keripik Pisang (0401021204)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5603,
    "Keripik Pisang (0401021204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5604,
    "Keripik Pisang (0401021204)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5605,
    "Keripik Salak (0401021205)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5606,
    "Keripik Salak (0401021205)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5607,
    "Keripik Salak (0401021205)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5608,
    "Keripik Salak (0401021205)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5609,
    "Keripik Salak (0401021205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5610,
    "Keripik Salak (0401021205)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5611,
    "Keripik Sanjai (150106)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5612,
    "Keripik Sanjai (150106)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5613,
    "Keripik Sanjai (150106)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5614,
    "Keripik Sanjai (150106)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5615,
    "Keripik Sanjai (150106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5616,
    "Keripik Singkong (150104)",
    "Kadar air (%) (dusty)",
    "=6",
  ],
  [
    5617,
    "Keripik Singkong (150104)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5618,
    "Keripik Singkong (150104)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5619,
    "Keripik Singkong (150104)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5620,
    "Keripik Singkong (150104)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5621,
    "Keripik Singkong (150104)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5622,
    "Keripik Singkong (150104)",
    "Kadar air (%) (salut)",
    "=7",
  ],
  [
    5623,
    "Keripik Sukun (0401021206)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    5624,
    "Keripik Sukun (0401021206)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    5625,
    "Keripik Sukun (0401021206)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5626,
    "Keripik Sukun (0401021206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    5627,
    "Keripik Sukun (0401021206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5628,
    "Keripik Sukun (0401021206)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    5629,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Kadar air (%)",
    "=10",
  ],
  [
    5630,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5631,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5632,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5633,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5634,
    "Keripik Tahu / Keripik Produk Tahu / Keripik Kembang Tahu (150111)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5635,
    "Keripik Talas (150112)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5636,
    "Keripik Talas (150112)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5637,
    "Keripik Talas (150112)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5638,
    "Keripik Talas (150112)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5639,
    "Keripik Talas (150112)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5640, "Keripik Talas (150112)", "Kadar air (%)", "=5"],
  [5641, "Keripik Tempe (150109)", "Kadar air (%)", "=4"],
  [
    5642,
    "Keripik Tempe (150109)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5643,
    "Keripik Tempe (150109)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5644,
    "Keripik Tempe (150109)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5645,
    "Keripik Tempe (150109)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5646,
    "Keripik Tempe (150109)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5647, "Keripik Ubi Jalar (150108)", "Kadar air (%)", "=5"],
  [
    5648,
    "Keripik Ubi Jalar (150108)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5649,
    "Keripik Ubi Jalar (150108)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5650,
    "Keripik Ubi Jalar (150108)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5651,
    "Keripik Ubi Jalar (150108)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5652,
    "Keripik Ubi Jalar (150108)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5653,
    "Kerupuk Beras (150123)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5654,
    "Kerupuk Beras (150123)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5655,
    "Kerupuk Beras (150123)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5656,
    "Kerupuk Beras (150123)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5657,
    "Kerupuk Beras (150123)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5658,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5659,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    5660,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    5661,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5662,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5663,
    "Kerupuk Berbasis Daging, Daging Unggas dan Daging Hewan Buruan (08020216)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    5664,
    "Kerupuk Cumi (150303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5665,
    "Kerupuk Cumi (150303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5666,
    "Kerupuk Cumi (150303)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5667,
    "Kerupuk Cumi (150303)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5668,
    "Kerupuk Cumi (150303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5669, "Kerupuk Ikan (09020506)", "Sensori (angka 1-9)", "", "=7"],
  [
    5670,
    "Kerupuk Ikan (09020506)",
    "Kadar abu tak larut dalam asam (%)",
    "=0.2",
  ],
  [5671, "Kerupuk Ikan (09020506)", "Kadar Protein (%)", "", "=5"],
  [5672, "Kerupuk Ikan (09020506)", "As (ppm atau mg/kg)", "=0.25"],
  [5673, "Kerupuk Ikan (09020506)", "Cd (ppm atau mg/kg)", "=0.1"],
  [5674, "Kerupuk Ikan (09020506)", "Hg (ppm atau mg/kg)", "=0.5"],
  [
    5675,
    "Kerupuk Ikan (09020506)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5676,
    "Kerupuk Ikan (09020506)",
    "Sn (dalam kaleng) (ppm atau mg/kg)",
    "=250",
  ],
  [5677, "Kerupuk Ikan (09020506)", "Pb (ppm atau mg/kg)", "=0.2"],
  [5678, "Kerupuk Ikan (150301)", "Kadar air (%)", "=3"],
  [
    5679,
    "Kerupuk Ikan (150301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    5680,
    "Kerupuk Ikan (150301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5681,
    "Kerupuk Ikan (150301)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5682,
    "Kerupuk Ikan (150301)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5683,
    "Kerupuk Ikan (150301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.3",
  ],
  [
    5684,
    "Kerupuk Intip (150126)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5685,
    "Kerupuk Intip (150126)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5686,
    "Kerupuk Intip (150126)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5687,
    "Kerupuk Intip (150126)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5688,
    "Kerupuk Intip (150126)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5689,
    "Kerupuk Jengkol (0402020808)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5690,
    "Kerupuk Jengkol (0402020808)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5691,
    "Kerupuk Jengkol (0402020808)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5692,
    "Kerupuk Jengkol (0402020808)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5693,
    "Kerupuk Jengkol (0402020808)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5694,
    "Kerupuk Karak (150125)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5695,
    "Kerupuk Karak (150125)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5696,
    "Kerupuk Karak (150125)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5697,
    "Kerupuk Karak (150125)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5698,
    "Kerupuk Karak (150125)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5699,
    "Kerupuk Kulit Ayam (08020217)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    5700,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    5701,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    5702,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    5703,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    5704,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    5705,
    "Kerupuk Kulit Ikan Mentah (09020527)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    5706,
    "Kerupuk Kulit/Rambak (08020214)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5707,
    "Kerupuk Kulit/Rambak (08020214)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    5708,
    "Kerupuk Kulit/Rambak (08020214)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    5709,
    "Kerupuk Kulit/Rambak (08020214)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5710,
    "Kerupuk Kulit/Rambak (08020214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5711,
    "Kerupuk Kulit/Rambak (08020214)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    5712,
    "Kerupuk Lainnya (150132)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5713,
    "Kerupuk Lainnya (150132)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5714,
    "Kerupuk Lainnya (150132)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5715,
    "Kerupuk Lainnya (150132)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5716,
    "Kerupuk Lainnya (150132)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5717,
    "Kerupuk Mentah (06040324)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5718,
    "Kerupuk Mentah (06040324)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5719,
    "Kerupuk Mentah (06040324)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5720,
    "Kerupuk Mentah (06040324)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    5721,
    "Kerupuk Mentah (06040324)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5722,
    "Kerupuk Mentah (06040324)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5723,
    "Kerupuk Puli (150124)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5724,
    "Kerupuk Puli (150124)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5725,
    "Kerupuk Puli (150124)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5726,
    "Kerupuk Puli (150124)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5727,
    "Kerupuk Puli (150124)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5728, "Kerupuk Udang Matang (150302)", "Kadar air (%)", "=3"],
  [
    5729,
    "Kerupuk Udang Matang (150302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5730,
    "Kerupuk Udang Matang (150302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5731,
    "Kerupuk Udang Matang (150302)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5732,
    "Kerupuk Udang Matang (150302)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    5733,
    "Kerupuk Udang Matang (150302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [5734, "Kerupuk Udang Mentah (09020510)", "Kadar air (%)", "=12"],
  [
    5735,
    "Kerupuk Udang Mentah (09020510)",
    "Kadar abu tak larut dalam asam (%)",
    "=0.2",
  ],
  [
    5736,
    "Kerupuk Udang Mentah (09020510)",
    "Kadar Protein (%) (Grade I)",
    "",
    "=8",
  ],
  [
    5737,
    "Kerupuk Udang Mentah (09020510)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    5738,
    "Kerupuk Udang Mentah (09020510)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5739,
    "Kerupuk Udang Mentah (09020510)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5740,
    "Kerupuk Udang Mentah (09020510)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5741,
    "Kerupuk Udang Mentah (09020510)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    5742,
    "Kerupuk Udang Mentah (09020510)",
    "Kadar Protein (%) (Grade II)",
    "",
    "=5",
  ],
  [
    5743,
    "Kerupuk Udang Mentah (09020510)",
    "Kadar Protein (%) (Grade III)",
    "",
    "=2",
  ],
  [
    5744,
    "Ketumbar (12020161)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    5745,
    "Ketumbar (12020161)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5746,
    "Ketumbar (12020161)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5747,
    "Ketumbar (12020161)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5748,
    "Ketumbar (12020161)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    5749,
    "Ketumbar (12020161)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    5750,
    "Ketumbar (12020161)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5751,
    "Ketumbar (12020161)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [5752, "Ketumbar Bubuk (12020163)", "Kadar air (%)", "=12"],
  [
    5753,
    "Ketumbar Bubuk (12020163)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    5754,
    "Ketumbar Bubuk (12020163)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5755,
    "Ketumbar Bubuk (12020163)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5756,
    "Ketumbar Bubuk (12020163)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5757,
    "Ketumbar Bubuk (12020163)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    5758,
    "Ketumbar Bubuk (12020163)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    5759,
    "Ketumbar Bubuk (12020163)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5760,
    "Ketumbar Bubuk (12020163)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5761,
    "Khoa (01030110)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    5762,
    "Khoa (01030110)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    5763,
    "Khoa (01030110)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    5764,
    "Khoa (01030110)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    5765,
    "Khoa (01030110)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    5766,
    "Khoa (01030110)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [5767, "Khoa (01030110)", "Aflatoksin M1 (mcg/kg)", "=0.5"],
  [
    5768,
    "Kimchi (0402020708)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5769,
    "Kimchi (0402020708)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [5770, "Kimchi (0402020708)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    5771,
    "Kimchi (0402020708)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5772,
    "Kimchi (0402020708)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [5773, "Kinako (06020123)", "Arsen (As) (mg/kg)", "=0.1"],
  [5774, "Kinako (06020123)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [5775, "Kinako (06020123)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [5776, "Kinako (06020123)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [5777, "Kinako (06020123)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    5778,
    "Kipang Kacang Mete (150206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5779,
    "Kipang Kacang Mete (150206)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    5780,
    "Kipang Kacang Mete (150206)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    5781,
    "Kipang Kacang Mete (150206)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5782,
    "Kipang Kacang Mete (150206)",
    "Timah dalam kaleng (Sn) (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5783,
    "Kipang Kacang Mete (150206)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5784,
    "Kipang Kacang Mete (150206)",
    "Aflatoksin Total (ppb atau mcg/kg) ",
    "=10",
  ],
  [
    5785,
    "Kitosan (Chitosan) (09020525)",
    "Angka Lempeng Total (koloni/g)",
    "<10000",
  ],
  [5786, "Kitosan (Chitosan) (09020525)", "Staphylcoccus"],
  [
    5787,
    "Kitosan (Chitosan) (09020525)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    5788,
    "Kitosan (Chitosan) (09020525)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    5789,
    "Kitosan (Chitosan) (09020525)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    5790,
    "Kitosan (Chitosan) (09020525)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    5791,
    "Kitosan (Chitosan) (09020525)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5792,
    "Kluwek (12020165)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5793,
    "Kluwek (12020165)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    5794,
    "Kluwek (12020165)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [5795, "Kluwek (12020165)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [5796, "Kluwek (12020165)", "Timbal (Pb) (ppm atau mg/kg)", "=1"],
  [
    5797,
    "Kluwek (12020165)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    5798,
    "Kluwek (12020165)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    5799,
    "Koji atau Ragi Tauco atau Ragi Kecap (120807)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    5800,
    "Koji atau Ragi Tauco atau Ragi Kecap (120807)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    5801,
    "Koji atau Ragi Tauco atau Ragi Kecap (120807)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    5802,
    "Koji atau Ragi Tauco atau Ragi Kecap (120807)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    5803,
    "Koji atau Ragi Tauco atau Ragi Kecap (120807)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    5804,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    5805,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    5806,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    5807,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    5808,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    5809,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    5810,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5811,
    "Koktail Anggur (Wine Cocktail) (14020703)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    5812,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Bobot tuntas (%)",
    "",
    "=40",
  ],
  [
    5813,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5814,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5815,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5816,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    5817,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    5818,
    "Koktil Buah Dalam Kemasan (0401020403)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [5819, "Kolak (1674)", "Arsen (As) (mg/kg) ", "=0.25"],
  [5820, "Kolak (1674)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [5821, "Kolak (1674)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    5822,
    "Kolak (1674)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    5823,
    "Kolak (1674)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [5824, "Kolak (1674)", "Timbal (Pb) (mg/kg) ", "=0.25"],
  [
    5825,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Rongga kosong (headspace) (% v/v)",
    "=10.00",
  ],
  [
    5826,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Bobot tuntas (%)",
    "",
    "=50",
  ],
  [
    5827,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    5828,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    5829,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5830,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    5831,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    5832,
    "Kolang Kaling Dalam Kemasan (0401020402)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    5833,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Kadar air (untuk : biskuit, biskuit non terigu, biskuit marie, kukis, kukis gula, kukis oatmeal, wafer, pai, roti bagelen) (%) ",
    "=5",
  ],
  [
    5834,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Kadar air (untuk : kukis lunak, nastar, kastengel, pai isi) (%) ",
    "=10",
  ],
  [
    5835,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    5836,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    5837,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    5838,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg) ",
    "=250",
  ],
  [
    5839,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Timah pangan olahan yang tidak dikemas dalam kaleng (Sn) (mg/kg) ",
    "=40",
  ],
  [
    5840,
    "Kombinasi Pangan Olahan (Produk Bakeri Istimewa dan Minuman Serbuk) (1671)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [5841, "Konjac Flour (06020124)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    5842,
    "Konjac Flour (06020124)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5843,
    "Konjac Flour (06020124)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5844,
    "Konjac Flour (06020124)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [5845, "Konjac Flour (06020124)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    5846,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5847,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5848,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5849,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5850,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5851,
    "Konsentrat Sari Buah dan Sari Sayuran (1401020402)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5852,
    "Konsentrat Asam Jawa/Tamarin (0401020812)",
    "Total Padatan Terlarut (%)",
    "",
    "=65",
  ],
  [
    5853,
    "Konsentrat Lemonade Beku (1401040301)",
    "Total padatan terlarut (%) (dihitung sebagai nilai sukrosa)",
    "",
    "=48",
  ],
  [
    5854,
    "Konsentrat Lemonade Beku (1401040301)",
    "Keasaman lemonade (% b/v) (saat produk diencerkan) (sebagai asam sitrat anhidrat)",
    "",
    "=0.77",
  ],
  [
    5855,
    "Konsentrat Lemonade Beku (1401040301)",
    "Total padatan terlarut (%) (saat produk diencerkan)",
    "",
    "=10.5",
  ],
  [
    5856,
    "Konsentrat Lemonade Beku (1401040301)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5857,
    "Konsentrat Lemonade Beku (1401040301)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5858,
    "Konsentrat Lemonade Beku (1401040301)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5859,
    "Konsentrat Lemonade Beku (1401040301)",
    "Timah (Sn) (Minuman dalam kemasan kaleng) (ppm atau mg/kg)",
    "=100",
  ],
  [
    5860,
    "Konsentrat Lemonade Beku (1401040301)",
    "Timah (Sn) (Pangan olahan yang tidak dikemas dalam kaleng) (ppm atau mg/kg)",
    "=40",
  ],
  [
    5861,
    "Konsentrat Lemonade Beku (1401040301)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    5862,
    "Konsentrat Minuman Buah (1401020311)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5863,
    "Konsentrat Minuman Buah (1401020311)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5864,
    "Konsentrat Minuman Buah (1401020311)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5865,
    "Konsentrat Minuman Buah (1401020311)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5866,
    "Konsentrat Minuman Buah (1401020311)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5867,
    "Konsentrat Minuman Buah (1401020311)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5868,
    "Konsentrat Minuman Buah (1401020311)",
    "Kandungan sari buah setelah diencerkan (%)",
    "<35",
    "=10",
  ],
  [
    5869,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "kadar asam total dihitung sebagai asam asetat (%) (b/v)",
    "<3",
  ],
  [
    5870,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5871,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5872,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5873,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5874,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5875,
    "Konsentrat Minuman Cuka (Konsentrat Minuman Vinegar) (1401040316)",
    "Timbal (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5876,
    "Konsentrat Minuman Kopi (14010520)",
    "Arsen (As) ( mg/kg ) ",
    "=1",
  ],
  [
    5877,
    "Konsentrat Minuman Kopi (14010520)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    5878,
    "Konsentrat Minuman Kopi (14010520)",
    "Raksa (Hg) ( mg/kg ) ",
    "=0.03",
  ],
  [
    5879,
    "Konsentrat Minuman Kopi (14010520)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    5880,
    "Konsentrat Minuman Kopi (14010520)",
    "Timbal (Pb) ( mg/kg )",
    "=2",
  ],
  [
    5881,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5882,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5883,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5884,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5885,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5886,
    "Konsentrat Minuman Rasa/Berperisa (1401040320)",
    "Timbal (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5887,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5888,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5889,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    5890,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5891,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5892,
    "Konsentrat Minuman Rasa/Berperisa (Steril Komersial) (1401040319)",
    "Timbal (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    5893,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5894,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5895,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5896,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5897,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5898,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5899,
    "Konsentrat Minuman Sari Buah (1401020309)",
    "Kandungan sari buah setelah diencerkan (%)",
    "",
    "=35",
  ],
  [
    5900,
    "Konsentrat Minuman Teh (14010514)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    5901,
    "Konsentrat Minuman Teh (14010514)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    5902,
    "Konsentrat Minuman Teh (14010514)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5903,
    "Konsentrat Minuman Teh (14010514)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5904,
    "Konsentrat Minuman Teh (14010514)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    5905,
    "Konsentrat Nektar Buah (14010303)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    5906,
    "Konsentrat Nektar Buah (14010303)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    5907,
    "Konsentrat Nektar Buah (14010303)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5908,
    "Konsentrat Nektar Buah (14010303)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5909,
    "Konsentrat Nektar Buah (14010303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5910,
    "Konsentrat Nektar Buah (14010303)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.2",
  ],
  [
    5911,
    "Konsentrat Nektar Sayur (14010304)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    5912,
    "Konsentrat Nektar Sayur (14010304)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    5913,
    "Konsentrat Nektar Sayur (14010304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5914,
    "Konsentrat Nektar Sayur (14010304)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.2",
  ],
  [
    5915,
    "Konsentrat Nektar Sayur (14010304)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    5916,
    "Konsentrat Nektar Sayur (14010304)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [5917, "Konsentrat Sari Buah ... (1401020310)", "pH ", "=4"],
  [
    5918,
    "Konsentrat Sari Buah ... (1401020310)",
    "total padatan terlarut (%)",
    "",
    "=15",
  ],
  [
    5919,
    "Konsentrat Sari Buah ... (1401020310)",
    "kadar etanol (%)",
    "=0.5",
  ],
  [
    5920,
    "Konsentrat Sari Buah ... (1401020310)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5921,
    "Konsentrat Sari Buah ... (1401020310)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5922,
    "Konsentrat Sari Buah ... (1401020310)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5923,
    "Konsentrat Sari Buah ... (1401020310)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5924,
    "Konsentrat Sari Buah ... (1401020310)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5925,
    "Konsentrat Sari Buah ... (1401020310)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5926,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5927,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5928,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5929,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5930,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5931,
    "Konsentrat Sari Buah Anggur (1401020304)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=20",
  ],
  [
    5932,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C tanpa koreksi keasaman",
    "",
    "=30",
  ],
  [
    5933,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5934,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5935,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5936,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5937,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5938,
    "Konsentrat Sari Buah Anggur Manis (1401020305)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5939,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=20",
  ],
  [
    5940,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5941,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5942,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5943,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5944,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5945,
    "Konsentrat Sari Buah Apel (1401020303)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5946,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=20",
  ],
  [
    5947,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5948,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5949,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5950,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5951,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5952,
    "Konsentrat Sari Buah Blackcurrant (1401020306)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5953,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5954,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5955,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5956,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5957,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5958,
    "Konsentrat Sari Buah dan Sari Sayur (1401020312)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5959,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=20",
  ],
  [
    5960,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5961,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5962,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5963,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5964,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5965,
    "Konsentrat Sari Buah Jeruk Orange, Valencia (1401020301)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5966,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=20",
  ],
  [
    5967,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5968,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5969,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5970,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5971,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5972,
    "Konsentrat Sari Buah Jeruk Siam, Tangerine (1401020302)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5973,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5974,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5975,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5976,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5977,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5978,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5979,
    "Konsentrat Sari Buah Nanas (1401020307)",
    "Total padatan ( %) yang diukur dengan refraktometer pada suhu 20\xB0C",
    "",
    "=40",
  ],
  [
    5980,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5981,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5982,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5983,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5984,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5985,
    "Konsentrat Sari Buah Nanas dengan Pengawet untuk Keperluan Industri Pangan (1401020308)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5986,
    "Konsentrat Sari Kedelai (06080104)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    5987,
    "Konsentrat Sari Kedelai (06080104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    5988,
    "Konsentrat Sari Kedelai (06080104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    5989,
    "Konsentrat Sari Kedelai (06080104)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    5990,
    "Konsentrat Sari Kedelai (06080104)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    5991,
    "Konsentrat Sari Kedelai (06080104)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    5992,
    "Konsentrat Sari Sayur (1401020403)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5993,
    "Konsentrat Sari Sayur (1401020403)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    5994,
    "Konsentrat Sari Sayur (1401020403)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    5995,
    "Konsentrat Sari Sayur (1401020403)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    5996,
    "Konsentrat Sari Sayur (1401020403)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    5997,
    "Konsentrat Sari Sayur (1401020403)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    5998,
    "Konsentrat Sari Tomat (1401020401)",
    "pasta tomat (%)",
    "",
    "=24",
  ],
  [
    5999,
    "Konsentrat Sari Tomat (1401020401)",
    "puree tomat (%)",
    "=24",
    "=8",
  ],
  [
    6000,
    "Konsentrat Sari Tomat (1401020401)",
    "Arsen (As) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6001,
    "Konsentrat Sari Tomat (1401020401)",
    "Kadmium (Cd) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6002,
    "Konsentrat Sari Tomat (1401020401)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    6003,
    "Konsentrat Sari Tomat (1401020401)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    6004,
    "Konsentrat Sari Tomat (1401020401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6005,
    "Konsentrat Sari Tomat (1401020401)",
    "Timbal (Pb) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6006,
    "Konsentrat untuk Minuman (1401040302)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    6007,
    "Konsentrat untuk Minuman (1401040302)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    6008,
    "Konsentrat untuk Minuman (1401040302)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    6009,
    "Konsentrat untuk Minuman (1401040302)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    6010,
    "Konsentrat untuk Minuman (1401040302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6011,
    "Konsentrat untuk Minuman (1401040302)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [6012, "Kopi Bubuk (14010516)", "Kadar air (%)", "=7"],
  [6013, "Kopi Bubuk (14010516)", "Arsen (As) (mg/kg) ", "=1"],
  [6014, "Kopi Bubuk (14010516)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [6015, "Kopi Bubuk (14010516)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    6016,
    "Kopi Bubuk (14010516)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6017, "Kopi Bubuk (14010516)", "Timbal (Pb) (mg/kg)", "=2"],
  [6018, "Kopi Bubuk (14010516)", "Kafein anhidrat (%)", "=2.5"],
  [6019, "Kopi Campur (14010518)", "Kadar kopi", "", "=50"],
  [6020, "Kopi Campur (14010518)", "Arsen (As) (mg/kg) ", "=1"],
  [6021, "Kopi Campur (14010518)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [
    6022,
    "Kopi Campur (14010518)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    6023,
    "Kopi Campur (14010518)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [6024, "Kopi Campur (14010518)", "Timbal (Pb) (mg/kg)", "=2"],
  [
    6025,
    "Kopi Campur (14010518)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [6026, "Kopi Celup (14010550)", "Bau"],
  [6027, "Kopi Celup (14010550)", "Rasa"],
  [6028, "Kopi Celup (14010550)", "Warna"],
  [
    6029,
    "Kopi Celup (14010550)",
    "Mutu I: mengandung sari kopi (% b/b) ",
    "=36",
    "=20",
  ],
  [
    6030,
    "Kopi Celup (14010550)",
    "Mutu II : mengandung sari kopi (% b/b) ",
    "=60",
  ],
  [6031, "Kopi Celup (14010550)", "Arsen (mg/kg) ", "=1"],
  [6032, "Kopi Celup (14010550)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [6033, "Kopi Celup (14010550)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    6034,
    "Kopi Celup (14010550)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [6035, "Kopi Celup (14010550)", "Timbal (Pb) (mg/kg) ", "=2"],
  [6036, "Kopi Dekafein (14010544)", "Kadar air (%)", "=7"],
  [
    6037,
    "Kopi Dekafein (14010544)",
    "Kafein Anhidrat (%) dihitung terhadap bobot kering",
    "=0.1",
  ],
  [6038, "Kopi Dekafein (14010544)", "Arsen (As) ( mg/kg ) ", "=1"],
  [
    6039,
    "Kopi Dekafein (14010544)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    6040,
    "Kopi Dekafein (14010544)",
    "Merkuri (Hg) ( mg/kg ) ",
    "=0.03",
  ],
  [
    6041,
    "Kopi Dekafein (14010544)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [6042, "Kopi Dekafein (14010544)", "Timbal (Pb) ( mg/kg )", "=2"],
  [6043, "Kopi Instan (14010517)", "Bau"],
  [6044, "Kopi Instan (14010517)", "Warna"],
  [
    6045,
    "Kopi Instan (14010517)",
    "Air (pengujian dengan metode oven vaccum*) (%b/b) *pilih salah satu metode",
    "=4",
  ],
  [
    6046,
    "Kopi Instan (14010517)",
    "Air (pengujian dengan metode Karl Fischer*) (%b/b) *pilih salah satu metode",
    "=5",
  ],
  [6047, "Kopi Instan (14010517)", "Abu (% b/b)", "=14", "=6"],
  [6048, "Kopi Instan (14010517)", "Kafein (%)", "", "=2.5"],
  [6049, "Kopi Instan (14010517)", "Total Glukosa (%)", "=2.46"],
  [6050, "Kopi Instan (14010517)", "Total Xylosa (%)", "=0.45"],
  [
    6051,
    "Kopi Instan (14010517)",
    "Kelarutan dalam air panas (detik)",
    "=30",
  ],
  [
    6052,
    "Kopi Instan (14010517)",
    "Kelarutan dalam air dingin (menit)",
    "=3",
  ],
  [6053, "Kopi Instan (14010517)", "Timbal (Pb) (mg/kg) ", "=2"],
  [6054, "Kopi Instan (14010517)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [
    6055,
    "Kopi Instan (14010517)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6056,
    "Kopi Instan (14010517)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    6057,
    "Kopi Instan (14010517)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [6058, "Kopi Instan (14010517)", "Arsen (As) (mg/kg) ", "=1"],
  [
    6059,
    "Kopi Instan (14010517)",
    "Angka Lempeng Total (ALT) (koloni/g)",
    "=3000",
  ],
  [
    6060,
    "Kopi Instan (14010517)",
    "Kapang dan Khamir (koloni/g)",
    "=100",
  ],
  [
    6061,
    "Kopi Instan (14010517)",
    "Okratoksin A (ppb atau mcg/kg)",
    "=10",
  ],
  [6062, "Kopi Instan Dekafein (14010545)", "Bau"],
  [6063, "Kopi Instan Dekafein (14010545)", "Warna"],
  [
    6064,
    "Kopi Instan Dekafein (14010545)",
    "Air (pengujian dengan metode oven vaccum) (%b/b) *pilih salah satu metode",
    "=4",
  ],
  [
    6065,
    "Kopi Instan Dekafein (14010545)",
    "Air (pengujian dengan metode Karl Fischer) (%b/b) *pilih salah satu metode",
    "=5",
  ],
  [
    6066,
    "Kopi Instan Dekafein (14010545)",
    "Abu (% b/b)",
    "=14",
    "=6",
  ],
  [6067, "Kopi Instan Dekafein (14010545)", "Kafein (%)", "=0.3"],
  [
    6068,
    "Kopi Instan Dekafein (14010545)",
    "Total Glukosa (%)",
    "=2.46",
  ],
  [
    6069,
    "Kopi Instan Dekafein (14010545)",
    "Total Xylosa (%)",
    "=0.45",
  ],
  [
    6070,
    "Kopi Instan Dekafein (14010545)",
    "Kelarutan dalam air panas (detik)",
    "=30",
  ],
  [
    6071,
    "Kopi Instan Dekafein (14010545)",
    "Kelarutan dalam air dingin (menit)",
    "=3",
  ],
  [
    6072,
    "Kopi Instan Dekafein (14010545)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    6073,
    "Kopi Instan Dekafein (14010545)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    6074,
    "Kopi Instan Dekafein (14010545)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6075,
    "Kopi Instan Dekafein (14010545)",
    "Timah produk yang dikemas dalam kaleng (Sn) (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    6076,
    "Kopi Instan Dekafein (14010545)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6077,
    "Kopi Instan Dekafein (14010545)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    6078,
    "Kopi Instan Dekafein (14010545)",
    "Okratoksin A (ppb atau mcg/kg)",
    "=10",
  ],
  [
    6079,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (140105)",
    "Kadar kafein",
    "=6000",
    "=1500",
  ],
  [
    6080,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    6081,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    6082,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    6083,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6084,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    6085,
    "Kopi, Kopi Substitusi, Teh, Seduhan Herbal, dan Minuman Biji-Bijian dan Sereal Panas, kecuali Cokelat (14010547)",
    "Kafein",
  ],
  [6086, "Kopra (0401020204)", "Kadar air (%)", "=12.00"],
  [
    6087,
    "Kopra (0401020204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6088,
    "Kopra (0401020204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6089,
    "Kopra (0401020204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6090,
    "Kopra (0401020204)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    6091,
    "Kopra (0401020204)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    6092,
    "Kopra (0401020204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    6093,
    "Kornet Daging (Beku) (08030308)",
    "Kandungan daging (%)",
    "",
    "=45",
  ],
  [
    6094,
    "Kornet Daging (Beku) (08030308)",
    "Kadar protein (%)",
    "",
    "=17",
  ],
  [
    6095,
    "Kornet Daging (Beku) (08030308)",
    "Kadar lemak (%)",
    "=12",
  ],
  [
    6096,
    "Kornet Daging (Beku) (08030308)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6097,
    "Kornet Daging (Beku) (08030308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6098,
    "Kornet Daging (Beku) (08030308)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6099,
    "Kornet Daging (Beku) (08030308)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6100,
    "Kornet Daging (Beku) (08030308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6101,
    "Kornet Daging (Beku) (08030308)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6102,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Kadar protein (%) ",
    "",
    "=10",
  ],
  [
    6103,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Kadar lemak (%) ",
    "=12",
  ],
  [
    6104,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6105,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6106,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    6107,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6108,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6109,
    "Kornet Daging (Sapi/ Kambing/ Babi) Kombinasi (08030227)",
    "Kandungan Daging (%) ",
    "",
    "=25",
  ],
  [
    6110,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Kadar protein (%)",
    "",
    "=17",
  ],
  [
    6111,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6112,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6113,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6114,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6115,
    "Kornet Daging Ayam (Corned Chicken) dalam Kemasan (08030223)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6116,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Kandungan daging (%)",
    "",
    "=25",
  ],
  [
    6117,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Kadar protein (%)",
    "",
    "=10",
  ],
  [
    6118,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Kadar lemak (%)",
    "=12",
  ],
  [
    6119,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6120,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6121,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6122,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6123,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6124,
    "Kornet Daging Kombinasi (Beku) (08030309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6125,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Kadar Daging (%)",
    "",
    "=25",
  ],
  [
    6126,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6127,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Kadar Protein (%)",
    "",
    "=10",
  ],
  [
    6128,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6129,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6130,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6131,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6132,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6133,
    "Kornet Daging Kombinasi non sterilisasi (0803010112)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6134,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Kadar Daging (%)",
    "",
    "=25",
  ],
  [
    6135,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Kadar Protein (%)",
    "",
    "=10",
  ],
  [
    6136,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6137,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6138,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6139,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6140,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6141,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6142,
    "Kornet Daging Kombinasi Sterilisasi (08030235)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6143,
    "Kornet Daging non sterilisasi (0803010111)",
    "Kadar Daging (%)",
    "",
    "=45",
  ],
  [
    6144,
    "Kornet Daging non sterilisasi (0803010111)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6145,
    "Kornet Daging non sterilisasi (0803010111)",
    "Kadar Protein (%)",
    "",
    "=17",
  ],
  [
    6146,
    "Kornet Daging non sterilisasi (0803010111)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6147,
    "Kornet Daging non sterilisasi (0803010111)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6148,
    "Kornet Daging non sterilisasi (0803010111)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6149,
    "Kornet Daging non sterilisasi (0803010111)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6150,
    "Kornet Daging non sterilisasi (0803010111)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6151,
    "Kornet Daging non sterilisasi (0803010111)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6152,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Kadar protein (%)",
    "",
    "=17",
  ],
  [
    6153,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Kadar lemak (%)",
    "=12",
  ],
  [
    6154,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6155,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6156,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    6157,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6158,
    "Kornet Daging Sapi (Corned Beef) dalam Kemasan (08030206)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6159,
    "Kornet Daging Sterilisasi (08030234)",
    "Kadar Daging (%)",
    "",
    "=45",
  ],
  [
    6160,
    "Kornet Daging Sterilisasi (08030234)",
    "Kadar Protein (%)",
    "",
    "=17",
  ],
  [
    6161,
    "Kornet Daging Sterilisasi (08030234)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6162,
    "Kornet Daging Sterilisasi (08030234)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6163,
    "Kornet Daging Sterilisasi (08030234)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6164,
    "Kornet Daging Sterilisasi (08030234)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6165,
    "Kornet Daging Sterilisasi (08030234)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6166,
    "Kornet Daging Sterilisasi (08030234)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6167,
    "Kornet Daging Sterilisasi (08030234)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6168,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Kadar lemak (%) ",
    "=12",
  ],
  [
    6169,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Kadar protein (%) ",
    "",
    "=8",
  ],
  [
    6170,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Kandungan Daging (%) ",
    "",
    "=20",
  ],
  [
    6171,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6172,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6173,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6174,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6175,
    "Kornet Daging Unggas Kombinasi (08030228)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [6176, "Kornet Ikan (090411)", "Arsen (As) (mg/kg) ", "=0.25"],
  [6177, "Kornet Ikan (090411)", "Kadmium (Cd) (mg/kg) ", "=0.1"],
  [6178, "Kornet Ikan (090411)", "Merkuri (Hg) (mg/kg) ", "=0.5"],
  [6179, "Kornet Ikan (090411)", "Timah (Sn) (mg/kg) ", "=250"],
  [6180, "Kornet Ikan (090411)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    6181,
    "Kornet Unggas (Beku) (08030310)",
    "Kandungan daging (%)",
    "",
    "=35",
  ],
  [
    6182,
    "Kornet Unggas (Beku) (08030310)",
    "Kadar protein (%)",
    "",
    "=12",
  ],
  [
    6183,
    "Kornet Unggas (Beku) (08030310)",
    "Kadar lemak (%)",
    "=12",
  ],
  [
    6184,
    "Kornet Unggas (Beku) (08030310)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6185,
    "Kornet Unggas (Beku) (08030310)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6186,
    "Kornet Unggas (Beku) (08030310)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6187,
    "Kornet Unggas (Beku) (08030310)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6188,
    "Kornet Unggas (Beku) (08030310)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6189,
    "Kornet Unggas (Beku) (08030310)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6190,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Kandungan Daging (%)",
    "",
    "=20",
  ],
  [
    6191,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Kadar protein (%)",
    "",
    "=8",
  ],
  [
    6192,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Kadar lemak (%)",
    "=12",
  ],
  [
    6193,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6194,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6195,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6196,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6197,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6198,
    "Kornet Unggas Kombinasi (Beku) (08030311)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6199,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Kadar Daging (%)",
    "",
    "=20",
  ],
  [
    6200,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6201,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    6202,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6203,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6204,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6205,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6206,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6207,
    "Kornet Unggas Kombinasi non sterilisasi (0803010114)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6208,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Kandungan daging (%)",
    "",
    "=20",
  ],
  [
    6209,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6210,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6211,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    6212,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6213,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6214,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    6215,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Kadar lemak keduanya (%) ",
    "=12",
  ],
  [
    6216,
    "Kornet Unggas Kombinasi Sterilisasi (08030237)",
    "Kadar protein (%) ",
    "",
    "=8",
  ],
  [
    6217,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Kadar Daging (%)",
    "",
    "=35",
  ],
  [
    6218,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6219,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Kadar Protein (%)",
    "",
    "=12",
  ],
  [
    6220,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6221,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6222,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6223,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6224,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6225,
    "Kornet Unggas non sterilisasi (0803010113)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6226,
    "Kornet Unggas Sterilisasi (08030236)",
    "Kadar Daging (%)",
    "",
    "=35",
  ],
  [
    6227,
    "Kornet Unggas Sterilisasi (08030236)",
    "Kadar Protein (%)",
    "",
    "=12",
  ],
  [
    6228,
    "Kornet Unggas Sterilisasi (08030236)",
    "Kadar Lemak (%)",
    "=12",
  ],
  [
    6229,
    "Kornet Unggas Sterilisasi (08030236)",
    "Arsen (mg/kg)",
    "=0.25",
  ],
  [
    6230,
    "Kornet Unggas Sterilisasi (08030236)",
    "Kadmium (mg/kg)",
    "=0.05",
  ],
  [
    6231,
    "Kornet Unggas Sterilisasi (08030236)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    6232,
    "Kornet Unggas Sterilisasi (08030236)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6233,
    "Kornet Unggas Sterilisasi (08030236)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6234,
    "Kornet Unggas Sterilisasi (08030236)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [6235, "Krekers (07010201)", "Kadar air (%)", "=5"],
  [6236, "Krekers (07010201)", "Arsen (As) (mg/kg)", "=0.5"],
  [6237, "Krekers (07010201)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6238, "Krekers (07010201)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6239, "Krekers (07010201)", "Timah (Sn) (mg/kg)", "=40"],
  [6240, "Krekers (07010201)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6241, "Krekers Beras (Senbei) (150103)", "Kadar air (%)", "=3"],
  [
    6242,
    "Krekers Beras (Senbei) (150103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6243,
    "Krekers Beras (Senbei) (150103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6244,
    "Krekers Beras (Senbei) (150103)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6245,
    "Krekers Beras (Senbei) (150103)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6246,
    "Krekers Beras (Senbei) (150103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6247,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    6248,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    6249,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6250,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6251,
    "Krekers Gurih (Savoury Cracker), Snack Cracker (07010207)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [6252, "Krekers Krim (07010202)", "Arsen (As) (mg/kg)", "=0.5"],
  [6253, "Krekers Krim (07010202)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6254, "Krekers Krim (07010202)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6255, "Krekers Krim (07010202)", "Timah (Sn) (mg/kg)", "=40"],
  [6256, "Krekers Krim (07010202)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6257, "Krekers Krim (07010202)", "Kadar air (%)", "=5"],
  [6258, "Krekers Rasa (150135)", "Kadar Air (%)", "=5"],
  [6259, "Krekers Rasa (150135)", "Arsen (As) (mg/kg)", "=0.25"],
  [6260, "Krekers Rasa (150135)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [6261, "Krekers Rasa (150135)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    6262,
    "Krekers Rasa (150135)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6263,
    "Krekers Rasa (150135)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6264, "Krekers Rasa (150135)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    6265,
    "Krekers Sandwich (07010203)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    6266,
    "Krekers Sandwich (07010203)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    6267,
    "Krekers Sandwich (07010203)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6268,
    "Krekers Sandwich (07010203)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6269,
    "Krekers Sandwich (07010203)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    6270,
    "Krekers Sandwich (150136)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    6271,
    "Krekers Sandwich (150136)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6272,
    "Krekers Sandwich (150136)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6273,
    "Krekers Sandwich (150136)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6274,
    "Krekers Sandwich (150136)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6275,
    "Krekers Sandwich (150136)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6276,
    "Krekers Sandwich (150136)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [6277, "Krekers Soda (07010206)", "Arsen (As) (mg/kg)", "=0.5"],
  [6278, "Krekers Soda (07010206)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6279, "Krekers Soda (07010206)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6280, "Krekers Soda (07010206)", "Timah (Sn) (mg/kg)", "=40"],
  [6281, "Krekers Soda (07010206)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6282, "Krekers Soda (07010206)", "Kadar Air (%)", "=5"],
  [6283, "Krim (0104AA)", "Kadar lemak susu (%)", "", "=35"],
  [6284, "Krim (0104AA)", "Arsen (As) (mg/kg) ", "=0.1"],
  [6285, "Krim (0104AA)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [6286, "Krim (0104AA)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    6287,
    "Krim (0104AA)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6288,
    "Krim (0104AA)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [6289, "Krim (0104AA)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [6290, "Krim Asam (01040301)", "kadar lemak susu (%)", "", "=10"],
  [6291, "Krim Asam (01040301)", "Arsen (As) (mg/kg) ", "=0.1"],
  [6292, "Krim Asam (01040301)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [6293, "Krim Asam (01040301)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    6294,
    "Krim Asam (01040301)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6295,
    "Krim Asam (01040301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [6296, "Krim Asam (01040301)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [6297, "Krim Asam (01040301)", "Aflatoksin M1 (mcg/kg)", "=0.5"],
  [6298, "Krim Bubuk (01050105)", "Kadar lemak susu (%)", "", "=42"],
  [6299, "Krim Bubuk (01050105)", "Kadar air (%)", "=5"],
  [
    6300,
    "Krim Bubuk (01050105)",
    "Kadar protein dari padatan susu bukan lemak minimal 32 (%)",
  ],
  [
    6301,
    "Krim Bubuk (01050105)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    6302,
    "Krim Bubuk (01050105)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    6303,
    "Krim Bubuk (01050105)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    6304,
    "Krim Bubuk (01050105)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    6305,
    "Krim Bubuk (01050105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    6306,
    "Krim Bubuk (01050105)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [6307, "Krim Bubuk (01050105)", "Aflatoksin M1 (mcg/kg)", "=5"],
  [
    6308,
    "Krim Kelapa (0401020809)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6309,
    "Krim Kelapa (0401020809)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6310,
    "Krim Kelapa (0401020809)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6311,
    "Krim Kelapa (0401020809)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    6312,
    "Krim Kelapa (0401020809)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    6313,
    "Krim Kelapa (0401020809)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    6314,
    "Krim Kental Manis (01030108)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    6315,
    "Krim Kental Manis (01030108)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6316,
    "Krim Kental Manis (01030108)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    6317,
    "Krim Kental Manis (01030108)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6318,
    "Krim Kental Manis (01030108)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    6319,
    "Krim Kental Manis (01030108)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    6320,
    "Krim Kental Manis (01030108)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    6321,
    "Krim Kental Manis (01030108)",
    "Kadar lemak susu (%)",
    "",
    "=45",
  ],
  [
    6322,
    "Krim Kental Manis (01030108)",
    "Total padatan (%)",
    "",
    "=65",
  ],
  [6323, "Krim Nabati (01040401)", "Kadar lemak (%) ", "", "=10"],
  [6324, "Krim Nabati (01040401)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    6325,
    "Krim Nabati (01040401)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    6326,
    "Krim Nabati (01040401)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    6327,
    "Krim Nabati (01040401)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6328,
    "Krim Nabati (01040401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [6329, "Krim Nabati (01040401)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [
    6330,
    "Krim Nabati (01040401)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    6331,
    "Krim Nabati Bubuk (01040402)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6332,
    "Krim Nabati Bubuk (01040402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6333,
    "Krim Nabati Bubuk (01040402)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6334,
    "Krim Nabati Bubuk (01040402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6335,
    "Krim Nabati Bubuk (01040402)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6336,
    "Krim Nabati Bubuk (01040402)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    6337,
    "Krim Nabati Bubuk (01040402)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    6338,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    6339,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6340,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    6341,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6342,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    6343,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    6344,
    "Krim Pasteurisasi (Plain) (01040101)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    6345,
    "Krim Rendah Lemak (01040202)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6346,
    "Krim Rendah Lemak (01040202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    6347,
    "Krim Rendah Lemak (01040202)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    6348,
    "Krim Rendah Lemak (01040202)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6349,
    "Krim Rendah Lemak (01040202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6350,
    "Krim Rendah Lemak (01040202)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    6351,
    "Krim Rendah Lemak (01040202)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    6352,
    "Krim Sterilisasi (01040204)",
    "Kadar lemak susu (%)",
    "",
    "=10",
  ],
  [
    6353,
    "Krim Sterilisasi (01040204)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6354,
    "Krim Sterilisasi (01040204)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    6355,
    "Krim Sterilisasi (01040204)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    6356,
    "Krim Sterilisasi (01040204)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6357,
    "Krim Sterilisasi (01040204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6358,
    "Krim Sterilisasi (01040204)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    6359,
    "Krim Sterilisasi (01040204)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [6360, "Krim UHT (0104AA01)", "Kadar lemak susu (%)", "", "=35"],
  [6361, "Krim UHT (0104AA01)", "Arsen (As) (mg/kg) ", "=0.1"],
  [6362, "Krim UHT (0104AA01)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [6363, "Krim UHT (0104AA01)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    6364,
    "Krim UHT (0104AA01)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6365,
    "Krim UHT (0104AA01)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [6366, "Krim UHT (0104AA01)", "Timbal (Pb) (mg/kg) ", "=0.02"],
  [6367, "Krim UHT (0104AA01)", "Aflatoksin M1 (mcg/kg)", "=0.5"],
  [6368, "Krim UHT (0104AA01)", "Rhdamin"],
  [
    6369,
    "Krim yang Diasamkan (01040302)",
    "kadar lemak susu (%)",
    "",
    "=18",
  ],
  [
    6370,
    "Krim yang Diasamkan (01040302)",
    "total asam (%)",
    "",
    "=0.5",
  ],
  [
    6371,
    "Krim yang Diasamkan (01040302)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6372,
    "Krim yang Diasamkan (01040302)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    6373,
    "Krim yang Diasamkan (01040302)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    6374,
    "Krim yang Diasamkan (01040302)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6375,
    "Krim yang Diasamkan (01040302)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    6376,
    "Krim yang Diasamkan (01040302)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    6377,
    "Krim yang Diasamkan (01040302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6378,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6379,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6380,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6381,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6382,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    6383,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    6384,
    "Krim yang Digumpalkan dengan Enzim (01040303)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    6385,
    "Krimer Kental Manis (01030109)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    6386,
    "Krimer Kental Manis (01030109)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6387,
    "Krimer Kental Manis (01030109)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    6388,
    "Krimer Kental Manis (01030109)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6389,
    "Krimer Kental Manis (01030109)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    6390,
    "Krimer Kental Manis (01030109)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    6391,
    "Krimer Kental Manis (01030109)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    6392,
    "Krimer Kental Manis (01030204)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6393,
    "Krimer Kental Manis (01030204)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    6394,
    "Krimer Kental Manis (01030204)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6395,
    "Krimer Kental Manis (01030204)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6396,
    "Krimer Kental Manis (01030204)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    6397,
    "Krimer Kental Manis (01030204)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    6398,
    "Krimer Kental Manis (01030204)",
    "Kadar Lemak Total (%)",
    "",
    "=8",
  ],
  [
    6399,
    "Krimer Kental Manis (01030204)",
    "Kadar Protein Total (%)",
    "",
    "=1",
  ],
  [
    6400,
    "Krimer Kental Manis (01030204)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    6401,
    "Krimer Minuman (01030201)",
    "Produk cair: mengandung lemak (%)",
    "",
    "=3.25",
  ],
  [
    6402,
    "Krimer Minuman (01030201)",
    "Produk cair: Total Padatan (%)",
    "=8.25",
  ],
  [
    6403,
    "Krimer Minuman (01030201)",
    "Produk bubuk : mengandung lemak (%)",
    "",
    "=26",
  ],
  [
    6404,
    "Krimer Minuman (01030201)",
    "Produk bubuk : Kadar Air (%)",
    "=5",
  ],
  [
    6405,
    "Krimer Minuman (01030201)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    6406,
    "Krimer Minuman (01030201)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6407,
    "Krimer Minuman (01030201)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    6408,
    "Krimer Minuman (01030201)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    6409,
    "Krimer Minuman (01030201)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    6410,
    "Krimer Minuman (01030201)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    6411,
    "Krimer Minuman (01030201)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [6412, "Krokant/Brittles (05020212)", "Arsen (As) (mg/kg)", "=1"],
  [
    6413,
    "Krokant/Brittles (05020212)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    6414,
    "Krokant/Brittles (05020212)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6415,
    "Krokant/Brittles (05020212)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6416,
    "Krokant/Brittles (05020212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6417,
    "Krokant/Brittles (05020212)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    6418,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    6419,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    6420,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6421,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6422,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6423,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    6424,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Aflatoksin B1 (ppb)",
    "=15",
  ],
  [
    6425,
    "Krokant/Nugat (Praline)/Brittles (05020207)",
    "Aflatoksin total (ppb)",
    "=20",
  ],
  [6426, "Kroket Isi (1662)", "Arsen (As) (mg/kg)", "=0.25"],
  [6427, "Kroket Isi (1662)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6428, "Kroket Isi (1662)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    6429,
    "Kroket Isi (1662)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6430,
    "Kroket Isi (1662)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6431, "Kroket Isi (1662)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [6432, "Kuaci (0402020211)", "Arsen (As) (mg/kg)", "=0.15"],
  [6433, "Kuaci (0402020211)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [6434, "Kuaci (0402020211)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    6435,
    "Kuaci (0402020211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6436, "Kuaci (0402020211)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    6437,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6438,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6439,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6440,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6441,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6442,
    "Kue Berbahan Dasar Beras Lainnya (060733)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6443,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    6444,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    6445,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6446,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6447,
    "Kue Berbahan Dasar Terigu (07020129)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    6448,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    6449,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    6450,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    6451,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6452,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    6453,
    "Kue Cumi/Sotong/Udang Kukus (0902040212)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    6454,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    6455,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    6456,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    6457,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6458,
    "Kue Ikan Kukus (Steamed Fish Cake) (0902040110)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    6459,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Kandungan surimi (%) ",
    "",
    "=30",
  ],
  [
    6460,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    6461,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    6462,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    6463,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6464,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    6465,
    "Kue Ikan/Kamaboko/Fish Cake (goreng atau panggang) (0902040311)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    6466,
    "Kue Lapis Beras (060712)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6467,
    "Kue Lapis Beras (060712)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6468,
    "Kue Lapis Beras (060712)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6469,
    "Kue Lapis Beras (060712)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6470,
    "Kue Lapis Beras (060712)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6471,
    "Kue Lapis Beras (060712)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6472,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6473,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6474,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6475,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6476,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6477,
    "Kue Mangkok (dari Tepung Beras) (060709)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6478,
    "Kue Mochi (060703)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6479,
    "Kue Mochi (060703)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6480,
    "Kue Mochi (060703)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6481,
    "Kue Mochi (060703)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6482,
    "Kue Mochi (060703)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [6483, "Kue Tambang (07020208)", "Arsen (As) (mg/kg) ", "=0.5"],
  [6484, "Kue Tambang (07020208)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [6485, "Kue Tambang (07020208)", "Raksa (Hg) (mg/kg) ", "=0.05"],
  [6486, "Kue Tambang (07020208)", "Timah (Sn) (mg/kg) ", "=40"],
  [6487, "Kue Tambang (07020208)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    6488,
    "Kue Teuck/Tteok (060704)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6489,
    "Kue Teuck/Tteok (060704)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6490,
    "Kue Teuck/Tteok (060704)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6491,
    "Kue Teuck/Tteok (060704)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6492,
    "Kue Teuck/Tteok (060704)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6493,
    "Kuetiaw Instan (06040306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6494,
    "Kuetiaw Instan (06040306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6495,
    "Kuetiaw Instan (06040306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6496,
    "Kuetiaw Instan (06040306)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6497,
    "Kuetiaw Instan (06040306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [6498, "Kuetiaw Kering (06040201)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    6499,
    "Kuetiaw Kering (06040201)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6500,
    "Kuetiaw Kering (06040201)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6501,
    "Kuetiaw Kering (06040201)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6502,
    "Kuetiaw Kering (06040201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6503,
    "Kuetiaw Lainnya (06040220)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6504,
    "Kuetiaw Lainnya (06040220)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6505,
    "Kuetiaw Lainnya (06040220)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6506,
    "Kuetiaw Lainnya (06040220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    6507,
    "Kuetiaw Lainnya (06040220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    6508,
    "Kuetiaw Lainnya (06040220)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [6509, "Kukis (07020115)", "Arsen (As) (mg/kg)", "=0.5"],
  [6510, "Kukis (07020115)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6511, "Kukis (07020115)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6512, "Kukis (07020115)", "Timah (Sn) (mg/kg)", "=40"],
  [6513, "Kukis (07020115)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6514, "Kukis (07020115)", "Kadar Air (%)", "=5"],
  [6515, "Kukis Gula (07020116)", "Arsen (As) (mg/kg)", "=0.5"],
  [6516, "Kukis Gula (07020116)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6517, "Kukis Gula (07020116)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6518, "Kukis Gula (07020116)", "Timah (Sn) (mg/kg)", "=40"],
  [6519, "Kukis Gula (07020116)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6520, "Kukis Gula (07020116)", "Kadar air (%)", "=5"],
  [
    6521,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Kadar air (%)",
    "=14.5",
    "=5",
  ],
  [
    6522,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    6523,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    6524,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6525,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6526,
    "Kukis Lunak (Soft Cookies) (07020133)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [6527, "Kukis Oatmeal (07020117)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    6528,
    "Kukis Oatmeal (07020117)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [6529, "Kukis Oatmeal (07020117)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [6530, "Kukis Oatmeal (07020117)", "Timah (Sn) (mg/kg)", "=40"],
  [6531, "Kukis Oatmeal (07020117)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [6532, "Kukis Oatmeal (07020117)", "Kadar air (%)", "=5"],
  [6533, "Kulit Ayam Goreng (08020311)", "As (mg/kg)", "=0.25"],
  [6534, "Kulit Ayam Goreng (08020311)", "Cd (mg/kg)", "=0.05"],
  [6535, "Kulit Ayam Goreng (08020311)", "Hg (mg/kg)", "=0.03"],
  [
    6536,
    "Kulit Ayam Goreng (08020311)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6537,
    "Kulit Ayam Goreng (08020311)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6538, "Kulit Ayam Goreng (08020311)", "Pb (mg/kg)", "=0.5"],
  [
    6539,
    "Kulit Buah Bergula (0401020703)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6540,
    "Kulit Buah Bergula (0401020703)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6541,
    "Kulit Buah Bergula (0401020703)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6542,
    "Kulit Buah Bergula (0401020703)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    6543,
    "Kulit Buah Bergula (0401020703)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    6544,
    "Kulit Keju Peram (01060202)",
    "Kadar air berdasarkan padatan tanpa lemak (PTL) (%)",
  ],
  [
    6545,
    "Kulit Keju Peram (01060202)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6546,
    "Kulit Keju Peram (01060202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    6547,
    "Kulit Keju Peram (01060202)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    6548,
    "Kulit Keju Peram (01060202)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6549,
    "Kulit Keju Peram (01060202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6550,
    "Kulit Keju Peram (01060202)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    6551,
    "Kulit Keju Peram (01060202)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    6552,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6553,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6554,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6555,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6556,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Timah (Sn) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6557,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6558,
    "Kulit Pangsit/Risol/Lumpia (06040102)",
    "Kadar air (%)",
    "=35",
    "=20",
  ],
  [
    6559,
    "Kumys (010201B0)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [6560, "Kumys (010201B0)", "Kadar asam laktat (%) ", "", "=0.7"],
  [6561, "Kumys (010201B0)", "Kadar etanol (%) ", "", "=0.5"],
  [6562, "Kumys (010201B0)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    6563,
    "Kumys (010201B0)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    6564,
    "Kumys (010201B0)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6565,
    "Kumys (010201B0)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    6566,
    "Kumys (010201B0)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    6567,
    "Kumys (010201B0)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [6568, "Kumys (010201B0)", "Aflatoksin M1 (mcg/kg) ", "=0.5"],
  [
    6569,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6570,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    6571,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6572,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6573,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    6574,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    6575,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    6576,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    6577,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Kadar asam laktat (%)",
    "",
    "=0.7",
  ],
  [
    6578,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Kadar etanol (%)",
    "",
    "=0.5",
  ],
  [
    6579,
    "Kumys (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010208)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    6580,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6581,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6582,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6583,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    6584,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    6585,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    6586,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    6587,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Kadar asam laktat (%)",
    "",
    "=0.7",
  ],
  [
    6588,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Kadar etanol (%)",
    "",
    "=0.5",
  ],
  [
    6589,
    "Kumys (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010108)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    6590,
    "Kuning Telur Beku (10020203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6591,
    "Kuning Telur Beku (10020203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6592,
    "Kuning Telur Beku (10020203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6593,
    "Kuning Telur Beku (10020203)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6594,
    "Kuning Telur Beku (10020203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6595,
    "Kunyit (12020166)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=4",
  ],
  [
    6596,
    "Kunyit (12020166)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6597,
    "Kunyit (12020166)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6598,
    "Kunyit (12020166)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [6599, "Kunyit (12020166)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [6600, "Kunyit (12020166)", "Timbal (Pb) (ppm atau mg/kg)", "=1"],
  [
    6601,
    "Kunyit (12020166)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6602,
    "Kunyit (12020166)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6603, "Kunyit Bubuk (12020167)", "Kadar air (%)", "=13"],
  [
    6604,
    "Kunyit Bubuk (12020167)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=4",
  ],
  [
    6605,
    "Kunyit Bubuk (12020167)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6606,
    "Kunyit Bubuk (12020167)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6607,
    "Kunyit Bubuk (12020167)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6608,
    "Kunyit Bubuk (12020167)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6609,
    "Kunyit Bubuk (12020167)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6610,
    "Kunyit Bubuk (12020167)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6611,
    "Kunyit Bubuk (12020167)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6612, "Lada Bubuk Campuran (12020172)", "Kadar air (%)", "=14"],
  [
    6613,
    "Lada Bubuk Campuran (12020172)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=0.7",
  ],
  [
    6614,
    "Lada Bubuk Campuran (12020172)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6615,
    "Lada Bubuk Campuran (12020172)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6616,
    "Lada Bubuk Campuran (12020172)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6617,
    "Lada Bubuk Campuran (12020172)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6618,
    "Lada Bubuk Campuran (12020172)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6619,
    "Lada Bubuk Campuran (12020172)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6620,
    "Lada Bubuk Campuran (12020172)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6621, "Lada Hitam (12020168)", "Kadar air (%)", "=13.5"],
  [
    6622,
    "Lada Hitam (12020168)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    6623,
    "Lada Hitam (12020168)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6624,
    "Lada Hitam (12020168)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6625,
    "Lada Hitam (12020168)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6626,
    "Lada Hitam (12020168)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6627,
    "Lada Hitam (12020168)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6628,
    "Lada Hitam (12020168)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6629,
    "Lada Hitam (12020168)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6630, "Lada Hitam Bubuk (12020169)", "Kadar air (%)", "=14"],
  [
    6631,
    "Lada Hitam Bubuk (12020169)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1",
  ],
  [
    6632,
    "Lada Hitam Bubuk (12020169)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6633,
    "Lada Hitam Bubuk (12020169)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6634,
    "Lada Hitam Bubuk (12020169)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6635,
    "Lada Hitam Bubuk (12020169)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6636,
    "Lada Hitam Bubuk (12020169)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6637,
    "Lada Hitam Bubuk (12020169)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6638,
    "Lada Hitam Bubuk (12020169)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6639, "Lada Putih (12020170)", "Kadar air (%)", "=14"],
  [
    6640,
    "Lada Putih (12020170)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6641,
    "Lada Putih (12020170)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6642,
    "Lada Putih (12020170)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6643,
    "Lada Putih (12020170)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6644,
    "Lada Putih (12020170)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6645,
    "Lada Putih (12020170)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6646,
    "Lada Putih (12020170)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    6647,
    "Lada Putih Bubuk (12020171)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6648,
    "Lada Putih Bubuk (12020171)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6649,
    "Lada Putih Bubuk (12020171)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6650,
    "Lada Putih Bubuk (12020171)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6651,
    "Lada Putih Bubuk (12020171)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6652,
    "Lada Putih Bubuk (12020171)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6653,
    "Lada Putih Bubuk (12020171)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6654, "Laktosa (11010401)", "Laktosa (%)", "", "=99"],
  [6655, "Laktosa (11010401)", "Arsen (As) (ppm atau mg/kg)", "=1"],
  [
    6656,
    "Laktosa (11010401)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    6657,
    "Laktosa (11010401)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6658,
    "Laktosa (11010401)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6659,
    "Laktosa (11010401)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6660,
    "Lalampa (060728)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [6661, "Lalampa (060728)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    6662,
    "Lalampa (060728)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6663,
    "Lalampa (060728)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6664,
    "Lalampa (060728)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6665,
    "Lalampa (060728)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6666,
    "Lalampa (060728)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [6667, "Lamang (060732)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    6668,
    "Lamang (060732)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6669,
    "Lamang (060732)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6670,
    "Lamang (060732)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6671,
    "Lamang (060732)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6672,
    "Lamang (060732)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6673,
    "Lapek Bugis (060731)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6674,
    "Lapek Bugis (060731)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6675,
    "Lapek Bugis (060731)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    6676,
    "Lapek Bugis (060731)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6677,
    "Lapek Bugis (060731)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6678,
    "Lassi (Plain) (01010205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6679,
    "Lassi (Plain) (01010205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    6680,
    "Lassi (Plain) (01010205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6681,
    "Lassi (Plain) (01010205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    6682,
    "Lassi (Plain) (01010205)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    6683,
    "Lassi (Plain) (01010205)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [6684, "Lassi (Plain) (01010205)", "Aflatoksin M1 (ppb)", "=0.5"],
  [
    6685,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    6686,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    6687,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    6688,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    6689,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    6690,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    6691,
    "Lassi (Rasa/Berperisa) (01010406)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
  ],
  [6692, "", "=0.5"],
  [6693, "Legomoro (060735)", "Arsen (As) (mg/kg)", "=0.1"],
  [6694, "Legomoro (060735)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [6695, "Legomoro (060735)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    6696,
    "Legomoro (060735)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    6697,
    "Legomoro (060735)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [6698, "Legomoro (060735)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    6699,
    "Lemak Babi atau Lard (02010302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6700,
    "Lemak Babi atau Lard (02010302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6701,
    "Lemak Babi atau Lard (02010302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6702,
    "Lemak Babi atau Lard (02010302)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6703,
    "Lemak Babi atau Lard (02010302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6704,
    "Lemak Babi atau Lard (02010302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6705,
    "Lemak Babi atau Lard (02010302)",
    "Bilangan penyabunan mg KOH/g",
    "=203",
    "=192",
  ],
  [
    6706,
    "Lemak Babi atau Lard (02010302)",
    "Bilangan iod Wijs",
    "=65",
    "=55",
  ],
  [
    6707,
    "Lemak Babi atau Lard (02010302)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [
    6708,
    "Lemak dan Minyak Nabati (02010201)",
    "Kadar air (%) untuk minyak yang telah dimurnikan/rafinasi",
    "=0.15",
  ],
  [
    6709,
    "Lemak dan Minyak Nabati (02010201)",
    "Kadar asam lemak bebas (%) untuk minyak yang telah dimurnikan/rafinasi",
    "=0.3",
  ],
  [
    6710,
    "Lemak dan Minyak Nabati (02010201)",
    "Kadar air (%) untuk minyak mentah",
    "=0.5",
  ],
  [
    6711,
    "Lemak dan Minyak Nabati (02010201)",
    "Kadar asam lemak bebas (%) untuk minyak mentah",
    "=5",
  ],
  [
    6712,
    "Lemak dan Minyak Nabati (02010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6713,
    "Lemak dan Minyak Nabati (02010201)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6714,
    "Lemak dan Minyak Nabati (02010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6715,
    "Lemak dan Minyak Nabati (02010201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6716,
    "Lemak dan Minyak Nabati (02010201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6717,
    "Lemak dan Minyak Nabati (02010201)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    6718,
    "Lemak Hewani (02010301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6719,
    "Lemak Hewani (02010301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6720,
    "Lemak Hewani (02010301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6721,
    "Lemak Hewani (02010301)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6722,
    "Lemak Hewani (02010301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6723,
    "Lemak Hewani (02010301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6724,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    6725,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    6726,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6727,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    6728,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6729,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    6730,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Asam lemak bebas (%)",
    "=1.75",
  ],
  [
    6731,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Bahan yang tidak tersaponifikasi - non press (%)",
    "=0.7",
  ],
  [
    6732,
    "Lemak Kakao (Cocoa Butter) (05010116)",
    "Bahan yang tidak tersaponifikasi - pressed (%)",
    "=0.35",
  ],
  [
    6733,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Kadar asam lemak bebas (sebagai asam oleat) (%)",
    "=1.75",
  ],
  [
    6734,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Bahan yang tidak tersaponifikasi (%)",
    "=0.7",
  ],
  [
    6735,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Bahan yang tidak tersaponifikasi untuk lemak kakao dari pengepresan (%)",
    "=0.35",
  ],
  [
    6736,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    6737,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    6738,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6739,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    6740,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6741,
    "Lemak Kakao (Cocoa Butter) (05010402)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    6742,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6743,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6744,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6745,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6746,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6747,
    "Lemak Oles Loyang (Pan Release) (02020202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6748,
    "Lemak Reroti (Shortening) (02010209)",
    "As (mg/kg)",
    "=0.1",
  ],
  [
    6749,
    "Lemak Reroti (Shortening) (02010209)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6750,
    "Lemak Reroti (Shortening) (02010209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6751,
    "Lemak Reroti (Shortening) (02010209)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6752,
    "Lemak Reroti (Shortening) (02010209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6753,
    "Lemak Reroti (Shortening) (02010209)",
    "Pb(mg/kg)",
    "=0.1",
  ],
  [
    6754,
    "Lemak Reroti (Shortening) (02010209)",
    "Kadar asam lemak bebas berasal dari minyak sawit dihitung sebagai asam palmitat, berasal dari minyak kelapa atau minyak inti sawit dihitung sebagai asam laurat, berasal dari minyak nabati lainnya dihitung sebagai asam oleat. (%)",
    "=0.3",
  ],
  [
    6755,
    "Lemak Reroti (Shortening) (02010209)",
    "Kadar air (%) ",
    "=0.15",
  ],
  [
    6756,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Bilangan penyabunan mg KOH/g",
    "=202",
    "=190",
  ],
  [
    6757,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Bilangan iod Wijs",
    "=50",
    "=32",
  ],
  [
    6758,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Bilangan asam mg KOH/g",
    "=2.5",
  ],
  [
    6759,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Bilangan peroksida mek O2/kg",
    "=10",
  ],
  [
    6760,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Kadar bahan tak tersabunkan g/kg",
    "=12",
  ],
  [
    6761,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Berat jenis 40\xB0C/air pada 20\xB0C",
    "=0.904",
    "=0.893",
  ],
  [
    6762,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Indeks bias pada suhu 40\xB0C",
    "=1.46",
    "=1.448",
  ],
  [
    6763,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6764,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6765,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6766,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6767,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6768,
    "Lemak Sapi (Edible Beef Fat) (02010305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6769,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Bilangan penyabunan mg KOH/g",
    "=200",
    "=190",
  ],
  [
    6770,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Bilangan iod Wijs",
    "=47",
    "=36",
  ],
  [
    6771,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Bilangan peroksida mek O2/kg",
    "=10",
  ],
  [
    6772,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Kadar bahan tak tersabunkan g/kg",
    "=10",
  ],
  [
    6773,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6774,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6775,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6776,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6777,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6778,
    "Lemak Sapi Utama (Prime Beef Fat (Premier Jus atau Oleo Stock)) (02010304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    6779,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "As (mg/kg)",
    "=0.1",
  ],
  [
    6780,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Cd(mg/kg)",
    "=0.1",
  ],
  [
    6781,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Hg(mg/kg)",
    "=0.05",
  ],
  [
    6782,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6783,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6784,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Pb(mg/kg)",
    "=0.1",
  ],
  [
    6785,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Lemak Susu Anhidrat : Kadar Lemak Susu (%)",
    "",
    "=99.8",
  ],
  [
    6786,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Minyak Mentega Anhidrat : Kadar Lemak Susu (%)",
    "",
    "=99.8",
  ],
  [
    6787,
    "Lemak Susu Anhidrat (AMF), Minyak Mentega (butter oil) (02010101)",
    "Minyak Mentega : Kadar Lemak Susu (%)",
    "",
    "=99.3",
  ],
  [
    6788,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6789,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    6790,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    6791,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    6792,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6793,
    "Lemonade dan \x91Fruit-Ades\x92 Lainnya (1401040212)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6794,
    "Lempuyang (120201A5)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6795,
    "Lempuyang (120201A5)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6796,
    "Lempuyang (120201A5)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6797,
    "Lempuyang (120201A5)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6798,
    "Lempuyang (120201A5)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6799,
    "Lempuyang (120201A5)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6800,
    "Lempuyang (120201A5)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    6801,
    "Lengkuas/Laos (12020174)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6802,
    "Lengkuas/Laos (12020174)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6803,
    "Lengkuas/Laos (12020174)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6804,
    "Lengkuas/Laos (12020174)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    6805,
    "Lengkuas/Laos (12020174)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6806,
    "Lengkuas/Laos (12020174)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6807,
    "Lengkuas/Laos (12020174)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    6808,
    "Lengkuas/Laos Bubuk (12020175)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    6809,
    "Lengkuas/Laos Bubuk (12020175)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    6810,
    "Lengkuas/Laos Bubuk (12020175)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    6811,
    "Lengkuas/Laos Bubuk (12020175)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    6812,
    "Lengkuas/Laos Bubuk (12020175)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    6813,
    "Lengkuas/Laos Bubuk (12020175)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    6814,
    "Lengkuas/Laos Bubuk (12020175)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [6815, "Licorice (05020205)", "Arsen (As) (mg/kg)", "=1"],
  [6816, "Licorice (05020205)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [6817, "Licorice (05020205)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    6818,
    "Licorice (05020205)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6819,
    "Licorice (05020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6820, "Licorice (05020205)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    6821,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    6822,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6823,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6824,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Timah (Sn), pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6825,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Timah (Sn), minuman dalam kemasan kaleng (mg/kg)",
    "=250",
  ],
  [
    6826,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    6827,
    "Lidah Buaya Dalam Kemasan (0402020411)",
    "Bobot Tuntas (%)",
  ],
  [
    6828,
    "Limun (1401040116)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6829,
    "Limun (1401040116)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    6830,
    "Limun (1401040116)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    6831,
    "Limun (1401040116)",
    "Timah (Sn) Minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    6832,
    "Limun (1401040116)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6833,
    "Limun (1401040116)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [6834, "Liqueur (14020612)", "Kadar etanol (%)", "", "=15"],
  [
    6835,
    "Liqueur (14020612)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [6836, "Liqueur (14020612)", "Arsen (mg/kg)", "=0.1"],
  [6837, "Liqueur (14020612)", "Kadmium (mg/kg)", "=0.2"],
  [6838, "Liqueur (14020612)", "Merkuri (mg/kg)", "=0.03"],
  [
    6839,
    "Liqueur (14020612)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    6840,
    "Liqueur (14020612)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6841, "Liqueur (14020612)", "Timbal (mg/kg)", "=0.2"],
  [
    6842,
    "Liqueur (14020612)",
    "Kadar gula dihitung terhadap berat produk akhir (% b/b)",
    "",
    "=2.5",
  ],
  [
    6843,
    "Lobster Rebus Beku (0902040203)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6844,
    "Lobster Rebus Beku (0902040203)",
    "Cd (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    6845,
    "Lobster Rebus Beku (0902040203)",
    "Hg (ppm atau mg/kg ",
    "=0.5",
  ],
  [
    6846,
    "Lobster Rebus Beku (0902040203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6847,
    "Lobster Rebus Beku (0902040203)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    6848,
    "Lumpia Daging (08030314)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6849,
    "Lumpia Daging (08030314)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6850,
    "Lumpia Daging (08030314)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6851,
    "Lumpia Daging (08030314)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6852,
    "Lumpia Daging (08030314)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6853,
    "Lumpia Daging (08030314)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    6854,
    "Lumpia Daging (08030314)",
    "Total Meat Content (%)",
    "",
    "=30",
  ],
  [6855, "Lumpia Daging (08030314)", "Kadar Daging (%)", "", ">15"],
  [6856, "Lumpia Daging (08030314)", "Kadar Ikan (%)", "<15"],
  [6857, "Lumpia Isi (1661)", "Arsen (As) (mg/kg)", "=0.25"],
  [6858, "Lumpia Isi (1661)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [6859, "Lumpia Isi (1661)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    6860,
    "Lumpia Isi (1661)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6861,
    "Lumpia Isi (1661)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [6862, "Lumpia Isi (1661)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    6863,
    "Madu (110501)",
    "Kadar hidroksimetil furfural (mg/kg)",
    "=50",
  ],
  [
    6864,
    "Madu (110501)",
    "Aktivitas enzim diastase (DN) untuk madu budidaya",
    "",
    "=3",
  ],
  [6865, "Madu (110501)", "Arsen (As) (ppm atau mg/kg)", "=1"],
  [6866, "Madu (110501)", "Kadmium (Cd) (ppm atau mg/kg)", "=0.2"],
  [6867, "Madu (110501)", "Merkuri (Hg) (ppm atau mg/kg)", "=0.03"],
  [
    6868,
    "Madu (110501)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [6869, "Madu (110501)", "Timbal (Pb) (ppm atau mg/kg)", "=1"],
  [
    6870,
    "Madu (110501)",
    "Aktivitas enzim diastase (DN) untuk madu hutan dan madu lebah tanpa sengat",
    "",
    "=1",
  ],
  [
    6871,
    "Madu Sarang (Comb Honey) (110503)",
    "Kadar hidroksimetil fulfural (HMF) (mg/kg)",
    "=50",
  ],
  [
    6872,
    "Madu Sarang (Comb Honey) (110503)",
    "Aktivitas enzim diastase (DN) untuk madu hutan dan madu lebah tanpa sengat",
    "",
    "=1",
  ],
  [
    6873,
    "Madu Sarang (Comb Honey) (110503)",
    "Aktivitas enzim diastase (DN) untuk madu budidaya",
    "",
    "=3",
  ],
  [
    6874,
    "Madu Sarang (Comb Honey) (110503)",
    "Kandungan Bakteri Asam Laktat (%)",
    "",
    "> 10",
  ],
  [
    6875,
    "Madu Sarang (Comb Honey) (110503)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6876,
    "Madu Sarang (Comb Honey) (110503)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    6877,
    "Madu Sarang (Comb Honey) (110503)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6878,
    "Madu Sarang (Comb Honey) (110503)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    6879,
    "Madu Sarang (Comb Honey) (110503)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6880,
    "Madu Sarang (Comb Honey) (110503)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    6881,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6882,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6883,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6884,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Timah yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6885,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Timah yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6886,
    "Makanan Diet Diabetes Berbasis Susu (Cair) (130319)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6887,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6888,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6889,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6890,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Timah yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6891,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Timah yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6892,
    "Makanan Diet Diabetes Berbasis Susu (Padat) (130318)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6893,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    6894,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    6895,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    6896,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=100",
  ],
  [
    6897,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Timah (Sn) (mg/l) yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6898,
    "Makanan Diet Diabetes Bubuk Instan (130324)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.25",
  ],
  [
    6899,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6900,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6901,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6902,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Timah yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6903,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Timah yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6904,
    "Makanan Diet Diabetes Siap Masak (Cair) (130321)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6905,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6906,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6907,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6908,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Timah yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6909,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Timah yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6910,
    "Makanan Diet Diabetes Siap Masak (Padat) (130320)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6911,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.02",
  ],
  [
    6912,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    6913,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.01",
  ],
  [
    6914,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=250",
  ],
  [
    6915,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Timah (Sn) (mg/l) yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6916,
    "Makanan Diet Diabetes Siap Santap (Cair) (130323)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi ",
    "=0.25",
  ],
  [
    6917,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Arsen (As) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6918,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Kadmium (Cd) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6919,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Merkuri (Hg) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.01",
  ],
  [
    6920,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Timah yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    6921,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Timah yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    6922,
    "Makanan Diet Diabetes Siap Santap (Padat) (130322)",
    "Timbal (Pb) (mg/kg) (dihitung terhadap produk siap komsumsi)",
    "=0.02",
  ],
  [
    6923,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6924,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    6925,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    6926,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    6927,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    6928,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6929,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Cair (Steril) (1304010102)",
    "Aflatoksin M1 (mcg/kg) - Berbasis Susu",
    "=0.5",
  ],
  [
    6930,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6931,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    6932,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    6933,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    6934,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    6935,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6936,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Sebagian Makan Padat (1304010101)",
    "Aflatoksin M1 (mcg/kg) - Berbasis Susu ",
    "=0.5",
  ],
  [
    6937,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6938,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    6939,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    6940,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    6941,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    6942,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6943,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Cair (Steril) (1304010202)",
    "Aflatoksin M1 (mcg/kg) - Berbasis Susu",
    "=0.5",
  ],
  [
    6944,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    6945,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    6946,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    6947,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    6948,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    6949,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6950,
    "Makanan Formula Sebagai Makanan Diet Kontrol Berat Badan - Pengganti Seluruh Makan Padat (1304010201)",
    "Aflatoksin M1 (mcg/kg) - Berbasis Susu ",
    "=0.5",
  ],
  [
    6951,
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah (0401020911)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    6952,
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah (0401020911)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6953,
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah (0401020911)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    6954,
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah (0401020911)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6955,
    "Makanan Pencuci Mulut (Dessert) Berbasis Buah Termasuk Makanan Pencuci Mulut Berbasis Air Berflavor Buah (0401020911)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    6956,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Arsen (As) (ppm) - siap konsumsi",
    "=0.1",
  ],
  [
    6957,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Kadmium (Cd) (ppm) - siap konsumsi",
    "=0.05",
  ],
  [
    6958,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Merkuri (Hg) (ppm) - siap konsumsi",
    "=0.02",
  ],
  [
    6959,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=250",
  ],
  [
    6960,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    6961,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    6962,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (010714)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    6963,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Arsen (As) (ppm) - siap konsumsi",
    "=0.1",
  ],
  [
    6964,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Kadmium (Cd) (ppm) - siap konsumsi",
    "=0.05",
  ],
  [
    6965,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Merkuri (Hg) (ppm) - siap konsumsi",
    "=0.02",
  ],
  [
    6966,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=250",
  ],
  [
    6967,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    6968,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    6969,
    "Makanan Pencuci Mulut Berbahan Dasar Susu (Bubuk) (010725)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    6970,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6971,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    6972,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    6973,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    6974,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    6975,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    6976,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Aflatoksin B1(jika bahan baku dari kacang tanah) (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    6977,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/Kg) ",
    "=20",
  ],
  [
    6978,
    "Makanan Ringan Berbahan Dasar Kacang (150215)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    6979,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6980,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6981,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6982,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6983,
    "Makanan Ringan Berbasis Ikan, dll (150308)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6984,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    6985,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    6986,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    6987,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    6988,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    6989,
    "Makanan Ringan Berbentuk Batang/Bar (150140)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    6990,
    "Makanan Ringan Ekstrudat (150129)",
    "Kadar air (%)",
    "=4",
  ],
  [
    6991,
    "Makanan Ringan Ekstrudat (150129)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6992,
    "Makanan Ringan Ekstrudat (150129)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6993,
    "Makanan Ringan Ekstrudat (150129)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6994,
    "Makanan Ringan Ekstrudat (150129)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    6995,
    "Makanan Ringan Ekstrudat (150129)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6996,
    "Makanan Ringan Lain (150133)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    6997,
    "Makanan Ringan Lain (150133)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    6998,
    "Makanan Ringan Lain (150133)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    6999,
    "Makanan Ringan Lain (150133)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7000,
    "Makanan Ringan Lain (150133)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7001,
    "Makanan Ringan Simulasi (150113)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7002,
    "Makanan Ringan Simulasi (150113)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7003,
    "Makanan Ringan Simulasi (150113)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7004,
    "Makanan Ringan Simulasi (150113)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7005,
    "Makanan Ringan Simulasi (150113)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7006,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Kakao (Untuk Bayi Di Atas 9 Bulan) (%)",
    "=1.5",
  ],
  [
    7007,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7008,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    7009,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Raksa (Hg) (mg/kg)",
    "=0.01",
  ],
  [
    7010,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7011,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Timah (Sn) (mg/kg)",
    "=10",
  ],
  [
    7012,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Energi (kkal/100 g)",
    "=100",
  ],
  [
    7013,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Lemak Trans dibandingkan Lemak Total (%) ",
    "=3",
  ],
  [
    7014,
    "Makanan Selingan untuk Anak - Cair (Steril) (1391)",
    "Sukrosa + Fruktosa + Glukosa + Sirup Glukosa + Madu (g/100 kkal)",
    "=5",
  ],
  [
    7015,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Kakao (Untuk Bayi Di Atas 9 Bulan) (%)",
    "=1.5",
  ],
  [
    7016,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7017,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    7018,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Raksa (Hg) (mg/kg)",
    "=0.01",
  ],
  [
    7019,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7020,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Timah (Sn) (mg/kg)",
    "=10",
  ],
  [
    7021,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Energi (kkal/100 g)",
    "=100",
  ],
  [
    7022,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Lemak Trans dibandingkan Lemak Total (%) ",
    "=3",
  ],
  [
    7023,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Sukrosa + Fruktosa + Glukosa + Sirup Glukosa + Madu (g/100 kkal)",
    "=5",
  ],
  [
    7024,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Fruktosa (g/100 kkal)",
    "=2.5",
  ],
  [
    7025,
    "Makanan Selingan untuk Anak (Padat) (1390)",
    "Fruktosa (g/100 kkal)",
    "=2.5",
  ],
  [
    7026,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7027,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7028,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7029,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    7030,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    7031,
    "Makanan Siap Saji Berbasis Kentang (Terkemas) (1678)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    7032,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    7033,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7034,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7035,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    7036,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7037,
    "Makanan Siap Saji Berbasis Kuah (Terkemas) (1682)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7038,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7039,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7040,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7041,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    7042,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7043,
    "Makanan Siap Saji Berbasis Mi/Bihun (Terkemas) (1677)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7044,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    7045,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7046,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7047,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    7048,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    7049,
    "Makanan Siap Saji Berbasis Nasi (Terkemas) (1676)",
    "Timbal (Pb) (mg/kg)",
    "=0.20",
  ],
  [
    7050,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7051,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7052,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7053,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    7054,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    7055,
    "Makanan Siap Saji Berbasis Pasta (Terkemas) (1679)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    7056,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7057,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7058,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7059,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    7060,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    7061,
    "Makanan Siap Saji Berbasis Roti (Terkemas) (1681)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    7062,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7063,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7064,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7065,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    7066,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    7067,
    "Makanan Siap Saji Berbasis Sayuran (Terkemas) (1683)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    7068,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    7069,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7070,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7071,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    7072,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    7073,
    "Makanan Siap Saji Berbasis Umbi (Terkemas) (1680)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [7074, "Makaroni (06040202)", "Kadar air (%)", "=12.5"],
  [
    7075,
    "Makaroni (06040202)",
    "Kadar Protein (%) jika tepung gluten terigu (gom gluten) ditambahkan",
    "=10",
  ],
  [
    7076,
    "Makaroni (06040202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7077,
    "Makaroni (06040202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7078,
    "Makaroni (06040202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7079,
    "Makaroni (06040202)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7080,
    "Makaroni (06040202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [7081, "Makaroni (06040302)", "Kadar air (%)", "=12.5"],
  [
    7082,
    "Makaroni (06040302)",
    "Kadar Protein (%) jika tepung gluten terigu (gom gluten) ditambahkan",
    "=13",
  ],
  [
    7083,
    "Makaroni (06040302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7084,
    "Makaroni (06040302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7085,
    "Makaroni (06040302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7086,
    "Makaroni (06040302)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7087,
    "Makaroni (06040302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7088,
    "Makaroni Instan (06040307)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7089,
    "Makaroni Instan (06040307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7090,
    "Makaroni Instan (06040307)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7091,
    "Makaroni Instan (06040307)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7092,
    "Makaroni Instan (06040307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [7093, "Malkist (07010204)", "Arsen (As) (mg/kg)", "=0.5"],
  [7094, "Malkist (07010204)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [7095, "Malkist (07010204)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [7096, "Malkist (07010204)", "Timah (Sn) (mg/kg)", "=40"],
  [7097, "Malkist (07010204)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [7098, "Malkist (150137)", "Kadar Air (%)", "=5"],
  [7099, "Malkist (150137)", "Arsen (As) (mg/kg)", "=0.25"],
  [7100, "Malkist (150137)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [7101, "Malkist (150137)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    7102,
    "Malkist (150137)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7103,
    "Malkist (150137)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7104, "Malkist (150137)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [7105, "Malt Liqueur (14020104)", "Kadar etanol (%)", "=9", "=5"],
  [
    7106,
    "Malt Liqueur (14020104)",
    "Kadar metanol (% dihitung terhadap etanol)",
    "=0.1",
  ],
  [7107, "Malt Liqueur (14020104)", "Arsen (mg/kg)", "=0.1"],
  [7108, "Malt Liqueur (14020104)", "Kadmium (mg/kg)", "=0.2"],
  [7109, "Malt Liqueur (14020104)", "Merkuri (mg/kg)", "=0.03"],
  [
    7110,
    "Malt Liqueur (14020104)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7111,
    "Malt Liqueur (14020104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7112, "Malt Liqueur (14020104)", "Timbal (mg/kg)", "=0.2"],
  [7113, "Manisan Buah (0401020901)", "Kadar air (%)", "=44"],
  [
    7114,
    "Manisan Buah (0401020901)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    7115,
    "Manisan Buah (0401020901)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    7116,
    "Manisan Buah (0401020901)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    7117,
    "Manisan Buah (0401020901)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    7118,
    "Manisan Buah (0401020901)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    7119,
    "Manisan Buah (0401020901)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    7120,
    "Manisan Buah (0401020901)",
    "Kadar Gula (sebagai sakarosa) (%)",
    "",
    "=25",
  ],
  [
    7121,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Bobot tuntas (%)",
    "",
    "=17",
  ],
  [
    7122,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Arsen (As) inorganik (ppm atau mg/kg)",
    "=1",
  ],
  [
    7123,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7124,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7125,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    7126,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7127,
    "Manisan Rumput Laut Dalam Kemasan (0402020410)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7128, "Mantao (07010501)", "Arsen (As) (mg/kg)", "=0.5"],
  [7129, "Mantao (07010501)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [7130, "Mantao (07010501)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [7131, "Mantao (07010501)", "Timah (Sn) (mg/kg)", "=40"],
  [7132, "Mantao (07010501)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    7133,
    "Margarin (0202010201)",
    "Kadar lemak makan (%)",
    "",
    "=80",
  ],
  [7134, "Margarin (0202010201)", "Kadar air (%)", "=18"],
  [
    7135,
    "Margarin (0202010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7136,
    "Margarin (0202010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7137,
    "Margarin (0202010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7138,
    "Margarin (0202010201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7139,
    "Margarin (0202010201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7140,
    "Margarin (0202010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [7141, "Margarin (02020205)", "Kadar lemak (%)", "", "=80"],
  [7142, "Margarin (02020205)", "Kadar air (%)", "=18"],
  [
    7143,
    "Margarin (02020205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7144,
    "Margarin (02020205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7145,
    "Margarin (02020205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7146,
    "Margarin (02020205)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7147,
    "Margarin (02020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7148,
    "Margarin (02020205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7149,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "kadar lemak (%)",
    "=80",
  ],
  [
    7150,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7151,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7152,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7153,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7154,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7155,
    "Margarin Krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7156,
    "Margarin Meja (02020207)",
    "Kandungan lemak (%)",
    "",
    "=80",
  ],
  [7157, "Margarin Meja (02020207)", "Kadar air (%)", "=18"],
  [
    7158,
    "Margarin Meja (02020207)",
    "Vitamin A yang ditambahkan (IU/100 g)",
    "=3500",
    "=2500",
  ],
  [
    7159,
    "Margarin Meja (02020207)",
    "Vitamin D yang ditambahkan (IU/100 g)",
    "=350",
    "=250",
  ],
  [
    7160,
    "Margarin Meja (02020207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7161,
    "Margarin Meja (02020207)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7162,
    "Margarin Meja (02020207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7163,
    "Margarin Meja (02020207)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7164,
    "Margarin Meja (02020207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7165,
    "Margarin Meja (02020207)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [7166, "Marjoram (12020177)", "Arsen (As) (mg/kg)", "=0.15"],
  [7167, "Marjoram (12020177)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [7168, "Marjoram (12020177)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [7169, "Marjoram (12020177)", "Timah (Sn) (mg/kg)", "=40"],
  [7170, "Marjoram (12020177)", "Timbal (Pb) (mg/kg)", "=1"],
  [7171, "Marjoram (12020177)", "Kadar air (%)", "=10"],
  [
    7172,
    "Marjoram (12020177)",
    "Kadar minyak atsiri (%v/b)",
    "",
    "=0.7",
  ],
  [
    7173,
    "Marmalad (0401020503)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1.00",
  ],
  [
    7174,
    "Marmalad (0401020503)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    7175,
    "Marmalad (0401020503)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7176,
    "Marmalad (0401020503)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    7177,
    "Marmalad (0401020503)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    7178,
    "Marmalad (0401020503)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.40",
  ],
  [7179, "Marshmallow (05020208)", "Arsen (As) (mg/kg)", "=1"],
  [7180, "Marshmallow (05020208)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [7181, "Marshmallow (05020208)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    7182,
    "Marshmallow (05020208)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7183,
    "Marshmallow (05020208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7184, "Marshmallow (05020208)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    7185,
    "Martabak Telur (100405)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    7186,
    "Martabak Telur (100405)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    7187,
    "Martabak Telur (100405)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    7188,
    "Martabak Telur (100405)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7189,
    "Martabak Telur (100405)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    7190,
    "Marzipan, Almond Paste (05020306)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7191,
    "Marzipan, Almond Paste (05020306)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7192,
    "Marzipan, Almond Paste (05020306)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7193,
    "Marzipan, Almond Paste (05020306)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7194,
    "Marzipan, Almond Paste (05020306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7195,
    "Marzipan, Almond Paste (05020306)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7196,
    "Marzipan, Almond Paste (05020306)",
    "Aflatoksin total (ppb atau mcg/kg)",
    "=10",
  ],
  [7197, "Masin (09020521)", "As (ppm atau mg/kg) ", "=0.25"],
  [7198, "Masin (09020521)", "Cd (ppm atau mg/kg) ", "=0.1"],
  [7199, "Masin (09020521)", "Hg (ppm atau mg/kg ", "=0.5"],
  [
    7200,
    "Masin (09020521)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7201,
    "Masin (09020521)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [7202, "Masin (09020521)", "Pb (ppm atau mg/kg) ", "=0.2"],
  [
    7203,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Kandungan lemak kakao (%)",
    "=60",
    "=47",
  ],
  [
    7204,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Kandungan lemak (g/100g)",
    "=48",
  ],
  [
    7205,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Bilangan oid (wijis) (%)",
    "=42",
    "=33",
  ],
  [
    7206,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Kadar abu (dari bahan kering tanpa lemak (%)",
    "=14",
  ],
  [
    7207,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Kadar abu tak larut dalam asam (dari bahan kering tanpa lemak (%)",
    "=0.3",
  ],
  [
    7208,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Kulit (shell) (%)",
    "=4",
  ],
  [
    7209,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7210,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7211,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7212,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7213,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    7214,
    "Massa Kakao dan Cairan Kental (Liquor) Cokelat (05010108)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7215,
    "Mayonais, Mayonnaise (12060101)",
    "Kadar lemak total (%)",
    "",
    "=65",
  ],
  [
    7216,
    "Mayonais, Mayonnaise (12060101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    7217,
    "Mayonais, Mayonnaise (12060101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    7218,
    "Mayonais, Mayonnaise (12060101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7219,
    "Mayonais, Mayonnaise (12060101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7220,
    "Mayonais, Mayonnaise (12060101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7221,
    "Mayonais, Mayonnaise (12060101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    7222,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7223,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7224,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7225,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7226,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7227,
    "MDM (Mechanically Deboned Meat) (08010211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    7228,
    "Mead, Anggur Madu (140205)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    7229,
    "Mead, Anggur Madu (140205)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [7230, "Mead, Anggur Madu (140205)", "Arsen (mg/kg)", "=0.1"],
  [7231, "Mead, Anggur Madu (140205)", "Kadmium (mg/kg)", "=0.2"],
  [7232, "Mead, Anggur Madu (140205)", "Merkuri (mg/kg)", "=0.03"],
  [
    7233,
    "Mead, Anggur Madu (140205)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7234,
    "Mead, Anggur Madu (140205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7235, "Mead, Anggur Madu (140205)", "Timbal (mg/kg)", "=0.2"],
  [7236, "Meal (060303)", "Arsen (As) (mg/kg) ", "=0.1"],
  [7237, "Meal (060303)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [7238, "Meal (060303)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [7239, "Meal (060303)", "Timah (Sn) (mg/kg)", "=40"],
  [7240, "Meal (060303)", "Timbal (Pb) (mg/kg) ", "=0.25"],
  [
    7241,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Kandungan Lembaga (%)",
    "",
    "=60",
  ],
  [
    7242,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    7243,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    7244,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    7245,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    7246,
    "Meal Lembaga Gandum (Wheat Germ Meal) (060304)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [7247, "Meat Wine (14020705)", "Kadar protein (g/l)", "", "=20"],
  [7248, "Meat Wine (14020705)", "Arsen (mg/kg)", "=0.1"],
  [7249, "Meat Wine (14020705)", "Kadmium (mg/kg)", "=0.2"],
  [7250, "Meat Wine (14020705)", "Merkuri (mg/kg)", "=0.03"],
  [
    7251,
    "Meat Wine (14020705)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7252,
    "Meat Wine (14020705)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7253, "Meat Wine (14020705)", "Timbal (mg/kg)", "=0.2"],
  [
    7254,
    "Meat Wine (14020705)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [7255, "Meat Wine (14020705)", "Kadar etanol (%)", "=24", "=7"],
  [
    7256,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "kadar lemak (%)",
    "",
    "=5",
  ],
  [
    7257,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7258,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7259,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7260,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7261,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7262,
    "Melorin atau Non-Dairy Ice Cream (020401)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [7263, "Mentega (0202010101)", "Kadar lemak susu (%)", "", "=80"],
  [7264, "Mentega (0202010101)", "Kadar Air (%)", "=16"],
  [
    7265,
    "Mentega (0202010101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7266,
    "Mentega (0202010101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7267,
    "Mentega (0202010101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7268,
    "Mentega (0202010101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7269,
    "Mentega (0202010101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7270,
    "Mentega (0202010101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7271,
    "Mentega Rekombinasi (0202010102)",
    "Kadar lemak susu (%)",
    "",
    "=80",
  ],
  [
    7272,
    "Mentega Rekombinasi (0202010102)",
    "Kadar Air (%)",
    "=16",
  ],
  [
    7273,
    "Mentega Rekombinasi (0202010102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7274,
    "Mentega Rekombinasi (0202010102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7275,
    "Mentega Rekombinasi (0202010102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7276,
    "Mentega Rekombinasi (0202010102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7277,
    "Mentega Rekombinasi (0202010102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7278,
    "Mentega Rekombinasi (0202010102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7279,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7280,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Kadmium (Cd)(mg/kg)",
    "=0.5",
  ],
  [
    7281,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7282,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    7283,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    7284,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7285,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "= 2.5",
  ],
  [
    7286,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Total padatan kakao (%)",
    "",
    "= 20",
  ],
  [
    7287,
    "Meses Susu/Cokelat Susu Butir/Cokelat Susu Vermicelli (05010432)",
    "Padatan susu (%)",
    "",
    "= 12",
  ],
  [
    7288,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Kadar lemak kakao (%)",
    "",
    "=12",
  ],
  [
    7289,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Padatan kakao tanpa lemak (%)",
    "",
    "=14",
  ],
  [
    7290,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Total padatan kakao (%)",
    "",
    "=32",
  ],
  [
    7291,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7292,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7293,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7294,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    7295,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    7296,
    "Meses/Cokelat Butir/Cokelat Vermicelli/Streusel (05010416)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [7297, "Mesoyi (120201A6)", "Arsen (As) (mg/kg)", "=0.15"],
  [7298, "Mesoyi (120201A6)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    7299,
    "Mesoyi (120201A6)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7300,
    "Mesoyi (120201A6)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7301, "Mesoyi (120201A6)", "Timbal (Pb) (mg/kg)", "=1"],
  [7302, "Mesoyi (120201A6)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    7303,
    "Mete Gelondong (0402020214)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    7304,
    "Mete Gelondong (0402020214)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7305,
    "Mete Gelondong (0402020214)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7306,
    "Mete Gelondong (0402020214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7307,
    "Mete Gelondong (0402020214)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    7308,
    "Mi Basah Matang (06040308)",
    "Kadar air (%)",
    "=60",
    "=20",
  ],
  [
    7309,
    "Mi Basah Matang (06040308)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7310,
    "Mi Basah Matang (06040308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7311,
    "Mi Basah Matang (06040308)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7312,
    "Mi Basah Matang (06040308)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7313,
    "Mi Basah Matang (06040308)",
    "Timah (Sn) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7314,
    "Mi Basah Matang (06040308)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7315,
    "Mi Basah Matang Lainnya (06040316)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7316,
    "Mi Basah Matang Lainnya (06040316)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7317,
    "Mi Basah Matang Lainnya (06040316)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7318,
    "Mi Basah Matang Lainnya (06040316)",
    "Timah (Sn) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7319,
    "Mi Basah Matang Lainnya (06040316)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7320,
    "Mi Basah Mentah (06040101)",
    "Kadar air (%)",
    "=40",
    "=20",
  ],
  [
    7321,
    "Mi Basah Mentah (06040101)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7322,
    "Mi Basah Mentah (06040101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7323,
    "Mi Basah Mentah (06040101)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7324,
    "Mi Basah Mentah (06040101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7325,
    "Mi Basah Mentah (06040101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7326,
    "Mi Basah Mentah (06040101)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    7327,
    "Mi Basah Mentah (06040101)",
    "Kadar Protein (%)",
    "",
    "=5",
  ],
  [
    7328,
    "Mi Basah Mentah lainnya (06040104)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7329,
    "Mi Basah Mentah lainnya (06040104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7330,
    "Mi Basah Mentah lainnya (06040104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7331,
    "Mi Basah Mentah lainnya (06040104)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7332,
    "Mi Basah Mentah lainnya (06040104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7333,
    "Mi Basah Mentah lainnya (06040104)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    7334,
    "Mi Instan (06040309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7335,
    "Mi Instan (06040309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7336,
    "Mi Instan (06040309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7337,
    "Mi Instan (06040309)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7338,
    "Mi Instan (06040309)",
    "Timah (Sn) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7339,
    "Mi Instan (06040309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7340,
    "Mi Instan (06040309)",
    "Kadar air (jika diolah dengan proses penggorengan) (%)",
    "=10",
  ],
  [
    7341,
    "Mi Instan (06040309)",
    "Kadar air (jika diolah dengan proses pengeringan) (%)",
    "=14",
  ],
  [
    7342,
    "Mi Instan Lainnya (06040310)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7343,
    "Mi Instan Lainnya (06040310)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7344,
    "Mi Instan Lainnya (06040310)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7345,
    "Mi Instan Lainnya (06040310)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7346,
    "Mi Instan Lainnya (06040310)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    7347,
    "Mi Instan Lainnya (06040310)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7348,
    "Mi Kering (06040217)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    7349,
    "Mi Kering (06040217)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7350,
    "Mi Kering (06040217)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    7351,
    "Mi Kering (06040217)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    7352,
    "Mi Kering (06040217)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [7353, "Mi Kering Gandum (06040303)", "Kadar air (%)", "=11"],
  [
    7354,
    "Mi Kering Gandum (06040303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7355,
    "Mi Kering Gandum (06040303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7356,
    "Mi Kering Gandum (06040303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7357,
    "Mi Kering Gandum (06040303)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7358,
    "Mi Kering Gandum (06040303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7359,
    "Mi Kering Gandum (06040303)",
    "Kadar protein (%)",
    "",
    "=6",
  ],
  [
    7360,
    "Mi Kering Lainnya (06040304)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7361,
    "Mi Kering Lainnya (06040304)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7362,
    "Mi Kering Lainnya (06040304)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7363,
    "Mi Kering Lainnya (06040304)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7364,
    "Mi Kering Lainnya (06040304)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [7365, "Mi Kering Lainnya (06040304)", "Kadar air (%)", "=10"],
  [
    7366,
    "Mi Soa (06040322)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7367,
    "Mi Soa (06040322)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7368,
    "Mi Soa (06040322)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7369,
    "Mi Soa (06040322)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7370,
    "Mi Soa (06040322)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7371,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Kadar lemak (%)",
    "=80",
  ],
  [
    7372,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7373,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7374,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7375,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7376,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7377,
    "Minarin (Minarine), Margarin krim, Margarin Oles (Fat Spread), Margarine Compound, Bread Compound dan Bakery Compound (02020201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7378,
    "Minarin atau Halvarine (02020204)",
    "kadar lemak (%)",
    "=41",
    "=39",
  ],
  [
    7379,
    "Minarin atau Halvarine (02020204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7380,
    "Minarin atau Halvarine (02020204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7381,
    "Minarin atau Halvarine (02020204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7382,
    "Minarin atau Halvarine (02020204)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7383,
    "Minarin atau Halvarine (02020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7384,
    "Minarin atau Halvarine (02020204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7385,
    "Minarin Meja atau Halvarine (02020209)",
    "Kadar lemak (%) ",
    "=41",
    "=39",
  ],
  [
    7386,
    "Minarin Meja atau Halvarine (02020209)",
    "Vitamin A yang ditambahkan (IU/100 g)",
    "=3500",
    "=2500",
  ],
  [
    7387,
    "Minarin Meja atau Halvarine (02020209)",
    "Vitamin D yang ditambahkan (IU/100 g)",
    "=350",
    "=250",
  ],
  [
    7388,
    "Minarin Meja atau Halvarine (02020209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7389,
    "Minarin Meja atau Halvarine (02020209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7390,
    "Minarin Meja atau Halvarine (02020209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7391,
    "Minarin Meja atau Halvarine (02020209)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7392,
    "Minarin Meja atau Halvarine (02020209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7393,
    "Minarin Meja atau Halvarine (02020209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [7394, "Mint (12020178)", "Arsen (As) (mg/kg)", "=0.15"],
  [7395, "Mint (12020178)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [7396, "Mint (12020178)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [7397, "Mint (12020178)", "Timah (Sn) (mg/kg)", "=40"],
  [7398, "Mint (12020178)", "Timbal (Pb) (mg/kg)", "=1"],
  [7399, "Minuman Bandrek (14010535)", "Arsen (As) (mg/kg)", "=1"],
  [
    7400,
    "Minuman Bandrek (14010535)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7401,
    "Minuman Bandrek (14010535)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7402,
    "Minuman Bandrek (14010535)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7403, "Minuman Bandrek (14010535)", "Timbal (Pb) (mg/kg)", "=2"],
  [7404, "Minuman Cincau (14010540)", "Arsen (As) (mg/kg)", "=1"],
  [
    7405,
    "Minuman Cincau (14010540)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7406,
    "Minuman Cincau (14010540)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7407,
    "Minuman Cincau (14010540)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7408, "Minuman Cincau (14010540)", "Timbal (Pb) (mg/kg)", "=2"],
  [
    7409,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7410,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7411,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7412,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7413,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    7414,
    "Minuman Cincau (Steril Komersial) (14010541)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7415,
    "Minuman Krisanthemum (14010543)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7416,
    "Minuman Krisanthemum (14010543)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7417,
    "Minuman Krisanthemum (14010543)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7418,
    "Minuman Krisanthemum (14010543)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7419,
    "Minuman Krisanthemum (14010543)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [7420, "Minuman Rosella (14010539)", "Arsen (As) (mg/kg)", "=1"],
  [
    7421,
    "Minuman Rosella (14010539)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7422,
    "Minuman Rosella (14010539)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7423,
    "Minuman Rosella (14010539)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7424, "Minuman Rosella (14010539)", "Timbal (Pb) (mg/kg)", "=2"],
  [7425, "Minuman Sekoteng (14010536)", "Arsen (As) (mg/kg)", "=1"],
  [
    7426,
    "Minuman Sekoteng (14010536)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7427,
    "Minuman Sekoteng (14010536)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7428,
    "Minuman Sekoteng (14010536)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7429,
    "Minuman Sekoteng (14010536)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    7430,
    "Minuman ... (Steril Komersial) (14010542)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7431,
    "Minuman ... (Steril Komersial) (14010542)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7432,
    "Minuman ... (Steril Komersial) (14010542)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7433,
    "Minuman ... (Steril Komersial) (14010542)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7434,
    "Minuman ... (Steril Komersial) (14010542)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [7435, "Minuman ... (Steril Komersial) (14010542)", "Kafein"],
  [
    7436,
    "Minuman ... (Steril Komersial) (14010542)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=100",
  ],
  [
    7437,
    "Minuman Air Kelapa (1401040226)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7438,
    "Minuman Air Kelapa (1401040226)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7439,
    "Minuman Air Kelapa (1401040226)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7440,
    "Minuman Air Kelapa (1401040226)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7441,
    "Minuman Air Kelapa (1401040226)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7442,
    "Minuman Air Kelapa (1401040226)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7443,
    "Minuman Asam Jawa (1401040220)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7444,
    "Minuman Asam Jawa (1401040220)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7445,
    "Minuman Asam Jawa (1401040220)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7446,
    "Minuman Asam Jawa (1401040220)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7447,
    "Minuman Asam Jawa (1401040220)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7448,
    "Minuman Asam Jawa (1401040220)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [7449, "Minuman Asam Jawa (14010566)", "Arsen (mg/kg)", "=1"],
  [7450, "Minuman Asam Jawa (14010566)", "Kadmium (mg/kg)", "=0.2"],
  [
    7451,
    "Minuman Asam Jawa (14010566)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    7452,
    "Minuman Asam Jawa (14010566)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7453,
    "Minuman Asam Jawa (14010566)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7454, "Minuman Asam Jawa (14010566)", "Timbal (mg/kg)", "=2"],
  [
    7455,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7456,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7457,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7458,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7459,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7460,
    "Minuman Asam Jawa (Steril Komersil) (1401040237)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7461,
    "Minuman Beralkohol Golongan A (140208)",
    "Kadar etanol (%)",
    "=5",
    "=1",
  ],
  [
    7462,
    "Minuman Beralkohol Golongan A (140208)",
    "Kadar metanol tidak lebih dari ...... (%) dihitung terhadap etanol",
    "=0.1",
  ],
  [
    7463,
    "Minuman Beralkohol Golongan A (140208)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    7464,
    "Minuman Beralkohol Golongan A (140208)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    7465,
    "Minuman Beralkohol Golongan A (140208)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    7466,
    "Minuman Beralkohol Golongan A (140208)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7467,
    "Minuman Beralkohol Golongan A (140208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7468,
    "Minuman Beralkohol Golongan A (140208)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [7469, "Minuman Beralkohol Golongan A (140208)", "Alkohol"],
  [
    7470,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Kadar etanol (%)",
    "=5",
    "=1",
  ],
  [
    7471,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    7472,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Arsen (mg/L) ",
    "=0.1",
  ],
  [
    7473,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Kadmium (mg/L) ",
    "=0.2",
  ],
  [
    7474,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Merkuri (mg/L) ",
    "=0.03",
  ],
  [
    7475,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Timah, minuman dalam kemasan kaleng (mg/L) ",
    "=100",
  ],
  [
    7476,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L) ",
    "=40",
  ],
  [
    7477,
    "Minuman Beralkohol Golongan A (1402A1)",
    "Timbal (mg/L) ",
    "=0.2",
  ],
  [7478, "Minuman Beralkohol Golongan A (1402A1)", "Alkohol"],
  [
    7479,
    "Minuman Beralkohol Golongan A (14020709)",
    "Kadar etanol (%)",
    "=5",
    "=1",
  ],
  [
    7480,
    "Minuman Beralkohol Golongan A (14020709)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    7481,
    "Minuman Beralkohol Golongan A (14020709)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7482,
    "Minuman Beralkohol Golongan A (14020709)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7483,
    "Minuman Beralkohol Golongan A (14020709)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7484,
    "Minuman Beralkohol Golongan A (14020709)",
    "Timah (Sn) untuk minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7485,
    "Minuman Beralkohol Golongan A (14020709)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7486,
    "Minuman Beralkohol Golongan A (14020709)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7487,
    "Minuman Beralkohol Golongan B (140209)",
    "Kadar etanol (%)",
    "=20",
    ">5",
  ],
  [
    7488,
    "Minuman Beralkohol Golongan B (140209)",
    "Kadar metanol tidak lebih dari ...... (%) dihitung terhadap etanol",
    "=0.1",
  ],
  [
    7489,
    "Minuman Beralkohol Golongan B (140209)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    7490,
    "Minuman Beralkohol Golongan B (140209)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    7491,
    "Minuman Beralkohol Golongan B (140209)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    7492,
    "Minuman Beralkohol Golongan B (140209)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7493,
    "Minuman Beralkohol Golongan B (140209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7494,
    "Minuman Beralkohol Golongan B (140209)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [7495, "Minuman Beralkohol Golongan B (140209)", "Alkohol"],
  [
    7496,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Kadar etanol (%)",
    "=20",
    ">5",
  ],
  [
    7497,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    7498,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Arsen (mg/L) ",
    "=0.1",
  ],
  [
    7499,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Kadmium (mg/L) ",
    "=0.2",
  ],
  [
    7500,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Merkuri (mg/L) ",
    "=0.03",
  ],
  [
    7501,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Timah, minuman dalam kemasan kaleng (mg/L) ",
    "=100",
  ],
  [
    7502,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L) ",
    "=40",
  ],
  [
    7503,
    "Minuman Beralkohol Golongan B (1402B1)",
    "Timbal (mg/L) ",
    "=0.2",
  ],
  [7504, "Minuman Beralkohol Golongan B (1402B1)", "Alkohol"],
  [7505, "Minuman Beralkohol Golongan B (1402B1)", "Alkohol"],
  [
    7506,
    "Minuman Beralkohol Golongan B (14020710)",
    "Kadar etanol (%)",
    "=20",
    ">5",
  ],
  [
    7507,
    "Minuman Beralkohol Golongan B (14020710)",
    "Kadar metanol dihitung terhadap volume produk (% v/v) ",
    "=0.01",
  ],
  [
    7508,
    "Minuman Beralkohol Golongan B (14020710)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7509,
    "Minuman Beralkohol Golongan B (14020710)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7510,
    "Minuman Beralkohol Golongan B (14020710)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7511,
    "Minuman Beralkohol Golongan B (14020710)",
    "Timah (Sn) untuk minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7512,
    "Minuman Beralkohol Golongan B (14020710)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7513,
    "Minuman Beralkohol Golongan B (14020710)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7514,
    "Minuman Beralkohol Golongan C (140210)",
    "Kadar etanol (%)",
    "",
    ">20",
  ],
  [
    7515,
    "Minuman Beralkohol Golongan C (140210)",
    "Kadar metanol tidak lebih dari ...... (%) dihitung terhadap etanol",
    "=0.1",
  ],
  [
    7516,
    "Minuman Beralkohol Golongan C (140210)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    7517,
    "Minuman Beralkohol Golongan C (140210)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    7518,
    "Minuman Beralkohol Golongan C (140210)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    7519,
    "Minuman Beralkohol Golongan C (140210)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    7520,
    "Minuman Beralkohol Golongan C (140210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7521,
    "Minuman Beralkohol Golongan C (140210)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [7522, "Minuman Beralkohol Golongan C (140210)", "Alkohol"],
  [
    7523,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Kadar Etanol (%) ",
    "=55",
    ">20",
  ],
  [
    7524,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    7525,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Arsen (mg/L) ",
    "=0.1",
  ],
  [
    7526,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Kadmium (mg/L) ",
    "=0.2",
  ],
  [
    7527,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Merkuri (mg/L) ",
    "=0.03",
  ],
  [
    7528,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Timah, minuman dalam kemasan kaleng (mg/L) ",
    "=100",
  ],
  [
    7529,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L) ",
    "=40",
  ],
  [
    7530,
    "Minuman Beralkohol Golongan C (1402C1)",
    "Timbal (mg/L) ",
    "=0.2",
  ],
  [
    7531,
    "Minuman Beralkohol Golongan C (14020711)",
    "Kadar Etanol (%) ",
    "=55",
    ">20",
  ],
  [
    7532,
    "Minuman Beralkohol Golongan C (14020711)",
    "Kadar metanol dihitung terhadap volume produk (% v/v) ",
    "=0.01",
  ],
  [
    7533,
    "Minuman Beralkohol Golongan C (14020711)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    7534,
    "Minuman Beralkohol Golongan C (14020711)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7535,
    "Minuman Beralkohol Golongan C (14020711)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7536,
    "Minuman Beralkohol Golongan C (14020711)",
    "Timah (Sn) untuk minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7537,
    "Minuman Beralkohol Golongan C (14020711)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7538,
    "Minuman Beralkohol Golongan C (14020711)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7539,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Arsen (As) (mg/kg) - Siap Konsumsi",
    "=0.1",
  ],
  [
    7540,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Kadmium (Cd) (mg/kg) - Siap Konsumsi",
    "=0.05",
  ],
  [
    7541,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Merkuri (Hg) (mg/kg) - Siap Konsumsi",
    "=0.02",
  ],
  [
    7542,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/Kg) - Siap Konsumsi",
    "=250",
  ],
  [
    7543,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/Kg) - Siap Konsumsi",
    "=40",
  ],
  [
    7544,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Timbal (Pb) (mg/Kg) - Siap Konsumsi",
    "=0.02",
  ],
  [
    7545,
    "Minuman Berbasis Whey (Berperisa/Rasa) (01010407)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.05",
  ],
  [
    7546,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Kadar kafein (mg/kg)",
    "=320",
    "=145",
  ],
  [
    7547,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    7548,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7549,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7550,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7551,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7552,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Cair) (14010558)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    7553,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Kadar kafein (mg/kg)",
    "=320",
    "=145",
  ],
  [
    7554,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    7555,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7556,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7557,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7558,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7559,
    "Minuman Berkafein Formulasi (Formulated Caffeinated Beverages) (Serbuk) (14010557)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    7560,
    "Minuman Berkarbonat (1401040108)",
    "Arsen (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7561,
    "Minuman Berkarbonat (1401040108)",
    "Kadmium (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7562,
    "Minuman Berkarbonat (1401040108)",
    "Merkuri (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7563,
    "Minuman Berkarbonat (1401040108)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7564,
    "Minuman Berkarbonat (1401040108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7565,
    "Minuman Berkarbonat (1401040108)",
    "Timbal (ppm atau mg/kg)",
    "=0.05",
  ],
  [7566, "Minuman Berkarbonat (1401040108)", "Melanin"],
  [7567, "Minuman Berkarbonat (1401040108)", "CO2 (%)"],
  [
    7568,
    "Minuman Berperisa (140104A2)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7569,
    "Minuman Berperisa (140104A2)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7570,
    "Minuman Berperisa (140104A2)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7571,
    "Minuman Berperisa (140104A2)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7572,
    "Minuman Berperisa (140104A2)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7573,
    "Minuman Berperisa (140104A2)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7574,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7575,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7576,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7577,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7578,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7579,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7580,
    "Minuman Berperisa Berkarbonat (1401040121)",
    "CO2 (mg/L)",
    "=5890",
  ],
  [
    7581,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7582,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7583,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7584,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg",
    "=100",
  ],
  [
    7585,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7586,
    "Minuman Berperisa Tidak Berkarbonat (1401040246)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7587,
    "Minuman Berperisa... (1401040209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7588,
    "Minuman Berperisa... (1401040209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7589,
    "Minuman Berperisa... (1401040209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7590,
    "Minuman Berperisa... (1401040209)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7591,
    "Minuman Berperisa... (1401040209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7592,
    "Minuman Berperisa... (1401040209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [7593, "Minuman Berperisa... (1401040209)", "Melanin"],
  [
    7594,
    "Minuman Berperisa... (1401040209)",
    "Kadar gula sebagai sakarosa (%)",
  ],
  [
    7595,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7596,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7597,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7598,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    7599,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    7600,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Jika mengandung kinina, kadar kinina (mg/kg)",
    "=40",
  ],
  [
    7601,
    "Minuman Botanikal/Minuman Rempah (Cair) (14010521)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7602,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    7603,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7604,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7605,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7606,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7607,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    7608,
    "Minuman botanikal/minuman rempah (Seduhan) (14010560)",
    "Jika mengandung kinina, kadar kinina (mg/kg)",
    "=40",
  ],
  [
    7609,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    7610,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    7611,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    7612,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7613,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7614,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    7615,
    "Minuman botanikal/minuman rempah (Serbuk) (14010559)",
    "Jika mengandung kinina, kadar kinina (mg/kg)",
    "=40",
  ],
  [
    7616,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7617,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7618,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7619,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7620,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7621,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    7622,
    "Minuman botanikal/minuman rempah (Steril Komersial) (14010548)",
    "Jika mengandung kinina, kadar kinina (mg/kg)",
    "=40",
  ],
  [
    7623,
    "Minuman Buah (1401040235)",
    "Total sari buah (% b/v)",
    "=35",
    "=10",
  ],
  [7624, "Minuman Buah (1401040235)", "Arsen (mg/kg)", "=0.05"],
  [7625, "Minuman Buah (1401040235)", "Kadmium (mg/kg)", "=0.01"],
  [7626, "Minuman Buah (1401040235)", "Merkuri (mg/kg)", "=0.01"],
  [
    7627,
    "Minuman Buah (1401040235)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7628,
    "Minuman Buah (1401040235)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7629, "Minuman Buah (1401040235)", "Timbal (mg/kg)", "=0.05"],
  [
    7630,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Total sari buah (% b/v)",
    "=35",
    "=10",
  ],
  [
    7631,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7632,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7633,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7634,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7635,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7636,
    "Minuman Buah (Steril Komersial) (1401040236)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7637,
    "Minuman Buah Berkarbonat (1401040122)",
    "Total sari buah (% b/v)",
    "=35",
    "=10",
  ],
  [
    7638,
    "Minuman Buah Berkarbonat (1401040122)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7639,
    "Minuman Buah Berkarbonat (1401040122)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7640,
    "Minuman Buah Berkarbonat (1401040122)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7641,
    "Minuman Buah Berkarbonat (1401040122)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7642,
    "Minuman Buah Berkarbonat (1401040122)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7643,
    "Minuman Buah Berkarbonat (1401040122)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7644,
    "Minuman Buah Berkarbonat (1401040122)",
    "Kadar CO2 (mg/L)",
    "=5890",
  ],
  [7645, "Minuman Citrus (1401040114)", "Kandungan (Brix)", "=14"],
  [
    7646,
    "Minuman Citrus (1401040114)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7647,
    "Minuman Citrus (1401040114)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7648,
    "Minuman Citrus (1401040114)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7649,
    "Minuman Citrus (1401040114)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7650,
    "Minuman Citrus (1401040114)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7651,
    "Minuman Citrus (1401040114)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7652,
    "Minuman Citrus Comminutes (1401020108)",
    "Kandungan buah dalam minuman sebelum diencerkan (tergantung jenisnya) (%)",
    "=10",
    "=7",
  ],
  [
    7653,
    "Minuman Citrus Comminutes (1401020108)",
    "Kandungan buah dalam minuman yang dikonsumsi tanpa pengenceran (%)",
    "=2",
    "=1.5",
  ],
  [
    7654,
    "Minuman Citrus Comminutes (1401020108)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7655,
    "Minuman Citrus Comminutes (1401020108)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    7656,
    "Minuman Citrus Comminutes (1401020108)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7657,
    "Minuman Citrus Comminutes (1401020108)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)",
    "=100",
  ],
  [
    7658,
    "Minuman Citrus Comminutes (1401020108)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    7659,
    "Minuman Citrus Comminutes (1401020108)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    7660,
    "Minuman Citrus Comminutes (140104A3)",
    "kandungan gula (g/kg)",
    "=100",
  ],
  [
    7661,
    "Minuman Citrus Comminutes (140104A3)",
    "Kandungan buah dalam minuman sebelum diencerkan (tergantung jenisnya) (%)",
    "=10",
    "=7",
  ],
  [
    7662,
    "Minuman Citrus Comminutes (140104A3)",
    "Kandungan buah dalam minuman yang dikonsumsi tanpa pengenceran (%)",
    "=2",
    "=1.5",
  ],
  [
    7663,
    "Minuman Citrus Comminutes (140104A3)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7664,
    "Minuman Citrus Comminutes (140104A3)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    7665,
    "Minuman Citrus Comminutes (140104A3)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7666,
    "Minuman Citrus Comminutes (140104A3)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7667,
    "Minuman Citrus Comminutes (140104A3)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7668,
    "Minuman Citrus Comminutes (140104A3)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    7669,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Kandungan buah dalam minuman sebelum diencerkan (tergantung jenisnya) (%)",
    "=10",
    "=7",
  ],
  [
    7670,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Kandungan Buah dalam minuman yang dikonsumsi tanpa pengenceran (%)",
    "=2",
    "=1.5",
  ],
  [
    7671,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7672,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7673,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7674,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7675,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7676,
    "Minuman Citrus Comminutes (Berkarbonat) (1401040123)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7677,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Kandungan buah dalam minuman sebelum diencerkan (tergantung jenisnya) (%)",
    "=10",
    "=7",
  ],
  [
    7678,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Kandungan Buah (untuk minuman yang dikonsumsi tanpa pengenceran) (%)",
    "=2",
    "=1.5",
  ],
  [
    7679,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7680,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7681,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7682,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7683,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7684,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7685,
    "Minuman Citrus Comminutes (Tidak Berkarbonat) (1401040249)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7686,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Kandungan kakao (total cocoa solid) dihitung dari basis berat kering (%)",
    "",
    "=5",
  ],
  [
    7687,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7688,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7689,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7690,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    7691,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    7692,
    "Minuman Cokelat Paduan (Bubuk) (05010509)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7693,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Kandungan kakao (total cocoa solid) dihitung dari basis berat kering (%)",
    "",
    "=5",
  ],
  [
    7694,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7695,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7696,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7697,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7698,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7699,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (05010517)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7700,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Kandungan kakao (total cocoa solid) dihitung dari basis berat kering (%)",
    "",
    "=5",
  ],
  [
    7701,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7702,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7703,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7704,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7705,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7706,
    "Minuman Cokelat Paduan (Siap minum, Konsentrat) (Steril Komersial) (05010518)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7707,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Saat minuman elektrolit dibuat maka kadar natrium minuman harus (mmol/l)",
    "<10",
  ],
  [
    7708,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Kadar fruktosa (g/l)",
    "<50",
  ],
  [
    7709,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7710,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7711,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7712,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7713,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7714,
    "Minuman Dasar Elektrolit (Electrolyte Drinks Base) Tidak Berkarbonat (1401040219)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7715,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7716,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7717,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7718,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7719,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7720,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    7721,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Kadar natrium saat minuman elektrolit dibuat (mmol/l)",
    "",
    "=10",
  ],
  [
    7722,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Cair) (1401040314)",
    "Kadar fruktosa (gram/liter)",
    "=50",
  ],
  [
    7723,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Kadar natrium saat minuman elektrolit dibuat (mmol/l)",
    "",
    "=10",
  ],
  [
    7724,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Kadar fruktosa (gram/liter)",
    "=50",
  ],
  [
    7725,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7726,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7727,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7728,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Timah (Sn) dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7729,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7730,
    "Minuman Dasar Elektrolit Berkarbonat (Electrolyte Drinks Base)(Serbuk) (1401040313)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    7731,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Kadar natrium saat minuman elektrolit dibuat (mmol/l) ",
    "",
    "=10",
  ],
  [
    7732,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Kadar fruktosa (gram/liter)",
    "=50",
  ],
  [
    7733,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7734,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7735,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7736,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7737,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7738,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Cair) (1401040318)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    7739,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Kadar natrium saat minuman elektrolit dibuat (mmol/l)",
    "",
    "=10",
  ],
  [
    7740,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Kadar fruktosa (gram/liter)",
    "=50",
  ],
  [
    7741,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7742,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    7743,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    7744,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Timah (Sn) dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    7745,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Timah (Sn) (ppm atau mg/kg) yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    7746,
    "Minuman Dasar Elektrolit Tidak Berkarbonat (Electrolyte Drinks Base) (Serbuk) (1401040317)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    7747,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Kandungan natrium (mmol/l)",
    "",
    "=10",
  ],
  [
    7748,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7749,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7750,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7751,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7752,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7753,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg",
    "=0.01",
  ],
  [
    7754,
    "Minuman Elektrolit Berkarbonat (1401040101)",
    "Kadar Fruktosa (g/L)",
    "=50",
  ],
  [
    7755,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Kandungan natrium (mmol/l)",
    "",
    "=10",
  ],
  [
    7756,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Kadar Fruktosa (g/l)",
    "=50",
  ],
  [
    7757,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7758,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7759,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7760,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7761,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7762,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7763,
    "Minuman Elektrolit Tidak Berkarbonat (1401040215)",
    "Kadar gula (jumlah total dekstrosa, fruktosa, sirup glukosa, maltodekstrin dan sukrosa) (g/L)",
    "=100",
    "=50",
  ],
  [
    7764,
    "Minuman Fermentasi (1401040251)",
    "Arsen (As) (mg/kg)",
    "=0.05",
  ],
  [
    7765,
    "Minuman Fermentasi (1401040251)",
    "Kadmium (Cd) (mg/kg)",
    "=0.01",
  ],
  [
    7766,
    "Minuman Fermentasi (1401040251)",
    "Merkuri (Hg) (mg/kg)",
    "=0.01",
  ],
  [
    7767,
    "Minuman Fermentasi (1401040251)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7768,
    "Minuman Fermentasi (1401040251)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7769,
    "Minuman Fermentasi (1401040251)",
    "Timbal (Pb) (mg/kg)",
    "=0.05",
  ],
  [
    7770,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Osmolaritas (miliOsmol/l)",
    "",
    ">340",
  ],
  [
    7771,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7772,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7773,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7774,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7775,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7776,
    "Minuman Hipertonik Tidak Berkarbonat (1401040218)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7777,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Osmolaritas (miliOsmol/l)",
    "<250",
  ],
  [
    7778,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7779,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7780,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7781,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7782,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7783,
    "Minuman Hipotonik Tidak Berkarbonat (1401040216)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7784,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Osmolaritas (miliOsmol/l)",
    "<340",
    ">250",
  ],
  [
    7785,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Kandungan Karbohidrat (%)",
    "=8",
    "=2",
  ],
  [
    7786,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Fruktosa (%)",
    "<5",
  ],
  [
    7787,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Kadar natrium (mg/l)",
    "=690",
    "=200",
  ],
  [
    7788,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Kadar kalium (mg/l)",
    "=200",
    "=125",
  ],
  [
    7789,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Arsen (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7790,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Kadmium (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7791,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Merkuri (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7792,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7793,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7794,
    "Minuman Isotonik Berkarbonat (1401040103)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7795,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Osmolaritas (miliOsmol/l)",
    "<340",
    ">250",
  ],
  [
    7796,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Kandungan Karbohidrat (%)",
    "=8",
    "=2",
  ],
  [
    7797,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Fruktosa (%)",
    "<5",
  ],
  [
    7798,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Kadar natrium (mg/l)",
    "=690",
    "=200",
  ],
  [
    7799,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Kadar kalium (mg/l)",
    "=200",
    "=125",
  ],
  [
    7800,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7801,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7802,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7803,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7804,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7805,
    "Minuman Isotonik Tidak Berkarbonat (1401040217)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [7806, "Minuman Jahe (14010538)", "Arsen (As) (mg/kg)", "=1"],
  [7807, "Minuman Jahe (14010538)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [7808, "Minuman Jahe (14010538)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    7809,
    "Minuman Jahe (14010538)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7810, "Minuman Jahe (14010538)", "Timbal (Pb) (mg/kg)", "=2"],
  [7811, "Minuman Jeli (1401040229)", "Arsen (mg/kg)", "=0.05"],
  [7812, "Minuman Jeli (1401040229)", "Kadmium (mg/kg)", "=0.01"],
  [7813, "Minuman Jeli (1401040229)", "Merkuri (mg/kg)", "=0.01"],
  [
    7814,
    "Minuman Jeli (1401040229)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7815, "Minuman Jeli (1401040229)", "Timbal (mg/kg)", "=0.05"],
  [
    7816,
    "Minuman Jeli (1401040229)",
    "Kandungan minimal hidrokoloid (%)",
    "",
    "=0.1",
  ],
  [
    7817,
    "Minuman Jeli (1401040229)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7818,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7819,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    7820,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    7821,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7822,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    7823,
    "Minuman Kakao (Drinking Cocoa) (05010110)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    7824,
    "Minuman Kedelai (1401040117)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7825,
    "Minuman Kedelai (1401040117)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7826,
    "Minuman Kedelai (1401040117)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7827,
    "Minuman Kedelai (1401040117)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7828,
    "Minuman Kedelai (1401040117)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7829,
    "Minuman Kedelai (1401040117)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7830,
    "Minuman Kedelai Steril (1401040118)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    7831,
    "Minuman Kedelai Steril (1401040118)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7832,
    "Minuman Kedelai Steril (1401040118)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    7833,
    "Minuman Kedelai Steril (1401040118)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7834,
    "Minuman Kedelai Steril (1401040118)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7835,
    "Minuman Kedelai Steril (1401040118)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [7836, "Minuman Kola (1401040115)", "Kandungan (Brix)", "=14"],
  [
    7837,
    "Minuman Kola (1401040115)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7838,
    "Minuman Kola (1401040115)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7839,
    "Minuman Kola (1401040115)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7840,
    "Minuman Kola (1401040115)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7841,
    "Minuman Kola (1401040115)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7842,
    "Minuman Kola (1401040115)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7843,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    7844,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7845,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    7846,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7847,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7848,
    "Minuman Konsentrat Rasa ... (1401040303)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [7849, "Minuman Konsentrat Rasa ... (1401040303)", "Melanin"],
  [7850, "Minuman Kopi (1401040243)", "Kadar Kopi (%)", "", "=4"],
  [
    7851,
    "Minuman Kopi (1401040243)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7852,
    "Minuman Kopi (1401040243)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7853,
    "Minuman Kopi (1401040243)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7854,
    "Minuman Kopi (1401040243)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7855,
    "Minuman Kopi (1401040243)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7856,
    "Minuman Kopi (1401040243)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7857,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Kafein (ppm atau mg/kg) ",
    "",
    "=250",
  ],
  [
    7858,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Kadar Kopi (dihitung dari basis berat kering) (%) ",
    "",
    "=4",
  ],
  [
    7859,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7860,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7861,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7862,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    7863,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    7864,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7865,
    "Minuman Kopi (Steril Komersial) (1401040247)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7866,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7867,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7868,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7869,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7870,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7871,
    "Minuman Kopi Dalam Kemasan (1401040238)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [7872, "Minuman Kopi Dalam Kemasan (1401040238)", "Kafein"],
  [
    7873,
    "Minuman Kopi Dalam Kemasan (14010519)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    7874,
    "Minuman Kopi Dalam Kemasan (14010519)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    7875,
    "Minuman Kopi Dalam Kemasan (14010519)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    7876,
    "Minuman Kopi Dalam Kemasan (14010519)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    7877,
    "Minuman Kopi Dalam Kemasan (14010519)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [7878, "Minuman Kopi Dalam Kemasan (14010519)", "Kafein"],
  [
    7879,
    "Minuman Lidah Buaya (1401040227)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7880,
    "Minuman Lidah Buaya (1401040227)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7881,
    "Minuman Lidah Buaya (1401040227)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7882,
    "Minuman Lidah Buaya (1401040227)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7883,
    "Minuman Lidah Buaya (1401040227)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [7884, "Minuman Madu (1401040230)", "Arsen (mg/kg)", "=0.05"],
  [7885, "Minuman Madu (1401040230)", "Kadmium (mg/kg)", "=0.01"],
  [7886, "Minuman Madu (1401040230)", "Merkuri (mg/kg)", "=0.01"],
  [
    7887,
    "Minuman Madu (1401040230)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7888,
    "Minuman Madu (1401040230)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [7889, "Minuman Madu (1401040230)", "Timbal (mg/kg)", "=0.05"],
  [
    7890,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Kadar lemak susu (%) ",
    "",
    "=0.3",
  ],
  [
    7891,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7892,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7893,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7894,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7895,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7896,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    7897,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=0.78",
  ],
  [
    7898,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Kadar protein (%)",
    "",
    "=0.27",
  ],
  [
    7899,
    "Minuman Mengandung Susu (Cair) (Plain) (01010202)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    7900,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Kadar lemak susu setelah direkonstitusi (%) ",
    "",
    "=0.3",
  ],
  [
    7901,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7902,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7903,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7904,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7905,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7906,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    7907,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Total padatan susu bukan lemak setelah direkonstitusi (%)",
    "",
    "=1.2",
  ],
  [
    7908,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Kadar protein setelah direkonstitusi (%)",
    "",
    "=1",
  ],
  [
    7909,
    "Minuman Mengandung Susu (Serbuk) (01010210)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    7910,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7911,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    7912,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7913,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    7914,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    7915,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    7916,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Kadar lemak susu (%)",
  ],
  [7917, "", "", "=0.26"],
  [
    7918,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Kadar protein (%)",
  ],
  [7919, "", "", "=0.23"],
  [
    7920,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Total padatan susu bukan-lemak (%)",
  ],
  [7921, "", "", "=0.66"],
  [
    7922,
    "Minuman Mengandung Susu Berperisa/Rasa (01010404)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    7923,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7924,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7925,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7926,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    7927,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    7928,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    7929,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Kadar Lemak Susu (%)",
    "",
    "=2.6",
  ],
  [
    7930,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Kadar Air (%)",
    "=5",
  ],
  [
    7931,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Kadar protein dari padatan susu bukan lemak (%)",
    "",
    "=3.2",
  ],
  [
    7932,
    "Minuman Mengandung Susu Bubuk (Plain) (01050112)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    7933,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    7934,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    7935,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    7936,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    7937,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/Kg)",
    "=40",
  ],
  [
    7938,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    7939,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    7940,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Kadar air (%)",
    "=5.00",
  ],
  [
    7941,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Kadar protein (%)",
    "",
    "=1.10",
  ],
  [
    7942,
    "Minuman Mengandung Susu Bubuk Berperisa atau dengan (Rasa) (01010415)",
    "Aflatoksin M1 (mcg/Kg)",
    "=0.50",
  ],
  [
    7943,
    "Minuman Mengandung Susu Steril (01010206)",
    "Kadar lemak susu (%) ",
    "",
    "=0.3",
  ],
  [
    7944,
    "Minuman Mengandung Susu Steril (01010206)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7945,
    "Minuman Mengandung Susu Steril (01010206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7946,
    "Minuman Mengandung Susu Steril (01010206)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    7947,
    "Minuman Mengandung Susu Steril (01010206)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    7948,
    "Minuman Mengandung Susu Steril (01010206)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    7949,
    "Minuman Mengandung Susu Steril (01010206)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    7950,
    "Minuman Mengandung Susu Steril (01010206)",
    "Total padatan susu bukan lemak (%) ",
    "",
    "=1.2",
  ],
  [
    7951,
    "Minuman Mengandung Susu Steril (01010206)",
    "Kadar protein (%)",
    "",
    "=1",
  ],
  [
    7952,
    "Minuman Mengandung Susu Steril (01010206)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    7953,
    "Minuman Nata De Coco (1401040228)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7954,
    "Minuman Nata De Coco (1401040228)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7955,
    "Minuman Nata De Coco (1401040228)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7956,
    "Minuman Nata De Coco (1401040228)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7957,
    "Minuman Nata De Coco (1401040228)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7958,
    "Minuman Nata De Coco (1401040228)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7959,
    "Minuman Nata de Coco (Steril) (1401040234)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    7960,
    "Minuman Nata de Coco (Steril) (1401040234)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    7961,
    "Minuman Nata de Coco (Steril) (1401040234)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    7962,
    "Minuman Nata de Coco (Steril) (1401040234)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    7963,
    "Minuman Nata de Coco (Steril) (1401040234)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    7964,
    "Minuman Olahraga (Cair) (1393)",
    "Osmolalitas (mOsml/kg)",
    "=340",
  ],
  [
    7965,
    "Minuman Olahraga (Cair) (1393)",
    "Energi (kkal/L)",
    "",
    "=240",
  ],
  [7966, "Minuman Olahraga (Cair) (1393)", "Fruktosa (%)", "=3"],
  [
    7967,
    "Minuman Olahraga (Cair) (1393)",
    "Natrium (mg/L)",
    "=575",
    "=230",
  ],
  [7968, "Minuman Olahraga (Cair) (1393)", "Kalium (mg/L)", "=200"],
  [7969, "Minuman Olahraga (Cair) (1393)", "pH", "=8.5"],
  [
    7970,
    "Minuman Olahraga (Cair) (1393)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7971,
    "Minuman Olahraga (Cair) (1393)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7972,
    "Minuman Olahraga (Cair) (1393)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7973,
    "Minuman Olahraga (Cair) (1393)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7974,
    "Minuman Olahraga (Cair) (1393)",
    "Timah (Sn) Pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7975,
    "Minuman Olahraga (Cair) (1393)",
    "Timbal (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7976,
    "Minuman Olahraga (Cair) (1393)",
    "Osmolalitas (mOsml/kg)",
    "=340",
  ],
  [
    7977,
    "Minuman Olahraga (Cair) (1393)",
    "Energi (kkal/L)",
    "",
    "=240",
  ],
  [7978, "Minuman Olahraga (Cair) (1393)", "Fruktosa (%)", "=3"],
  [
    7979,
    "Minuman Olahraga (Cair) (1393)",
    "Natrium (mg/L)",
    "=575",
    "=230",
  ],
  [7980, "Minuman Olahraga (Cair) (1393)", "Kalium (mg/L)", "=200"],
  [7981, "Minuman Olahraga (Cair) (1393)", "pH", "=8.5"],
  [
    7982,
    "Minuman Olahraga (Padat) (1392)",
    "Osmolalitas (mOsml/kg)",
    "=340",
  ],
  [
    7983,
    "Minuman Olahraga (Padat) (1392)",
    "Energi (kkal/L)",
    "",
    "=240",
  ],
  [7984, "Minuman Olahraga (Padat) (1392)", "Fruktosa (%)", "=3"],
  [
    7985,
    "Minuman Olahraga (Padat) (1392)",
    "Natrium (mg/L)",
    "=575",
    "=230",
  ],
  [
    7986,
    "Minuman Olahraga (Padat) (1392)",
    "Kalium (mg/L)",
    "=200",
  ],
  [7987, "Minuman Olahraga (Padat) (1392)", "pH", "=8.5"],
  [
    7988,
    "Minuman Olahraga (Padat) (1392)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    7989,
    "Minuman Olahraga (Padat) (1392)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7990,
    "Minuman Olahraga (Padat) (1392)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    7991,
    "Minuman Olahraga (Padat) (1392)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    7992,
    "Minuman Olahraga (Padat) (1392)",
    "Timah (Sn) Pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    7993,
    "Minuman Olahraga (Padat) (1392)",
    "Timbal (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    7994,
    "Minuman Olahraga (Padat) (1392)",
    "Osmolalitas (mOsml/kg)",
    "=340",
  ],
  [
    7995,
    "Minuman Olahraga (Padat) (1392)",
    "Energi (kkal/L)",
    "",
    "=240",
  ],
  [7996, "Minuman Olahraga (Padat) (1392)", "Fruktosa (%)", "=3"],
  [
    7997,
    "Minuman Olahraga (Padat) (1392)",
    "Natrium (mg/L)",
    "=575",
    "=230",
  ],
  [
    7998,
    "Minuman Olahraga (Padat) (1392)",
    "Kalium (mg/L)",
    "=200",
  ],
  [7999, "Minuman Olahraga (Padat) (1392)", "pH", "=8.5"],
  [
    8000,
    "Minuman Rasa Buah (1401040205)",
    "Total sari buah (% b/v)",
    "<10",
  ],
  [
    8001,
    "Minuman Rasa Buah (1401040205)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8002,
    "Minuman Rasa Buah (1401040205)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8003,
    "Minuman Rasa Buah (1401040205)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8004,
    "Minuman Rasa Buah (1401040205)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    8005,
    "Minuman Rasa Buah (1401040205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8006,
    "Minuman Rasa Buah (1401040205)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8007,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Total sari buah (% b/v)",
    "<10",
  ],
  [
    8008,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    8009,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    8010,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    8011,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    8012,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8013,
    "Minuman Rasa Buah (Steril Komersial) (1401040233)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    8014,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8015,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8016,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8017,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    8018,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8019,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Susu (dihitung sebagai susu segar) (%)",
    "<10",
  ],
  [
    8020,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "lemak susu (%)",
    "<0.3",
  ],
  [
    8021,
    "Minuman Rasa Susu (Cair) (140104A1)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8022,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Lemak susu (%)",
    "<0.3",
  ],
  [
    8023,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8024,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8025,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8026,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    8027,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    8028,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8029,
    "Minuman Rasa Susu (Cair) (Berkarbonat) (1401040120)",
    "Kadar CO2 (mg/L)",
    "=5890",
  ],
  [
    8030,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Kadar Lemak Susu (%)",
    "<0.3",
  ],
  [
    8031,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8032,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8033,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8034,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng ",
    "=100",
  ],
  [
    8035,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8036,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8037,
    "Minuman Rasa Susu (Cair) (Tidak Berkarbonat) (1401040248)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8038,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Susu (dihitung sebagai susu segar) (%)",
    "<10",
  ],
  [
    8039,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "lemak susu (%)",
    "<0.3",
  ],
  [
    8040,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    8041,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    8042,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    8043,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    8044,
    "Minuman Rasa Susu (Serbuk) (140104A4)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    8045,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Susu (dihitung sebagai susu segar) (%) ",
    "<10",
  ],
  [
    8046,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "lemak susu (%) ",
    "<0.3",
  ],
  [
    8047,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8048,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8049,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8050,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg) ",
    "=100",
  ],
  [
    8051,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Timah pangan olahan yang tidak dikemas dalam kaleng (Sn) (mg/kg) ",
    "=40",
  ],
  [
    8052,
    "Minuman Rasa Susu (Serbuk) (Tidak Berkarbonat) (1401040250)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8053,
    "Minuman Ringan (Plain) (1401040252)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8054,
    "Minuman Ringan (Plain) (1401040252)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8055,
    "Minuman Ringan (Plain) (1401040252)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8056,
    "Minuman Ringan (Plain) (1401040252)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8057,
    "Minuman Ringan (Plain) (1401040252)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8058,
    "Minuman Ringan (Plain) (1401040252)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8059,
    "Minuman Ringan Beralkohol (14020701)",
    "Kadar etanol (%)",
    "=1",
  ],
  [
    8060,
    "Minuman Ringan Beralkohol (14020701)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    8061,
    "Minuman Ringan Beralkohol (14020701)",
    "Arsen (mg/kg)",
    "=0.1",
  ],
  [
    8062,
    "Minuman Ringan Beralkohol (14020701)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    8063,
    "Minuman Ringan Beralkohol (14020701)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    8064,
    "Minuman Ringan Beralkohol (14020701)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    8065,
    "Minuman Ringan Beralkohol (14020701)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8066,
    "Minuman Ringan Beralkohol (14020701)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    8067,
    "Minuman Sari Buah (1401040204)",
    "Total sari buah (% b/v) ",
    "",
    "=35",
  ],
  [
    8068,
    "Minuman Sari Buah (1401040204)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8069,
    "Minuman Sari Buah (1401040204)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8070,
    "Minuman Sari Buah (1401040204)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8071,
    "Minuman Sari Buah (1401040204)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    8072,
    "Minuman Sari Buah (1401040204)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8073,
    "Minuman Sari Buah (1401040204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8074,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Total sari buah (% b/v)",
    "",
    "=35",
  ],
  [
    8075,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    8076,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    8077,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    8078,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    8079,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8080,
    "Minuman Sari Buah (Steril Komersial) (1401040231)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [
    8081,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Total sari buah (% b/v)",
    "",
    "=35",
  ],
  [
    8082,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8083,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8084,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    8085,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    8086,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    8087,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8088,
    "Minuman Sari Buah Berkarbonat (1401040119)",
    "Kadar CO2 (mg/L)",
    "=5890",
  ],
  [
    8089,
    "Minuman Sari Kacang Hijau (14010529)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    8090,
    "Minuman Sari Kacang Hijau (14010529)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8091,
    "Minuman Sari Kacang Hijau (14010529)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    8092,
    "Minuman Sari Kacang Hijau (14010529)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    8093,
    "Minuman Sari Kacang Hijau (14010529)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8094,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Arsen (ppm atau mg/kg)",
    "=1",
  ],
  [
    8095,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Kadmium (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8096,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Merkuri (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8097,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8098,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8099,
    "Minuman Sari Kacang Hijau (Kemasan Tetrapack) (14010549)",
    "Timbal (ppm atau mg/kg)",
    "=2",
  ],
  [
    8100,
    "Minuman Serbuk (14010537)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=1",
  ],
  [
    8101,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    8102,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    8103,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    8104,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8105,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Timah (Sn) (ppm atau mg/kg) Pangan olahan yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    8106,
    "Minuman Serbuk Berperisa (Berkarbonat) (1401040305)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    8107,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    8108,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    8109,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    8110,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8111,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Timah (Sn) (ppm atau mg/kg) Pangan olahan yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8112,
    "Minuman Serbuk Berperisa (Tidak Berkarbonat) (1401040306)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    8113,
    "Minuman Serbuk Biji Salak (14010572)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    8114,
    "Minuman Serbuk Biji Salak (14010572)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8115,
    "Minuman Serbuk Biji Salak (14010572)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8116,
    "Minuman Serbuk Biji Salak (14010572)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8117,
    "Minuman Serbuk Biji Salak (14010572)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    8118,
    "Minuman Serbuk Biji Salak (14010572)",
    "Kadar Air (%)",
    "=7",
  ],
  [
    8119,
    "Minuman Serbuk Kopi (14010532)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    8120,
    "Minuman Serbuk Kopi (14010532)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8121,
    "Minuman Serbuk Kopi (14010532)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8122,
    "Minuman Serbuk Kopi (14010532)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    8123,
    "Minuman Serbuk Kopi (14010532)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8124,
    "Minuman Serbuk Kopi (14010532)",
    "Kandungan kopi dihitung dari basis berat kering (%)",
    "",
    "=4",
  ],
  [
    8125,
    "Minuman Serbuk Kopi (14010532)",
    "Kadar kafein (mg/kg)",
    "",
    "=1500",
  ],
  [
    8126,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Kandungan kopi dihitung dari basis berat kering (%)",
    "",
    "=4",
  ],
  [
    8127,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Kadar kafein (mg/kg)",
    "=6000",
    "=1500",
  ],
  [
    8128,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8129,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    8130,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    8131,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8132,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8133,
    "Minuman Serbuk Kopi Gula (14010555)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    8134,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Kadar kafein (mg/kg) ",
    "",
    "=1500",
  ],
  [
    8135,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Kadar lemak (%b/b) ",
    "",
    "=6",
  ],
  [
    8136,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    8137,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8138,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    8139,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8140,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Arsen (mg/kg)",
    "=1",
  ],
  [
    8141,
    "Minuman Serbuk Kopi Krimer (14010554)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8142,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Kadar kafein (mg/kg)",
    "",
    "=1500",
  ],
  [
    8143,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Kadar Protein (N x 6,38) (% b/b)",
    "",
    "=2",
  ],
  [
    8144,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Arsen (mg/kg)",
    "=1",
  ],
  [
    8145,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8146,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    8147,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    8148,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8149,
    "Minuman Serbuk Kopi Susu (14010553)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8150,
    "Minuman Serbuk Teh (14010567)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    8151,
    "Minuman Serbuk Teh (14010567)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8152,
    "Minuman Serbuk Teh (14010567)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8153,
    "Minuman Serbuk Teh (14010567)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8154,
    "Minuman Serbuk Teh (14010567)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8155,
    "Minuman Serbuk Teh (14010567)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [8156, "Minuman Serealia (14010565)", "Arsen (As) (ppm)", "=1"],
  [
    8157,
    "Minuman Serealia (14010565)",
    "Kadmium (Cd) (ppm) ",
    "=0.2",
  ],
  [
    8158,
    "Minuman Serealia (14010565)",
    "Merkuri (Hg) (ppm) ",
    "=0.03",
  ],
  [
    8159,
    "Minuman Serealia (14010565)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm) ",
    "=40",
  ],
  [8160, "Minuman Serealia (14010565)", "Timbal (Pb) (ppm) ", "=2"],
  [8161, "Minuman Spirit (14020601)", "Kadar etanol (%)", "", "=15"],
  [
    8162,
    "Minuman Spirit (14020601)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [8163, "Minuman Spirit (14020601)", "Arsen (mg/kg)", "=0.1"],
  [8164, "Minuman Spirit (14020601)", "Kadmium (mg/kg)", "=0.2"],
  [8165, "Minuman Spirit (14020601)", "Merkuri (mg/kg)", "=0.03"],
  [
    8166,
    "Minuman Spirit (14020601)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    8167,
    "Minuman Spirit (14020601)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [8168, "Minuman Spirit (14020601)", "Timbal (mg/kg)", "=0.2"],
  [
    8169,
    "Minuman Susu Berperisa (01010201)",
    "Kadar lemak susu (%)",
    "<2",
    "=1.2",
  ],
  [
    8170,
    "Minuman Susu Berperisa (01010201)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=4.4",
  ],
  [
    8171,
    "Minuman Susu Berperisa (01010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8172,
    "Minuman Susu Berperisa (01010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8173,
    "Minuman Susu Berperisa (01010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8174,
    "Minuman Susu Berperisa (01010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8175,
    "Minuman Susu Berperisa (01010201)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8176,
    "Minuman Susu Berperisa (01010201)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8177,
    "Minuman Susu Berperisa (01010201)",
    "Kadar protein (%)",
    "",
    "=1",
  ],
  [
    8178,
    "Minuman Susu Berperisa (01010201)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    8179,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    8180,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    8181,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    8182,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    8183,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    8184,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    8185,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Kadar lemak susu tidak kurang (%)",
  ],
  [8186, "", "=2", "=1.2"],
  [
    8187,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Total padatan susu bukan-lemak (%)",
  ],
  [8188, "", "", "=4.4"],
  [
    8189,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Kadar protein (%)",
  ],
  [8190, "", "", "=1"],
  [
    8191,
    "Minuman Susu Berperisa/Rasa (01010403)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    8192,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Kadar lemak susu (%)",
    "<2",
    "=1.2",
  ],
  [
    8193,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Total Padatan Susu Bukan Lemak (%)",
    "",
    "=4.4",
  ],
  [
    8194,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8195,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8196,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8197,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8198,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8199,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8200,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Kadar Protein (%)",
    "",
    "=1",
  ],
  [
    8201,
    "Minuman Susu Evaporasi (Plain dan Berperisa) (01010209)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    8202,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8203,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8204,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8205,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8206,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8207,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8208,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=2.6",
  ],
  [
    8209,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Kadar Protein Susu (%)",
    "",
    "=0.92",
  ],
  [
    8210,
    "Minuman Susu Fermentasi (Plain) (01010203)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8211,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    8212,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    8213,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    8214,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    8215,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    8216,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    8217,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Total padatan susu bukan-lemak (%)",
  ],
  [8218, "", "", "=2.6"],
  [
    8219,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Kadar protein susu (%)",
  ],
  [8220, "", "", "=0.92"],
  [
    8221,
    "Minuman Susu Fermentasi Berperisa/Rasa (01010405)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    8222,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Kadar lemak susu (%)",
    "<2",
    "=1.2",
  ],
  [
    8223,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=4.4",
  ],
  [
    8224,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8225,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8226,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8227,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8228,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8229,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8230,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Kadar protein (%)",
    "",
    "=1",
  ],
  [
    8231,
    "Minuman Susu Pasteurisasi (Plain) (01010208)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    8232,
    "Minuman Susu Steril (Plain) (01010207)",
    "Kadar lemak susu (%)",
    "<2",
    "=1.2",
  ],
  [
    8233,
    "Minuman Susu Steril (Plain) (01010207)",
    "Total Padatan Susu Bukan Lemak (%)",
    "",
    "=4.4",
  ],
  [
    8234,
    "Minuman Susu Steril (Plain) (01010207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8235,
    "Minuman Susu Steril (Plain) (01010207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8236,
    "Minuman Susu Steril (Plain) (01010207)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8237,
    "Minuman Susu Steril (Plain) (01010207)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8238,
    "Minuman Susu Steril (Plain) (01010207)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8239,
    "Minuman Susu Steril (Plain) (01010207)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8240,
    "Minuman Susu Steril (Plain) (01010207)",
    "Kadar protein (%)",
    "",
    "=1",
  ],
  [
    8241,
    "Minuman Susu Steril (Plain) (01010207)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    8242,
    "Minuman Teh (1401040244)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8243,
    "Minuman Teh (1401040244)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8244,
    "Minuman Teh (1401040244)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8245,
    "Minuman Teh (1401040244)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8246,
    "Minuman Teh (1401040244)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8247,
    "Minuman Teh (1401040244)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8248,
    "Minuman Teh (1401040244)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8249,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Arsen (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8250,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Kadmium (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8251,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Merkuri (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8252,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    8253,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8254,
    "Minuman Teh Dalam Kemasan (1401040239)",
    "Timbal (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8255,
    "Minuman Teh Dalam Kemasan (14010512)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    8256,
    "Minuman Teh Dalam Kemasan (14010512)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8257,
    "Minuman Teh Dalam Kemasan (14010512)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    8258,
    "Minuman Teh Dalam Kemasan (14010512)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    8259,
    "Minuman Teh Dalam Kemasan (14010512)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8260,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Arsen (As) (mg/kg)",
    "=0.05",
  ],
  [
    8261,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Kadmium (Cd) (mg/kg)",
    "=0.01",
  ],
  [
    8262,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Merkuri (Hg) (mg/kg)",
    "=0.01",
  ],
  [
    8263,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8264,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Timbal (Pb) (mg/kg)",
    "=0.05",
  ],
  [
    8265,
    "Minuman Teh dalam Kemasan (Steril Komersial) (1401040240)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    8266,
    "Minuman Teh dalam Kemasan Tetrapak (14010546)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    8267,
    "Minuman Teh dalam Kemasan Tetrapak (14010546)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    8268,
    "Minuman Teh dalam Kemasan Tetrapak (14010546)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8269,
    "Minuman Teh dalam Kemasan Tetrapak (14010546)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    8270,
    "Minuman Teh dalam Kemasan Tetrapak (14010546)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    8271,
    "Minuman Tradisional (Cair) (14010551)",
    "Arsen (mg/kg) ",
    "=1",
  ],
  [
    8272,
    "Minuman Tradisional (Cair) (14010551)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    8273,
    "Minuman Tradisional (Cair) (14010551)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8274,
    "Minuman Tradisional (Cair) (14010551)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    8275,
    "Minuman Tradisional (Cair) (14010551)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    8276,
    "Minuman Tradisional (Cair) (14010551)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8277,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    8278,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8279,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8280,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8281,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8282,
    "Minuman Tradisional (Seduhan) (14010562)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    8283,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8284,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8285,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8286,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    8287,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    8288,
    "Minuman Tradisional (Serbuk) (14010561)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    8289,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    8290,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8291,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    8292,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8293,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8294,
    "Minuman Tradisional (Steril Komersial) (14010563)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    8295,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8296,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8297,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8298,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8299,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng - siap konsumsi",
    "=100",
  ],
  [
    8300,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8301,
    "Minuman untuk Ibu Hamil Bubuk (13050106)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/kg)",
    "=0.03",
  ],
  [
    8302,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8303,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8304,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8305,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8306,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=100",
  ],
  [
    8307,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8308,
    "Minuman untuk Ibu Hamil Pasteurisasi (13050101)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/l)",
    "=0.03",
  ],
  [
    8309,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8310,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8311,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8312,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8313,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=100",
  ],
  [
    8314,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8315,
    "Minuman untuk Ibu Hamil Sterilisasi (13050102)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/l)",
    "=0.03",
  ],
  [
    8316,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8317,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8318,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8319,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8320,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng - siap konsumsi",
    "=100",
  ],
  [
    8321,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8322,
    "Minuman untuk Ibu Menyusui Bubuk (13050103)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/l)",
    "=0.03",
  ],
  [
    8323,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8324,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8325,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8326,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8327,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=100",
  ],
  [
    8328,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8329,
    "Minuman untuk Ibu Menyusui Pasteurisasi (13050104)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/l)",
    "=0.03",
  ],
  [
    8330,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Arsen (As) (mg/l) ",
    "=0.02",
  ],
  [
    8331,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Kadmium (Cd) (mg/l) ",
    "=0.01",
  ],
  [
    8332,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Merkuri (Hg) (mg/l)",
    "=0.01",
  ],
  [
    8333,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Timbal (Pb) (mg/l) ",
    "=0.02",
  ],
  [
    8334,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Timah (Sn) (mg/l) yang dikemas dalam kaleng",
    "=100",
  ],
  [
    8335,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Timah (Sn) (mg/l) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    8336,
    "Minuman untuk Ibu Menyusui Sterilisasi (13050105)",
    "Aflatoksin M1 jika berbasis susu (ppb atau mcg/l)",
    "=0.03",
  ],
  [
    8337,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8338,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8339,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8340,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    8341,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8342,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    8343,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Total padatan susu bukan lemak (%) ",
    "",
    "=2.6",
  ],
  [
    8344,
    "Minuman Yogurt (Plain dan Berperisa) (01010204)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    8345,
    "Minyak Biji Bunga Matahari (02010231)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=194",
    "=188",
  ],
  [
    8346,
    "Minyak Biji Bunga Matahari (02010231)",
    "Bilangan Iod (Wijs)",
    "=141",
    "=118",
  ],
  [
    8347,
    "Minyak Biji Bunga Matahari (02010231)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8348,
    "Minyak Biji Bunga Matahari (02010231)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8349,
    "Minyak Biji Bunga Matahari (02010231)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8350,
    "Minyak Biji Bunga Matahari (02010231)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8351,
    "Minyak Biji Bunga Matahari (02010231)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8352,
    "Minyak Biji Bunga Matahari (02010231)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8353,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=198",
    "=189",
  ],
  [
    8354,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Bilangan Iod (Wijs)",
    "=115",
    "=96",
  ],
  [
    8355,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8356,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8357,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8358,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8359,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8360,
    "Minyak Biji Kapas (Refined Bleached Deodorized Cottonseed Oil) (02010233)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8361,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    8362,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    8363,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    8364,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    8365,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    8366,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    8367,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Bilangan asam (acid value) untuk Lemak dan minyak yang dimurnikan (refined fats and oils) (mg KOH/g lemak atau minyak)",
    "=0.6",
  ],
  [
    8368,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Bilangan asam (acid value) untuk Lemak dan minyak cold pressed (cold pressed fats and oils) (mg KOH/g lemak atau minyak)",
    "=4",
  ],
  [
    8369,
    "Minyak Biji Rami/Flaxseed Oil/Flax Oil/Linseed Oil (02010249)",
    "Bilangan peroksida (peroxide value) untuk Lemak dan minyak lainnya (Other fats and oils) (mek O2/kg minyak)",
    "=10",
  ],
  [
    8370,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8371,
    "Deodorized Rice Brand Oil) (02010232)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=189",
    "=181",
  ],
  [
    8372,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8373,
    "Deodorized Rice Brand Oil) (02010232)",
    "Bilangan Iod (Wijs)",
    "=108",
    "=92",
  ],
  [
    8374,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8375,
    "Deodorized Rice Brand Oil) (02010232)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8376,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8377,
    "Deodorized Rice Brand Oil) (02010232)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8378,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8379,
    "Deodorized Rice Brand Oil) (02010232)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8380,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8381,
    "Deodorized Rice Brand Oil) (02010232)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8382,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8383,
    "Deodorized Rice Brand Oil) (02010232)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8384,
    "Minyak Dedak atau Minyak Bekatul atau Minyak Katul (Refined Bleached",
  ],
  [
    8385,
    "Deodorized Rice Brand Oil) (02010232)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8386,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Kadar air (%)",
    "=0.15",
  ],
  [
    8387,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Kadar asam lemak bebas (%)",
    "=0.3",
  ],
  [
    8388,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8389,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8390,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8391,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8392,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8393,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    8394,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Kadar asam lemak linolenat (%)",
    "=2",
  ],
  [
    8395,
    "Minyak Goreng (Frying oil atau frying fat) (02010204)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8396,
    "Minyak Goreng (Frying oil) (02010244)",
    "Kadar air (%)",
    "=0.15",
  ],
  [
    8397,
    "Minyak Goreng (Frying oil) (02010244)",
    "Bilangan asam (mg KOH/g)",
    "=0.6",
  ],
  [
    8398,
    "Minyak Goreng (Frying oil) (02010244)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8399,
    "Minyak Goreng (Frying oil) (02010244)",
    "Kadar asam lemak linolenat (%)",
    "=2",
  ],
  [
    8400,
    "Minyak Goreng (Frying oil) (02010244)",
    "Asam lemak trans",
  ],
  [
    8401,
    "Minyak Goreng (Frying oil) (02010244)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8402,
    "Minyak Goreng (Frying oil) (02010244)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8403,
    "Minyak Goreng (Frying oil) (02010244)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8404,
    "Minyak Goreng (Frying oil) (02010244)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8405,
    "Minyak Goreng (Frying oil) (02010244)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8406,
    "Minyak Goreng (Frying oil) (02010244)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8407,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Kadar air (%)",
    "=0.1",
  ],
  [
    8408,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Kadar asam lemak bebas sebagai asam palmitat (%)",
    "=0.3",
  ],
  [
    8409,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8410,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Kadar asam lemak trans",
  ],
  [
    8411,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8412,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8413,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8414,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8415,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8416,
    "Minyak Goreng Padat (Frying Fat) (02010241)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8417,
    "Minyak Goreng Sawit (02010237)",
    "Vitamin A (IU/g)",
    "",
    "=20",
  ],
  [
    8418,
    "Minyak Goreng Sawit (02010237)",
    "Kadar air dan bahan menguap (b/b) (%)",
    "=0.1",
  ],
  [
    8419,
    "Minyak Goreng Sawit (02010237)",
    "Asam lemak bebas (dihitung sebagai asam palmitat) (%)",
    "=0.3",
  ],
  [
    8420,
    "Minyak Goreng Sawit (02010237)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [8421, "Minyak Goreng Sawit (02010237)", "Minyak pelikan"],
  [
    8422,
    "Minyak Goreng Sawit (02010237)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    8423,
    "Minyak Goreng Sawit (02010237)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    8424,
    "Minyak Goreng Sawit (02010237)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    8425,
    "Minyak Goreng Sawit (02010237)",
    "Timah dalam kemasan kaleng (Sn) (mg/kg)",
    "=250",
  ],
  [
    8426,
    "Minyak Goreng Sawit (02010237)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    8427,
    "Minyak Goreng Sawit (02010237)",
    "Cemaran arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    8428,
    "Minyak Ikan (02010309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8429,
    "Minyak Ikan (02010309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8430,
    "Minyak Ikan (02010309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8431,
    "Minyak Ikan (02010309)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8432,
    "Minyak Ikan (02010309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8433,
    "Minyak Ikan (02010309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8434,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=195",
    "=187",
  ],
  [
    8435,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Bilangan Iod (Wijs)",
    "=135",
    "=107",
  ],
  [
    8436,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8437,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8438,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8439,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8440,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8441,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8442,
    "Minyak Jagung (Refined Bleached Deodorized Corn Oil) (02010225)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8443,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8444,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=265",
    "=248",
  ],
  [
    8445,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8446,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Bilangan Iod (Wijs)",
    "=107",
    "=83",
  ],
  [
    8447,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8448,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8449,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8450,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8451,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8452,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8453,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8454,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8455,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8456,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8457,
    "Minyak Kacang Tanah (Refined Bleached Deodorized Peanut Oil/",
  ],
  [
    8458,
    "Refined Bleached Deodorized Groundnut Oil) (02010224)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8459,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=181",
    "=168",
  ],
  [
    8460,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Bilangan Iod (Wijs)",
    "=120",
    "=94",
  ],
  [
    8461,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8462,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8463,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8464,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8465,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8466,
    "Minyak Kanola (Refined Bleached Deodorized Rapeseed Oil) (02010234)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8467,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=195",
    "=189",
  ],
  [
    8468,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Bilangan Iod (Wijs)",
    "=139",
    "=124",
  ],
  [
    8469,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8470,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8471,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8472,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8473,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8474,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8475,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8476,
    "Minyak Kedelai (Refined Bleached Deodorized Soyabean Oil) (02010227)",
    "Asam lemak bebas dihitung sebagai asam oleat (%)",
    "=0.15",
  ],
  [
    8477,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=265",
    "=248",
  ],
  [
    8478,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Bilangan Iod (Wijs)",
    "=13",
    "=7",
  ],
  [
    8479,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8480,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8481,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8482,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8483,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8484,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8485,
    "Minyak Kelapa (Refined Bleached Deodorized Coconut Oil ) (02010222)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8486,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=209",
    "=190",
  ],
  [
    8487,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Bilangan Iod (Wijs)",
    "=55",
    "=50",
  ],
  [
    8488,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Titik Leleh (\xB0C)",
    "=39",
    "=33",
  ],
  [
    8489,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8490,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8491,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8492,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8493,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8494,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8495,
    "Minyak Kelapa Sawit (Refined Bleached Deodorized Palm Oil/RBDPO) (02010214)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8496,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=202",
    "=184",
  ],
  [
    8497,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Bilangan Iod (Wijs)",
    "=167",
    "=136",
  ],
  [
    8498,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8499,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8500,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8501,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8502,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8503,
    "Minyak Kemiri (Refined Bleached Deodorized Candlenut/Lumbang Oil) (02010226)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8504,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Kadar air (%)",
    "=0.15",
  ],
  [
    8505,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Kadar asam lemak bebas (%)",
    "=0.3",
  ],
  [
    8506,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8507,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8508,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8509,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8510,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8511,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8512,
    "Minyak Masak atau Minyak Sayur (Cooking Oil) (02010205)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    8513,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Titik Leleh/ Lebur (\xB0C)",
    "=30",
  ],
  [
    8514,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Bilangan Iod (Wijs)",
    "",
    "=56",
  ],
  [
    8515,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=202",
    "=194",
  ],
  [
    8516,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Bilangan Peroksida (mek O2/kg)",
    "=10",
  ],
  [
    8517,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8518,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8519,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8520,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8521,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8522,
    "Minyak Olein Kelapa Sawit (Refined Bleached Deodorized Palm Olein) (02010218)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8523,
    "Minyak Safflower (02010230)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=198",
    "=186",
  ],
  [
    8524,
    "Minyak Safflower (02010230)",
    "Bilangan Iod (Wijs)",
    "=150",
    "=135",
  ],
  [
    8525,
    "Minyak Safflower (02010230)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8526,
    "Minyak Safflower (02010230)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8527,
    "Minyak Safflower (02010230)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8528,
    "Minyak Safflower (02010230)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8529,
    "Minyak Safflower (02010230)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8530,
    "Minyak Safflower (02010230)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8531,
    "Minyak Salad (Salad Oil) (02010206)",
    "Kadar air (%)",
    "=0.15",
  ],
  [
    8532,
    "Minyak Salad (Salad Oil) (02010206)",
    "Kadar asam lemak bebas (%)",
    "=0.2",
  ],
  [
    8533,
    "Minyak Salad (Salad Oil) (02010206)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8534,
    "Minyak Salad (Salad Oil) (02010206)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8535,
    "Minyak Salad (Salad Oil) (02010206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8536,
    "Minyak Salad (Salad Oil) (02010206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8537,
    "Minyak Salad (Salad Oil) (02010206)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8538,
    "Minyak Salad (Salad Oil) (02010206)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    8539,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Titik Leleh/ Lebur (\xB0C)",
    "",
    "=44",
  ],
  [
    8540,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Bilangan Iod (Wijs)",
    "=48",
  ],
  [
    8541,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8542,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8543,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8544,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8545,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8546,
    "Minyak Stearin Kelapa Sawit (Refined Bleached Deodorized Palm Stearin) (02010219)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8547,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=195",
    "=187",
  ],
  [
    8548,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Bilangan Iod (Wijs)",
    "=120",
    "=104",
  ],
  [
    8549,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8550,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8551,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8552,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8553,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8554,
    "Minyak Wijen (Sesame Oil) (02010228)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8555,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=196",
    "=184",
  ],
  [
    8556,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Bilangan Iod (Wijs)",
    "=94",
    "=74",
  ],
  [
    8557,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8558,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8559,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8560,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8561,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8562,
    "Minyak Zaitun (Refined Bleached Deodorized Olive Oil) (02010229)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [8563, "Miso (12090103)", "Arsen (As) (mg/kg)", "=0.15"],
  [8564, "Miso (12090103)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [8565, "Miso (12090103)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [8566, "Miso (12090103)", "Timah (Sn) (mg/kg)", "=40"],
  [8567, "Miso (12090103)", "Timbal (Pb) (mg/kg)", "=1"],
  [8568, "Mitsumame (0401020908)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    8569,
    "Mitsumame (0401020908)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    8570,
    "Mitsumame (0401020908)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8571,
    "Mitsumame (0401020908)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    8572,
    "Mitsumame (0401020908)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [8573, "Mitsumame (0401020908)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    8574,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    8575,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    8576,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    8577,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8578,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8579,
    "Moluska (Kerang, Bekicot, Siput Laut\x{2026}.) dalam Kaleng (090410)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [8580, "Mousse Cokelat (010707)", "Arsen (As) (mg/kg) ", "=0.1"],
  [
    8581,
    "Mousse Cokelat (010707)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    8582,
    "Mousse Cokelat (010707)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    8583,
    "Mousse Cokelat (010707)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    8584,
    "Mousse Cokelat (010707)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [8585, "Mousse Cokelat (010707)", "Timbal (Pb) (mg/kg)", "=0.02"],
  [
    8586,
    "Mousse Cokelat (010707)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    8587,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8588,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8589,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8590,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8591,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8592,
    "MP ASI Kudapan usia 6 sampai 12 bulan Cair (1318)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8593,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8594,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8595,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8596,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8597,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8598,
    "MP ASI Kudapan usia 6 sampai 12 bulan Padat (1317)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8599,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8600,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8601,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8602,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8603,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8604,
    "MP ASI Kudapan usia sampai 2 tahun Cair (1320)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8605,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8606,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8607,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8608,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8609,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8610,
    "MP ASI Kudapan usia sampai 2 tahun Padat (1319)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8611,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8612,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8613,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8614,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8615,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8616,
    "MP ASI Pokok usia 6 sampai 12 bulan Cair (1314)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8617,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8618,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8619,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8620,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8621,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8622,
    "MP ASI Pokok usia 6 sampai 12 bulan Padat (1313)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8623,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8624,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8625,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8626,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8627,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8628,
    "MP ASI Pokok usia sampai 2 tahun Cair (1316)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8629,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8630,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    8631,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8632,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8633,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Timah (Sn) (ppm mg/kg)",
    "=40",
  ],
  [
    8634,
    "MP ASI Pokok usia sampai 2 tahun Padat (1315)",
    "Aflatoksin B1 (hanya berlaku untuk produk berbasis serealia) (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    8635,
    "Muffin Amerika (American Muffin) (07020206)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    8636,
    "Muffin Amerika (American Muffin) (07020206)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8637,
    "Muffin Amerika (American Muffin) (07020206)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    8638,
    "Muffin Amerika (American Muffin) (07020206)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    8639,
    "Muffin Amerika (American Muffin) (07020206)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    8640,
    "Muffin Inggris (English Muffin) (07010304)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    8641,
    "Muffin Inggris (English Muffin) (07010304)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    8642,
    "Muffin Inggris (English Muffin) (07010304)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    8643,
    "Muffin Inggris (English Muffin) (07010304)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    8644,
    "Muffin Inggris (English Muffin) (07010304)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [8645, "Mustard (1204)", "Arsen (As) (mg/kg)", "=0.15"],
  [8646, "Mustard (1204)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [8647, "Mustard (1204)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [8648, "Mustard (1204)", "Timah (Sn) (mg/kg)", "=40"],
  [8649, "Mustard (1204)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    8650,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Bilangan Penyabunan (mg KOH/g)",
    "=184",
    "=170",
  ],
  [
    8651,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Bilangan Iod (Wijs)",
    "=125",
    "=92",
  ],
  [
    8652,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8653,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8654,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8655,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8656,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8657,
    "Mustardseed Oil (Refined Bleached Deodorized Mustardseed Oil) (02010235)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [8658, "Naget Ayam (08030302)", "Kadar protein (%)", "", "=12"],
  [8659, "Naget Ayam (08030302)", "Kadar lemak (%)", "=20"],
  [
    8660,
    "Naget Ayam (08030302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8661,
    "Naget Ayam (08030302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8662,
    "Naget Ayam (08030302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8663,
    "Naget Ayam (08030302)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8664,
    "Naget Ayam (08030302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8665,
    "Naget Ayam (08030302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8666,
    "Naget Ayam (08030321)",
    "Kandungan Daging Ayam (%)",
    "",
    "=35",
  ],
  [8667, "Naget Ayam (08030321)", "Kadar protein (%)", "", "=12"],
  [8668, "Naget Ayam (08030321)", "Kadar lemak (%)", "=20"],
  [
    8669,
    "Naget Ayam (08030321)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8670,
    "Naget Ayam (08030321)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8671,
    "Naget Ayam (08030321)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8672,
    "Naget Ayam (08030321)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8673,
    "Naget Ayam (08030321)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8674,
    "Naget Ayam (08030321)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8675,
    "Naget Ayam Kombinasi (08030306)",
    "Kandungan daging ayam (%)",
    "",
    "=22.5",
  ],
  [
    8676,
    "Naget Ayam Kombinasi (08030306)",
    "Kadar protein (%)",
    "",
    "=9",
  ],
  [
    8677,
    "Naget Ayam Kombinasi (08030306)",
    "Kadar lemak (%)",
    "=20",
  ],
  [
    8678,
    "Naget Ayam Kombinasi (08030306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8679,
    "Naget Ayam Kombinasi (08030306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8680,
    "Naget Ayam Kombinasi (08030306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8681,
    "Naget Ayam Kombinasi (08030306)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8682,
    "Naget Ayam Kombinasi (08030306)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8683,
    "Naget Ayam Kombinasi (08030306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8684,
    "Naget Daging (08030303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8685,
    "Naget Daging (08030303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8686,
    "Naget Daging (08030303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8687,
    "Naget Daging (08030303)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8688,
    "Naget Daging (08030303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8689,
    "Naget Daging (08030303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8690,
    "Naget Daging Sapi (08030322)",
    "Kandungan daging sapi (%)",
    "",
    "=35",
  ],
  [
    8691,
    "Naget Daging Sapi (08030322)",
    "Kadar protein (%)",
    "",
    "=12",
  ],
  [8692, "Naget Daging Sapi (08030322)", "Kadar lemak (%)", "=20"],
  [
    8693,
    "Naget Daging Sapi (08030322)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8694,
    "Naget Daging Sapi (08030322)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8695,
    "Naget Daging Sapi (08030322)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8696,
    "Naget Daging Sapi (08030322)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8697,
    "Naget Daging Sapi (08030322)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8698,
    "Naget Daging Sapi (08030322)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8699,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Kandungan daging sapi (%)",
    "",
    "=15",
  ],
  [
    8700,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Kadar protein (%)",
    "",
    "=9",
  ],
  [
    8701,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Kadar lemak (%)",
    "=20",
  ],
  [
    8702,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8703,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8704,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8705,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8706,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8707,
    "Naget Daging Sapi Kombinasi (08030307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8708,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8709,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8710,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8711,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8712,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8713,
    "Naget Ikan/Udang/Cumi/Kerang Beku (09020204)",
    "Lumatan daging ikan/udang/cumi/kerang dan atau surimi (%)",
    "",
    "=30",
  ],
  [8714, "Naget Udang (09020205)", "As (ppm atau mg/kg)", "=0.25"],
  [8715, "Naget Udang (09020205)", "Cd (ppm atau mg/kg)", "=0.1"],
  [8716, "Naget Udang (09020205)", "Hg (ppm atau mg/kg)", "=0.5"],
  [
    8717,
    "Naget Udang (09020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [8718, "Naget Udang (09020205)", "Pb (ppm atau mg/kg)", "=0.2"],
  [
    8719,
    "Naget Udang (09020205)",
    "Lumatan daging Udang (%)",
    "",
    "=30",
  ],
  [8720, "Namagashi (0402020610)", "Arsen (As) (mg/kg)", "=0.15"],
  [8721, "Namagashi (0402020610)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [8722, "Namagashi (0402020610)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    8723,
    "Namagashi (0402020610)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8724,
    "Namagashi (0402020610)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [8725, "Namagashi (0402020610)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [8726, "Nasi Beku (06070101)", "Arsen (As) (mg/kg)", "=0.1"],
  [8727, "Nasi Beku (06070101)", "Kadmium (Cd)(mg/kg)", "=0.05"],
  [8728, "Nasi Beku (06070101)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [8729, "Nasi Beku (06070101)", "Timah (Sn) (mg/kg)", "=40"],
  [8730, "Nasi Beku (06070101)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    8731,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "As (ppm)",
    "=0.5",
  ],
  [
    8732,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "Cd (ppm)",
    "=0.3",
  ],
  [
    8733,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "Hg (ppm)",
    "=0.03",
  ],
  [
    8734,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=200",
  ],
  [
    8735,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    8736,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (1665)",
    "Pb (ppm)",
    "=1",
  ],
  [
    8737,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "As (ppm)",
    "=0.5",
  ],
  [
    8738,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "Cd (ppm)",
    "=0.3",
  ],
  [
    8739,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "Hg (ppm)",
    "=0.03",
  ],
  [
    8740,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=200",
  ],
  [
    8741,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    8742,
    "Nasi Campur Lauk (Daging atau Unggas dengan Sayur) (Steril) (1664)",
    "Pb (ppm)",
    "=1",
  ],
  [
    8743,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Arsen (As) (mg/kg) ",
    "=0.5",
  ],
  [
    8744,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    8745,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8746,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    8747,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Timbal (Pb) (mg/kg) ",
    "=0.3",
  ],
  [
    8748,
    "Nasi Campur Lauk (daging, ikan, dll) (1663)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=200",
  ],
  [
    8749,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "As (ppm)",
    "=1",
  ],
  [
    8750,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "Cd (ppm)",
    "=0.1",
  ],
  [
    8751,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "Hg (ppm)",
    "=0.5",
  ],
  [
    8752,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=250",
  ],
  [
    8753,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    8754,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (1667)",
    "Pb (ppm)",
    "=0.3",
  ],
  [
    8755,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "As (ppm)",
    "=1",
  ],
  [
    8756,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "Cd (ppm)",
    "=0.1",
  ],
  [
    8757,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "Hg (ppm)",
    "=0.5",
  ],
  [
    8758,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "Sn yang dikemas dalam kaleng (ppm)",
    "=250",
  ],
  [
    8759,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "Sn yang tidak dikemas dalam kaleng (ppm)",
    "=40",
  ],
  [
    8760,
    "Nasi Campur Lauk (Ikan dan Hasil Olahnya dengan Sayur) (Steril) (1666)",
    "Pb (ppm)",
    "=0.3",
  ],
  [
    8761,
    "Nasi Dengan Lauk Daging Dalam Kaleng (08020223)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    8762,
    "Nasi Dengan Lauk Daging Dalam Kaleng (08020223)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8763,
    "Nasi Dengan Lauk Daging Dalam Kaleng (08020223)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    8764,
    "Nasi Dengan Lauk Daging Dalam Kaleng (08020223)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    8765,
    "Nasi Dengan Lauk Daging Dalam Kaleng (08020223)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    8766,
    "Nasi Dengan Lauk Ikan Dalam Kaleng (090412)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    8767,
    "Nasi Dengan Lauk Ikan Dalam Kaleng (090412)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    8768,
    "Nasi Dengan Lauk Ikan Dalam Kaleng (090412)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    8769,
    "Nasi Dengan Lauk Ikan Dalam Kaleng (090412)",
    "Timah (Sn) (mg/kg) ",
    "=250",
  ],
  [
    8770,
    "Nasi Dengan Lauk Ikan Dalam Kaleng (090412)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    8771,
    "Nasi Goreng Instan (1606)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8772,
    "Nasi Goreng Instan (1606)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8773,
    "Nasi Goreng Instan (1606)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8774,
    "Nasi Goreng Instan (1606)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8775,
    "Nasi Goreng Instan (1606)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8776,
    "Nasi Goreng Instan (1606)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [8777, "Nasi Instan (060120)", "Arsen (As) (mg/kg)", "=0.1"],
  [8778, "Nasi Instan (060120)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [8779, "Nasi Instan (060120)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    8780,
    "Nasi Instan (060120)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    8781,
    "Nasi Instan (060120)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [8782, "Nasi Instan (060120)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [8783, "Nasi Instan (060120)", "Kadar Air (%)", "=14"],
  [8784, "Nasi Instan (06040311)", "Arsen (As) (mg/kg)", "=0.1"],
  [8785, "Nasi Instan (06040311)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [8786, "Nasi Instan (06040311)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    8787,
    "Nasi Instan (06040311)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8788,
    "Nasi Instan (06040311)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [8789, "Nasi Instan (06040311)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [8790, "Nasi Instan (06040311)", "Kadar Air (%)", "=14"],
  [
    8791,
    "Nasi Instan Dengan .... (1668)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8792,
    "Nasi Instan Dengan .... (1668)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8793,
    "Nasi Instan Dengan .... (1668)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8794,
    "Nasi Instan Dengan .... (1668)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8795,
    "Nasi Instan Dengan .... (1668)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8796,
    "Nasi Instan Dengan .... (1668)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    8797,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8798,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8799,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8800,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8801,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8802,
    "Nasi Instan Dengan .... (Steril) (1673)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    8803,
    "Nasi Instan Steril (06040314)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8804,
    "Nasi Instan Steril (06040314)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8805,
    "Nasi Instan Steril (06040314)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8806,
    "Nasi Instan Steril (06040314)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8807,
    "Nasi Instan Steril (06040314)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    8808,
    "Nasi Instan Steril (06040314)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [8809, "Nasi Jagung (060308)", "Arsen (As) (mg/kg)", "=0.1"],
  [8810, "Nasi Jagung (060308)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [8811, "Nasi Jagung (060308)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    8812,
    "Nasi Jagung (060308)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8813,
    "Nasi Jagung (060308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [8814, "Nasi Jagung (060308)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    8815,
    "Nasi Jagung (060308)",
    "Aflatoksin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    8816,
    "Nasi Jagung (060308)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    8817,
    "Nasi Kuning Instan (1609)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8818,
    "Nasi Kuning Instan (1609)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8819,
    "Nasi Kuning Instan (1609)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8820,
    "Nasi Kuning Instan (1609)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8821,
    "Nasi Kuning Instan (1609)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8822,
    "Nasi Kuning Instan (1609)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8823,
    "Nasi Kunyit Instan (1611)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8824,
    "Nasi Kunyit Instan (1611)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8825,
    "Nasi Kunyit Instan (1611)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8826,
    "Nasi Kunyit Instan (1611)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8827,
    "Nasi Kunyit Instan (1611)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8828,
    "Nasi Kunyit Instan (1611)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8829,
    "Nasi Liwet Instan (1613)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8830,
    "Nasi Liwet Instan (1613)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8831,
    "Nasi Liwet Instan (1613)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8832,
    "Nasi Liwet Instan (1613)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8833,
    "Nasi Liwet Instan (1613)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8834,
    "Nasi Liwet Instan (1613)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8835,
    "Nasi Uduk Instan (1615)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8836,
    "Nasi Uduk Instan (1615)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8837,
    "Nasi Uduk Instan (1615)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8838,
    "Nasi Uduk Instan (1615)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8839,
    "Nasi Uduk Instan (1615)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8840,
    "Nasi Uduk Instan (1615)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8841,
    "Nastar (07020134)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    8842,
    "Nastar (07020134)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    8843,
    "Nastar (07020134)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8844,
    "Nastar (07020134)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8845,
    "Nastar (07020134)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8846,
    "Nastar (07020134)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [8847, "Nastar (07020134)", "Kadar air (%)", "=10", "=5"],
  [
    8848,
    "Nata (0401020811)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    8849,
    "Nata (0401020811)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8850,
    "Nata (0401020811)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8851,
    "Nata (0401020811)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    8852,
    "Nata (0401020811)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    8853,
    "Nata (0401020811)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [8854, "Nata Dalam Kemasan (0401020902)", "Nata (%)", "", "=50"],
  [
    8855,
    "Nata Dalam Kemasan (0401020902)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    8856,
    "Nata Dalam Kemasan (0401020902)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    8857,
    "Nata Dalam Kemasan (0401020902)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    8858,
    "Nata Dalam Kemasan (0401020902)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8859,
    "Nata Dalam Kemasan (0401020902)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8860,
    "Nata Dalam Kemasan (0401020902)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    8861,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Arsen (mg/kg)",
    "=0.05",
  ],
  [
    8862,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Kadmium (mg/kg)",
    "=0.01",
  ],
  [
    8863,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Merkuri (mg/kg)",
    "=0.01",
  ],
  [
    8864,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    8865,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8866,
    "Nata De Coco Dalam Minuman (1401040225)",
    "Timbal (mg/kg)",
    "=0.05",
  ],
  [8867, "Natto (06080602)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    8868,
    "Natto (06080602)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8869,
    "Natto (06080602)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8870,
    "Natto (06080602)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    8871,
    "Natto (06080602)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    8872,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "kandungan buah untuk nektar peach dan pir/pear (%)",
    "",
    "=40",
  ],
  [
    8873,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "nektar aprikot (buah tunggal yang diperoleh dari bahan konsentrat) (%)",
    "",
    "=35",
  ],
  [
    8874,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "total padatan terlarut yang diukur menggunakan refraktometer pada 20\xB0C (%)",
    "=20",
  ],
  [
    8875,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "kandungan etanol (%)",
    "=0.3",
  ],
  [
    8876,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8877,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8878,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8879,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8880,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8881,
    "Nektar Aprikot, Nektar Peach atau Nektar Pir/Pear (1401030103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8882,
    "Nektar Blackcurrant (1401030104)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8883,
    "Nektar Blackcurrant (1401030104)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8884,
    "Nektar Blackcurrant (1401030104)",
    "kandungan buah blackcurrant (%)",
    "",
    "=30",
  ],
  [
    8885,
    "Nektar Blackcurrant (1401030104)",
    "total padatan terlarut yang diukur menggunakan refraktometer pada 20\xB0C (%)",
    "=20",
  ],
  [
    8886,
    "Nektar Blackcurrant (1401030104)",
    "kadar etanol (%)",
    "=0.2",
  ],
  [
    8887,
    "Nektar Blackcurrant (1401030104)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8888,
    "Nektar Blackcurrant (1401030104)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8889,
    "Nektar Blackcurrant (1401030104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8890,
    "Nektar Blackcurrant (1401030104)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8891,
    "Nektar Buah (1401030107)",
    "kandungan buah tunggal (yang diperoleh dari bahan konsentrat, kecuali untuk produk atau buah dengan tingkat keasaman tinggi, mengandung hancuran buah (pulpy) tinggi, atau jika mengandung perisa tinggi, maka kandungannya dapat berkurang) (%)",
    "",
    "=50",
  ],
  [
    8892,
    "Nektar Buah (1401030107)",
    "kandungan buah (%)",
    "",
    "=25",
  ],
  [
    8893,
    "Nektar Buah (1401030107)",
    "total padatan terlarut yang diukur menggunakan refraktometer pada 20\xB0C (%)",
    "=20",
  ],
  [8894, "Nektar Buah (1401030107)", "kadar etanol (%)", "=0.3"],
  [
    8895,
    "Nektar Buah (1401030107)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8896,
    "Nektar Buah (1401030107)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8897,
    "Nektar Buah (1401030107)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8898,
    "Nektar Buah (1401030107)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8899,
    "Nektar Buah (1401030107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8900,
    "Nektar Buah (1401030107)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8901,
    "Nektar Buah Campuran (1401030102)",
    "kandungan buah tunggal (yang diperoleh dari bahan konsentrat, kecuali untuk produk atau buah dengan tingkat keasaman tinggi, mengandung hancuran buah (pulpy) tinggi, atau jika mengandung perisa tinggi, maka kandungannya dapat berkurang) (%)",
    "",
    "=50",
  ],
  [
    8902,
    "Nektar Buah Campuran (1401030102)",
    "kandungan buah (%)",
    "",
    "=25",
  ],
  [
    8903,
    "Nektar Buah Campuran (1401030102)",
    "total padatan terlarut yang diukur menggunakan refraktometer pada 20\xB0C (%)",
    "=20",
  ],
  [
    8904,
    "Nektar Buah Campuran (1401030102)",
    "kadar etanol (%)",
    "=0.3",
  ],
  [
    8905,
    "Nektar Buah Campuran (1401030102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8906,
    "Nektar Buah Campuran (1401030102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8907,
    "Nektar Buah Campuran (1401030102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8908,
    "Nektar Buah Campuran (1401030102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8909,
    "Nektar Buah Campuran (1401030102)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8910,
    "Nektar Buah Campuran (1401030102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8911,
    "Nektar Buah Citrus (1401030105)",
    "kandungan buah tunggal atau yang setara dengan itu yang diperoleh dari bahan konsentrat (%)",
    "",
    "=50",
  ],
  [
    8912,
    "Nektar Buah Citrus (1401030105)",
    "Total padatan terlarut yang diukur dengan refraktometer pada suhu 20 \xB0C; (%)",
    "=12",
  ],
  [
    8913,
    "Nektar Buah Citrus (1401030105)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    8914,
    "Nektar Buah Citrus (1401030105)",
    "Penambahan 10% buah mandarin (C. reticulata) termasuk ke dalam kandungan total buah citrus;",
  ],
  [
    8915,
    "Nektar Buah Citrus (1401030105)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8916,
    "Nektar Buah Citrus (1401030105)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8917,
    "Nektar Buah Citrus (1401030105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8918,
    "Nektar Buah Citrus (1401030105)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8919,
    "Nektar Buah Citrus (1401030105)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8920,
    "Nektar Buah Citrus (1401030105)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8921,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal sea buckthorn (%)",
    "",
    "=25",
  ],
  [
    8922,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal blackcurrant (%)",
    "",
    "=30",
  ],
  [
    8923,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal rowanberries (%)",
    "",
    "=30",
  ],
  [
    8924,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal redcurrant (%)",
    "",
    "=30",
  ],
  [
    8925,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal whitecurrant (%)",
    "",
    "=30",
  ],
  [
    8926,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal gooseberries (%)",
    "",
    "=30",
  ],
  [
    8927,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal blackberries (%)",
    "",
    "=30",
  ],
  [
    8928,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal cloudberries (%)",
    "",
    "=30",
  ],
  [
    8929,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal cranberries (%)",
    "",
    "=30",
  ],
  [
    8930,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal whortleberries (%)",
    "",
    "=30",
  ],
  [
    8931,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal raspberries (%)",
    "",
    "=40",
  ],
  [
    8932,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal strawberi (%)",
    "",
    "=40",
  ],
  [
    8933,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal bilberries (%)",
    "",
    "=40",
  ],
  [
    8934,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal rose hips (%)",
    "",
    "=40",
  ],
  [
    8935,
    "Nektar Buah Kecil (1401030101)",
    "kandungan buah tunggal elderberries (%)",
    "",
    "=50",
  ],
  [
    8936,
    "Nektar Buah Kecil (1401030101)",
    "total padatan terlarut (yang diukur menggunakan refraktometer pada 20\xB0C) (%)",
    "=20",
  ],
  [
    8937,
    "Nektar Buah Kecil (1401030101)",
    "kadar etanol (%)",
    "=0.3",
  ],
  [
    8938,
    "Nektar Buah Kecil (1401030101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8939,
    "Nektar Buah Kecil (1401030101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8940,
    "Nektar Buah Kecil (1401030101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8941,
    "Nektar Buah Kecil (1401030101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8942,
    "Nektar Buah Kecil (1401030101)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8943,
    "Nektar Buah Kecil (1401030101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8944,
    "Nektar Jambu Biji (1401030106)",
    "kandungan buah untuk tunggal yang diperoleh dari bahan konsentrat (%)",
    "",
    "=25",
  ],
  [
    8945,
    "Nektar Jambu Biji (1401030106)",
    "total padatan terlarut yang diukur menggunakan refraktometer pada 20\xB0C (%)",
    "=20",
  ],
  [
    8946,
    "Nektar Jambu Biji (1401030106)",
    "kadar etanol (g/kg)",
    "=3",
  ],
  [
    8947,
    "Nektar Jambu Biji (1401030106)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8948,
    "Nektar Jambu Biji (1401030106)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8949,
    "Nektar Jambu Biji (1401030106)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8950,
    "Nektar Jambu Biji (1401030106)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8951,
    "Nektar Jambu Biji (1401030106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8952,
    "Nektar Jambu Biji (1401030106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8953,
    "Nektar Mangga (1401030108)",
    "Kandungan pur\xE9e buah mangga atau yang setara dengan itu yang diperoleh dari bahan konsentrat (%v/v)",
    "",
    "=25",
  ],
  [
    8954,
    "Nektar Mangga (1401030108)",
    "Total padatan terlarut diukur dengan refraktometer pada suhu 20 \xB0C; minimum Brix Level untuk Sari Buah Rekonstitusi 13,5 Brix. (%)",
    "=20",
  ],
  [8955, "Nektar Mangga (1401030108)", "Kadar etanol (%)", "=0.3"],
  [
    8956,
    "Nektar Mangga (1401030108)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8957,
    "Nektar Mangga (1401030108)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8958,
    "Nektar Mangga (1401030108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8959,
    "Nektar Mangga (1401030108)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8960,
    "Nektar Mangga (1401030108)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8961,
    "Nektar Mangga (1401030108)",
    "Merkuri (Hg) (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8962,
    "Nektar Sayur (1401030201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8963,
    "Nektar Sayur (1401030201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8964,
    "Nektar Sayur (1401030201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    8965,
    "Nektar Sayur (1401030201)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8966,
    "Nektar Sayur (1401030201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8967,
    "Nektar Sayur (1401030201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8968,
    "Nektar Sirsak (1401030109)",
    "Kandungan pur\xE9e buah sirsak atau yang setara dengan itu yang diperoleh dari bahan konsentrat (%)",
    "",
    "=25",
  ],
  [
    8969,
    "Nektar Sirsak (1401030109)",
    "Total padatan terlarut yang diukur dengan refraktometer pada suhu 20 \xB0C; Minimum Brix Level untuk Sari Buah Rekonstitusi 14,5Brix (%)",
    "=20",
  ],
  [8970, "Nektar Sirsak (1401030109)", "Kadar etanol (%)", "=0.3"],
  [
    8971,
    "Nektar Sirsak (1401030109)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8972,
    "Nektar Sirsak (1401030109)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8973,
    "Nektar Sirsak (1401030109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8974,
    "Nektar Sirsak (1401030109)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    8975,
    "Nektar Sirsak (1401030109)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    8976,
    "Nektar Sirsak (1401030109)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [8977, "Nib Kakao (05010107)", "Arsen (As) (mg/kg)", "=1"],
  [8978, "Nib Kakao (05010107)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [8979, "Nib Kakao (05010107)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    8980,
    "Nib Kakao (05010107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8981,
    "Nib Kakao (05010107)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [8982, "Nib Kakao (05010107)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    8983,
    "Non Dairy Pudding (010709)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    8984,
    "Non Dairy Pudding (010709)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    8985,
    "Non Dairy Pudding (010709)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    8986,
    "Non Dairy Pudding (010709)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8987,
    "Non Dairy Pudding (010709)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8988,
    "Non Dairy Pudding (010709)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [8989, "Non-Dairy Mousse (020402)", "Kadar lemak (%)", "", "=9"],
  [
    8990,
    "Non-Dairy Mousse (020402)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8991,
    "Non-Dairy Mousse (020402)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8992,
    "Non-Dairy Mousse (020402)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    8993,
    "Non-Dairy Mousse (020402)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    8994,
    "Non-Dairy Mousse (020402)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    8995,
    "Non-Dairy Mousse (020402)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8996,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Kadar lemak (%)",
    "=40",
  ],
  [
    8997,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8998,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    8999,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9000,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9001,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9002,
    "Non-Dairy Toppings, Fillings, Frostings (020301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9003,
    "Non-Dairy Whipped Cream (020302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9004,
    "Non-Dairy Whipped Cream (020302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9005,
    "Non-Dairy Whipped Cream (020302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9006,
    "Non-Dairy Whipped Cream (020302)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9007,
    "Non-Dairy Whipped Cream (020302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9008,
    "Non-Dairy Whipped Cream (020302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9009,
    "Non-Dairy Whipped Cream (020302)",
    "kadar lemak (%)",
    "=40",
  ],
  [9010, "Nopia (07020217)", "Arsen (As) (mg/kg)", "=0.5"],
  [9011, "Nopia (07020217)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [9012, "Nopia (07020217)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [
    9013,
    "Nopia (07020217)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    9014,
    "Nopia (07020217)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9015, "Nopia (07020217)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    9016,
    "Nori (0402020205)",
    "Arsen inorganik (As) (ppm atau mg/kg)",
    "=1",
  ],
  [9017, "Nori (0402020205)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [9018, "Nori (0402020205)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    9019,
    "Nori (0402020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9020, "Nori (0402020205)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [9021, "Nougat (05020301)", "Arsen (As) (mg/kg)", "=1"],
  [9022, "Nougat (05020301)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [9023, "Nougat (05020301)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    9024,
    "Nougat (05020301)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9025,
    "Nougat (05020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9026, "Nougat (05020301)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    9027,
    "Nougat (05020301)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9028,
    "Nougat (05020301)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9029,
    "Nougat (05020301)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [9030, "Oatmeal (060305)", "Kandungan lemak (%). ", "", "=5"],
  [9031, "Oatmeal (060305)", "Arsen (As) (mg/kg) ", "=0.1"],
  [9032, "Oatmeal (060305)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [9033, "Oatmeal (060305)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [9034, "Oatmeal (060305)", "Timah (Sn) (mg/kg)", "=40"],
  [9035, "Oatmeal (060305)", "Timbal (Pb) (mg/kg) ", "=0.25"],
  [
    9036,
    "Okra yang Digoreng (0402020806)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9037,
    "Okra yang Digoreng (0402020806)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9038,
    "Okra yang Digoreng (0402020806)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9039,
    "Okra yang Digoreng (0402020806)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9040,
    "Okra yang Digoreng (0402020806)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    9041,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    9042,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    9043,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    9044,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    9045,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    9046,
    "Olahan Gluten (Diolah dengan Perlakuan Panas) (1672)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    9047,
    "Olahan Ikan Berbumbu (0902040122)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    9048,
    "Olahan Ikan Berbumbu (0902040122)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    9049,
    "Olahan Ikan Berbumbu (0902040122)",
    "Raksa (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    9050,
    "Olahan Ikan Berbumbu (0902040122)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    9051,
    "Olahan Ikan Berbumbu (0902040122)",
    "Timah (Sn) dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    9052,
    "Olahan Ikan Berbumbu (0902040122)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    9053,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9054,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9055,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9056,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    9057,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    9058,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9059,
    "Olahan Ikan Dalam Kemasan (090419)",
    "Kandungan Daging Ikan (%)",
    "",
    "=30",
  ],
  [
    9060,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9061,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9062,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9063,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9064,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9065,
    "Olahan Ikan dan Produk Perikanan Termasuk Moluska, Krustase, Ekinodermata Goreng atau Panggang (Oven atau Bara) (0902040308)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9066,
    "Olesan Berbasis Kacang (0402020508)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9067,
    "Olesan Berbasis Kacang (0402020508)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9068,
    "Olesan Berbasis Kacang (0402020508)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9069,
    "Olesan Berbasis Kacang (0402020508)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9070,
    "Olesan Berbasis Kacang (0402020508)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9071,
    "Olesan Berbasis Kacang (0402020508)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9072,
    "Olesan Berbasis Kacang (0402020508)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9073,
    "Olesan Berbasis Kacang (0402020508)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb/mcg/kg)",
    "=10",
  ],
  [
    9074,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    9075,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9076,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9077,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    9078,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    9079,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9080,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9081,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9082,
    "Olesan Berbasis Kacang-Cokelat (Nut-Chocolate Based Spread) (05010302)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    9083,
    "Olesan Berbasis Sayur (0402020506)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9084,
    "Olesan Berbasis Sayur (0402020506)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9085,
    "Olesan Berbasis Sayur (0402020506)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9086,
    "Olesan Berbasis Sayur (0402020506)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9087,
    "Olesan Berbasis Sayur (0402020506)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    9088,
    "Olesan Berbasis Sayur (0402020506)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9089,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    9090,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9091,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9092,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    9093,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    9094,
    "Olesan Cokelat Berbasis Air (Chocolate Water-Based Spread) (05010303)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9095,
    "Olesan Kacang (0402020509)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9096,
    "Olesan Kacang (0402020509)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    9097,
    "Olesan Kacang (0402020509)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9098,
    "Olesan Kacang (0402020509)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    9099,
    "Olesan Kacang (0402020509)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    9100,
    "Olesan Kacang (0402020509)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9101,
    "Olesan Kacang (0402020509)",
    "Kandungan total kacang (%)",
    "",
    "=40",
  ],
  [9102, "Olesan Kacang (0402020509)", "Aflatoksin B1", "=15"],
  [9103, "Olesan Kacang (0402020509)", "Aflatoksin Total", "=20"],
  [
    9104,
    "Olesan Mengandung Kacang (0402020510)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9105,
    "Olesan Mengandung Kacang (0402020510)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9106,
    "Olesan Mengandung Kacang (0402020510)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9107,
    "Olesan Mengandung Kacang (0402020510)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg) ",
    "=250",
  ],
  [
    9108,
    "Olesan Mengandung Kacang (0402020510)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    9109,
    "Olesan Mengandung Kacang (0402020510)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9110,
    "Olesan Mengandung Kacang (0402020510)",
    "Kandungan total kacang (%)",
    "",
    "=15",
  ],
  [
    9111,
    "Olesan Mengandung Kacang (0402020510)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    9112,
    "Olesan Mengandung Kacang (0402020510)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/kg) ",
    "=20",
  ],
  [
    9113,
    "Olesan Mengandung Kacang (0402020510)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg) ",
    "=10",
  ],
  [9114, "Olesan/Saus (120703)", "Arsen (As) (mg/kg)", "=0.15"],
  [9115, "Olesan/Saus (120703)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [9116, "Olesan/Saus (120703)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [9117, "Olesan/Saus (120703)", "Timah (Sn) (mg/kg)", "=40"],
  [9118, "Olesan/Saus (120703)", "Timbal (Pb) (mg/kg)", "=1"],
  [9119, "Ombus-ombus (060734)", "Arsen (As) (mg/kg)", "=0.1"],
  [9120, "Ombus-ombus (060734)", "Kadmium (Cd)(mg/kg)", "=0.05"],
  [9121, "Ombus-ombus (060734)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    9122,
    "Ombus-ombus (060734)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    9123,
    "Ombus-ombus (060734)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [9124, "Ombus-ombus (060734)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    9125,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Arsen (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9126,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Kadmium (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9127,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Merkuri (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9128,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9129,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9130,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Timbal (ppm atau mg/kg)",
    "=1",
  ],
  [
    9131,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9132,
    "Onion Bubuk/Bawang Bombay Bubuk (12020180)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9133,
    "Onion/Bawang Bombay (12020179)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9134,
    "Onion/Bawang Bombay (12020179)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9135,
    "Onion/Bawang Bombay (12020179)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9136,
    "Onion/Bawang Bombay (12020179)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9137,
    "Onion/Bawang Bombay (12020179)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9138,
    "Onion/Bawang Bombay (12020179)",
    "Aflatoxin B1 (ppb atau mcg/kg) ",
    "=15",
  ],
  [
    9139,
    "Onion/Bawang Bombay (12020179)",
    "Aflatoxin Total (ppb atau mcg/kg) ",
    "=20",
  ],
  [9140, "Opak (150115)", "Arsen (As) (ppm atau mg/kg)", "=0.25"],
  [9141, "Opak (150115)", "Kadmium (Cd) (ppm atau mg/kg)", "=0.05"],
  [9142, "Opak (150115)", "Raksa (Hg) (ppm atau mg/kg)", "=0.03"],
  [
    9143,
    "Opak (150115)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [9144, "Opak (150115)", "Timbal (Pb) (ppm atau mg/kg)", "=0.25"],
  [9145, "Opak (150115)", "Kadar air (%)", "=3"],
  [
    9146,
    "Ordinary Virgin olive oil (02010240)",
    "Kadar asam lemak bebas sebagai asam oleat (g/100g) ",
    "=3.3",
  ],
  [
    9147,
    "Ordinary Virgin olive oil (02010240)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9148,
    "Ordinary Virgin olive oil (02010240)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9149,
    "Ordinary Virgin olive oil (02010240)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9150,
    "Ordinary Virgin olive oil (02010240)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9151,
    "Ordinary Virgin olive oil (02010240)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9152,
    "Ordinary Virgin olive oil (02010240)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9153,
    "Oregano (12020181)",
    "Kadar air tidak lebih dari (%)",
    "=10",
  ],
  [
    9154,
    "Oregano (12020181)",
    "Minyak atsiri tidak kurang dari (%v/b)",
    "",
    "=2.5",
  ],
  [
    9155,
    "Oregano (12020181)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9156,
    "Oregano (12020181)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9157,
    "Oregano (12020181)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9158,
    "Oregano (12020181)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    9159,
    "Oregano (12020181)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    9160,
    "Otak - Otak Ayam (08030222)",
    "Kadar daging (%)",
    "",
    "=50",
  ],
  [
    9161,
    "Otak - Otak Ayam (08030222)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9162,
    "Otak - Otak Ayam (08030222)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9163,
    "Otak - Otak Ayam (08030222)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9164,
    "Otak - Otak Ayam (08030222)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9165,
    "Otak - Otak Ayam (08030222)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9166,
    "Otak - Otak Ayam (08030222)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9167,
    "Otak-Otak Ikan (0902040109)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9168,
    "Otak-Otak Ikan (0902040109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9169,
    "Otak-Otak Ikan (0902040109)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9170,
    "Otak-Otak Ikan (0902040109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9171,
    "Otak-Otak Ikan (0902040109)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9172,
    "Otak-Otak Ikan (0902040109)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9173,
    "Otak-Otak Ikan (0902040109)",
    "Kandungan daging ikan dan/atau surimi (%)",
    "",
    "=30",
  ],
  [
    9174,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9175,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9176,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9177,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9178,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9179,
    "Otak-Otak Ikan Analog/Produk ikan Analog (0902040118)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9180,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9181,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9182,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9183,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    9184,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    9185,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9186,
    "Otak-Otak Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090415)",
    "Kandungan daging ikan/moluska/krustase/ekinodermata (%)",
    "",
    "=30",
  ],
  [9187, "Pai (07020136)", "Kadar air (%) ", "=5"],
  [9188, "Pai (07020136)", "Arsen (As) (mg/kg) ", "=0.5"],
  [9189, "Pai (07020136)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [9190, "Pai (07020136)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [9191, "Pai (07020136)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [9192, "Pai (07020136)", "Timah (Sn) (mg/kg)", "=40"],
  [9193, "Pai Isi (07020137)", "Kadar air (%) ", "=10", "=5"],
  [9194, "Pai Isi (07020137)", "Arsen (As) (mg/kg) ", "=0.5"],
  [9195, "Pai Isi (07020137)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [9196, "Pai Isi (07020137)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [9197, "Pai Isi (07020137)", "Timah (Sn) (mg/kg)", "=40"],
  [9198, "Pai Isi (07020137)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [9199, "Pala (12020182)", "Arsen (As) (mg/kg)", "=0.15"],
  [9200, "Pala (12020182)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [9201, "Pala (12020182)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [9202, "Pala (12020182)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [9203, "Pala (12020182)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    9204,
    "Pala (12020182)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9205,
    "Pala (12020182)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9206,
    "Pala Bubuk (12020184)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    9207,
    "Pala Bubuk (12020184)",
    "Cadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    9208,
    "Pala Bubuk (12020184)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    9209,
    "Pala Bubuk (12020184)",
    "Timah (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    9210,
    "Pala Bubuk (12020184)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    9211,
    "Pala Bubuk (12020184)",
    "Kadar air tidak lebih dari (%)",
    "=8",
  ],
  [
    9212,
    "Pala Bubuk (12020184)",
    "Minyak atsiri tidak kurang dari (%v/b) ",
    "",
    "=7",
  ],
  [
    9213,
    "Pala Bubuk (12020184)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9214,
    "Pala Bubuk (12020184)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9215,
    "Pala Untuk Destilasi (12020183)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9216,
    "Pala Untuk Destilasi (12020183)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9217,
    "Pala Untuk Destilasi (12020183)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9218,
    "Pala Untuk Destilasi (12020183)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    9219,
    "Pala Untuk Destilasi (12020183)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9220,
    "Pala Untuk Destilasi (12020183)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9221,
    "Pala Untuk Destilasi (12020183)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9222,
    "Palai Bada/Teri (0902040117)",
    "Angka Lempeng Total (30 C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    9223,
    "Palai Bada/Teri (0902040117)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9224,
    "Palai Bada/Teri (0902040117)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9225,
    "Palai Bada/Teri (0902040117)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9226,
    "Palai Bada/Teri (0902040117)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9227,
    "Palai Bada/Teri (0902040117)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [9228, "Panekuk (07020214)", "Arsen (As) (mg/kg) ", "=0.5"],
  [9229, "Panekuk (07020214)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [9230, "Panekuk (07020214)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [
    9231,
    "Panekuk (07020214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [9232, "Panekuk (07020214)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    9233,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9234,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9235,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9236,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9237,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9238,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9239,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm mg/kg) ",
    "=100",
  ],
  [
    9240,
    "Pangan Diet Penurun Berat Badan Cair (1338)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9241,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9242,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9243,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9244,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9245,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9246,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9247,
    "Pangan Diet Penurun Berat Badan Padat (1337)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9248,
    "Pangan Ibu Hamil Cair (1322)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9249,
    "Pangan Ibu Hamil Cair (1322)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9250,
    "Pangan Ibu Hamil Cair (1322)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9251,
    "Pangan Ibu Hamil Cair (1322)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9252,
    "Pangan Ibu Hamil Cair (1322)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9253,
    "Pangan Ibu Hamil Cair (1322)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9254,
    "Pangan Ibu Hamil Cair (1322)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9255,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9256,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9257,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9258,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9259,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9260,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9261,
    "Pangan Ibu Hamil dan Menyusui Cair (1326)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9262,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9263,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9264,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9265,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9266,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9267,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9268,
    "Pangan Ibu Hamil dan Menyusui Padat (1325)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9269,
    "Pangan Ibu Hamil Padat (1321)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9270,
    "Pangan Ibu Hamil Padat (1321)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9271,
    "Pangan Ibu Hamil Padat (1321)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9272,
    "Pangan Ibu Hamil Padat (1321)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9273,
    "Pangan Ibu Hamil Padat (1321)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9274,
    "Pangan Ibu Hamil Padat (1321)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9275,
    "Pangan Ibu Hamil Padat (1321)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9276,
    "Pangan Ibu Menyusui Cair (1324)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9277,
    "Pangan Ibu Menyusui Cair (1324)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9278,
    "Pangan Ibu Menyusui Cair (1324)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9279,
    "Pangan Ibu Menyusui Cair (1324)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9280,
    "Pangan Ibu Menyusui Cair (1324)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9281,
    "Pangan Ibu Menyusui Cair (1324)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9282,
    "Pangan Ibu Menyusui Cair (1324)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9283,
    "Pangan Ibu Menyusui Padat (1323)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9284,
    "Pangan Ibu Menyusui Padat (1323)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9285,
    "Pangan Ibu Menyusui Padat (1323)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9286,
    "Pangan Ibu Menyusui Padat (1323)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    9287,
    "Pangan Ibu Menyusui Padat (1323)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9288,
    "Pangan Ibu Menyusui Padat (1323)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9289,
    "Pangan Ibu Menyusui Padat (1323)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9290,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    9291,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9292,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9293,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi",
    "=10",
  ],
  [
    9294,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9295,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Laktosa (mg/100 kkal)",
    "=10",
  ],
  [
    9296,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    9297,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    9298,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    9299,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Protein susu non hidrolisat (g/100 kkal)",
    "",
    "=2",
  ],
  [
    9300,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    9301,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    9302,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    9303,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    9304,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    9305,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%)",
    "=30",
  ],
  [
    9306,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml) ",
    "=2",
  ],
  [
    9307,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    9308,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Penambahan Fruktosa (%)",
    "=Negatif",
  ],
  [
    9309,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    9310,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Cair) (1397)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9311,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Arsen (As) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    9312,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Kadmium (Cd) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9313,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Merkuri (Hg) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9314,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Timah (Sn) (mg/l) dihitung terhadap produk siap konsumsi",
    "=10",
  ],
  [
    9315,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Timbal (Pb) (mg/l) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    9316,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Laktosa (mg/100kkal)",
    "=10",
  ],
  [
    9317,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Protein Susu (g/100 kkal)",
    "=3",
    "=1.8",
  ],
  [
    9318,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Isolat Protein Kedelai (g/100 kkal)",
    "=3",
    "=2.25",
  ],
  [
    9319,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Mutu protein dibandingkan mutu kasein (%)",
    "",
    "=85",
  ],
  [
    9320,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Protein susu non hidrolisat (g/100 kkal) ",
    "",
    "=2",
  ],
  [
    9321,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Protein hidrolisat (g/100 kkal)",
    "",
    "=2.25",
  ],
  [
    9322,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Kandungan kombinasi asam laurat dan asam miristat dari total asam lemak (%)",
    "=20",
  ],
  [
    9323,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Kandungan asam lemak trans dari dari total asam lemak (%) ",
    "=3",
  ],
  [
    9324,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Kandungan asam erusat (erucic acid) dari total asam lemak (%)",
    "=1",
  ],
  [
    9325,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Kandungan total fosfolipid (mg/100 kkal)",
    "=300",
  ],
  [
    9326,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) dari total karbohidrat (%)",
    "=30",
  ],
  [
    9327,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Penambahan pati (hanya pati yang secara alami bebas gluten yang telah dimasak (precooked) dan atau pati yang telah digelatinisasi) (g/100ml) ",
    "=2",
  ],
  [
    9328,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Penambahan sukrosa (bila diperlukan) dari total karbohidrat (%)",
    "=20",
  ],
  [
    9329,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Jika fluor terdapat secara alami dalam bahan baku, kandungan fluor dalam produk Formula Bayi siap konsumsi (mcg/100 kkal)",
    "=100",
  ],
  [
    9330,
    "Pangan Olahan Keperluan Medis Khusus Bagi Bayi Intoleransi Laktosa (Padat) (1396)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9331,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Osmolalitas (mOsml/kg)",
  ],
  [
    9332,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    9333,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    9334,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    9335,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    9336,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=40",
  ],
  [
    9337,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Cair) (1395)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9338,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Osmolalitas (mOsml/kg)",
  ],
  [
    9339,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    9340,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    9341,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    9342,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    9343,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Timah (Sn) (ppm atau mg/kg) - Siap Konsumsi",
    "=40",
  ],
  [
    9344,
    "Pangan Olahan Keperluan Medis Khusus Diet Ketogenik (Padat) (1394)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9345,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Arsen (As) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9346,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Merkuri (Hg) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9347,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Kadmium (Cd) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9348,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Timbal (Pb) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9349,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/L)",
    "=250",
  ],
  [
    9350,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/L) ",
    "=40",
  ],
  [
    9351,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9352,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Densitas Energi (Produk standar) (kkal/ml)",
    "=2",
    "=0.9",
  ],
  [
    9353,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Densitas Energi (Produk energi lebih tinggi) (kkal/ml)",
  ],
  [9354, "", "", ">1.2"],
  [
    9355,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Cair (1358)",
    "Osmolalitas (mOsm/kgH2O)",
    "=1180",
  ],
  [
    9356,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Arsen (As) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9357,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Merkuri (Hg) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9358,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Kadmium (Cd) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9359,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Timbal (Pb) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9360,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/L)",
    "=250",
  ],
  [
    9361,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/L) ",
    "=40",
  ],
  [
    9362,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=0.5",
  ],
  [
    9363,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Densitas Energi (Produk Standar) (kkal/ml)",
    "=2",
    "=0.9",
  ],
  [
    9364,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Densitas Energi (Produk energi lebih tinggi) (kkal/ml)",
  ],
  [9365, "", "", ">1.2"],
  [
    9366,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1357)",
    "Osmolalitas (mOsm/kgH2O)",
    "=1180",
  ],
  [
    9367,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9368,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9369,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9370,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9371,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/L)",
    "=250",
  ],
  [
    9372,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/L) ",
    "=40",
  ],
  [
    9373,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9374,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9375,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9376,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9377,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9378,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9379,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/L)",
    "=250",
  ],
  [
    9380,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/L) ",
    "=40",
  ],
  [
    9381,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9382,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Dukungan Nutrisi Bagi Orang Dewasa Beresiko Gizi Kurang, Atau Gizi Buruk Padat (1375)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9383,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9384,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9385,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9386,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9387,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9388,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9389,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9390,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik dengan Terapi Dialisis Cair (1376)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9391,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9392,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9393,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9394,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9395,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9396,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9397,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9398,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Cair (1374)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9399,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    9400,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9401,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9402,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.02",
  ],
  [
    9403,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9404,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9405,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Ginjal Kronik Pradialisis Padat (1373)",
    "Densitas Energi (kkal/ml)",
    "",
    "=1.5",
  ],
  [
    9406,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9407,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9408,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9409,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9410,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9411,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9412,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Cair (1372)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9413,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9414,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9415,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9416,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9417,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9418,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9419,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Ensefalopati Padat (1371)",
    "Osmolalitas (mOsm/kg)",
    "=500",
    "=300",
  ],
  [
    9420,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9421,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9422,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9423,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9424,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9425,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9426,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Cair (1370)",
    "Osmolalitas (mOsm/kg",
    "=500",
    "=300",
  ],
  [
    9427,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9428,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9429,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9430,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9431,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9432,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9433,
    "Pangan Olahan untuk Keperluan Medis Khusus untuk Pasien Penyakit Hati Non Ensefalopati Padat (1369)",
    "Osmolalitas (mOsm/kg",
    "=500",
    "=300",
  ],
  [
    9434,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Arsen (As) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9435,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Merkuri (Hg) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9436,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Kadmium (Cd) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9437,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Timbal (Pb) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9438,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9439,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Cair (1368)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9440,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Arsen (As) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9441,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Merkuri (Hg) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9442,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Kadmium (Cd) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9443,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Timbal (Pb) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9444,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9445,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Peyandang Diabetes Padat (1367)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9446,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Arsen (As) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9447,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Merkuri (Hg) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9448,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Kadmium (Cd) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9449,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Timbal (Pb) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9450,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9451,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9452,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9453,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Asam Amino Valin",
  ],
  [
    9454,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Asam Amino Leusin",
  ],
  [
    9455,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Cair (1366)",
    "Asam Amino Isoleusin",
  ],
  [
    9456,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Arsen (As) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9457,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Merkuri (Hg) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9458,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Kadmium (Cd) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9459,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Timbal (Pb) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9460,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9461,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9462,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9463,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Asam Amino Isoleusin",
  ],
  [
    9464,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Asam Amino Leusin",
  ],
  [
    9465,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Maple Syrup Urine Disease (MSUD) Padat (1365)",
    "Asam Amino Valin",
  ],
  [
    9466,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Arsen (As) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9467,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Merkuri (Hg) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9468,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Kadmium (Cd) (ppm atau mg/kg) (siap konsumsi)",
    "=0.01",
  ],
  [
    9469,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Timbal (Pb) (ppm atau mg/kg) (siap konsumsi)",
    "=0.02",
  ],
  [
    9470,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9471,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9472,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9473,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Fenilalanin",
  ],
  [
    9474,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Cair (1364)",
    "Tirosin",
  ],
  [9475, ""],
  [
    9476,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Arsen (As) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9477,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Merkuri (Hg) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9478,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Kadmium (Cd) (ppm atau mg/L) - Siap Konsumsi",
    "=0.01",
  ],
  [
    9479,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Timbal (Pb) (ppm atau mg/L) - Siap Konsumsi",
    "=0.02",
  ],
  [
    9480,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/L)",
    "=250",
  ],
  [
    9481,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/L) ",
    "=40",
  ],
  [
    9482,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    9483,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Fenilalanin",
  ],
  [
    9484,
    "Pangan Olahan Untuk Keperluan Medis Khusus Untuk Tatalaksana Diet Penyakit Kelainan Bawaan Metabolik Tyrosinemia Padat (1363)",
    "Tirosin",
  ],
  [
    9485,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    9486,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9487,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    9488,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9489,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9490,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9491,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Energi bersumber dari Karbohidrat (%)",
    "",
    "=90",
  ],
  [
    9492,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (1377)",
    "Berat produk bersumber dari karbohidrat (%) (b/b)",
    "",
    "=15",
  ],
  [
    9493,
    "Pangan Tambahan untuk Olahragawan Berbasis Karbohidrat (Cair) (1378)",
    "Prolin (mg/hari)",
    "=1100",
  ],
  [
    9494,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9495,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9496,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9497,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9498,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9499,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    9500,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Energi dari Lemak (%)",
    "=25",
  ],
  [
    9501,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Energi dari Protein (%)",
    "=30",
    "=15",
  ],
  [
    9502,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Alanin (mg/hari)",
    "=1200",
  ],
  [
    9503,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Arginin (mg/hari)",
    "=1100",
  ],
  [
    9504,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Asam aspartat (mg/hari)",
    "=600",
  ],
  [
    9505,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Sistein (mg/hari)",
    "=440",
  ],
  [
    9506,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Glutamin (mg/hari)",
    "=1900",
  ],
  [
    9507,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Asam Glutamat (mg/hari)",
    "=1600",
  ],
  [
    9508,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Glisin (mg/hari)",
    "=1500",
  ],
  [
    9509,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Histidin (mg/hari)",
    "=420",
  ],
  [
    9510,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Isoleusin (mg/hari)",
    "=350",
  ],
  [
    9511,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Leusin (mg/hari)",
    "=490",
  ],
  [
    9512,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Lisin (mg/hari)",
    "=420",
  ],
  [
    9513,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Metionin (mg/hari)",
    "=180",
  ],
  [
    9514,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Ornitin (mg/hari)",
    "=360",
  ],
  [
    9515,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Fenilalanin (mg/hari)",
    "=490",
  ],
  [
    9516,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Serin (mg/hari)",
    "=1400",
  ],
  [
    9517,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Taurin (mg/hari)",
    "=60",
  ],
  [
    9518,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Treonin (mg/hari)",
    "=245",
  ],
  [
    9519,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Tirosin (mg/hari)",
    "=400",
  ],
  [
    9520,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Triptofan (mg/hari)",
    "=100",
  ],
  [
    9521,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Valin (mg/hari)",
    "=350",
  ],
  [
    9522,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "L-Karnitin (mg/hari)",
    "=100",
  ],
  [
    9523,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Kolin (mg/hari)",
    "=10",
  ],
  [
    9524,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Inosin (mg/hari)",
    "=10",
  ],
  [
    9525,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Kreatin (g/hari)",
    "=3",
  ],
  [
    9526,
    "Pangan Tambahan untuk Olahragawan Berbasis Protein (1379)",
    "Kafein (mg/hari)",
    "=150",
  ],
  [
    9527,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9528,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9529,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9530,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9531,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9532,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Cair (1334)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9533,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9534,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9535,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9536,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9537,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9538,
    "Pangan Tambahan untuk Olahragawan Diperkaya Protein Padat (1333)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9539,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9540,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9541,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9542,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9543,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9544,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9545,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Cair (1330)",
    "Kafein (mg/100 g)",
    "=150",
  ],
  [
    9546,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9547,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9548,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9549,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9550,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9551,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9552,
    "Pangan Tambahan untuk Olahragawan Karbohidrat Elektrolit Padat (1329)",
    "Kafein (mg/100 g)",
    "=150",
  ],
  [
    9553,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9554,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9555,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9556,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9557,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9558,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9559,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Aflaktoksin M1 (ppb)/ (mcg/kg)",
    "=5",
  ],
  [
    9560,
    "Pangan Tambahan untuk Olahragawan Protein Konsentrat Padat (1331)",
    "Kafein (mg/100g)",
    "=150",
  ],
  [
    9561,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9562,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9563,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9564,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9565,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=100",
  ],
  [
    9566,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Cair (Steril) (13050506)",
    "Aflatoksin (M1) mcg/kg) ",
    "=0.5",
  ],
  [
    9567,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9568,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9569,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9570,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9571,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    9572,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi Dari Karbohidrat - Padat (13050505)",
    "Aflatoksin (M1) mcg/kg) - Basis Susu",
    "=0.5",
  ],
  [
    9573,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9574,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9575,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9576,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9577,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9578,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Cair (1328)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9579,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9580,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9581,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9582,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9583,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9584,
    "Pangan Tambahan Untuk Olahragawan Tinggi Energi dari Karbohidrat Padat (1327)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9585,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9586,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9587,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9588,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9589,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9590,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9591,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Energi dari Lemak (%)",
    "=25",
  ],
  [
    9592,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Energi dari Protein (%)",
    "=70",
    "=31",
  ],
  [
    9593,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Vitamin B6 (Piridoksin) (mg/gram protein)",
    "",
    "=0.02",
  ],
  [
    9594,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Alanin (mg/hari)",
    "=1200",
  ],
  [
    9595,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Arginin (mg/hari)",
    "=1100",
  ],
  [
    9596,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Asam aspartat (mg/hari)",
    "=600",
  ],
  [
    9597,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Sistein (mg/hari)",
    "=440",
  ],
  [
    9598,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Glutamin (mg/hari)",
    "=1900",
  ],
  [
    9599,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Asam Glutamat (mg/hari)",
    "=1600",
  ],
  [
    9600,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Glisin (mg/hari)",
    "=1500",
  ],
  [
    9601,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Isoleusin (mg/hari)",
    "=350",
  ],
  [
    9602,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Leusin (mg/hari)",
    "=490",
  ],
  [
    9603,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Lisin (mg/hari)",
    "=420",
  ],
  [
    9604,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Metionin (mg/hari)",
    "=180",
  ],
  [
    9605,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Ornitin (mg/hari)",
    "=360",
  ],
  [
    9606,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Fenilalanin (mg/hari)",
    "=490",
  ],
  [
    9607,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Prolin (mg/hari)",
    "=1100",
  ],
  [
    9608,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Serin (mg/hari)",
    "=1400",
  ],
  [
    9609,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Taurin (mg/hari)",
    "=60",
  ],
  [
    9610,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Treonin (mg/hari)",
    "=245",
  ],
  [
    9611,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Tirosin (mg/hari)",
    "=400",
  ],
  [
    9612,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Triptofan (mg/hari)",
    "=100",
  ],
  [
    9613,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Valin (mg/hari)",
    "=350",
  ],
  [
    9614,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "L-Karnitin (mg/hari)",
    "=100",
  ],
  [
    9615,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Kolin (mg/hari)",
    "=10",
  ],
  [
    9616,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Inosin (mg/hari)",
    "<10",
  ],
  [
    9617,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Kreatin (g/hari)",
    "=3",
  ],
  [
    9618,
    "Pangan Tambahan untuk Olahragawan Tinggi Energi Protein (1388)",
    "Kafein (mg/hari)",
    "=150",
  ],
  [
    9619,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9620,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9621,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9622,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9623,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=100",
  ],
  [
    9624,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Cair (Steril) (13050508)",
    "Aflatoksin (M1) mcg/kg) ",
    "=0.5",
  ],
  [
    9625,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9626,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9627,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9628,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9629,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    9630,
    "Pangan Tambahan Untuk Olahragawan Tinggi Karbohidrat Elektrolit - Padat (13050507)",
    "Aflatoksin (M1) mcg/kg) - Basis Susu",
    "=0.5",
  ],
  [
    9631,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9632,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9633,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9634,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9635,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=100",
  ],
  [
    9636,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Cair (Steril) (13050502)",
    "Aflatoksin (M1) mcg/kg) ",
    "=0.5",
  ],
  [
    9637,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9638,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9639,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9640,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9641,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    9642,
    "Pangan Tambahan Untuk Olahragawan Tinggi Protein Konsentrat - Padat (13050501)",
    "Aflatoksin (M1) mcg/kg) - Basis Susu",
    "=0.5",
  ],
  [
    9643,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9644,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9645,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9646,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9647,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=100",
  ],
  [
    9648,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Cair (Steril) (13050504)",
    "Aflatoksin (M1) mcg/kg) ",
    "=0.5",
  ],
  [
    9649,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    9650,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.01",
  ],
  [
    9651,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.01",
  ],
  [
    9652,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Timah (Sn) (mg/kg) yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    9653,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Timah (Sn) (mg/kg) yang dikemas dalam kaleng ",
    "=250",
  ],
  [
    9654,
    "Pangan Tambahan Untuk Olahragawan Yang Diperkaya Protein - Padat (13050503)",
    "Aflatoksin (M1) mcg/kg) - Basis Susu",
    "=0.5",
  ],
  [
    9655,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9656,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9657,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9658,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9659,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9660,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9661,
    "Pangan Untuk Kontrol Berat Badan Cair (1336)",
    "Kadar Protein (% dari energi total per saji)",
    "=50",
    "=20",
  ],
  [
    9662,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9663,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9664,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    9665,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9666,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9667,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg)",
    "=40",
  ],
  [
    9668,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Kadar Protein (% dari energi total per saji)",
    "=50",
    "=20",
  ],
  [
    9669,
    "Pangan Untuk Kontrol Berat Badan Padat (1335)",
    "Kadar Asam Linolet (% dari energi total)",
    "",
    "=3",
  ],
  [
    9670,
    "Pangsit Daging (08030315)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9671,
    "Pangsit Daging (08030315)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9672,
    "Pangsit Daging (08030315)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9673,
    "Pangsit Daging (08030315)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9674,
    "Pangsit Daging (08030315)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9675,
    "Pangsit Daging (08030315)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [9676, "Pangsit Daging (08030315)", "Kadar Daging (%)", "", ">15"],
  [9677, "Pangsit Daging (08030315)", "Kadar Ikan (%)", "<15"],
  [
    9678,
    "Pangsit Daging (08030315)",
    "Total Meat Content (%)",
    "",
    "=30",
  ],
  [
    9679,
    "Pangsit Isi Sayuran (1658)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9680,
    "Pangsit Isi Sayuran (1658)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    9681,
    "Pangsit Isi Sayuran (1658)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9682,
    "Pangsit Isi Sayuran (1658)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9683,
    "Pangsit Isi Sayuran (1658)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9684,
    "Pangsit Isi Sayuran (1658)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9685,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9686,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    9687,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9688,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9689,
    "Pangsit Seafood (Ikan, Udang, Cumi, dll) (0902040119)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9690,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    9691,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    9692,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9693,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    9694,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    9695,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Mentah (06040105)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9696,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    9697,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    9698,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9699,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    9700,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    9701,
    "Pangsit/Pastel/Lumpia/Risol/Samosa Pramasak (06040326)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9702,
    "Paprika Bubuk (12020186)",
    "Kadar air tidak lebih dari (%)",
    "=14",
  ],
  [9703, "Paprika Bubuk (12020186)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    9704,
    "Paprika Bubuk (12020186)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [9705, "Paprika Bubuk (12020186)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    9706,
    "Paprika Bubuk (12020186)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [9707, "Paprika Bubuk (12020186)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    9708,
    "Parsley (12020185)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    9709,
    "Parsley (12020185)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    9710,
    "Parsley (12020185)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    9711,
    "Parsley (12020185)",
    "Timah (Sn) untuk produk yang diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    9712,
    "Parsley (12020185)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    9713,
    "Parsley (12020185)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [9714, "Pasta (06040218)", "Kadar air (%)", "=12.5"],
  [9715, "Pasta (06040218)", "Kadar protein", "", "=10"],
  [9716, "Pasta (06040218)", "Arsen (As) (mg/kg)", "=0.1"],
  [9717, "Pasta (06040218)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [9718, "Pasta (06040218)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    9719,
    "Pasta (06040218)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9720,
    "Pasta (06040218)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9721, "Pasta (06040218)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    9722,
    "Pasta (06040218)",
    "Total Padatan Susu (untuk produk pasta susu) (%)",
    "",
    "=3.8",
  ],
  [9723, "Pasta (0604A0)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    9724,
    "Pasta (0604A0)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9725,
    "Pasta (0604A0)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9726,
    "Pasta (0604A0)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [9727, "Pasta (0604A0)", "Timbal (Pb) (ppm atau mg/kg)", "=0.25"],
  [
    9728,
    "Pasta (0604A0)",
    "Total Padatan Susu (untuk produk pasta susu) (%)",
    "",
    "=3.8",
  ],
  [
    9729,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....) (1670)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9730,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....) (1670)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    9731,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....) (1670)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9732,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....) (1670)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=200",
  ],
  [
    9733,
    "Pasta (Spagheti, Makaroni,...) dengan Saus dan Daging (Sapi, Babi, Ayam, ....) (1670)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9734,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9735,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9736,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9737,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9738,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9739,
    "Pasta Biji Kopi Manis (Untuk Bahan Pengisi) (0402020608)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [9740, "Pasta Buah (0401020803)", "Total padatan (%)", "", "=25"],
  [
    9741,
    "Pasta Buah (0401020803)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9742,
    "Pasta Buah (0401020803)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9743,
    "Pasta Buah (0401020803)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9744,
    "Pasta Buah (0401020803)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    9745,
    "Pasta Buah (0401020803)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    9746,
    "Pasta Daging (08030208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9747,
    "Pasta Daging (08030208)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9748,
    "Pasta Daging (08030208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9749,
    "Pasta Daging (08030208)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9750,
    "Pasta Daging (08030208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9751,
    "Pasta Daging (08030208)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9752,
    "Pasta Gonad Bulu Babi (09020523)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    9753,
    "Pasta Gonad Bulu Babi (09020523)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    9754,
    "Pasta Gonad Bulu Babi (09020523)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    9755,
    "Pasta Gonad Bulu Babi (09020523)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    9756,
    "Pasta Gonad Bulu Babi (09020523)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    9757,
    "Pasta Gonad Bulu Babi (09020523)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [9758, "Pasta Ikan (09020518)", "Arsen (As) (mg/kg)", "=0.25"],
  [9759, "Pasta Ikan (09020518)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [9760, "Pasta Ikan (09020518)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [9761, "Pasta Ikan (09020518)", "Timah (Sn) (mg/kg)", "=40"],
  [9762, "Pasta Ikan (09020518)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [9763, "Pasta Instan (06040321)", "Kadar Air (%)", "=12.5"],
  [9764, "Pasta Instan (06040321)", "Kadar Protein (%)", "", "=10"],
  [
    9765,
    "Pasta Instan (06040321)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9766,
    "Pasta Instan (06040321)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9767,
    "Pasta Instan (06040321)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9768,
    "Pasta Instan (06040321)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    9769,
    "Pasta Instan (06040321)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9770,
    "Pasta Instan Lainnya (06040320)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9771,
    "Pasta Instan Lainnya (06040320)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9772,
    "Pasta Instan Lainnya (06040320)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9773,
    "Pasta Instan Lainnya (06040320)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    9774,
    "Pasta Instan Lainnya (06040320)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    9775,
    "Pasta Instan Lainnya (06040320)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9776,
    "Pasta Instan Lainnya (06040320)",
    "Kadar air (%)",
    "=12.5",
  ],
  [
    9777,
    "Pasta Kacang Merah Manis (0402020607)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9778,
    "Pasta Kacang Merah Manis (0402020607)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9779,
    "Pasta Kacang Merah Manis (0402020607)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9780,
    "Pasta Kacang Merah Manis (0402020607)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9781,
    "Pasta Kacang Merah Manis (0402020607)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9782,
    "Pasta Kacang Merah Manis (0402020607)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9783,
    "Pasta Kacang Merah Manis (0402020607)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [9784, "Pasta Kelapa (0401020810)", "Kadar Lemak (%)", "", "=60"],
  [
    9785,
    "Pasta Kelapa (0401020810)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9786,
    "Pasta Kelapa (0401020810)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9787,
    "Pasta Kelapa (0401020810)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9788,
    "Pasta Kelapa (0401020810)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    9789,
    "Pasta Kelapa (0401020810)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    9790,
    "Pasta Kelapa (0401020810)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [9791, "Pasta lainnya (06040219)", "Kadar air (%)", "=12.5"],
  [9792, "Pasta lainnya (06040219)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    9793,
    "Pasta lainnya (06040219)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9794,
    "Pasta lainnya (06040219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9795,
    "Pasta lainnya (06040219)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9796,
    "Pasta lainnya (06040219)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9797,
    "Pasta lainnya (06040219)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9798,
    "Pasta Tomat (0402020601)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    9799,
    "Pasta Tomat (0402020601)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9800,
    "Pasta Tomat (0402020601)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9801,
    "Pasta Tomat (0402020601)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9802,
    "Pasta Tomat (0402020601)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    9803,
    "Pasta Tomat (0402020601)",
    "Total padatan terlarut (%)",
    "",
    "=24",
  ],
  [
    9804,
    "Pasta Tomat (0402020601)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [9805, "Pasta Umbi (0402020615)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    9806,
    "Pasta Umbi (0402020615)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9807,
    "Pasta Umbi (0402020615)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9808,
    "Pasta Umbi (0402020615)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    9809,
    "Pasta Umbi (0402020615)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [9810, "Pasta Umbi (0402020615)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [9811, "Pastiles (05020102)", "Arsen (As) (mg/kg)", "=1"],
  [9812, "Pastiles (05020102)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [9813, "Pastiles (05020102)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    9814,
    "Pastiles (05020102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9815, "Pastiles (05020102)", "Timbal (Pb) (mg/kg)", "=1"],
  [9816, "Pastri (07020201)", "Arsen (As) (mg/kg)", "=0.5"],
  [9817, "Pastri (07020201)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [9818, "Pastri (07020201)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [9819, "Pastri (07020201)", "Timah (Sn) (mg/kg)", "=40"],
  [9820, "Pastri (07020201)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    9821,
    "Pate Daging (08030232)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    9822,
    "Pate Daging (08030232)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    9823,
    "Pate Daging (08030232)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9824,
    "Pate Daging (08030232)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9825,
    "Pate Daging (08030232)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9826,
    "Pate Daging (08030232)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [9827, "Pati Gandum (06020209)", "Arsen (As) (mg/kg)", "=0.10"],
  [9828, "Pati Gandum (06020209)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [9829, "Pati Gandum (06020209)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [9830, "Pati Gandum (06020209)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [
    9831,
    "Pati Gandum (06020209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9832, "Pati Garut (06020201)", "Arsen (As) (mg/kg)", "=0.1"],
  [9833, "Pati Garut (06020201)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [9834, "Pati Garut (06020201)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    9835,
    "Pati Garut (06020201)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9836,
    "Pati Garut (06020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [9837, "Pati Garut (06020201)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [9838, "Pati Garut (06020201)", "Kadar air (%)", "=16"],
  [
    9839,
    "Pati Garut (06020201)",
    "kehalusan (lolos ayakan 100 mesh)",
    "",
    "=95",
  ],
  [
    9840,
    "Pati Jagung atau Maizena (06020202)",
    "Kadar air (%)",
    "=14",
  ],
  [
    9841,
    "Pati Jagung atau Maizena (06020202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9842,
    "Pati Jagung atau Maizena (06020202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9843,
    "Pati Jagung atau Maizena (06020202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9844,
    "Pati Jagung atau Maizena (06020202)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9845,
    "Pati Jagung atau Maizena (06020202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9846,
    "Pati Jagung atau Maizena (06020202)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9847,
    "Pati Jagung atau Maizena (06020202)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9848,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Kadar air (%)",
    "=14",
  ],
  [
    9849,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    9850,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9851,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9852,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9853,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9854,
    "Pati Kacang Hijau/Hunkwee (06020204)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9855,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    9856,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9857,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9858,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Timah (Sn) pangan olahan Lain yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    9859,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    9860,
    "Pati Lainnya (Biji-Bijian, Umbi-Umbian, dll) (06020210)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9861,
    "Pati Sagu (06020203)",
    "Kadar air tidak lebih dari (%) ",
    "=13",
  ],
  [9862, "Pati Sagu (06020203)", "Arsen (As) (mg/kg) ", "=0.1"],
  [9863, "Pati Sagu (06020203)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [9864, "Pati Sagu (06020203)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [9865, "Pati Sagu (06020203)", "Timah (Sn) (mg/kg)", "=40"],
  [9866, "Pati Sagu (06020203)", "Timbal (Pb) (mg/kg) ", "=0.25"],
  [
    9867,
    "Pati Termodifikasi (06020207)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    9868,
    "Pati Termodifikasi (06020207)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9869,
    "Pati Termodifikasi (06020207)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9870,
    "Pati Termodifikasi (06020207)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9871,
    "Pati Termodifikasi (06020207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9872,
    "Pati Termodifikasi (06020207)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9873,
    "Patilo / Rengginang Singkong (150139)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9874,
    "Patilo / Rengginang Singkong (150139)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    9875,
    "Patilo / Rengginang Singkong (150139)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    9876,
    "Patilo / Rengginang Singkong (150139)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    9877,
    "Patilo / Rengginang Singkong (150139)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9878,
    "Patties (08010216)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9879,
    "Patties (08010216)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9880,
    "Patties (08010216)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9881,
    "Patties (08010216)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9882,
    "Patties (08010216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9883,
    "Patties (08010216)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9884,
    "Patties Daging Matang (08030209)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9885,
    "Patties Daging Matang (08030209)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9886,
    "Patties Daging Matang (08030209)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9887,
    "Patties Daging Matang (08030209)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9888,
    "Patties Daging Matang (08030209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9889,
    "Patties Daging Matang (08030209)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9890,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9891,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9892,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9893,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9894,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9895,
    "Patties Daging Panggang Setengah Matang (08030201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9896,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9897,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9898,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9899,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9900,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9901,
    "Patties Daging Sapi Segar (Burger) (08010201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9902,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    9903,
    "Pekak/Bunga Lawang/Star Anise (12020191)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    9904,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9905,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9906,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9907,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    9908,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    9909,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9910,
    "Pempek Ikan (Goreng atau Panggang) (0902040313)",
    "Kandungan lumatan daging ikan segar dan/atau surimi (%)",
    "",
    "=30",
  ],
  [
    9911,
    "Pempek Ikan (Rebus) (0902040112)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9912,
    "Pempek Ikan (Rebus) (0902040112)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9913,
    "Pempek Ikan (Rebus) (0902040112)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9914,
    "Pempek Ikan (Rebus) (0902040112)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9915,
    "Pempek Ikan (Rebus) (0902040112)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9916,
    "Pempek Ikan (Rebus) (0902040112)",
    "Kandungan lumatan daging ikan segar dan/atau surimi (%)",
    "",
    "=30",
  ],
  [
    9917,
    "Pempek Ikan Rebus Beku (09020132)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9918,
    "Pempek Ikan Rebus Beku (09020132)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9919,
    "Pempek Ikan Rebus Beku (09020132)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9920,
    "Pempek Ikan Rebus Beku (09020132)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    9921,
    "Pempek Ikan Rebus Beku (09020132)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    9922,
    "Pempek Ikan Rebus Beku (09020132)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9923,
    "Pempek Ikan Rebus Beku (09020132)",
    "Kandungan lumatan daging ikan segar dan/atau surimi (%)",
    "",
    "=30",
  ],
  [
    9924,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9925,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    9926,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9927,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9928,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9929,
    "Pengembang Roti/Kue (Bread Improver) (1657)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    9930,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Kandungan Natrium Total (g/100g) ",
    "=0.12",
  ],
  [
    9931,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Kadar Iodium dihitung sebagai KIO3 (mg/kg) ",
    "",
    "=30",
  ],
  [
    9932,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Uji Organoleptik",
  ],
  [
    9933,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9934,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9935,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9936,
    "Pengganti Garam atau Garam Substitusi (Salt Substitute) (120102)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9937,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9938,
    "Substitute=CBS Lauric) (05010502)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    9939,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9940,
    "Substitute=CBS Lauric) (05010502)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9941,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9942,
    "Substitute=CBS Lauric) (05010502)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9943,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9944,
    "Substitute=CBS Lauric) (05010502)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    9945,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9946,
    "Substitute=CBS Lauric) (05010502)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    9947,
    "Pengganti Lemak Kakao Laurat (Lauric Cocoa Butter Replacer/",
  ],
  [
    9948,
    "Substitute=CBS Lauric) (05010502)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9949,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9950,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    9951,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9952,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9953,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9954,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9955,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9956,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    9957,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9958,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    9959,
    "Pengganti Lemak Kakao Non-Laurat (Nonlauric Cocoa Butter Replacer/",
  ],
  [
    9960,
    "Substitute = CBS Non-Lauric) (05010503)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9961,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9962,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9963,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9964,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9965,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9966,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    9967,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Kadar air (%) ",
    "=0.15",
  ],
  [
    9968,
    "Pengganti Minyak Mentega (Butter Oil Substitute) (02010210)",
    "Kadar asam lemak bebas berasal dari minyak sawit dihitung sebagai asam palmitat, berasal dari minyak kelapa atau minyak inti sawit dihitung sebagai asam laurat, berasal dari minyak nabati lainnya dihitung sebagai asam oleat (%)",
    "=0.3",
  ],
  [
    9969,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Angka Lempeng Total (30\xB0C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    9970,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    9971,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    9972,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    9973,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    9974,
    "Pepes Ikan/Pepes Teri (0902040114)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9975,
    "Pepes Udang (0902040207)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [9976, "Pepes Udang (0902040207)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    9977,
    "Pepes Udang (0902040207)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [9978, "Pepes Udang (0902040207)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [9979, "Pepes Udang (0902040207)", "Timah (Sn) (mg/kg)", "=40"],
  [9980, "Pepes Udang (0902040207)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    9981,
    "Pepperoni (08030243)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    9982,
    "Pepperoni (08030243)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    9983,
    "Pepperoni (08030243)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    9984,
    "Pepperoni (08030243)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9985,
    "Pepperoni (08030243)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9986,
    "Pepperoni (08030243)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    9987,
    "Perkedel Kentang Beku (0402020116)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    9988,
    "Perkedel Kentang Beku (0402020116)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    9989,
    "Perkedel Kentang Beku (0402020116)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    9990,
    "Perkedel Kentang Beku (0402020116)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    9991,
    "Perkedel Kentang Beku (0402020116)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    9992,
    "Perkedel Kentang Beku (0402020116)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    9993,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    9994,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    9995,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    9996,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    9997,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    9998,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    9999,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10000,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah (ppb atau mcg/kg)",
    "=20",
  ],
  [
    10001,
    "Permen Enting-Enting atau Nut Brittles (05020303)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah (ppb/mcg/kg)",
    "=10",
  ],
  [10002, "Perry (14020202)", "Kadar etanol (%)", "", "=8.5"],
  [
    10003,
    "Perry (14020202)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    10004,
    "Perry (14020202)",
    "Jumlah Sari Buah Apel dari total jumlah sari buah (% v/v)",
    "=25",
  ],
  [10005, "Perry (14020202)", "Arsen (ppm atau mg/L)", "=0.1"],
  [10006, "Perry (14020202)", "Kadmium (ppm atau mg/L)", "=0.2"],
  [10007, "Perry (14020202)", "Merkuri (ppm atau mg/L)", "=0.03"],
  [
    10008,
    "Perry (14020202)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    10009,
    "Perry (14020202)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [10010, "Perry (14020202)", "Timbal (ppm atau mg/L)", "=0.2"],
  [10011, "Petah (060714)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    10012,
    "Petah (060714)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10013,
    "Petah (060714)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10014,
    "Petah (060714)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    10015,
    "Petah (060714)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10016,
    "Petah (060714)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10017,
    "Picalili (0402020311)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10018,
    "Picalili (0402020311)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [10019, "Picalili (0402020311)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    10020,
    "Picalili (0402020311)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    10021,
    "Picalili (0402020311)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    10022,
    "Picalili (0402020311)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10023,
    "Picung (12020164)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10024,
    "Picung (12020164)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10025,
    "Picung (12020164)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10026,
    "Picung (12020164)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    10027,
    "Picung (12020164)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    10028,
    "Picung (12020164)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10029,
    "Picung (12020164)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    10030,
    "Pidan atau Telur Hitam (100304)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10031,
    "Pidan atau Telur Hitam (100304)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    10032,
    "Pidan atau Telur Hitam (100304)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    10033,
    "Pidan atau Telur Hitam (100304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10034,
    "Pidan atau Telur Hitam (100304)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10035,
    "Pikel (fermentasi) (0402020701)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10036,
    "Pikel (fermentasi) (0402020701)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10037,
    "Pikel (fermentasi) (0402020701)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10038,
    "Pikel (fermentasi) (0402020701)",
    "Timah (Sn) tidak dikemas kaleng (mg/kg)",
    "=40",
  ],
  [
    10039,
    "Pikel (fermentasi) (0402020701)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [10040, "Pikel Buah (0401021005)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    10041,
    "Pikel Buah (0401021005)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    10042,
    "Pikel Buah (0401021005)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10043,
    "Pikel Buah (0401021005)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    10044,
    "Pikel Buah (0401021005)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [10045, "Pikel Buah (0401021005)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    10046,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10047,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10048,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10049,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10050,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10051,
    "Pikel Daging Anjing Laut (Pickled Whale) (09030206)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10052,
    "Pikel Jahe (0402020706)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10053,
    "Pikel Jahe (0402020706)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10054,
    "Pikel Jahe (0402020706)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10055,
    "Pikel Jahe (0402020706)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    10056,
    "Pikel Jahe (0402020706)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10057,
    "Pikel Mentimun (0402020705)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10058,
    "Pikel Mentimun (0402020705)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10059,
    "Pikel Mentimun (0402020705)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10060,
    "Pikel Mentimun (0402020705)",
    "Timah (Sn) tidak dikemas kaleng (mg/kg)",
    "=40",
  ],
  [
    10061,
    "Pikel Mentimun (0402020705)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10062,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10063,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10064,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10065,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10066,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10067,
    "Pikel Persik (Plum Pickles) (0401021002)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    10068,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10069,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10070,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10071,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10072,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10073,
    "Pikel Pir (Pear Pickles) (0401021001)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    10074,
    "Pikel Zaitun (Olives) (0402020707)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10075,
    "Pikel Zaitun (Olives) (0402020707)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10076,
    "Pikel Zaitun (Olives) (0402020707)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10077,
    "Pikel Zaitun (Olives) (0402020707)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10078,
    "Pikel Zaitun (Olives) (0402020707)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [10079, "Pilus (150118)", "Kadar air (%) (tanpa coating)", "=2"],
  [10080, "Pilus (150118)", "Arsen (As) (ppm atau mg/kg)", "=0.25"],
  [
    10081,
    "Pilus (150118)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [10082, "Pilus (150118)", "Raksa (Hg) (ppm atau mg/kg)", "=0.03"],
  [
    10083,
    "Pilus (150118)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10084,
    "Pilus (150118)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [10085, "Pilus (150118)", "Kadar air (%) (dengan coating)", "=3"],
  [
    10086,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10087,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10088,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10089,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10090,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    10091,
    "Pink Beans yang telah Dimasak Dalam Kaleng (0402020414)",
    "Bobot Tuntas (%)",
  ],
  [10092, "Pizza (07020209)", "Arsen (As) (mg/kg)", "=0.5"],
  [10093, "Pizza (07020209)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10094, "Pizza (07020209)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    10095,
    "Pizza (07020209)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10096,
    "Pizza (07020209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [10097, "Pizza (07020209)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    10098,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Arsen (As) mg/kg (siap konsumsi)",
    "=0.02",
  ],
  [
    10099,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Timbal (Pb) mg/kg (siap konsumsi)",
    "=0.02",
  ],
  [
    10100,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Merkuri (Hg) mg/kg (siap konsumsi)",
    "=0.01",
  ],
  [
    10101,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Kadmium (Cd) mg/kg (siap konsumsi)",
    "=0.01",
  ],
  [
    10102,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Timah (Sn) mg/kg",
    "=40",
  ],
  [
    10103,
    "PKMK Program Pemerintah Untuk Anak (Padat) (1382)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    10104,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Arsen (As) (mg/kg)",
    "=0.02",
  ],
  [
    10105,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Kadmium (Cd) (mg/kg)",
    "=0.01",
  ],
  [
    10106,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Merkuri (Hg) (mg/kg)",
    "= 0.01",
  ],
  [
    10107,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "= 250",
  ],
  [
    10108,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "= 40",
  ],
  [
    10109,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Timbal (Pb) (mg/kg)",
    "= 0.02",
  ],
  [
    10110,
    "PKMK Program Pemerintah Untuk Dewasa (Padat) (1383)",
    "Aflaktoksin M1 (ppb atau mcg/kg) - Untuk produk berbasis susu",
    "=0.03",
  ],
  [
    10111,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Arsen (As) (mg/kg) dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    10112,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Kadmium (Cd) (mg/kg) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    10113,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Merkuri (Hg) (mg/kg) dihitung terhadap produk siap konsumsi",
    "=0.01",
  ],
  [
    10114,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Timah (Sn) (mg/kg) (Dikemas dalam Kaleng)",
    "=250",
  ],
  [
    10115,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Timah (Sn) (mg/kg) (Tidak Dikemas dalam Kaleng)",
    "=40",
  ],
  [
    10116,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Timbal (Pb) (mg/kg) dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    10117,
    "PKMK untuk Pasien Penyakit Ginjal Kronik dengan Terapi Dialisis (Padat) (1398)",
    "Densitas Energi (kkal/ml)",
    "",
    "=1.5",
  ],
  [
    10118,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Kadar Daging (%)",
    "",
    "=30",
  ],
  [
    10119,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "As (mg/kg)",
    "=0.25",
  ],
  [
    10120,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Cd (mg/kg)",
    "=0.05",
  ],
  [
    10121,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Hg (mg/kg)",
    "=0.03",
  ],
  [
    10122,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10123,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10124,
    "Potongan Daging dengan Saus dalam Kemasan yang Dibekukan (08020312)",
    "Pb (mg/kg)",
    "=0.5",
  ],
  [
    10125,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10126,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Cadmium (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10127,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10128,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Timah daging olahan dalam kemasan kaleng (Sn) (ppm atau mg/kg)",
    "=250",
  ],
  [
    10129,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Pangan olahan yang tidak dikemas dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    10130,
    "Potongan Daging Unggas dan Daging Hewan Buruan Yang Dilepaskan Dari Tulangnya, Digiling Mekanik dan Dibentuk (Dengan atau Tanpa Pembaluran atau Pelapisan) (08010210)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10131,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Kadar daging (%)",
    "",
    "=30",
  ],
  [
    10132,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10133,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10134,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10135,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10136,
    "Potongan Daging/Daging Cincang/Daging Giling dengan Saus dalam Kemasan (08030241)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [10137, "Praline (05010428)", "Kandungan cokelat (%)", "", "=25"],
  [10138, "Praline (05010428)", "Arsen (As) (mg/kg)", "=1"],
  [10139, "Praline (05010428)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [10140, "Praline (05010428)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    10141,
    "Praline (05010428)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10142,
    "Praline (05010428)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [10143, "Praline (05010428)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    10144,
    "Pre-Fried Potatoes (0402020805)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10145,
    "Pre-Fried Potatoes (0402020805)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10146,
    "Pre-Fried Potatoes (0402020805)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10147,
    "Pre-Fried Potatoes (0402020805)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10148,
    "Pre-Fried Potatoes (0402020805)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10149,
    "Premiks Es Bentuk Bubuk (0321)",
    "Arsen (As) (mg/kg)",
    "=0.20",
  ],
  [
    10150,
    "Premiks Es Bentuk Bubuk (0321)",
    "Kadmium (Cd)(mg/kg)",
    "=0.01",
  ],
  [
    10151,
    "Premiks Es Bentuk Bubuk (0321)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10152,
    "Premiks Es Bentuk Bubuk (0321)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10153,
    "Premiks Es Bentuk Bubuk (0321)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    10154,
    "Premiks Es Bentuk Bubuk (0321)",
    "Timbal (Pb) (mg/kg)",
    "=0.15",
  ],
  [
    10155,
    "Premiks Es Bentuk Cair (0322)",
    "Arsen (As) (mg/kg)",
    "=0.20",
  ],
  [
    10156,
    "Premiks Es Bentuk Cair (0322)",
    "Kadmium (Cd)(mg/kg)",
    "=0.01",
  ],
  [
    10157,
    "Premiks Es Bentuk Cair (0322)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10158,
    "Premiks Es Bentuk Cair (0322)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10159,
    "Premiks Es Bentuk Cair (0322)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    10160,
    "Premiks Es Bentuk Cair (0322)",
    "Timbal (Pb) (mg/kg)",
    "=0.15",
  ],
  [
    10161,
    "Premiks Es Krim (Bubuk) (010712)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    10162,
    "Premiks Es Krim (Bubuk) (010712)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    10163,
    "Premiks Es Krim (Bubuk) (010712)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10164,
    "Premiks Es Krim (Bubuk) (010712)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10165,
    "Premiks Es Krim (Bubuk) (010712)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10166,
    "Premiks Es Krim (Bubuk) (010712)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10167,
    "Premiks Es Krim (Bubuk) (010712)",
    "Kadar protein susu (%)",
    "",
    "=4.5",
  ],
  [
    10168,
    "Premiks Es Krim (Bubuk) (010712)",
    "Kadar lemak total (%)",
    "",
    "=15",
  ],
  [
    10169,
    "Premiks Es Krim (Bubuk) (010712)",
    "Kadar air (%)",
    "=5",
  ],
  [
    10170,
    "Premiks Es Krim (Bubuk) (010712)",
    "Kadar Lemak Susu (%)",
  ],
  [
    10171,
    "Premiks Es Krim (Bubuk) (010712)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    10172,
    "Premiks Es Krim (Cair) (010715)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    10173,
    "Premiks Es Krim (Cair) (010715)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    10174,
    "Premiks Es Krim (Cair) (010715)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10175,
    "Premiks Es Krim (Cair) (010715)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10176,
    "Premiks Es Krim (Cair) (010715)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10177,
    "Premiks Es Krim (Cair) (010715)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10178,
    "Premiks Es Krim (Cair) (010715)",
    "Kadar Lemak Total (%)",
    "",
    "=5",
  ],
  [
    10179,
    "Premiks Es Krim (Cair) (010715)",
    "Total Padatan Susu (%)",
    "",
    "=5",
  ],
  [
    10180,
    "Premiks Es Krim (Cair) (010715)",
    "Total Padatan (%)",
    "",
    "= 31",
  ],
  [
    10181,
    "Premiks Es Krim (Cair) (010715)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "= 0.5",
  ],
  [
    10182,
    "Premiks Es Susu (Bubuk) (010721)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    10183,
    "Premiks Es Susu (Bubuk) (010721)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    10184,
    "Premiks Es Susu (Bubuk) (010721)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10185,
    "Premiks Es Susu (Bubuk) (010721)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10186,
    "Premiks Es Susu (Bubuk) (010721)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10187,
    "Premiks Es Susu (Bubuk) (010721)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10188,
    "Premiks Es Susu (Bubuk) (010721)",
    "Kadar protein susu (%)",
    "",
    "=3",
  ],
  [
    10189,
    "Premiks Es Susu (Bubuk) (010721)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    10190,
    "Premiks Es Susu (Cair) (010722)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    10191,
    "Premiks Es Susu (Cair) (010722)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    10192,
    "Premiks Es Susu (Cair) (010722)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10193,
    "Premiks Es Susu (Cair) (010722)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10194,
    "Premiks Es Susu (Cair) (010722)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10195,
    "Premiks Es Susu (Cair) (010722)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    10196,
    "Premiks Es Susu (Cair) (010722)",
    "Kadar protein susu (%)",
    "",
    "=1",
  ],
  [
    10197,
    "Premiks Es Susu (Cair) (010722)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    10198,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    10199,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10200,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10201,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10202,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10203,
    "Premiks Pengisi Roti (Serbuk) (050409)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10204,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10205,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10206,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10207,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    10208,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10209,
    "Premiks Untuk Makanan Pencuci Mulut Berbasis Serealia dan Pati (060510)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10210,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10211,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10212,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10213,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10214,
    "Premiks Untuk Produk Bakeri Istimewa (07020301)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10215,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10216,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10217,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10218,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10219,
    "Premiks Untuk Roti Tawar Dan Produk Bakeri Tawar (07010601)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10220,
    "Premiks Untuk Stuffing (07010405)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10221,
    "Premiks Untuk Stuffing (07010405)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10222,
    "Premiks Untuk Stuffing (07010405)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10223,
    "Premiks Untuk Stuffing (07010405)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10224,
    "Premiks Untuk Stuffing (07010405)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10225,
    "Pressed Candy/Lozenges (05020103)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    10226,
    "Pressed Candy/Lozenges (05020103)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10227,
    "Pressed Candy/Lozenges (05020103)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10228,
    "Pressed Candy/Lozenges (05020103)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10229,
    "Pressed Candy/Lozenges (05020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10230,
    "Pressed Candy/Lozenges (05020103)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10231,
    "Produk Buah Oles (0401020603)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10232,
    "Produk Buah Oles (0401020603)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10233,
    "Produk Buah Oles (0401020603)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10234,
    "Produk Buah Oles (0401020603)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    10235,
    "Produk Buah Oles (0401020603)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10236,
    "Produk Buah Oles (0401020603)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    10237,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10238,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10239,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10240,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Timah (Sn) (mg/kg) untuk pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng",
    "=250",
  ],
  [
    10241,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Timah (Sn) (ppm atau mg/kg) untuk yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    10242,
    "Produk Buah Untuk Isi Pastri (04010211)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    10243,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10244,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    10245,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10246,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    10247,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    10248,
    "Produk Jeli Tidak Siap Konsumsi (0402020617)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    10249,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Penambahan tepung kedelai (%) ",
    "",
    "=3.8",
  ],
  [
    10250,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Kadar protein (%) ",
    "",
    "=11",
  ],
  [
    10251,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10252,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10253,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10254,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Timah (Sn) Pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    10255,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10256,
    "Produk Mi Gandum dan Kedelai (06040213)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    10257,
    "Produk Mi Sayur (06040214)",
    "Sayur yang ditambahkan sebagai sayuran segar (%)",
    "",
    "=3",
  ],
  [
    10258,
    "Produk Mi Sayur (06040214)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10259,
    "Produk Mi Sayur (06040214)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    10260,
    "Produk Mi Sayur (06040214)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10261,
    "Produk Mi Sayur (06040214)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10262,
    "Produk Mi Sayur (06040214)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    10263,
    "Produk Olahan Gluten (121006)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10264,
    "Produk Olahan Gluten (121006)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10265,
    "Produk Olahan Gluten (121006)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10266,
    "Produk Olahan Gluten (121006)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10267,
    "Produk Olahan Gluten (121006)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10268,
    "Produk Olahan Gluten (121006)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10269,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10270,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    10271,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    10272,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10273,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10274,
    "Produk Olahan Telur Bentuk Sosis (10020304)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10275,
    "Produk Oles Untuk Salad (120701)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10276,
    "Produk Oles Untuk Salad (120701)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10277,
    "Produk Oles Untuk Salad (120701)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10278,
    "Produk Oles Untuk Salad (120701)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10279,
    "Produk Oles Untuk Salad (120701)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10280,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Penambahan tepung kedelai (%) ",
    "",
    "=12.5",
  ],
  [
    10281,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Kadar protein (%) ",
    "",
    "=13",
  ],
  [
    10282,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10283,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10284,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10285,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10286,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10287,
    "Produk Pasta Gandum dan Kedelai (06040206)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    10288,
    "Produk Pasta Gandum Utuh (06040205)",
    "Kadar Air (%)",
    "=12.5",
  ],
  [
    10289,
    "Produk Pasta Gandum Utuh (06040205)",
    "Kadar Protein (%)",
    "",
    "=10",
  ],
  [
    10290,
    "Produk Pasta Gandum Utuh (06040205)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10291,
    "Produk Pasta Gandum Utuh (06040205)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10292,
    "Produk Pasta Gandum Utuh (06040205)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10293,
    "Produk Pasta Gandum Utuh (06040205)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10294,
    "Produk Pasta Gandum Utuh (06040205)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10295,
    "Produk Pasta Gandum Utuh (06040205)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    10296,
    "Produk Pasta Sayur (06040208)",
    "Penambahan sayur (%) dihitung sebagai bahan segar ",
    "",
    "=3",
  ],
  [
    10297,
    "Produk Pasta Sayur (06040208)",
    "Kadar protein (%) ",
    "",
    "=9",
  ],
  [
    10298,
    "Produk Pasta Sayur (06040208)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10299,
    "Produk Pasta Sayur (06040208)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10300,
    "Produk Pasta Sayur (06040208)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10301,
    "Produk Pasta Sayur (06040208)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10302,
    "Produk Pasta Sayur (06040208)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10303,
    "Produk Pasta Sayur (06040208)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    10304,
    "Produk Pasta Susu (06040207)",
    "Total padatan susu (%) ",
    "",
    "=3.8",
  ],
  [
    10305,
    "Produk Pasta Susu (06040207)",
    "Kadar protein (%) ",
    "",
    "=11",
  ],
  [
    10306,
    "Produk Pasta Susu (06040207)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10307,
    "Produk Pasta Susu (06040207)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10308,
    "Produk Pasta Susu (06040207)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10309,
    "Produk Pasta Susu (06040207)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10310,
    "Produk Pasta Susu (06040207)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    10311,
    "Produk Pasta Susu (06040207)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    10312,
    "Produk Protein Gandum (121001)",
    "Kadar protein (N x 6,25) tanpa vitamin, mineral dan asam amino. (%) (bk)",
    "",
    "=40",
  ],
  [
    10313,
    "Produk Protein Gandum (121001)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10314,
    "Produk Protein Gandum (121001)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10315,
    "Produk Protein Gandum (121001)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [10316, "Produk Protein Gandum (121001)", "Timah (mg/kg)", "=40"],
  [
    10317,
    "Produk Protein Gandum (121001)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10318,
    "Produk Protein Kedelai (06080801)",
    "Kadar Air (% bk)",
    "=10",
  ],
  [
    10319,
    "Produk Protein Kedelai (06080801)",
    "Kadar Protein (%) (Tepung Protein Kedelai)",
    "=65",
    "=50",
  ],
  [
    10320,
    "Produk Protein Kedelai (06080801)",
    "Kadar Protein (%) (Konsentrat Protein Kedelai)",
    "=90",
    "=65",
  ],
  [
    10321,
    "Produk Protein Kedelai (06080801)",
    "Kadar Protein (%) (Isolat Protein)",
    "",
    "=90",
  ],
  [
    10322,
    "Produk Protein Kedelai (06080801)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10323,
    "Produk Protein Kedelai (06080801)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10324,
    "Produk Protein Kedelai (06080801)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10325,
    "Produk Protein Kedelai (06080801)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    10326,
    "Produk Protein Kedelai (06080801)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10327,
    "Produk Protein Kedelai (06080801)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10328,
    "Produk Protein Kedelai (121002)",
    "Kadar air (%) (bk)",
    "=10",
  ],
  [
    10329,
    "Produk Protein Kedelai (121002)",
    "Arsen (mg/kg)",
    "=0.25",
  ],
  [
    10330,
    "Produk Protein Kedelai (121002)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    10331,
    "Produk Protein Kedelai (121002)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    10332,
    "Produk Protein Kedelai (121002)",
    "Timah (mg/kg)",
    "=40",
  ],
  [
    10333,
    "Produk Protein Kedelai (121002)",
    "Timbal (mg/kg)",
    "=0.25",
  ],
  [
    10334,
    "Produk Protein Kedelai (121002)",
    "Kadar Protein untuk Tepung Protein Kedelai (%)",
    "=65",
    "=50",
  ],
  [
    10335,
    "Produk Protein Kedelai (121002)",
    "Kadar Protein untuk Konsentrat Protein Kedelai (%)",
    "=90",
    "=65",
  ],
  [
    10336,
    "Produk Protein Kedelai (121002)",
    "Kadar Protein untuk Isolat Protein Kedelai (%)",
    "",
    "=90",
  ],
  [
    10337,
    "Produk Protein Nabati (Vegetable Protein Products) (121007)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10338,
    "Produk Protein Nabati (Vegetable Protein Products) (121007)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10339,
    "Produk Protein Nabati (Vegetable Protein Products) (121007)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10340,
    "Produk Protein Nabati (Vegetable Protein Products) (121007)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    10341,
    "Produk Protein Nabati (Vegetable Protein Products) (121007)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10342,
    "Protein Susu (121005)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10343,
    "Protein Susu (121005)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10344,
    "Protein Susu (121005)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10345,
    "Protein Susu (121005)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10346,
    "Protein Susu (121005)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10347,
    "Protein Susu (121005)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    10348,
    "Puding berbahan dasar susu (010710)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10349,
    "Puding berbahan dasar susu (010710)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    10350,
    "Puding berbahan dasar susu (010710)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10351,
    "Puding berbahan dasar susu (010710)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10352,
    "Puding berbahan dasar susu (010710)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10353,
    "Puding berbahan dasar susu (010710)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    10354,
    "Puding berbahan dasar susu (010710)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    10355,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    10356,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10357,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    10358,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10359,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10360,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    10361,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    10362,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Total kadar lemak susu",
    "",
    "=1.5",
  ],
  [
    10363,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Kadar padatan susu bukan-lemak",
    "",
    "=3.9",
  ],
  [
    10364,
    "Puding Butterscotch atau Puding Susu (010706)",
    "Kadar protein susu",
    "",
    "=1.4",
  ],
  [
    10365,
    "Puding Rasa/Berperisa (0401020910)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10366,
    "Puding Rasa/Berperisa (0401020910)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10367,
    "Puding Rasa/Berperisa (0401020910)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10368,
    "Puding Rasa/Berperisa (0401020910)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10369,
    "Puding Rasa/Berperisa (0401020910)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10370,
    "Puding Rasa/Berperisa (0401020910)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    10371,
    "Punches/Ades (1401040201)",
    "Arsen (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10372,
    "Punches/Ades (1401040201)",
    "Kadmium (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    10373,
    "Punches/Ades (1401040201)",
    "Merkuri (ppm atau mg/kg) ",
    "=0.01",
  ],
  [
    10374,
    "Punches/Ades (1401040201)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    10375,
    "Punches/Ades (1401040201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10376,
    "Punches/Ades (1401040201)",
    "Timbal (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10377,
    "Puree Buah (0401020802)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10378,
    "Puree Buah (0401020802)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10379,
    "Puree Buah (0401020802)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10380,
    "Puree Buah (0401020802)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10381,
    "Puree Buah (0401020802)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    10382,
    "Puree Chestnut Dalam Kaleng (0402020413)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10383,
    "Puree Chestnut Dalam Kaleng (0402020413)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10384,
    "Puree Chestnut Dalam Kaleng (0402020413)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10385,
    "Puree Chestnut Dalam Kaleng (0402020413)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10386,
    "Puree Chestnut Dalam Kaleng (0402020413)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10387,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    10388,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10389,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    10390,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10391,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    10392,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Jika Puree Tomat : Bobot Jenis (20oC)",
    "",
    "=1.05",
  ],
  [
    10393,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Jika Selai Kacang : Kandungan Kacang Tanah (%)",
    "",
    "=85",
  ],
  [
    10394,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Aflatoksin B1 (hanya berlaku jika bahan baku dari kacang tanah (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10395,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang tanah)(ppb atau mcg/kg)",
    "=20",
  ],
  [
    10396,
    "Puree dan Produk Oles Sayur, Kacang dan Biji-Bijian dalam Kaleng (0402020507)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    10397,
    "Puree Tomat (0402020501)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10398,
    "Puree Tomat (0402020501)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10399,
    "Puree Tomat (0402020501)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10400,
    "Puree Tomat (0402020501)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10401,
    "Puree Tomat (0402020501)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    10402,
    "Puree Tomat (0402020501)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10403,
    "Putih Telur Beku (10020202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10404,
    "Putih Telur Beku (10020202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10405,
    "Putih Telur Beku (10020202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10406,
    "Putih Telur Beku (10020202)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10407,
    "Putih Telur Beku (10020202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10408,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10409,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10410,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10411,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10412,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10413,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Timbal (Pb) (mg/kg)",
    "=1.0",
  ],
  [
    10414,
    "Ragi Kering (Tidak Aktif) (12020210)",
    "Kadar Air (%)",
    "=7",
  ],
  [
    10415,
    "Ragi Roti Cair (cream yeast) (120806)",
    "kadar air (%)",
    "=80",
    ">70",
  ],
  [
    10416,
    "Ragi Roti Cair (cream yeast) (120806)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10417,
    "Ragi Roti Cair (cream yeast) (120806)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10418,
    "Ragi Roti Cair (cream yeast) (120806)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10419,
    "Ragi Roti Cair (cream yeast) (120806)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10420,
    "Ragi Roti Cair (cream yeast) (120806)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10421,
    "Ragi Roti Kering (120801)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10422,
    "Ragi Roti Kering (120801)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10423,
    "Ragi Roti Kering (120801)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [10424, "Ragi Roti Kering (120801)", "Timah (Sn) (mg/kg)", "=40"],
  [10425, "Ragi Roti Kering (120801)", "Timbal (Pb) (mg/kg)", "=1"],
  [10426, "Ragi Roti Kering (120801)", "kadar air (%)", "=5"],
  [
    10427,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "kadar air (%)",
    "=70",
    "=63",
  ],
  [
    10428,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10429,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10430,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10431,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10432,
    "Ragi Roti Padat (compressed yeast) (120805)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10433,
    "Ragi Roti Semi Kering (120804)",
    "Kadar Air (%)",
    "=20",
    ">5",
  ],
  [
    10434,
    "Ragi Roti Semi Kering (120804)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10435,
    "Ragi Roti Semi Kering (120804)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10436,
    "Ragi Roti Semi Kering (120804)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10437,
    "Ragi Roti Semi Kering (120804)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10438,
    "Ragi Roti Semi Kering (120804)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [10439, "Ragi Tape (120802)", "Arsen (As) (mg/kg)", "=0.15"],
  [10440, "Ragi Tape (120802)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [10441, "Ragi Tape (120802)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10442, "Ragi Tape (120802)", "Timah (Sn) (mg/kg)", "=40"],
  [10443, "Ragi Tape (120802)", "Timbal (Pb) (mg/kg)", "=1"],
  [10444, "Ragi Tempe (120803)", "Arsen (As) (mg/kg)", "=0.15"],
  [10445, "Ragi Tempe (120803)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [10446, "Ragi Tempe (120803)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10447, "Ragi Tempe (120803)", "Timah (Sn) (mg/kg)", "=40"],
  [10448, "Ragi Tempe (120803)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    10449,
    "Ragi Untuk Minuman Beralkohol (120808)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10450,
    "Ragi Untuk Minuman Beralkohol (120808)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10451,
    "Ragi Untuk Minuman Beralkohol (120808)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10452,
    "Ragi Untuk Minuman Beralkohol (120808)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10453,
    "Ragi Untuk Minuman Beralkohol (120808)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10454,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Kadar asam erusat (%)",
    "=2",
  ],
  [
    10455,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Bilangan penyabunan (mg KOH/g)",
    "=193",
    "=182",
  ],
  [
    10456,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Bilangan iod (Wijs)",
    "=126",
    "=105",
  ],
  [
    10457,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10458,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10459,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10460,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10461,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10462,
    "Rapeseed oil - low erucic acid (low erucic acid turnip rape oil/low erucic acid colza oil/canola oil) (02010243)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10463,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10464,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    10465,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10466,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    10467,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    10468,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10469,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Bilangan penyabunan (KOH/g)",
    "=181",
    "=168",
  ],
  [
    10470,
    "Rapeseed oil (turnip rape oil/colza oil/ravison oil/sarson oil/toria oil) (02010248)",
    "Bilangan iod (Wijs)",
    "=120",
    "=94",
  ],
  [
    10471,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    10472,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10473,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10474,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10475,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10476,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10477,
    "Raw Marzipan, Base Almond Paste (05020305)",
    "Aflatoksin total (ppb atau mcg/kg)",
    "=10",
  ],
  [10478, "Rebon (09020533)", "Arsen (As) (mg/kg)", "=0.25"],
  [10479, "Rebon (09020533)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [10480, "Rebon (09020533)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [
    10481,
    "Rebon (09020533)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10482,
    "Rebon (09020533)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [10483, "Rebon (09020533)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    10484,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10485,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10486,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10487,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    10488,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10489,
    "Rebung Bambu Dalam Kemasan (0402020407)",
    "Bobot Tuntas (%)",
    "",
    "=50",
  ],
  [
    10490,
    "Remahan Biskuit (07020216)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10491,
    "Remahan Biskuit (07020216)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10492,
    "Remahan Biskuit (07020216)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    10493,
    "Remahan Biskuit (07020216)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    10494,
    "Remahan Biskuit (07020216)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10495,
    "Remahan Biskuit (07020216)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10496,
    "Rempah (12020102)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10497,
    "Rempah (12020102)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [10498, "Rempah Bubuk (12020103)", "Kadar air (%)", "=12"],
  [10499, "Rempah Bubuk (12020103)", "Arsen (As) (mg/kg)", "=0.15"],
  [
    10500,
    "Rempah Bubuk (12020103)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10501,
    "Rempah Bubuk (12020103)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [10502, "Rempah Bubuk (12020103)", "Sn (mg/kg)", "=40"],
  [10503, "Rempah Bubuk (12020103)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    10504,
    "Rempah Bubuk (12020103)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10505,
    "Rempah Bubuk (12020103)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    10506,
    "Rempeyek (150128)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10507,
    "Rempeyek (150128)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10508,
    "Rempeyek (150128)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10509,
    "Rempeyek (150128)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10510,
    "Rempeyek (150128)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10511,
    "Rempeyek (150128)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/Kg)",
    "=15",
  ],
  [
    10512,
    "Rempeyek (150128)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atau mcg/Kg)",
    "=20",
  ],
  [
    10513,
    "Rempeyek (150128)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    10514,
    "Rempeyek Ikan (150305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10515,
    "Rempeyek Ikan (150305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10516,
    "Rempeyek Ikan (150305)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10517,
    "Rempeyek Ikan (150305)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10518,
    "Rempeyek Ikan (150305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10519,
    "Rendang Ikan Tuna (0902040318)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10520,
    "Rendang Ikan Tuna (0902040318)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10521,
    "Rendang Ikan Tuna (0902040318)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10522,
    "Rendang Ikan Tuna (0902040318)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10523,
    "Rendang Ikan Tuna (0902040318)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    10524,
    "Rendang Ikan Tuna (0902040318)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    10525,
    "Rendang Kerang (0902040319)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10526,
    "Rendang Kerang (0902040319)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10527,
    "Rendang Kerang (0902040319)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10528,
    "Rendang Kerang (0902040319)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10529,
    "Rendang Kerang (0902040319)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    10530,
    "Rendang Kerang (0902040319)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    10531,
    "Rendang Telur (10020305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10532,
    "Rendang Telur (10020305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10533,
    "Rendang Telur (10020305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10534,
    "Rendang Telur (10020305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10535,
    "Rendang Telur (10020305)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10536,
    "Rendang Telur (10020305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10537,
    "Rendered Pork Fat (02010303)",
    "Bilangan penyabunan (mg KOH/g)",
    "=203",
    "=192",
  ],
  [
    10538,
    "Rendered Pork Fat (02010303)",
    "Bilangan iod (Wijs)",
    "=72",
    "=60",
  ],
  [
    10539,
    "Rendered Pork Fat (02010303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10540,
    "Rendered Pork Fat (02010303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10541,
    "Rendered Pork Fat (02010303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10542,
    "Rendered Pork Fat (02010303)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10543,
    "Rendered Pork Fat (02010303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10544,
    "Rendered Pork Fat (02010303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10545,
    "Rengginang/ Batiah (150127)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10546,
    "Rengginang/ Batiah (150127)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10547,
    "Rengginang/ Batiah (150127)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10548,
    "Rengginang/ Batiah (150127)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10549,
    "Rengginang/ Batiah (150127)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10550,
    "Rolade Daging (08030219)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10551,
    "Rolade Daging (08030219)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    10552,
    "Rolade Daging (08030219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10553,
    "Rolade Daging (08030219)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10554,
    "Rolade Daging (08030219)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10555,
    "Rolade Daging (08030219)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10556,
    "Rolade Ikan (0902040129)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10557,
    "Rolade Ikan (0902040129)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10558,
    "Rolade Ikan (0902040129)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10559,
    "Rolade Ikan (0902040129)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10560,
    "Rolade Ikan (0902040129)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    10561,
    "Rolade Ikan (0902040129)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    10562,
    "Rolade Ikan (0902040129)",
    "Kandungan lumatan daging ikan dan/atau surimi (%)",
    "",
    "=30",
  ],
  [10563, "Rollmops (09030101)", "As (ppm atau mg/kg)", "=0.25"],
  [10564, "Rollmops (09030101)", "Cd (ppm atau mg/kg)", "=0.1"],
  [10565, "Rollmops (09030101)", "Hg (ppm atau mg/kg", "=0.5"],
  [
    10566,
    "Rollmops (09030101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10567,
    "Rollmops (09030101)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [10568, "Rollmops (09030101)", "Pb (ppm atau mg/kg)", "=0.2"],
  [10569, "Root Beer (1401040111)", "Kandungan (Brix)", "=14"],
  [
    10570,
    "Root Beer (1401040111)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10571,
    "Root Beer (1401040111)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    10572,
    "Root Beer (1401040111)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    10573,
    "Root Beer (1401040111)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    10574,
    "Root Beer (1401040111)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10575,
    "Root Beer (1401040111)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [10576, "Rosemari (12020188)", "Kadar air (%)", "=9"],
  [
    10577,
    "Rosemari (12020188)",
    "Kadar minyak atsiri (% v/b)",
    "",
    "=1.2",
  ],
  [10578, "Rosemari (12020188)", "As (mg/kg)", "=0.15"],
  [10579, "Rosemari (12020188)", "Cd (mg/kg)", "=0.5"],
  [10580, "Rosemari (12020188)", "Hg (mg/kg)", "=0.05"],
  [10581, "Rosemari (12020188)", "Sn (mg/kg)", "=40"],
  [10582, "Rosemari (12020188)", "Pb (mg/kg)", "=1"],
  [10583, "Roti (070101A0)", "Arsen (As) (mg/kg)", "=0.5"],
  [10584, "Roti (070101A0)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10585, "Roti (070101A0)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [10586, "Roti (070101A0)", "Timah (Sn) (mg/kg)", "=40"],
  [10587, "Roti (070101A0)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10588, "Roti Bagelen (07020110)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    10589,
    "Roti Bagelen (07020110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [10590, "Roti Bagelen (07020110)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10591, "Roti Bagelen (07020110)", "Timah (Sn) (mg/kg)", "=40"],
  [10592, "Roti Bagelen (07020110)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10593, "Roti Bagelen (07020110)", "Kadar air (%)", "=5"],
  [
    10594,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10595,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    10596,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10597,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10598,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10599,
    "Roti Buah/Roti Kismis/Roti Chocochips (0701010101)",
    "Kandungan buah kering atau kismis (%)",
    "",
    "=10",
  ],
  [10600, "Roti Buaya (07020207)", "Arsen (As) (mg/kg) ", "=0.5"],
  [10601, "Roti Buaya (07020207)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [10602, "Roti Buaya (07020207)", "Raksa (Hg) (mg/kg) ", "=0.05"],
  [10603, "Roti Buaya (07020207)", "Timah (Sn) (mg/kg) ", "=40"],
  [10604, "Roti Buaya (07020207)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    10605,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Kadar gula total (%) ",
    "=5",
  ],
  [
    10606,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Kulit gandum yang ditambahkan terhadap total tepung (%) ",
    "",
    "=2",
  ],
  [
    10607,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Arsen (As) (mg/kg) ",
    "=0.5",
  ],
  [
    10608,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    10609,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    10610,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10611,
    "Roti Campuran Tepung Terigu dan Kulit Gandum / Roti dengan Kulit Gandum (Fine Bran) (0701010116)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [
    10612,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10613,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [
    10614,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10615,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10616,
    "Roti Canai/Roti Cane/Roti Kane/Roti Kanai/Roti Maryam (07010306)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10617,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10618,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10619,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10620,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10621,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10622,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Kadar gula total (%)",
    "=5",
  ],
  [
    10623,
    "Roti Gandum Utuh (WholeWheat) (0701010111)",
    "Kadar tepung gandum utuh dari total tepung (%)",
    "",
    "=10",
  ],
  [10624, "Roti Isi (07020203)", "Arsen (As) (mg/kg)", "=0.5"],
  [10625, "Roti Isi (07020203)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10626, "Roti Isi (07020203)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10627, "Roti Isi (07020203)", "Timah (Sn) (mg/kg)", "=40"],
  [10628, "Roti Isi (07020203)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10629, "Roti Jala (07010307)", "Arsen (As) (mg/kg) ", "=0.5"],
  [10630, "Roti Jala (07010307)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [10631, "Roti Jala (07010307)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [10632, "Roti Jala (07010307)", "Timah (Sn) (mg/kg)", "=40"],
  [10633, "Roti Jala (07010307)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [10634, "Roti Kadet (0701010103)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    10635,
    "Roti Kadet (0701010103)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [10636, "Roti Kadet (0701010103)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10637, "Roti Kadet (0701010103)", "Timah (Sn) (mg/kg)", "=40"],
  [10638, "Roti Kadet (0701010103)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    10639,
    "Roti Kadet Gandum (0701010119)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10640,
    "Roti Kadet Gandum (0701010119)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10641,
    "Roti Kadet Gandum (0701010119)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10642,
    "Roti Kadet Gandum (0701010119)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10643,
    "Roti Kadet Gandum (0701010119)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10644,
    "Roti Kadet Susu (0701010120)",
    "Padatan susu bukan lemak dari jumlah terigu (%)",
    "",
    "=4",
  ],
  [
    10645,
    "Roti Kadet Susu (0701010120)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10646,
    "Roti Kadet Susu (0701010120)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10647,
    "Roti Kadet Susu (0701010120)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10648,
    "Roti Kadet Susu (0701010120)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10649,
    "Roti Kadet Susu (0701010120)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [10650, "Roti Malt (0701010118)", "Arsen (As) (mg/kg)", "=0.5"],
  [10651, "Roti Malt (0701010118)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [
    10652,
    "Roti Malt (0701010118)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10653,
    "Roti Malt (0701010118)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [10654, "Roti Malt (0701010118)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10655, "Roti Manis (07020202)", "Arsen (As) (mg/kg)", "=0.5"],
  [10656, "Roti Manis (07020202)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10657, "Roti Manis (07020202)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10658, "Roti Manis (07020202)", "Timah (Sn) (mg/kg)", "=40"],
  [10659, "Roti Manis (07020202)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10660, "Roti Meal (0701010109)", "Arsen (As) (mg/kg)", "=0.5"],
  [10661, "Roti Meal (0701010109)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10662, "Roti Meal (0701010109)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10663, "Roti Meal (0701010109)", "Timah (Sn) (mg/kg)", "=40"],
  [10664, "Roti Meal (0701010109)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    10665,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10666,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10667,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10668,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10669,
    "Roti Meal Utuh (Whole Meal) (0701010110)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10670,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Kadar Gula Total (%)",
    "=5",
  ],
  [
    10671,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10672,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10673,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10674,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10675,
    "Roti Perancis (Baguette/pain courant francais) (0701010117)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [10676, "Roti Pita (07010303)", "Arsen (As) (mg/kg)", "=0.5"],
  [10677, "Roti Pita (07010303)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10678, "Roti Pita (07010303)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10679, "Roti Pita (07010303)", "Timah (Sn) (mg/kg)", "=40"],
  [10680, "Roti Pita (07010303)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    10681,
    "Roti Pumpernickel (0701010113)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10682,
    "Roti Pumpernickel (0701010113)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10683,
    "Roti Pumpernickel (0701010113)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10684,
    "Roti Pumpernickel (0701010113)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10685,
    "Roti Pumpernickel (0701010113)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [10686, "Roti Putih (0701010105)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    10687,
    "Roti Putih (0701010105)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [10688, "Roti Putih (0701010105)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10689, "Roti Putih (0701010105)", "Timah (Sn) (mg/kg)", "=40"],
  [10690, "Roti Putih (0701010105)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10691, "Roti Rye (0701010112)", "Arsen (As) (mg/kg)", "=0.5"],
  [10692, "Roti Rye (0701010112)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10693, "Roti Rye (0701010112)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10694, "Roti Rye (0701010112)", "Timah (Sn) (mg/kg)", "=40"],
  [10695, "Roti Rye (0701010112)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10696, "Roti Soda (0701010201)", "Arsen (As) (mg/kg)", "=0.5"],
  [10697, "Roti Soda (0701010201)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [10698, "Roti Soda (0701010201)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10699, "Roti Soda (0701010201)", "Timah (Sn) (mg/kg)", "=40"],
  [10700, "Roti Soda (0701010201)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    10701,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10702,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10703,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10704,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10705,
    "Roti Susu, Roll Susu, Bun Susu (0701010107)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [10706, "Roti Tawar (0701010104)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    10707,
    "Roti Tawar (0701010104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [10708, "Roti Tawar (0701010104)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10709, "Roti Tawar (0701010104)", "Timah (Sn) (mg/kg)", "=40"],
  [10710, "Roti Tawar (0701010104)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [10711, "Roti Tawar (0701010104)", "Kadar gula total (%)", "=5"],
  [
    10712,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Kadar gula total (%)",
    "=5",
  ],
  [
    10713,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Bahan pangan lain yang ditambahkan (%)",
    "=10",
  ],
  [
    10714,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10715,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10716,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    10717,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10718,
    "Roti Tawar dengan penambahan bahan pangan lain (0701010115)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [
    10719,
    "Roti Tawar Kupas (0701010106)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10720,
    "Roti Tawar Kupas (0701010106)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10721,
    "Roti Tawar Kupas (0701010106)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10722,
    "Roti Tawar Kupas (0701010106)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10723,
    "Roti Tawar Kupas (0701010106)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10724,
    "Roti Tawar Kupas (0701010106)",
    "Kadar gula total (%)",
    "=5",
  ],
  [
    10725,
    "Roti Untuk Stuffing (07010404)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10726,
    "Roti Untuk Stuffing (07010404)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10727,
    "Roti Untuk Stuffing (07010404)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10728,
    "Roti Untuk Stuffing (07010404)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10729,
    "Roti Untuk Stuffing (07010404)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10730,
    "Roti Wheat-Germ (0701010108)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    10731,
    "Roti Wheat-Germ (0701010108)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    10732,
    "Roti Wheat-Germ (0701010108)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10733,
    "Roti Wheat-Germ (0701010108)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10734,
    "Roti Wheat-Germ (0701010108)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    10735,
    "Roti Wheat-Germ (0701010108)",
    "Kandungan wheatgerm dari total tepung (%)",
    "",
    "=5",
  ],
  [
    10736,
    "Rujak (0401020303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10737,
    "Rujak (0401020303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10738,
    "Rujak (0401020303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10739,
    "Rujak (0401020303)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    10740,
    "Rujak (0401020303)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10741,
    "Rujak (0401020303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [10742, "Rum (14020605)", "Kadar etanol (% v/v)", "", "=37.5"],
  [
    10743,
    "Rum (14020605)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [10744, "Rum (14020605)", "Arsen (mg/kg)", "=0.1"],
  [10745, "Rum (14020605)", "Kadmium (mg/kg)", "=0.2"],
  [10746, "Rum (14020605)", "Merkuri (mg/kg)", "=0.03"],
  [
    10747,
    "Rum (14020605)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    10748,
    "Rum (14020605)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [10749, "Rum (14020605)", "Timbal (mg/kg)", "=0.2"],
  [
    10750,
    "Rumput Laut Kering (0402020204)",
    "Kadar air euchema",
    "=35",
  ],
  [
    10751,
    "Rumput Laut Kering (0402020204)",
    "Kadar air gellidium",
    "=15",
  ],
  [
    10752,
    "Rumput Laut Kering (0402020204)",
    "Kadar air gracillaria",
    "=25",
  ],
  [
    10753,
    "Rumput Laut Kering (0402020204)",
    "Kadar air Hypenea",
    "=20",
  ],
  [
    10754,
    "Rumput Laut Kering (0402020204)",
    "Arsen inorganik (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    10755,
    "Rumput Laut Kering (0402020204)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10756,
    "Rumput Laut Kering (0402020204)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10757,
    "Rumput Laut Kering (0402020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10758,
    "Rumput Laut Kering (0402020204)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [10759, "Rusip (09020532)", "Arsen (As) (mg/kg)", "=0.25"],
  [10760, "Rusip (09020532)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [10761, "Rusip (09020532)", "Merkuri (Hg) (mg/kg)", "=0.5"],
  [
    10762,
    "Rusip (09020532)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    10763,
    "Rusip (09020532)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [10764, "Rusip (09020532)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [10765, "Saffron (12020190)", "Senyawa menguap pada 103 C (%)"],
  [
    10766,
    "Saffron (12020190)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    10767,
    "Saffron (12020190)",
    "Cadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    10768,
    "Saffron (12020190)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10769,
    "Saffron (12020190)",
    "Timah (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10770,
    "Saffron (12020190)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    10771,
    "Saffron (12020190)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    10772,
    "Saffron (12020190)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    10773,
    "Saga (12020189)",
    "Kadar air tidak lebih dari (%)",
    "=10",
  ],
  [
    10774,
    "Saga (12020189)",
    "Minyak atsiri tidak kurang dari (%v/b) ",
    "",
    "=1",
  ],
  [10775, "Saga (12020189)", "Arsen (As) (mg/kg)", "=0.15"],
  [10776, "Saga (12020189)", "Kadmium (Cd) (mg/kg", "=0.5"],
  [10777, "Saga (12020189)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [10778, "Saga (12020189)", "Timah (Sn) (ppm atau mg/kg)", "=40"],
  [10779, "Saga (12020189)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    10780,
    "Sagu/Pati Mutiara (060511)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10781,
    "Sagu/Pati Mutiara (060511)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10782,
    "Sagu/Pati Mutiara (060511)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10783,
    "Sagu/Pati Mutiara (060511)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    10784,
    "Sagu/Pati Mutiara (060511)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    10785,
    "Sagu/Pati Mutiara (060511)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [10786, "Sake (14020408)", "Arsen (As) (mg/kg)", "=0.1"],
  [10787, "Sake (14020408)", "Kadmium (Cd)(mg/kg)", "=0.2"],
  [10788, "Sake (14020408)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    10789,
    "Sake (14020408)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    10790,
    "Sake (14020408)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [10791, "Sake (14020408)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [10792, "Sake (14020408)", "Kadar etanol (% v/v)", "=24", "=7"],
  [
    10793,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Kadar lemak total (%)",
    "",
    "=20",
  ],
  [
    10794,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10795,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10796,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10797,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10798,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10799,
    "Salad Dressing (Misalnya Thousand Island, Blue Cheese, Burger Dressing, dll) (12060102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    10800,
    "Salami (0803010303)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10801,
    "Salami (0803010303)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    10802,
    "Salami (0803010303)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    10803,
    "Salami (0803010303)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10804,
    "Salami (0803010303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10805,
    "Salami (0803010303)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    10806,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10807,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10808,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10809,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10810,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10811,
    "Salami dan Produk Sejenisnya (0803010102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10812,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10813,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10814,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10815,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10816,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10817,
    "Salami Matang / Pepperoni Matang (08030229)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10818,
    "Sale Pisang (0401020904)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10819,
    "Sale Pisang (0401020904)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    10820,
    "Sale Pisang (0401020904)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    10821,
    "Sale Pisang (0401020904)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10822,
    "Sale Pisang (0401020904)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10823,
    "Sale Pisang (0401020904)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [10824, "Salsa (0402020606)", "Arsen (As) (mg/kg)", "=0.15"],
  [10825, "Salsa (0402020606)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [10826, "Salsa (0402020606)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    10827,
    "Salsa (0402020606)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10828,
    "Salsa (0402020606)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [10829, "Salsa (0402020606)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    10830,
    "Sambal Buah (0401020602)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10831,
    "Sambal Buah (0401020602)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10832,
    "Sambal Buah (0401020602)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10833,
    "Sambal Buah (0401020602)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    10834,
    "Sambal Buah (0401020602)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10835,
    "Sambal Buah (0401020602)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    10836,
    "Sambal Goreng Ikan (0902040312)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10837,
    "Sambal Goreng Ikan (0902040312)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10838,
    "Sambal Goreng Ikan (0902040312)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10839,
    "Sambal Goreng Ikan (0902040312)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    10840,
    "Sambal Goreng Ikan (0902040312)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    10841,
    "Sambal Goreng Ikan (0902040312)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    10842,
    "Sambal Goreng Ikan (0902040312)",
    "Kandungan ikan (%)",
    "",
    "=30",
  ],
  [
    10843,
    "Sambal Goreng Udang (0902040301)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    10844,
    "Sambal Goreng Udang (0902040301)",
    "Cd (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    10845,
    "Sambal Goreng Udang (0902040301)",
    "Hg (ppm atau mg/kg ",
    "=0.5",
  ],
  [
    10846,
    "Sambal Goreng Udang (0902040301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10847,
    "Sambal Goreng Udang (0902040301)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    10848,
    "Sambal Goreng Udang (0902040301)",
    "Kandungan udang (%)",
    "",
    "=50",
  ],
  [
    10849,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10850,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10851,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10852,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Timah (Sn) (mg/Kg) ",
    "=40",
  ],
  [
    10853,
    "Sambal Goreng Udang Kering (Ebi) (0902040302)",
    "Timbal (Pb) (mg/Kg) ",
    "=0.2",
  ],
  [
    10854,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10855,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10856,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10857,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10858,
    "Sambal Kecap/Saus Sambal Kecap (12060202)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10859,
    "Sambal Siap Dikonsumsi (12060205)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10860,
    "Sambal Siap Dikonsumsi (12060205)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10861,
    "Sambal Siap Dikonsumsi (12060205)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    10862,
    "Sambal Siap Dikonsumsi (12060205)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    10863,
    "Sambal Siap Dikonsumsi (12060205)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    10864,
    "Sambal Terasi (12060220)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10865,
    "Sambal Terasi (12060220)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    10866,
    "Sambal Terasi (12060220)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [10867, "Sambal Terasi (12060220)", "Timah (Sn) (mg/kg)", "=40"],
  [10868, "Sambal Terasi (12060220)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    10869,
    "Samosa Ayam (08030305)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    10870,
    "Samosa Ayam (08030305)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10871,
    "Samosa Ayam (08030305)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10872,
    "Samosa Ayam (08030305)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10873,
    "Samosa Ayam (08030305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10874,
    "Samosa Ayam (08030305)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    10875,
    "Sandwich Spread (12060108)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    10876,
    "Sandwich Spread (12060108)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    10877,
    "Sandwich Spread (12060108)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    10878,
    "Sandwich Spread (12060108)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    10879,
    "Sandwich Spread (12060108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    10880,
    "Sandwich Spread (12060108)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    10881,
    "Santan Bubuk (0401020209)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    10882,
    "Santan Bubuk (0401020209)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    10883,
    "Santan Bubuk (0401020209)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10884,
    "Santan Bubuk (0401020209)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    10885,
    "Santan Bubuk (0401020209)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    10886,
    "Santan Bubuk (0401020209)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [10887, "Santan Bubuk (0401020209)", "Kadar air (%)", "=5"],
  [
    10888,
    "Santan Bubuk (0401020209)",
    "Kadar lemak kelapa - Dihitung setelah rekonstitusi (%)",
    "",
    "=5",
  ],
  [
    10889,
    "Santan Ekstraksi Air (0401020808)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10890,
    "Santan Ekstraksi Air (0401020808)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10891,
    "Santan Ekstraksi Air (0401020808)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10892,
    "Santan Ekstraksi Air (0401020808)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    10893,
    "Santan Ekstraksi Air (0401020808)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10894,
    "Santan Ekstraksi Air (0401020808)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    10895,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    10896,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    10897,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10898,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    10899,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    10900,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    10901,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Santan encer : kadar lemak kelapa (%)",
    "",
    "=5",
  ],
  [
    10902,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Santan encer : total padatan (%)",
    "=12.6",
    "=6.6",
  ],
  [
    10903,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Santan : kadar lemak kelapa (%)",
    "",
    "=10",
  ],
  [
    10904,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Santan : total padatan (%)",
    "=25.3",
    "=12.7",
  ],
  [
    10905,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Krim kelapa : kadar lemak kelapa (%)",
    "",
    "=20",
  ],
  [
    10906,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Krim kelapa : total padatan (%)",
    "=37.3",
    "=25.4",
  ],
  [
    10907,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Konsentrat krim kelapa : kadar lemak kelapa (%)",
    "",
    "=29",
  ],
  [
    10908,
    "Santan/Santan Encer/Krim Kelapa/Konsentrat Krim Kelapa (0401020807)",
    "Konsentrat krim kelapa : kadar total padatan (%)",
    "",
    "=37.4",
  ],
  [
    10909,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Sensori ",
    "",
    "=7",
  ],
  [
    10910,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Histamin (mg/kg) ",
    "=100",
  ],
  [
    10911,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    10912,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    10913,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Timah putih (Sn) (mg/kg) ",
    "=250",
  ],
  [
    10914,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Timbal (Pb) (mg/kg) ",
    "=0.3",
  ],
  [
    10915,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    10916,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Bobot Tuntas (%) ",
    "",
    "=50",
  ],
  [
    10917,
    "Sarden dan Makerel dalam Kemasan Kaleng (090408)",
    "Filth",
  ],
  [
    10918,
    "Sarden Media Saus Tomat (090409)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    10919,
    "Sarden Media Saus Tomat (090409)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    10920,
    "Sarden Media Saus Tomat (090409)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    10921,
    "Sarden Media Saus Tomat (090409)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10922,
    "Sarden Media Saus Tomat (090409)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    10923,
    "Sarden Media Saus Tomat (090409)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [10924, "Sari Buah (1401020101)", "Kadar etanol (%)", "=0.5"],
  [10925, "Sari Buah (1401020101)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    10926,
    "Sari Buah (1401020101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10927,
    "Sari Buah (1401020101)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10928,
    "Sari Buah (1401020101)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10929,
    "Sari Buah (1401020101)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [10930, "Sari Buah (1401020101)", "Timbal (Pb) (mg/kg)", "=0.1"],
  [
    10931,
    "Sari Buah (1401020101)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    10932,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10933,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10934,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10935,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10936,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10937,
    "Sari Buah (Kemasan Tetrapack) (1401020131)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [10938, "Sari Buah Anggur (1401020112)", "pH", "=4"],
  [
    10939,
    "Sari Buah Anggur (1401020112)",
    "Total padatan terlarut (%)",
    "",
    "=15",
  ],
  [
    10940,
    "Sari Buah Anggur (1401020112)",
    "Kadar etanol (%)",
    "=0.5",
  ],
  [
    10941,
    "Sari Buah Anggur (1401020112)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10942,
    "Sari Buah Anggur (1401020112)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10943,
    "Sari Buah Anggur (1401020112)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10944,
    "Sari Buah Anggur (1401020112)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10945,
    "Sari Buah Anggur (1401020112)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10946,
    "Sari Buah Anggur (1401020112)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10947,
    "Sari Buah Apel (1401020104)",
    "Total padatan (b/v) (%)",
    "",
    "=10",
  ],
  [
    10948,
    "Sari Buah Apel (1401020104)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10949,
    "Sari Buah Apel (1401020104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10950,
    "Sari Buah Apel (1401020104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10951,
    "Sari Buah Apel (1401020104)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10952,
    "Sari Buah Apel (1401020104)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10953,
    "Sari Buah Apel (1401020104)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10954,
    "Sari Buah Belimbing (1401020118)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=7.5",
  ],
  [
    10955,
    "Sari Buah Belimbing (1401020118)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10956,
    "Sari Buah Belimbing (1401020118)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10957,
    "Sari Buah Belimbing (1401020118)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10958,
    "Sari Buah Belimbing (1401020118)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10959,
    "Sari Buah Belimbing (1401020118)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10960,
    "Sari Buah Belimbing (1401020118)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10961,
    "Sari Buah Belimbing (1401020118)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    10962,
    "Sari Buah Blackberry (1401020126)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10963,
    "Sari Buah Blackberry (1401020126)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10964,
    "Sari Buah Blackberry (1401020126)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10965,
    "Sari Buah Blackberry (1401020126)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10966,
    "Sari Buah Blackberry (1401020126)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10967,
    "Sari Buah Blackberry (1401020126)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10968,
    "Sari Buah Blackberry (1401020126)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi ",
    "",
    "=9",
  ],
  [
    10969,
    "Sari Buah Blackcurrant (1401020114)",
    "Total padatan terlarut diukur dengan refraktometer pada 20\xB0C, dibaca sebagai \xB0Brix dalam skala sukrosa internasional tanpa koreksi keasaman (%)",
    "",
    "=11",
  ],
  [
    10970,
    "Sari Buah Blackcurrant (1401020114)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    10971,
    "Sari Buah Blackcurrant (1401020114)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10972,
    "Sari Buah Blackcurrant (1401020114)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10973,
    "Sari Buah Blackcurrant (1401020114)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10974,
    "Sari Buah Blackcurrant (1401020114)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10975,
    "Sari Buah Blackcurrant (1401020114)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10976,
    "Sari Buah Blackcurrant (1401020114)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10977,
    "Sari Buah Blueberry (1401020136)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10978,
    "Sari Buah Blueberry (1401020136)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10979,
    "Sari Buah Blueberry (1401020136)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10980,
    "Sari Buah Blueberry (1401020136)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10981,
    "Sari Buah Blueberry (1401020136)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10982,
    "Sari Buah Blueberry (1401020136)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10983,
    "Sari Buah Blueberry (1401020136)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi ",
    "",
    "=10",
  ],
  [
    10984,
    "Sari Buah Campuran (1401020102)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10985,
    "Sari Buah Campuran (1401020102)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10986,
    "Sari Buah Campuran (1401020102)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10987,
    "Sari Buah Campuran (1401020102)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10988,
    "Sari Buah Campuran (1401020102)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10989,
    "Sari Buah Campuran (1401020102)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10990,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    10991,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    10992,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    10993,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    10994,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    10995,
    "Sari Buah dan Sari Sayur (1401020132)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    10996,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    10997,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    10998,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    10999,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    11000,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11001,
    "Sari Buah dan Sari Sayuran (14010205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11002,
    "Sari Buah Delima (1401020123)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=12",
  ],
  [
    11003,
    "Sari Buah Delima (1401020123)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11004,
    "Sari Buah Delima (1401020123)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11005,
    "Sari Buah Delima (1401020123)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11006,
    "Sari Buah Delima (1401020123)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11007,
    "Sari Buah Delima (1401020123)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11008,
    "Sari Buah Delima (1401020123)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11009,
    "Sari Buah Jambu Biji (1401020122)",
    "Level brix untuk sari buah dan puree rekonstitusi (jambu biji merah)",
    "",
    "=7.5",
  ],
  [
    11010,
    "Sari Buah Jambu Biji (1401020122)",
    "Level brix untuk sari buah dan puree rekonstitusi (jambu biji putih)",
    "",
    "=9",
  ],
  [
    11011,
    "Sari Buah Jambu Biji (1401020122)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11012,
    "Sari Buah Jambu Biji (1401020122)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11013,
    "Sari Buah Jambu Biji (1401020122)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11014,
    "Sari Buah Jambu Biji (1401020122)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11015,
    "Sari Buah Jambu Biji (1401020122)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11016,
    "Sari Buah Jambu Biji (1401020122)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11017,
    "Sari Buah Jeruk Bali (1401020105)",
    "Total padatan (b/v) (%) ",
    "",
    "=9.5",
  ],
  [
    11018,
    "Sari Buah Jeruk Bali (1401020105)",
    "Total asam (sebagai asam sitrat anhidrat) (g) ",
    "=2",
    "=1",
  ],
  [
    11019,
    "Sari Buah Jeruk Bali (1401020105)",
    "Total padatan terlarut untuk setiap gram asam yang dihitung sebagai asam sitrat anhidrat (g) ",
    "",
    "=7",
  ],
  [
    11020,
    "Sari Buah Jeruk Bali (1401020105)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    11021,
    "Sari Buah Jeruk Bali (1401020105)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.03",
  ],
  [
    11022,
    "Sari Buah Jeruk Bali (1401020105)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    11023,
    "Sari Buah Jeruk Bali (1401020105)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11024,
    "Sari Buah Jeruk Bali (1401020105)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg) ",
    "=40",
  ],
  [
    11025,
    "Sari Buah Jeruk Bali (1401020105)",
    "Timbal (Pb) (mg/kg) ",
    "=0.1",
  ],
  [
    11026,
    "Sari Buah Jeruk Garut (1401020133)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11027,
    "Sari Buah Jeruk Garut (1401020133)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11028,
    "Sari Buah Jeruk Garut (1401020133)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11029,
    "Sari Buah Jeruk Garut (1401020133)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11030,
    "Sari Buah Jeruk Garut (1401020133)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11031,
    "Sari Buah Jeruk Garut (1401020133)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11032,
    "Sari Buah Jeruk Garut (1401020133)",
    "Total Padatan (%) ",
    "",
    "=10",
  ],
  [
    11033,
    "Sari Buah Jeruk Garut (1401020133)",
    "Total padatan, jika sari buah diperoleh dari padatan sari buah yang diencerkan dengan air (%) ",
    "",
    "=11",
  ],
  [
    11034,
    "Sari Buah Jeruk Garut (1401020133)",
    "Kadar Etanol (%) ",
    "=0.03",
  ],
  [
    11035,
    "Sari Buah Jeruk Medan (1401020134)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11036,
    "Sari Buah Jeruk Medan (1401020134)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11037,
    "Sari Buah Jeruk Medan (1401020134)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11038,
    "Sari Buah Jeruk Medan (1401020134)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11039,
    "Sari Buah Jeruk Medan (1401020134)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11040,
    "Sari Buah Jeruk Medan (1401020134)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11041,
    "Sari Buah Jeruk Medan (1401020134)",
    "Total Padatan (%) ",
    "",
    "=10",
  ],
  [
    11042,
    "Sari Buah Jeruk Medan (1401020134)",
    "Total padatan, jika sari buah diperoleh dari padatan sari buah yang diencerkan dengan air (%) ",
    "",
    "=11",
  ],
  [
    11043,
    "Sari Buah Jeruk Medan (1401020134)",
    "Kadar Etanol (%) ",
    "",
    "=0.03",
  ],
  [
    11044,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Total padatan (b/v) (%)",
    "",
    "=10",
  ],
  [
    11045,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Jika sari buah diperoleh dari padatan sari buah yang diencerkan dengan air, total padatan (%)",
    "",
    "=11",
  ],
  [
    11046,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    11047,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11048,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11049,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11050,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11051,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11052,
    "Sari Buah Jeruk Orange, Valencia (1401020106)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11053,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Total padatan (b/v) (%)",
    "",
    "=10",
  ],
  [
    11054,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Jika sari buah diperoleh dari padatan sari buah yang diencerkan dengan air, total padatan (%)",
    "",
    "=11",
  ],
  [
    11055,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    11056,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11057,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11058,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11059,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11060,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11061,
    "Sari Buah Jeruk Siam, Tangerine, Jeruk Pontianak (1401020107)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11062,
    "Sari Buah Kiwi (1401020138)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11063,
    "Sari Buah Kiwi (1401020138)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11064,
    "Sari Buah Kiwi (1401020138)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11065,
    "Sari Buah Kiwi (1401020138)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11066,
    "Sari Buah Kiwi (1401020138)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11067,
    "Sari Buah Kiwi (1401020138)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11068,
    "Sari Buah Leci (1401020137)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11069,
    "Sari Buah Leci (1401020137)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11070,
    "Sari Buah Leci (1401020137)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11071,
    "Sari Buah Leci (1401020137)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11072,
    "Sari Buah Leci (1401020137)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11073,
    "Sari Buah Leci (1401020137)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11074,
    "Sari Buah Leci (1401020137)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi ",
    "",
    "=11",
  ],
  [
    11075,
    "Sari Buah Lemon (1401020110)",
    "Total padatan (%)",
    "",
    "=6",
  ],
  [
    11076,
    "Sari Buah Lemon (1401020110)",
    "Total asam tertritasi (sebagai asam sitrat anhidrat) (%)",
    "",
    "=4.5",
  ],
  [
    11077,
    "Sari Buah Lemon (1401020110)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    11078,
    "Sari Buah Lemon (1401020110)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11079,
    "Sari Buah Lemon (1401020110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11080,
    "Sari Buah Lemon (1401020110)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11081,
    "Sari Buah Lemon (1401020110)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11082,
    "Sari Buah Lemon (1401020110)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11083,
    "Sari Buah Lemon (1401020110)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11084,
    "Sari Buah Mangga (1401020115)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=13",
  ],
  [
    11085,
    "Sari Buah Mangga (1401020115)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11086,
    "Sari Buah Mangga (1401020115)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11087,
    "Sari Buah Mangga (1401020115)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11088,
    "Sari Buah Mangga (1401020115)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11089,
    "Sari Buah Mangga (1401020115)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11090,
    "Sari Buah Mangga (1401020115)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11091,
    "Sari Buah Manggis (1401020129)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11092,
    "Sari Buah Manggis (1401020129)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11093,
    "Sari Buah Manggis (1401020129)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11094,
    "Sari Buah Manggis (1401020129)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11095,
    "Sari Buah Manggis (1401020129)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11096,
    "Sari Buah Manggis (1401020129)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11097,
    "Sari Buah Markisa (1401020111)",
    "Total padatan (b/v) (%)",
    "",
    "=12",
  ],
  [
    11098,
    "Sari Buah Markisa (1401020111)",
    "Total asam (sebagai asam sitrat) (b/v) (%)",
    "=4.5",
    "=1.5",
  ],
  [
    11099,
    "Sari Buah Markisa (1401020111)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11100,
    "Sari Buah Markisa (1401020111)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11101,
    "Sari Buah Markisa (1401020111)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11102,
    "Sari Buah Markisa (1401020111)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11103,
    "Sari Buah Markisa (1401020111)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11104,
    "Sari Buah Markisa (1401020111)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11105,
    "Sari Buah Naga (1401020139)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11106,
    "Sari Buah Naga (1401020139)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11107,
    "Sari Buah Naga (1401020139)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11108,
    "Sari Buah Naga (1401020139)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11109,
    "Sari Buah Naga (1401020139)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11110,
    "Sari Buah Naga (1401020139)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11111,
    "Sari Buah Nanas (1401020109)",
    "Total padatan (%)",
    "",
    "=10",
  ],
  [
    11112,
    "Sari Buah Nanas (1401020109)",
    "Jika sari buah diperoleh dari padatan sari buah yang diencerkan dengan air, total padatan (%)",
    "",
    "=13.5",
  ],
  [
    11113,
    "Sari Buah Nanas (1401020109)",
    "Kadar etanol (%)",
    "=0.3",
  ],
  [
    11114,
    "Sari Buah Nanas (1401020109)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11115,
    "Sari Buah Nanas (1401020109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11116,
    "Sari Buah Nanas (1401020109)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11117,
    "Sari Buah Nanas (1401020109)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11118,
    "Sari Buah Nanas (1401020109)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11119,
    "Sari Buah Nanas (1401020109)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11120,
    "Sari Buah Peach (1401020121)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=10.5",
  ],
  [
    11121,
    "Sari Buah Peach (1401020121)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11122,
    "Sari Buah Peach (1401020121)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11123,
    "Sari Buah Peach (1401020121)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11124,
    "Sari Buah Peach (1401020121)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11125,
    "Sari Buah Peach (1401020121)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11126,
    "Sari Buah Peach (1401020121)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11127,
    "Sari Buah Pir (1401020124)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=12",
  ],
  [
    11128,
    "Sari Buah Pir (1401020124)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11129,
    "Sari Buah Pir (1401020124)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11130,
    "Sari Buah Pir (1401020124)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11131,
    "Sari Buah Pir (1401020124)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11132,
    "Sari Buah Pir (1401020124)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11133,
    "Sari Buah Pir (1401020124)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [11134, "Sari Buah Pisang (1401020117)", "As(mg/kg)", "=0.1"],
  [11135, "Sari Buah Pisang (1401020117)", "Cd (mg/kg)", "=0.03"],
  [11136, "Sari Buah Pisang (1401020117)", "Hg(mg/kg)", "=0.02"],
  [
    11137,
    "Sari Buah Pisang (1401020117)",
    "Sn (mg/kg) : untuk kemasan kaleng -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11138,
    "Sari Buah Pisang (1401020117)",
    "Sn (mg/kg) : untuk kemasan bukan kaleng",
    "=40",
  ],
  [11139, "Sari Buah Pisang (1401020117)", "Pb (mg/kg)", "=0.1"],
  [
    11140,
    "Sari Buah Plum (1401020120)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=12",
  ],
  [11141, "Sari Buah Plum (1401020120)", "As(mg/kg)", "=0.1"],
  [11142, "Sari Buah Plum (1401020120)", "Cd (mg/kg)", "=0.03"],
  [11143, "Sari Buah Plum (1401020120)", "Hg(mg/kg)", "=0.02"],
  [
    11144,
    "Sari Buah Plum (1401020120)",
    "Sn (mg/kg) : untuk kemasan kaleng -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11145,
    "Sari Buah Plum (1401020120)",
    "Sn (mg/kg) : untuk kemasan bukan kaleng",
    "=40",
  ],
  [11146, "Sari Buah Plum (1401020120)", "Pb (mg/kg)", "=0.1"],
  [
    11147,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11148,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11149,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11150,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11151,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11152,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11153,
    "Sari Buah Prune (Prune Juice) (1401020135)",
    "Total Padatan (%) ",
    "",
    "=18.5",
  ],
  [
    11154,
    "Sari Buah Raspberry (1401020127)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11155,
    "Sari Buah Raspberry (1401020127)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11156,
    "Sari Buah Raspberry (1401020127)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11157,
    "Sari Buah Raspberry (1401020127)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11158,
    "Sari Buah Raspberry (1401020127)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11159,
    "Sari Buah Raspberry (1401020127)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11160,
    "Sari Buah Raspberry (1401020127)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi ",
    "",
    "=11",
  ],
  [
    11161,
    "Sari Buah Redcurrant (1401020125)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=10",
  ],
  [
    11162,
    "Sari Buah Redcurrant (1401020125)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11163,
    "Sari Buah Redcurrant (1401020125)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11164,
    "Sari Buah Redcurrant (1401020125)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11165,
    "Sari Buah Redcurrant (1401020125)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11166,
    "Sari Buah Redcurrant (1401020125)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11167,
    "Sari Buah Redcurrant (1401020125)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11168,
    "Sari Buah Sirsak (1401020116)",
    "Level brix untuk sari buah dan puree rekonstitusi",
    "",
    "=12",
  ],
  [
    11169,
    "Sari Buah Sirsak (1401020116)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11170,
    "Sari Buah Sirsak (1401020116)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11171,
    "Sari Buah Sirsak (1401020116)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11172,
    "Sari Buah Sirsak (1401020116)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11173,
    "Sari Buah Sirsak (1401020116)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11174,
    "Sari Buah Sirsak (1401020116)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11175,
    "Sari Buah Sirsak (1401020116)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    11176,
    "Sari Buah Stroberi (1401020128)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11177,
    "Sari Buah Stroberi (1401020128)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11178,
    "Sari Buah Stroberi (1401020128)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11179,
    "Sari Buah Stroberi (1401020128)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11180,
    "Sari Buah Stroberi (1401020128)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11181,
    "Sari Buah Stroberi (1401020128)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11182,
    "Sari Buah Stroberi (1401020128)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi ",
    "",
    "=7",
  ],
  [
    11183,
    "Sari Buah Terong Belanda (1401020130)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11184,
    "Sari Buah Terong Belanda (1401020130)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11185,
    "Sari Buah Terong Belanda (1401020130)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11186,
    "Sari Buah Terong Belanda (1401020130)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11187,
    "Sari Buah Terong Belanda (1401020130)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [
    11188,
    "Sari Buah Terong Belanda (1401020130)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11189,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Total padatan (b/v) (%) ",
    "",
    "=8",
  ],
  [
    11190,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Total asam (sebagai asam sitrat anhidrat) (b/v) (%)",
    "",
    "=6",
  ],
  [
    11191,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Level brix untuk sari buah rekonstitusi dan puree rekonstitusi (20\xB0C) (Brix) ",
    "",
    "=8",
  ],
  [
    11192,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    11193,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.03",
  ],
  [
    11194,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    11195,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg)-dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11196,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg) ",
    "=40",
  ],
  [
    11197,
    "Sari Jeruk Nipis (Lime Juice) (1401020103)",
    "Timbal (Pb) (mg/kg) ",
    "=0.1",
  ],
  [
    11198,
    "Sari Kedelai (06080101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11199,
    "Sari Kedelai (06080101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11200,
    "Sari Kedelai (06080101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11201,
    "Sari Kedelai (06080101)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=100",
  ],
  [
    11202,
    "Sari Kedelai (06080101)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11203,
    "Sari Kedelai (06080101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11204,
    "Sari Kedelai (06080101)",
    "Kadar protein (N x 5.71) (%) (b/v)",
    "",
    "=2",
  ],
  [
    11205,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11206,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11207,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11208,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=100",
  ],
  [
    11209,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11210,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11211,
    "Sari Kedelai Steril (Khusus Registrasi Ulang) (06080102)",
    "Kadar protein (N x 6.25) (%) (b/v)",
    "",
    "=2",
  ],
  [
    11212,
    "Sari Lidah Buaya (1401020205)",
    "Mineral larut dalam HCl 10% (mg/kg)",
    "=100",
  ],
  [
    11213,
    "Sari Lidah Buaya (1401020205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11214,
    "Sari Lidah Buaya (1401020205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11215,
    "Sari Lidah Buaya (1401020205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    11216,
    "Sari Lidah Buaya (1401020205)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    11217,
    "Sari Lidah Buaya (1401020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11218,
    "Sari Lidah Buaya (1401020205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11219,
    "Sari Pati Ayam (12050101)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    11220,
    "Sari Pati Ayam (12050101)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    11221,
    "Sari Pati Ayam (12050101)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    11222,
    "Sari Pati Ayam (12050101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    11223,
    "Sari Pati Ayam (12050101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11224,
    "Sari Pati Ayam (12050101)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    11225,
    "Sari Pati Ayam (12050101)",
    "Kadar Protein (%)",
    "",
    "=7.7",
  ],
  [11226, "Sari Sayur (1401020201)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    11227,
    "Sari Sayur (1401020201)",
    "Kadmium (Cd) (mg/kg)",
    "=0.03",
  ],
  [
    11228,
    "Sari Sayur (1401020201)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    11229,
    "Sari Sayur (1401020201)",
    "Timah (Sn) (minuman dalam kemasan kaleng) (mg/kg) -dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11230,
    "Sari Sayur (1401020201)",
    "Timah (Sn) (pangan olahan yang tidak dikemas dalam kaleng) (mg/kg)",
    "=40",
  ],
  [11231, "Sari Sayur (1401020201)", "Timbal (Pb) (mg/kg)", "=0.1"],
  [
    11232,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11233,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11234,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    11235,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11236,
    "Sari Sayur (Kemasan Tetrapack) (1401020204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11237,
    "Sari Sayur Campuran (1401020206)",
    "As (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11238,
    "Sari Sayur Campuran (1401020206)",
    "Cd(ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11239,
    "Sari Sayur Campuran (1401020206)",
    "Hg (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    11240,
    "Sari Sayur Campuran (1401020206)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    11241,
    "Sari Sayur Campuran (1401020206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11242,
    "Sari Sayur Campuran (1401020206)",
    "Pb(ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11243,
    "Sari Sayur dan Sari Buah (1401020207)",
    "As (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11244,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Cd(ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11245,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Hg (dihitung terhadap produk siap konsumsi) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    11246,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    11247,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11248,
    "Sari Sayur dan Sari Buah (1401020207)",
    "Pb(ppm atau mg/kg)",
    "=0.1",
  ],
  [11249, "Sari Tomat (1401020202)", "As (mg/kg) ", "=0.1"],
  [11250, "Sari Tomat (1401020202)", "Cd(mg/kg) ", "=0.03"],
  [11251, "Sari Tomat (1401020202)", "Hg(mg/kg) ", "=0.02"],
  [
    11252,
    "Sari Tomat (1401020202)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    11253,
    "Sari Tomat (1401020202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [11254, "Sari Tomat (1401020202)", "Timbal (Pb) (mg/kg)", "=0.1"],
  [
    11255,
    "Sari Tomat (1401020202)",
    "Total padatan terlarut tomat yang diukur dengan refraktometer pada 20\xB0C ",
    "",
    "=4.5",
  ],
  [11256, "Sari Wortel (1401020203)", "As (mg/kg) ", "=0.1"],
  [11257, "Sari Wortel (1401020203)", "Cd(mg/kg) ", "=0.03"],
  [11258, "Sari Wortel (1401020203)", "Hg(mg/kg) ", "=0.02"],
  [
    11259,
    "Sari Wortel (1401020203)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) ",
    "=100",
  ],
  [
    11260,
    "Sari Wortel (1401020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11261,
    "Sari Wortel (1401020203)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [11262, "Sarsaparilla (1401040110)", "Kandungan (Brix)", "=14"],
  [
    11263,
    "Sarsaparilla (1401040110)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11264,
    "Sarsaparilla (1401040110)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11265,
    "Sarsaparilla (1401040110)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11266,
    "Sarsaparilla (1401040110)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=150",
  ],
  [
    11267,
    "Sarsaparilla (1401040110)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11268,
    "Sarsaparilla (1401040110)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11269,
    "Sarsaparilla (1401040110)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [11270, "Sauerkraut (0402020703)", "Bobot Tuntas (%)", "", "=60"],
  [
    11271,
    "Sauerkraut (0402020703)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11272,
    "Sauerkraut (0402020703)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11273,
    "Sauerkraut (0402020703)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11274,
    "Sauerkraut (0402020703)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11275,
    "Sauerkraut (0402020703)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11276,
    "Saus Apel (Applesauce) (0401020805)",
    "Total padatan terlarut (%)",
    "",
    "=9",
  ],
  [
    11277,
    "Saus Apel (Applesauce) (0401020805)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11278,
    "Saus Apel (Applesauce) (0401020805)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11279,
    "Saus Apel (Applesauce) (0401020805)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11280,
    "Saus Apel (Applesauce) (0401020805)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    11281,
    "Saus Apel (Applesauce) (0401020805)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    11282,
    "Saus Asam Manis (12060221)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11283,
    "Saus Asam Manis (12060221)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    11284,
    "Saus Asam Manis (12060221)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    11285,
    "Saus Asam Manis (12060221)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    11286,
    "Saus Asam Manis (12060221)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    11287,
    "Saus Buah (0401020804)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11288,
    "Saus Buah (0401020804)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11289,
    "Saus Buah (0401020804)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11290,
    "Saus Buah (0401020804)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    11291,
    "Saus Buah (0401020804)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    11292,
    "Saus Buah dalam Kaleng (0401020817)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11293,
    "Saus Buah dalam Kaleng (0401020817)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    11294,
    "Saus Buah dalam Kaleng (0401020817)",
    "Timah (Sn) pangan olahan dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11295,
    "Saus Buah dalam Kaleng (0401020817)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11296,
    "Saus Buah dalam Kaleng (0401020817)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    11297,
    "Saus Bumbu Non-Emulsi dalam Kaleng (12060225)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11298,
    "Saus Bumbu Non-Emulsi dalam Kaleng (12060225)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    11299,
    "Saus Bumbu Non-Emulsi dalam Kaleng (12060225)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    11300,
    "Saus Bumbu Non-Emulsi dalam Kaleng (12060225)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11301,
    "Saus Bumbu Non-Emulsi dalam Kaleng (12060225)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    11302,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11303,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    11304,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    11305,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    11306,
    "Saus Bumbu Non-Emulsi Lainnya (12060222)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    11307,
    "Saus Bumbu Non-Emulsi Steril (Aseptis) (12060224)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11308,
    "Saus Bumbu Non-Emulsi Steril (Aseptis) (12060224)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    11309,
    "Saus Bumbu Non-Emulsi Steril (Aseptis) (12060224)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    11310,
    "Saus Bumbu Non-Emulsi Steril (Aseptis) (12060224)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11311,
    "Saus Bumbu Non-Emulsi Steril (Aseptis) (12060224)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    11312,
    "Saus Bumbu Teremulsi (12060106)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11313,
    "Saus Bumbu Teremulsi (12060106)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    11314,
    "Saus Bumbu Teremulsi (12060106)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11315,
    "Saus Bumbu Teremulsi (12060106)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11316,
    "Saus Bumbu Teremulsi (12060106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11317,
    "Saus Bumbu Teremulsi (12060106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [11318, "Saus Butterscotch (050403)", "Arsen (As) (mg/kg)", "=1"],
  [
    11319,
    "Saus Butterscotch (050403)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11320,
    "Saus Butterscotch (050403)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11321,
    "Saus Butterscotch (050403)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11322,
    "Saus Butterscotch (050403)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11323,
    "Saus Butterscotch (050403)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [11324, "Saus Cabe (12060201)", "Arsen (As) (mg/kg)", "=0.15"],
  [11325, "Saus Cabe (12060201)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11326, "Saus Cabe (12060201)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11327, "Saus Cabe (12060201)", "Timah (Sn) (mg/kg)", "=40"],
  [11328, "Saus Cabe (12060201)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11329,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Total nitrogen (%) ",
    "",
    "=0.3",
  ],
  [
    11330,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Kadar garam (%)",
    "",
    "=3",
  ],
  [
    11331,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11332,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11333,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11334,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11335,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11336,
    "Saus Campuran Protein Nabati Terhidrolisis (1209020307)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11337,
    "Saus Gado-gado (12060208)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11338,
    "Saus Gado-gado (12060208)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11339,
    "Saus Gado-gado (12060208)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [11340, "Saus Gado-gado (12060208)", "Timah (Sn) (mg/kg)", "=40"],
  [11341, "Saus Gado-gado (12060208)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11342,
    "Saus Gado-gado (12060208)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    11343,
    "Saus Gado-gado (12060208)",
    "Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atu mcg/kg)",
    "=20",
  ],
  [
    11344,
    "Saus Kedelai Fermentasi (12090201)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11345,
    "Saus Kedelai Fermentasi (12090201)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11346,
    "Saus Kedelai Fermentasi (12090201)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11347,
    "Saus Kedelai Fermentasi (12090201)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11348,
    "Saus Kedelai Fermentasi (12090201)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11349,
    "Saus Kedelai Fermentasi dalam Kaleng (12090204)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11350,
    "Saus Kedelai Fermentasi dalam Kaleng (12090204)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11351,
    "Saus Kedelai Fermentasi dalam Kaleng (12090204)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11352,
    "Saus Kedelai Fermentasi dalam Kaleng (12090204)",
    "Timah (mg/kg)",
    "=40",
  ],
  [
    11353,
    "Saus Kedelai Fermentasi dalam Kaleng (12090204)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11354,
    "Saus Kedelai Lainnya (1209020304)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11355,
    "Saus Kedelai Lainnya (1209020304)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11356,
    "Saus Kedelai Lainnya (1209020304)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11357,
    "Saus Kedelai Lainnya (1209020304)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11358,
    "Saus Kedelai Lainnya (1209020304)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11359,
    "Saus Kedelai Lainnya (1209020304)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm)",
    "=250",
  ],
  [
    11360,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11361,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11362,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11363,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11364,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11365,
    "Saus Kedelai Lainnya dalam Kaleng (1209020308)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11366,
    "Saus Kedelai Non-Fermentasi (1209020202)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11367,
    "Saus Kedelai Non-Fermentasi (1209020202)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11368,
    "Saus Kedelai Non-Fermentasi (1209020202)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11369,
    "Saus Kedelai Non-Fermentasi (1209020202)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11370,
    "Saus Kedelai Non-Fermentasi (1209020202)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11371,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11372,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11373,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11374,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11375,
    "Saus Keju (Cheese Sauce) (12060209)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [11376, "Saus Lobak (12060210)", "Arsen (As) (mg/kg)", "=0.15"],
  [11377, "Saus Lobak (12060210)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11378, "Saus Lobak (12060210)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11379, "Saus Lobak (12060210)", "Timah (Sn) (mg/kg)", "=40"],
  [11380, "Saus Lobak (12060210)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11381,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11382,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11383,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11384,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11385,
    "Saus Panggang/Saus Barbekue (BBQ Sauce) (12060211)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11386,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11387,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11388,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11389,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11390,
    "Saus Perendam/Saus Marinasi (Marinated Sauce) (12060216)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11391,
    "Saus Pizza (12060212)",
    "Total nitrogen (%)",
    "",
    "=2.75",
  ],
  [11392, "Saus Pizza (12060212)", "Kadar garam (%)", "", "=10"],
  [11393, "Saus Pizza (12060212)", "Arsen (As) (mg/kg)", "=0.15"],
  [11394, "Saus Pizza (12060212)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11395, "Saus Pizza (12060212)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11396, "Saus Pizza (12060212)", "Timah (Sn) (mg/kg)", "=40"],
  [11397, "Saus Pizza (12060212)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11398,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Total Nitrogen (%)",
    "",
    "=2.75",
  ],
  [
    11399,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Kadar Garam (%)",
    "",
    "=10",
  ],
  [
    11400,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11401,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11402,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11403,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11404,
    "Saus Protein Nabati Terhidrolisis (1209020203)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11405,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11406,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Kadmium (Cd) (mg/kg)",
    "=0.50",
  ],
  [
    11407,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11408,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    11409,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    11410,
    "Saus Putih (Berbasis Krim) (12060232)",
    "Timbal (Pb) (mg/kg)",
    "=1.00",
  ],
  [11411, "Saus Salsa (12060230)", "Arsen (As) (mg/kg)", "=0.15"],
  [11412, "Saus Salsa (12060230)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11413, "Saus Salsa (12060230)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11414, "Saus Salsa (12060230)", "Timah (Sn) (mg/kg)", "=40"],
  [11415, "Saus Salsa (12060230)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11416,
    "Saus Sambal Cabe Hijau (12060203)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11417,
    "Saus Sambal Cabe Hijau (12060203)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11418,
    "Saus Sambal Cabe Hijau (12060203)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11419,
    "Saus Sambal Cabe Hijau (12060203)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11420,
    "Saus Sambal Cabe Hijau (12060203)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [11421, "Saus Sate (12060213)", "Arsen (As) (mg/kg)", "=0.15"],
  [11422, "Saus Sate (12060213)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11423, "Saus Sate (12060213)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11424, "Saus Sate (12060213)", "Timah (Sn) (mg/kg)", "=40"],
  [11425, "Saus Sate (12060213)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11426,
    "Saus Sate (12060213)",
    "Aflatoksin B1 (jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    11427,
    "Saus Sate (12060213)",
    "Aflatoksin Total Aflatoksin Total (jika bahan baku dari kacang tanah) (ppb atu mcg/kg)",
    "=20",
  ],
  [
    11428,
    "Saus Sate (12060213)",
    "Aflatoksin Total (jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    11429,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11430,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11431,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11432,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11433,
    "Saus Spagheti (Spaghetti Sauce) (12060214)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11434,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11435,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    11436,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11437,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11438,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11439,
    "Saus Tar Tar (Tar Tar Sauce) (12060103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11440,
    "Saus Teriyaki (12060228)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11441,
    "Saus Teriyaki (12060228)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11442,
    "Saus Teriyaki (12060228)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [11443, "Saus Teriyaki (12060228)", "Timah (Sn) (mg/kg)", "=40"],
  [11444, "Saus Teriyaki (12060228)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11445,
    "Saus Tinta Cumi (12060231)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11446,
    "Saus Tinta Cumi (12060231)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11447,
    "Saus Tinta Cumi (12060231)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11448,
    "Saus Tinta Cumi (12060231)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11449,
    "Saus Tinta Cumi (12060231)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [11450, "Saus Tiram (12060215)", "Arsen (As) (mg/kg)", "=0.15"],
  [11451, "Saus Tiram (12060215)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11452, "Saus Tiram (12060215)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11453, "Saus Tiram (12060215)", "Timah (Sn) (mg/kg)", "=40"],
  [11454, "Saus Tiram (12060215)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11455,
    "Saus Tiram Bening (12060402)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11456,
    "Saus Tiram Bening (12060402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11457,
    "Saus Tiram Bening (12060402)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11458,
    "Saus Tiram Bening (12060402)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11459,
    "Saus Tiram Bening (12060402)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [11460, "Saus Tomat (12060217)", "Arsen (As) (mg/kg)", "=0.15"],
  [11461, "Saus Tomat (12060217)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [11462, "Saus Tomat (12060217)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11463, "Saus Tomat (12060217)", "Timah (Sn) (mg/kg)", "=40"],
  [11464, "Saus Tomat (12060217)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11465,
    "Saus Tomat Steril Komersial (12060223)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11466,
    "Saus Tomat Steril Komersial (12060223)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.5",
  ],
  [
    11467,
    "Saus Tomat Steril Komersial (12060223)",
    "Raksa (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    11468,
    "Saus Tomat Steril Komersial (12060223)",
    "Timah (Sn) Pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11469,
    "Saus Tomat Steril Komersial (12060223)",
    "Timah (Sn) Pangan olahan yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11470,
    "Saus Tomat Steril Komersial (12060223)",
    "Timbal (Pb) (mg/kg) ",
    "=1",
  ],
  [
    11471,
    "Saus Toping/Saus Siram (12060229)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11472,
    "Saus Toping/Saus Siram (12060229)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11473,
    "Saus Toping/Saus Siram (12060229)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11474,
    "Saus Toping/Saus Siram (12060229)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    11475,
    "Saus Toping/Saus Siram (12060229)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11476,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11477,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Kadmium (Cd)(mg/kg)",
    "=0.5",
  ],
  [
    11478,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11479,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    11480,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    11481,
    "Saus/Topping/Olesan (non buah) (050411)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11482,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11483,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11484,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11485,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11486,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11487,
    "Saus/Topping/Olesan Cokelat (050404)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11488,
    "Saus/Topping/Olesan Manis (050408)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11489,
    "Saus/Topping/Olesan Manis (050408)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11490,
    "Saus/Topping/Olesan Manis (050408)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11491,
    "Saus/Topping/Olesan Manis (050408)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11492,
    "Saus/Topping/Olesan Manis (050408)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11493,
    "Saus/Topping/Olesan Manis (050408)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    11494,
    "Sawi Asin (0402020702)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11495,
    "Sawi Asin (0402020702)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11496,
    "Sawi Asin (0402020702)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11497,
    "Sawi Asin (0402020702)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11498,
    "Sawi Asin (0402020702)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11499,
    "Sayap Beku Marinasi (08020305)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    11500,
    "Sayap Beku Marinasi (08020305)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    11501,
    "Sayap Beku Marinasi (08020305)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    11502,
    "Sayap Beku Marinasi (08020305)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    11503,
    "Sayap Beku Marinasi (08020305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11504,
    "Sayap Beku Marinasi (08020305)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    11505,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11506,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11507,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11508,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11509,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11510,
    "Sayur (Termasuk Jamur, Akar dan Umbi, Polong-polongan, dan Aloe Vera), Rumput Laut, Kacang Serta Biji-Bijian Kering dengan penambahan bahan lain (0402020228)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11511,
    "Sayur Asin (0402020302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11512,
    "Sayur Asin (0402020302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11513,
    "Sayur Asin (0402020302)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11514,
    "Sayur Asin (0402020302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11515,
    "Sayur Asin (0402020302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11516,
    "Sayur Asin (0402020302)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [11517, "Sayur Asin Kering (0402020206)", "Kadar air (%)", "=8"],
  [
    11518,
    "Sayur Asin Kering (0402020206)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11519,
    "Sayur Asin Kering (0402020206)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    11520,
    "Sayur Asin Kering (0402020206)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11521,
    "Sayur Asin Kering (0402020206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11522,
    "Sayur Asin Kering (0402020206)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    11523,
    "Sayur Beku (0402020101)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11524,
    "Sayur Beku (0402020101)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    11525,
    "Sayur Beku (0402020101)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11526,
    "Sayur Beku (0402020101)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11527,
    "Sayur Beku (0402020101)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11528,
    "Sayur Beku (0402020101)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    11529,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11530,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11531,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11532,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11533,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    11534,
    "Sayur Beku (Termasuk Jamur, Akar dan Umbi, Polong-polongan dan Aloe Vera) Rumput Laut, Kacang Serta Biji-Bijian Beku yang Diproses dengan Pemasakan dan atau Penambahan Bahan Pangan Lain (0402020114)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [11535, "Sayur dalam Kaleng (0402020415)", "Bobot Tuntas (%)"],
  [
    11536,
    "Sayur dalam Kaleng (0402020415)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11537,
    "Sayur dalam Kaleng (0402020415)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11538,
    "Sayur dalam Kaleng (0402020415)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11539,
    "Sayur dalam Kaleng (0402020415)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11540,
    "Sayur dalam Kaleng (0402020415)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [11541, "Sayur Dalam Kemasan (0402020401)", "Bobot Tuntas (%)"],
  [
    11542,
    "Sayur Dalam Kemasan (0402020401)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11543,
    "Sayur Dalam Kemasan (0402020401)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    11544,
    "Sayur Dalam Kemasan (0402020401)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11545,
    "Sayur Dalam Kemasan (0402020401)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    11546,
    "Sayur Dalam Kemasan (0402020401)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11547,
    "Sayur Dalam Kemasan (0402020401)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    11548,
    "Sayur Dalam Kemasan, Botol atau Dalam Retort Pouch (04020204)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    11549,
    "Sayur Goreng Beku (0402020115)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11550,
    "Sayur Goreng Beku (0402020115)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11551,
    "Sayur Goreng Beku (0402020115)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11552,
    "Sayur Goreng Beku (0402020115)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11553,
    "Sayur Goreng Beku (0402020115)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    11554,
    "Sayur Goreng Beku (0402020115)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [11555, "Sayur Kering (0402020201)", "Kadar air (%)", "=8"],
  [
    11556,
    "Sayur Kering (0402020201)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    11557,
    "Sayur Kering (0402020201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    11558,
    "Sayur Kering (0402020201)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11559,
    "Sayur Kering (0402020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11560,
    "Sayur Kering (0402020201)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    11561,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11562,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11563,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11564,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11565,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11566,
    "Sayur Kering (Freeze Dried/Microwave Dried/Roasting) (0402020230)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11567,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11568,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11569,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11570,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11571,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11572,
    "Sayur Olahan Yang Dibentuk (Meat Analog / Fish Analog / Seafood Analog) (0402020809)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [11573, "Scone (07020204)", "Arsen (As) (mg/kg)", "=0.5"],
  [11574, "Scone (07020204)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [11575, "Scone (07020204)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11576, "Scone (07020204)", "Timah (Sn) (mg/kg)", "=40"],
  [11577, "Scone (07020204)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [11578, "Sea Gel (09030102)", "As (ppm atau mg/kg)", "=0.25"],
  [11579, "Sea Gel (09030102)", "Cd (ppm atau mg/kg)", "=0.1"],
  [11580, "Sea Gel (09030102)", "Hg (ppm atau mg/kg", "=0.5"],
  [
    11581,
    "Sea Gel (09030102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11582,
    "Sea Gel (09030102)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [11583, "Sea Gel (09030102)", "Pb (ppm atau mg/kg)", "=0.2"],
  [
    11584,
    "Secunda Beef Fat (02010307)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11585,
    "Secunda Beef Fat (02010307)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11586,
    "Secunda Beef Fat (02010307)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11587,
    "Secunda Beef Fat (02010307)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11588,
    "Secunda Beef Fat (02010307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11589,
    "Secunda Beef Fat (02010307)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11590,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    11591,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    11592,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11593,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    11594,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku (0315)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11595,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril (0317)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    11596,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril (0317)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    11597,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril (0317)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11598,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril (0317)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    11599,
    "Sediaan Cair Yang Akan Dikonsumsi Dalam Keadaan Beku Steril (0317)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11600,
    "Sediaan Pemanis Alami (110602)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11601,
    "Sediaan Pemanis Alami (110602)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11602,
    "Sediaan Pemanis Alami (110602)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11603,
    "Sediaan Pemanis Alami (110602)",
    "Timah (Sn) yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11604,
    "Sediaan Pemanis Alami (110602)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11605,
    "Sediaan Pemanis Alami (110602)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11606,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11607,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11608,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11609,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Timah (Sn) yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11610,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (Sn) (mg/kg)",
    "=40",
  ],
  [
    11611,
    "Sediaan Pemanis Alami dan Buatan (110604)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11612,
    "Sediaan Pemanis Buatan (110603)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11613,
    "Sediaan Pemanis Buatan (110603)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11614,
    "Sediaan Pemanis Buatan (110603)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11615,
    "Sediaan Pemanis Buatan (110603)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg)",
    "=250",
  ],
  [
    11616,
    "Sediaan Pemanis Buatan (110603)",
    "Timah pangan olahan yang tidak dikemas dalam kaleng (Sn) (mg/kg)",
    "=40",
  ],
  [
    11617,
    "Sediaan Pemanis Buatan (110603)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11618,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11619,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11620,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11621,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Timah (Sn) yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    11622,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (Sn) (mg/kg)",
    "=40",
  ],
  [
    11623,
    "Sediaan Pemanis Campuran : Gula / Pemanis Alami / Pemanis Buatan / Bahan Lainnya (110605)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11624,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11625,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    11626,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    11627,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Timah dalam kaleng (Sn) (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    11628,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11629,
    "Seduhan Herbal (Daun Pepermint, dll)/Seduhan Biji-bijian (14010533)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    11630,
    "Selai Kacang (0402020502)",
    "Kandungan total kacang (%)",
    "",
    "=85",
  ],
  [
    11631,
    "Selai Kacang (0402020502)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11632,
    "Selai Kacang (0402020502)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11633,
    "Selai Kacang (0402020502)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11634,
    "Selai Kacang (0402020502)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11635,
    "Selai Kacang (0402020502)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11636,
    "Selai Kacang (0402020502)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11637,
    "Selai Kacang (0402020502)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    11638,
    "Selai Kacang (0402020502)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    11639,
    "Selai Kacang Lainnya (0402020504)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11640,
    "Selai Kacang Lainnya (0402020504)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11641,
    "Selai Kacang Lainnya (0402020504)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11642,
    "Selai Kacang Lainnya (0402020504)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11643,
    "Selai Kacang Lainnya (0402020504)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11644,
    "Selai Kacang Lainnya (0402020504)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11645,
    "Selai Kacang Lainnya (0402020504)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    11646,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11647,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11648,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11649,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11650,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11651,
    "Selai Kacang Mede (Cashew Butter) (0402020503)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    11652,
    "Selai Kaya (100401)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    11653,
    "Selai Kaya (100401)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    11654,
    "Selai Kaya (100401)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    11655,
    "Selai Kaya (100401)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11656,
    "Selai Kaya (100401)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    11657,
    "Selai Kaya (Steril) (100406)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    11658,
    "Selai Kaya (Steril) (100406)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    11659,
    "Selai Kaya (Steril) (100406)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    11660,
    "Selai Kaya (Steril) (100406)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11661,
    "Selai Kaya (Steril) (100406)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    11662,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11663,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11664,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11665,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Timah (Sn) pangan olahan yang tidak dikemas kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11666,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11667,
    "Selai Labu (Pumpkin Butter) (0402020505)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11668,
    "Selai Sayur (0402020511)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    11669,
    "Selai Sayur (0402020511)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    11670,
    "Selai Sayur (0402020511)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11671,
    "Selai Sayur (0402020511)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    11672,
    "Selai Sayur (0402020511)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    11673,
    "Selai Sayur (0402020511)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11674,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kadar protein (%) (Tepung Gandum Durum)",
    "",
    "=11",
  ],
  [
    11675,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kehalusan : lolos ayakan 45 mesh (%) (Tepung Gandum Durum)",
    "",
    "=80",
  ],
  [
    11676,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kadar air (%) (Semolina Gandum Durum)",
    "=14.5",
  ],
  [
    11677,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kadar protein (%) (Semolina Gandum Durum)",
    "",
    "=10.5",
  ],
  [
    11678,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kehalusan : lolos ayakan 45 mesh (%) (Semolina Gandum Durum)",
    "=79",
  ],
  [
    11679,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11680,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11681,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11682,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11683,
    "Semolina Gandum Durum dan Tepung Gandum Durum (06020108)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11684,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Kadar air (%)",
    "=14.5",
  ],
  [
    11685,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Kadar Abu (%) Untuk semolina gandum durum utuh",
    "=2.1",
  ],
  [
    11686,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Kadar Protein (%)",
    "",
    "=11.5",
  ],
  [
    11687,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11688,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11689,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11690,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11691,
    "Semolina Gandum Durum Utuh dan Tepung Gandum Durum Utuh (06020109)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [11692, "Serabi (07020119)", "Arsen (As) (mg/kg)", "=0.5"],
  [11693, "Serabi (07020119)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [11694, "Serabi (07020119)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [11695, "Serabi (07020119)", "Timah (Sn) (mg/kg)", "=40"],
  [11696, "Serabi (07020119)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    11697,
    "Serbuk Bandrek/Serbat/Sorbat (14010525)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    11698,
    "Serbuk Bandrek/Serbat/Sorbat (14010525)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    11699,
    "Serbuk Bandrek/Serbat/Sorbat (14010525)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11700,
    "Serbuk Bandrek/Serbat/Sorbat (14010525)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    11701,
    "Serbuk Bandrek/Serbat/Sorbat (14010525)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    11702,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11703,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11704,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11705,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11706,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11707,
    "Serbuk Lemak (Fat Powder) (02010242)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11708,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11709,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    11710,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11711,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    11712,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    11713,
    "Serbuk Lemak Hewani (Fat Powder) (02010312)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11714,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11715,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    11716,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11717,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    11718,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    11719,
    "Serbuk Lemak Nabati (Fat Powder) (02010245)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11720,
    "Serbuk Madu (110502)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11721,
    "Serbuk Madu (110502)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11722,
    "Serbuk Madu (110502)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11723,
    "Serbuk Madu (110502)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11724,
    "Serbuk Madu (110502)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [11725, "Serbuk Minuman (14010531)", "Arsen (As) (mg/kg) ", "=1"],
  [
    11726,
    "Serbuk Minuman (14010531)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11727,
    "Serbuk Minuman (14010531)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11728,
    "Serbuk Minuman (14010531)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11729,
    "Serbuk Minuman (14010531)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    11730,
    "Serbuk Minuman Berkarbonat (1401040106)",
    "As (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    11731,
    "Serbuk Minuman Berkarbonat (1401040106)",
    "Cd (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    11732,
    "Serbuk Minuman Berkarbonat (1401040106)",
    "Hg (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    11733,
    "Serbuk Minuman Berkarbonat (1401040106)",
    "Sn yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11734,
    "Serbuk Minuman Berkarbonat (1401040106)",
    "Pb (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    11735,
    "Serbuk Minuman Berperisa (1401040213)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11736,
    "Serbuk Minuman Berperisa (1401040213)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11737,
    "Serbuk Minuman Berperisa (1401040213)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11738,
    "Serbuk Minuman Berperisa (1401040213)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11739,
    "Serbuk Minuman Berperisa (1401040213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11740,
    "Serbuk Minuman Berperisa (1401040213)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11741,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Osmolaritas (miliOsmol/l)",
    "<340",
    ">250",
  ],
  [
    11742,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Kandungan Karbohidrat (%)",
    "=8",
    "=2",
  ],
  [
    11743,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Fruktosa (%)",
    "<5",
  ],
  [
    11744,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Kadar natrium (mg/l)",
    "=690",
    "=200",
  ],
  [
    11745,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Kadar kalium (mg/l)",
    "=200",
    "=125",
  ],
  [
    11746,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Arsen (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    11747,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Kadmium (ppm atau mg/kg)- Siap konsumsi",
    "=0.01",
  ],
  [
    11748,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Merkuri (ppm atau mg/kg)- Siap konsumsi",
    "=0.01",
  ],
  [
    11749,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    11750,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11751,
    "Serbuk Minuman Isotonik Tidak Berkarbonasi (1401040242)",
    "Timbal (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    11752,
    "Serbuk Minuman Jahe (14010523)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    11753,
    "Serbuk Minuman Jahe (14010523)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    11754,
    "Serbuk Minuman Jahe (14010523)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11755,
    "Serbuk Minuman Jahe (14010523)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11756,
    "Serbuk Minuman Jahe (14010523)",
    "Timbal (Pb) (mg/kg) ",
    "=2",
  ],
  [
    11757,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond (14010571)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11758,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond (14010571)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11759,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond (14010571)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11760,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond (14010571)",
    "Timah yang tidak dikemas kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    11761,
    "Serbuk Minuman Kacang Almond/Serbuk Minuman Sari Almond (14010571)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    11762,
    "Serbuk Minuman Kedelai (06080103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11763,
    "Serbuk Minuman Kedelai (06080103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11764,
    "Serbuk Minuman Kedelai (06080103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11765,
    "Serbuk Minuman Kedelai (06080103)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng - siap konsumsi",
    "=100",
  ],
  [
    11766,
    "Serbuk Minuman Kedelai (06080103)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11767,
    "Serbuk Minuman Kedelai (06080103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11768,
    "Serbuk Minuman Kedelai (06080103)",
    "Kadar protein (N x 6.25) (%)",
    "",
    "=0.8",
  ],
  [
    11769,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11770,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11771,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11772,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11773,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11774,
    "Serbuk Minuman Rasa Jeruk (1401040214)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11775,
    "Serbuk Minuman Sereal (060313)",
    "Kandungan serealia (%)",
    "",
    "=25",
  ],
  [
    11776,
    "Serbuk Minuman Sereal (060313)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11777,
    "Serbuk Minuman Sereal (060313)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11778,
    "Serbuk Minuman Sereal (060313)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11779,
    "Serbuk Minuman Sereal (060313)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11780,
    "Serbuk Minuman Sereal (060313)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11781,
    "Serbuk Minuman Sereal (060313)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11782,
    "Serbuk Minuman Tradisional (14010522)",
    "Kadar Gula (%)",
    "=85",
  ],
  [
    11783,
    "Serbuk Minuman Tradisional (14010522)",
    "Kadar Air (%)",
    "=3",
  ],
  [
    11784,
    "Serbuk Minuman Tradisional (14010522)",
    "Kadar Abu (%)",
    "=1.5",
  ],
  [
    11785,
    "Serbuk Minuman Tradisional (14010522)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    11786,
    "Serbuk Minuman Tradisional (14010522)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11787,
    "Serbuk Minuman Tradisional (14010522)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11788,
    "Serbuk Minuman Tradisional (14010522)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11789,
    "Serbuk Minuman Tradisional (14010522)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    11790,
    "Serbuk Minuman Tradisional (14010522)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    11791,
    "Serbuk Minyak (02010207)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11792,
    "Serbuk Minyak (02010207)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11793,
    "Serbuk Minyak (02010207)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11794,
    "Serbuk Minyak (02010207)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11795,
    "Serbuk Minyak (02010207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11796,
    "Serbuk Minyak (02010207)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    11797,
    "Serbuk Minyak Kelapa (02010223)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11798,
    "Serbuk Minyak Kelapa (02010223)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11799,
    "Serbuk Minyak Kelapa (02010223)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11800,
    "Serbuk Minyak Kelapa (02010223)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11801,
    "Serbuk Minyak Kelapa (02010223)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11802,
    "Serbuk Minyak Kelapa (02010223)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11803,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11804,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11805,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11806,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11807,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11808,
    "Serbuk Minyak Kelapa Sawit (02010215)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11809,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11810,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11811,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11812,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11813,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11814,
    "Serbuk Minyak Kelapa Virgin (02010221)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    11815,
    "Serbuk Sekoteng (14010524)",
    "Arsen (As) (mg/kg) ",
    "=1",
  ],
  [
    11816,
    "Serbuk Sekoteng (14010524)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    11817,
    "Serbuk Sekoteng (14010524)",
    "Raksa (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    11818,
    "Serbuk Sekoteng (14010524)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11819,
    "Serbuk Sekoteng (14010524)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [11820, "Serbuk Sekoteng (14010569)", "Arsen (As) (mg/kg)", "=1"],
  [
    11821,
    "Serbuk Sekoteng (14010569)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11822,
    "Serbuk Sekoteng (14010569)",
    "Raksa (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11823,
    "Serbuk Sekoteng (14010569)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11824,
    "Serbuk Sekoteng (14010569)",
    "Timbal (Pb) (mg/kg)",
    "=2",
  ],
  [
    11825,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11826,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11827,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11828,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11829,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11830,
    "Sereal Siap Saji (Steril Komersial) (060315)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11831,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Serealia utuh (%)",
    "=25",
  ],
  [
    11832,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Serat pangan (g /100 g)",
    "=3",
  ],
  [
    11833,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11834,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11835,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11836,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11837,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11838,
    "Sereal Siap Santap dengan Serealia Utuh (Whole Grain Ready To Eat Cereal) termasuk Sereal Sarapan dengan Serealia Utuh (060316)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11839,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11840,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11841,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11842,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11843,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11844,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11845,
    "Sereal Siap Santap termasuk Sereal Sarapan (060309)",
    "Kandungan Serealia (%)",
    "",
    "=50",
  ],
  [
    11846,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    11847,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    11848,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11849,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11850,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11851,
    "Sereal untuk Sarapan dengan Susu (060314)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    11852,
    "Serealia Celup (14010564)",
    "Kandungan serealia (%)",
    "",
    "=25",
  ],
  [
    11853,
    "Serealia Celup (14010564)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    11854,
    "Serealia Celup (14010564)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    11855,
    "Serealia Celup (14010564)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    11856,
    "Serealia Celup (14010564)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11857,
    "Serealia Celup (14010564)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [11858, "Sereh (120201A7)", "Arsen (As) (mg/kg)", "=0.15"],
  [11859, "Sereh (120201A7)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [
    11860,
    "Sereh (120201A7)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11861,
    "Sereh (120201A7)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [11862, "Sereh (120201A7)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11863,
    "Shandy (14020704)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [11864, "Shandy (14020704)", "Arsen (mg/kg)", "=0.1"],
  [11865, "Shandy (14020704)", "Kadmium (mg/kg)", "=0.2"],
  [11866, "Shandy (14020704)", "Merkuri (mg/kg)", "=0.03"],
  [
    11867,
    "Shandy (14020704)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    11868,
    "Shandy (14020704)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [11869, "Shandy (14020704)", "Timbal (mg/kg)", "=0.2"],
  [11870, "Shandy (14020704)", "Kadar etanol (%)", "=1"],
  [11871, "Sherbet (0309)", "Arsen (As) (ppm atau mg/kg)", "=0.20"],
  [
    11872,
    "Sherbet (0309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    11873,
    "Sherbet (0309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11874,
    "Sherbet (0309)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    11875,
    "Sherbet (0309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11876,
    "Shio-Kombu (0402020219)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11877,
    "Shio-Kombu (0402020219)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11878,
    "Shio-Kombu (0402020219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11879,
    "Shio-Kombu (0402020219)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11880,
    "Shio-Kombu (0402020219)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11881,
    "Shortened Bread (07010305)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    11882,
    "Shortened Bread (07010305)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    11883,
    "Shortened Bread (07010305)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11884,
    "Shortened Bread (07010305)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11885,
    "Shortened Bread (07010305)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11886,
    "Shortened Bread (07010305)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    11887,
    "Sidat Panggang Beku (09020131)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    11888,
    "Sidat Panggang Beku (09020131)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    11889,
    "Sidat Panggang Beku (09020131)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    11890,
    "Sidat Panggang Beku (09020131)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    11891,
    "Sidat Panggang Beku (09020131)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    11892,
    "Sidat Panggang Beku (09020131)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11893,
    "Simmered Beans (0402020804)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    11894,
    "Simmered Beans (0402020804)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11895,
    "Simmered Beans (0402020804)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    11896,
    "Simmered Beans (0402020804)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11897,
    "Simmered Beans (0402020804)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11898,
    "Simping (150116)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11899,
    "Simping (150116)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11900,
    "Simping (150116)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11901,
    "Simping (150116)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11902,
    "Simping (150116)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11903,
    "Siomay Daging (08030323)",
    "Total Meat Content (%)",
    "",
    "=30",
  ],
  [
    11904,
    "Siomay Daging (08030323)",
    "Kadar Daging (%) Lebih dari 50% dari Total Meat Content",
  ],
  [
    11905,
    "Siomay Daging (08030323)",
    "Kadar Ikan (%) Kurang dari 50% dari Total Meat Content",
  ],
  [
    11906,
    "Siomay Daging (08030323)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11907,
    "Siomay Daging (08030323)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    11908,
    "Siomay Daging (08030323)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11909,
    "Siomay Daging (08030323)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    11910,
    "Siomay Daging (08030323)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11911,
    "Siomay Daging (08030323)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    11912,
    "Siomay Ikan (0902040111)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    11913,
    "Siomay Ikan (0902040111)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    11914,
    "Siomay Ikan (0902040111)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [11915, "Siomay Ikan (0902040111)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [11916, "Siomay Ikan (0902040111)", "Timah (Sn) (mg/kg)", "=40"],
  [
    11917,
    "Siomay Ikan (0902040111)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11918,
    "Siomay Udang (0902040206)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    11919,
    "Siomay Udang (0902040206)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    11920,
    "Siomay Udang (0902040206)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    11921,
    "Siomay Udang (0902040206)",
    "Raksa (Hg) (mg/kg)",
    "=0.5",
  ],
  [11922, "Siomay Udang (0902040206)", "Timah (Sn) (mg/kg)", "=40"],
  [
    11923,
    "Siomay Udang (0902040206)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11924,
    "Siomay Udang (Khusus Registrasi Ulang) (0902040214)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    11925,
    "Siomay Udang (Khusus Registrasi Ulang) (0902040214)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    11926,
    "Siomay Udang (Khusus Registrasi Ulang) (0902040214)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    11927,
    "Siomay Udang (Khusus Registrasi Ulang) (0902040214)",
    "Timah (Sn) (mg/kg) ",
    "=40",
  ],
  [
    11928,
    "Siomay Udang (Khusus Registrasi Ulang) (0902040214)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    11929,
    "Sirup Agave (110407)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11930,
    "Sirup Agave (110407)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11931,
    "Sirup Agave (110407)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11932,
    "Sirup Agave (110407)",
    "Timah pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (Sn) (mg/kg) ",
    "=250",
  ],
  [
    11933,
    "Sirup Agave (110407)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11934,
    "Sirup Agave (110407)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11935,
    "Sirup Berperisa (1401040206)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11936,
    "Sirup Berperisa (1401040206)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11937,
    "Sirup Berperisa (1401040206)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11938,
    "Sirup Berperisa (1401040206)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11939,
    "Sirup Berperisa (1401040206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11940,
    "Sirup Berperisa (1401040206)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11941,
    "Sirup Berperisa (1401040206)",
    "Kadar Gula (%)",
    "",
    "=65",
  ],
  [
    11942,
    "Sirup Berperisa (1401040310)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    11943,
    "Sirup Berperisa (1401040310)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    11944,
    "Sirup Berperisa (1401040310)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    11945,
    "Sirup Berperisa (1401040310)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11946,
    "Sirup Berperisa (1401040310)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11947,
    "Sirup Berperisa (1401040310)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11948,
    "Sirup Berperisa (1401040310)",
    "Kadar Gula (%)",
    "",
    "=65",
  ],
  [
    11949,
    "Sirup Buah (1401040207)",
    "Kandungan sari buah atau bagian buah lain (%)",
    "",
    ">25",
  ],
  [11950, "Sirup Buah (1401040207)", "Total padatan (%)", "", ">30"],
  [
    11951,
    "Sirup Buah (1401040207)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11952,
    "Sirup Buah (1401040207)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11953,
    "Sirup Buah (1401040207)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11954,
    "Sirup Buah (1401040207)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11955,
    "Sirup Buah (1401040207)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11956,
    "Sirup Buah (1401040207)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11957,
    "Sirup Buah (1401040309)",
    "Kadar gula sebagai sakarosa",
    "",
    "=65",
  ],
  [
    11958,
    "Sirup Buah (1401040309)",
    "Kandungan sari buah atau bagian buah lain",
    "",
    "=25",
  ],
  [
    11959,
    "Sirup Buah (1401040309)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    11960,
    "Sirup Buah (1401040309)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    11961,
    "Sirup Buah (1401040309)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    11962,
    "Sirup Buah (1401040309)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11963,
    "Sirup Buah (1401040309)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11964,
    "Sirup Buah (1401040309)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [11965, "Sirup Cokelat (05010201)", "Arsen (As) (mg/kg)", "=1"],
  [
    11966,
    "Sirup Cokelat (05010201)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    11967,
    "Sirup Cokelat (05010201)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    11968,
    "Sirup Cokelat (05010201)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    11969,
    "Sirup Cokelat (05010201)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [11970, "Sirup Cokelat (05010201)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    11971,
    "Sirup Cokelat (05010201)",
    "Kandungan kakao (total cocoa solids) (%)",
    "",
    "=8",
  ],
  [
    11972,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11973,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11974,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    11975,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    11976,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    11977,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    11978,
    "Sirup Cokelat, Sirup Karamel, Sirup Kopi (1401040208)",
    "Kandungan kakao (total cocoa solids) (%)",
    "",
    "=8",
  ],
  [
    11979,
    "Sirup Encer Berperisa (1401040304)",
    "Arsen (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    11980,
    "Sirup Encer Berperisa (1401040304)",
    "Kadmium (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    11981,
    "Sirup Encer Berperisa (1401040304)",
    "Merkuri (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    11982,
    "Sirup Encer Berperisa (1401040304)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    11983,
    "Sirup Encer Berperisa (1401040304)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    11984,
    "Sirup Encer Berperisa (1401040304)",
    "Timbal (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    11985,
    "Sirup Encer Berperisa (1401040304)",
    "Larutan gula (%)",
    "=65",
    "=55",
  ],
  [
    11986,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "fruktosa (%)",
    "",
    "=42",
  ],
  [
    11987,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11988,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11989,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11990,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11991,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 (11030101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11992,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "dekstrosa (%)",
    "=53",
    "=50",
  ],
  [
    11993,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    11994,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    11995,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    11996,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    11997,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 42 dan HFS 55 (11030103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    11998,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "fruktosa (%)",
    "",
    "=55",
  ],
  [
    11999,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12000,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12001,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12002,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12003,
    "Sirup Fruktosa (High Fructose Syrup/HFS) 55 (11030102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12004,
    "Sirup Glukosa (11010303)",
    "Kadar Gula (Sebagai D-Glukosa) (%)",
    "",
    "=20",
  ],
  [
    12005,
    "Sirup Glukosa (11010303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12006,
    "Sirup Glukosa (11010303)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12007,
    "Sirup Glukosa (11010303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12008,
    "Sirup Glukosa (11010303)",
    "Timah (Sn) yang dikemas dalam kaleng (Sn) (mg/kg) ",
    "=250",
  ],
  [
    12009,
    "Sirup Glukosa (11010303)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12010,
    "Sirup Glukosa (11010303)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12011, "Sirup Jagung (110305)", "Arsen (As) (mg/kg)", "=1"],
  [12012, "Sirup Jagung (110305)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [12013, "Sirup Jagung (110305)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    12014,
    "Sirup Jagung (110305)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12015,
    "Sirup Jagung (110305)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12016, "Sirup Jagung (110305)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [12017, "Sirup Kopi (1401040312)", "Kadar gula (%)", "", "=45"],
  [
    12018,
    "Sirup Kopi (1401040312)",
    "Total padatan terlarut (%)",
    "",
    "=65",
  ],
  [
    12019,
    "Sirup Kopi (1401040312)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12020,
    "Sirup Kopi (1401040312)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12021,
    "Sirup Kopi (1401040312)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12022,
    "Sirup Kopi (1401040312)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    12023,
    "Sirup Kopi (1401040312)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12024,
    "Sirup Kopi (1401040312)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [12025, "Sirup Madu (1401040232)", "Arsen (mg/kg)", "=0.05"],
  [12026, "Sirup Madu (1401040232)", "Kadmium (mg/kg)", "=0.01"],
  [12027, "Sirup Madu (1401040232)", "Merkuri (mg/kg)", "=0.01"],
  [
    12028,
    "Sirup Madu (1401040232)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12029,
    "Sirup Madu (1401040232)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12030, "Sirup Madu (1401040232)", "Timbal (mg/kg)", "=0.05"],
  [
    12031,
    "Sirup Maltosa (11010309)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12032,
    "Sirup Maltosa (11010309)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12033,
    "Sirup Maltosa (11010309)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12034,
    "Sirup Maltosa (11010309)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12035,
    "Sirup Maltosa (11010309)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12036,
    "Sirup Maple (Maple Syrup) (110402)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12037,
    "Sirup Maple (Maple Syrup) (110402)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12038,
    "Sirup Maple (Maple Syrup) (110402)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12039,
    "Sirup Maple (Maple Syrup) (110402)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12040,
    "Sirup Maple (Maple Syrup) (110402)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12041,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    12042,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    12043,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    12044,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    12045,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    12046,
    "Sirup Tebu (Cane Syrup) (110306)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    12047,
    "Sirup Tebu (Cane Syrup) (110401)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12048,
    "Sirup Tebu (Cane Syrup) (110401)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12049,
    "Sirup Tebu (Cane Syrup) (110401)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12050,
    "Sirup Tebu (Cane Syrup) (110401)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12051,
    "Sirup Tebu (Cane Syrup) (110401)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12052, "Sirup Teh (1401040311)", "Kadar gula (%)", "", "=40"],
  [
    12053,
    "Sirup Teh (1401040311)",
    "Total padatan terlarut (%)",
    "",
    "=40.12",
  ],
  [12054, "Sirup Teh (1401040311)", "Total tanin (%)", "", "=0.12"],
  [
    12055,
    "Sirup Teh (1401040311)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12056,
    "Sirup Teh (1401040311)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    12057,
    "Sirup Teh (1401040311)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.01",
  ],
  [
    12058,
    "Sirup Teh (1401040311)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    12059,
    "Sirup Teh (1401040311)",
    "Timah (Sn) (ppm atau mg/kg) Pangan olahan yang tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12060,
    "Sirup Teh (1401040311)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12061,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12062,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12063,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12064,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12065,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12066,
    "Sirup Untuk Hiasan Produk Bakeri dan Es (Sirup Karamel, Sirup Beraroma) (110405)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    12067,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12068,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    12069,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12070,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    12071,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12072,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12073,
    "Sirup/Sirup Meja (Table Syrup) (110404)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12074, "Siwalan (0401020907)", "Arsen (As) (mg/kg) ", "=0.15"],
  [12075, "Siwalan (0401020907)", "Kadmium (Cd) (mg/kg) ", "=0.05"],
  [12076, "Siwalan (0401020907)", "Merkuri (Hg) (mg/kg) ", "=0.03"],
  [
    12077,
    "Siwalan (0401020907)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    12078,
    "Siwalan (0401020907)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [12079, "Siwalan (0401020907)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    12080,
    "Slondok (150117)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12081,
    "Slondok (150117)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12082,
    "Slondok (150117)",
    "Raksa (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12083,
    "Slondok (150117)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12084,
    "Slondok (150117)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12085,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12086,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12087,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12088,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12089,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12090,
    "Smoked Chicken Breast (Daging Dada Ayam Asap) (08030312)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12091,
    "Soda Krim (Cream soda) (1401040113)",
    "Kandungan (Brix)",
    "=14",
  ],
  [
    12092,
    "Soda Krim (Cream soda) (1401040113)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12093,
    "Soda Krim (Cream soda) (1401040113)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    12094,
    "Soda Krim (Cream soda) (1401040113)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    12095,
    "Soda Krim (Cream soda) (1401040113)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12096,
    "Soda Krim (Cream soda) (1401040113)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12097,
    "Soda Krim (Cream soda) (1401040113)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.05",
  ],
  [12098, "Sohun (06040216)", "Kadar air (%)", "=14.5"],
  [
    12099,
    "Sohun (06040216)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12100,
    "Sohun (06040216)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12101,
    "Sohun (06040216)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12102,
    "Sohun (06040216)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    12103,
    "Sohun (06040216)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12104, "Sohun (06040318)", "Kadar air (%)", "=13"],
  [
    12105,
    "Sohun (06040318)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12106,
    "Sohun (06040318)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12107,
    "Sohun (06040318)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12108,
    "Sohun (06040318)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12109,
    "Sohun (06040318)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12110,
    "Sohun Instan (06040323)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12111,
    "Sohun Instan (06040323)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12112,
    "Sohun Instan (06040323)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12113,
    "Sohun Instan (06040323)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12114,
    "Sohun Instan (06040323)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12115, "Sohun Lainnya (06040319)", "Kadar air (%)", "=13"],
  [
    12116,
    "Sohun Lainnya (06040319)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12117,
    "Sohun Lainnya (06040319)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12118,
    "Sohun Lainnya (06040319)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12119,
    "Sohun Lainnya (06040319)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12120,
    "Sohun Lainnya (06040319)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12121, "Soju (14020615)", "Kadar etanol (% v/v)", "=35", "=20"],
  [12122, "Soju (14020615)", "Arsen (mg/kg)", "=0.1"],
  [12123, "Soju (14020615)", "Kadmium (mg/kg)", "=0.2"],
  [12124, "Soju (14020615)", "Merkuri (mg/kg)", "=0.03"],
  [
    12125,
    "Soju (14020615)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12126, "Soju (14020615)", "Timbal (mg/kg)", "=0.2"],
  [
    12127,
    "Soju (14020615)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [12128, "Sorbet (0310)", "Arsen (As) (ppm atau mg/kg)", "=0.20"],
  [
    12129,
    "Sorbet (0310)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    12130,
    "Sorbet (0310)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [12131, "Sorbet (0310)", "Timah (Sn) (ppm atau mg/kg)", "=40.00"],
  [12132, "Sorbet (0310)", "Timbal (Pb) (ppm atau mg/kg)", "=0.15"],
  [
    12133,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12134,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12135,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12136,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12137,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12138,
    "Sosis Analog/Daging Analog/ Produk Analog (08030217)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12139,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    12140,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    12141,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    12142,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    12143,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    12144,
    "Sosis Analog/Daging Analog/ Produk Analog Steril (08030221)",
    "Timbal (Pb) (mg/kg) ",
    "=0.5",
  ],
  [
    12145,
    "Sosis Asap (0803010106)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12146,
    "Sosis Asap (0803010106)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12147,
    "Sosis Asap (0803010106)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12148,
    "Sosis Asap (0803010106)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12149,
    "Sosis Asap (0803010106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12150,
    "Sosis Asap (0803010106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [12151, "Sosis Asap (0803010106)", "Kadar Daging (%)", "", "=35"],
  [12152, "Sosis Asap (0803010106)", "Kadar Lemak (%)", "=20"],
  [12153, "Sosis Asap (0803010106)", "Kadar Protein (%)", "", "=13"],
  [
    12154,
    "Sosis Asap (0803010106)",
    "Benzo(a)piren (ppb atau mcg/kg)",
    "=5",
  ],
  [
    12155,
    "Sosis Asap Kombinasi (0803010108)",
    "Kadar Daging (%)",
    "",
    "=15",
  ],
  [
    12156,
    "Sosis Asap Kombinasi (0803010108)",
    "Kadar Lemak (%) ",
    "=20",
  ],
  [
    12157,
    "Sosis Asap Kombinasi (0803010108)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    12158,
    "Sosis Asap Kombinasi (0803010108)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12159,
    "Sosis Asap Kombinasi (0803010108)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12160,
    "Sosis Asap Kombinasi (0803010108)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12161,
    "Sosis Asap Kombinasi (0803010108)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12162,
    "Sosis Asap Kombinasi (0803010108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12163,
    "Sosis Asap Kombinasi (0803010108)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12164,
    "Sosis Asap Kombinasi (0803010108)",
    "Benzo(a)piren (ppb atau mcg/kg)",
    "=5",
  ],
  [
    12165,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "As (mg/kg)",
    "=0.25",
  ],
  [
    12166,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Cd (mg/kg)",
    "=0.05",
  ],
  [
    12167,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Hg (mg/kg)",
    "=0.03",
  ],
  [
    12168,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12169,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12170,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Pb (mg/kg)",
    "=0.5",
  ],
  [
    12171,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Kadar Daging (%)",
    "",
    "=35",
  ],
  [
    12172,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12173,
    "Sosis Cina - Sosis Daging (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010207)",
    "Kadar Protein (%)",
    "",
    "=13",
  ],
  [
    12174,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "As (mg/kg)",
    "=0.25",
  ],
  [
    12175,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Cd (mg/kg)",
    "=0.05",
  ],
  [
    12176,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Hg (mg/kg)",
    "=0.03",
  ],
  [
    12177,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12178,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12179,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Pb (mg/kg)",
    "=0.5",
  ],
  [
    12180,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Kadar Daging (%)",
    "",
    "=15",
  ],
  [
    12181,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12182,
    "Sosis Cina - Sosis Kombinasi (Termasuk Sosis Tradisional yang Dicuring atau Diasap) (0803010208)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    12183,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12184,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12185,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12186,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12187,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12188,
    "Sosis Cina (Termasuk Sosis Tradisional Yang Dikuring atau Diasap) atau Lup Cheong (0803010205)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12189,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12190,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12191,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12192,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12193,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12194,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12195,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12196,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Kadar Daging (%)",
    "",
    "=35",
  ],
  [
    12197,
    "Sosis Daging (dengan Perlakuan Panas) (08030247)",
    "Kadar Protein (%)",
    "",
    "=13",
  ],
  [
    12198,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12199,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12200,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12201,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12202,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12203,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) (08030215)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12204,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng (08030226)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12205,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng (08030226)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12206,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng (08030226)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12207,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng (08030226)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12208,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Kaleng (08030226)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12209,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril (08030224)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12210,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril (08030224)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12211,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril (08030224)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12212,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril (08030224)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12213,
    "Sosis Daging (sapi, ayam, babi, atau daging lainnya) Steril (08030224)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12214,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Kadar Daging (%)",
    "",
    "=35",
  ],
  [
    12215,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12216,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Kadar Protein (%)",
    "",
    "=13",
  ],
  [
    12217,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12218,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12219,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12220,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12221,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12222,
    "Sosis Daging (Tanpa Perlakuan Panas) (0803010109)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12223,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12224,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12225,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12226,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12227,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12228,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12229,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Kadar Daging (%)",
    "",
    "=15",
  ],
  [
    12230,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12231,
    "Sosis Daging Kombinasi (dengan Perlakuan Panas) (08030231)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    12232,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Kadar Daging (%)",
    "",
    "=15",
  ],
  [
    12233,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12234,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    12235,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12236,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12237,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12238,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12239,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12240,
    "Sosis Daging Kombinasi (Tanpa Perlakuan Panas) (0803010110)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12241,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Kadar Daging (%)",
    "",
    "=15",
  ],
  [
    12242,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Kadar Protein (%)",
    "",
    "=8",
  ],
  [
    12243,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Kadar Lemak (%)",
    "=20",
  ],
  [
    12244,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12245,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12246,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12247,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12248,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12249,
    "Sosis Daging Kombinasi Non Casing (08030239)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12250,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Kandungan daging (%)",
    "",
    "=15",
  ],
  [
    12251,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Kadar protein (%)",
    "",
    "=8",
  ],
  [
    12252,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Kadar lemak (%)",
    "=20",
  ],
  [
    12253,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12254,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12255,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12256,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12257,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12258,
    "Sosis Daging Kombinasi Siap Makan (08030246)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12259,
    "Sosis Daging Non Casing (08030238)",
    "Kadar Daging (%) ",
    "",
    "=35",
  ],
  [
    12260,
    "Sosis Daging Non Casing (08030238)",
    "Kadar protein (%) ",
    "",
    "=13",
  ],
  [
    12261,
    "Sosis Daging Non Casing (08030238)",
    "Kadar lemak (%)",
    "=20",
  ],
  [
    12262,
    "Sosis Daging Non Casing (08030238)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12263,
    "Sosis Daging Non Casing (08030238)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12264,
    "Sosis Daging Non Casing (08030238)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12265,
    "Sosis Daging Non Casing (08030238)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12266,
    "Sosis Daging Non Casing (08030238)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12267,
    "Sosis Daging Non Casing (08030238)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12268,
    "Sosis Daging Siap Makan (08030245)",
    "Kandungan daging (%)",
    "",
    "=35",
  ],
  [
    12269,
    "Sosis Daging Siap Makan (08030245)",
    "Kadar protein (%)",
    "",
    "=13",
  ],
  [
    12270,
    "Sosis Daging Siap Makan (08030245)",
    "Kadar lemak (%)",
    "=20",
  ],
  [
    12271,
    "Sosis Daging Siap Makan (08030245)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12272,
    "Sosis Daging Siap Makan (08030245)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12273,
    "Sosis Daging Siap Makan (08030245)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12274,
    "Sosis Daging Siap Makan (08030245)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12275,
    "Sosis Daging Siap Makan (08030245)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12276,
    "Sosis Daging Siap Makan (08030245)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [12277, "Sosis Ikan (0902040115)", "Arsen (As) (mg/kg)", "=0.25"],
  [
    12278,
    "Sosis Ikan (0902040115)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [12279, "Sosis Ikan (0902040115)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [12280, "Sosis Ikan (0902040115)", "Timah (Sn) (mg/kg)", "=40"],
  [12281, "Sosis Ikan (0902040115)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [
    12282,
    "Sosis Ikan (0902040115)",
    "Kandungan lumatan daging ikan atau surimi (%)",
    "",
    "=50",
  ],
  [
    12283,
    "Sosis Ikan Kombinasi (0902040128)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12284,
    "Sosis Ikan Kombinasi (0902040128)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    12285,
    "Sosis Ikan Kombinasi (0902040128)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    12286,
    "Sosis Ikan Kombinasi (0902040128)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    12287,
    "Sosis Ikan Kombinasi (0902040128)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    12288,
    "Sosis Ikan Kombinasi (0902040128)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12289,
    "Sosis Ikan Kombinasi (0902040128)",
    "Kandungan lumatan daging ikan atau surimi (%)",
    "",
    "=20",
  ],
  [
    12290,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12291,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    12292,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    12293,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    12294,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    12295,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12296,
    "Sosis Ikan/Moluska/Krustase/Ekinodermata Siap Santap (090414)",
    "Kandungan lumatan daging ikan/moluska/krustase/ekinodermata atau surimi (%)",
    "",
    "= 30",
  ],
  [
    12297,
    "Sosis Mentah (Breakfast Sausage) (08010204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12298,
    "Sosis Mentah (Breakfast Sausage) (08010204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12299,
    "Sosis Mentah (Breakfast Sausage) (08010204)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12300,
    "Sosis Mentah (Breakfast Sausage) (08010204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12301,
    "Sosis Mentah (Breakfast Sausage) (08010204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12302,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "kandungan daging (%)",
    "",
    "=15",
  ],
  [
    12303,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Protein (%)",
    "",
    "=8",
  ],
  [
    12304,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Lemak (%)",
    "=20",
  ],
  [
    12305,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Arsen (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12306,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Kadmium (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12307,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Merkuri (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12308,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12309,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12310,
    "Sosis Mentah (Sosis Daging Kombinasi) (08010214)",
    "Timbal (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12311,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "kandungan daging (%)",
    "",
    "=35",
  ],
  [
    12312,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Protein (%)",
    "",
    "=13",
  ],
  [
    12313,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Lemak (%)",
    "=20",
  ],
  [
    12314,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Arsen (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12315,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Kadmium (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12316,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Merkuri (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12317,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12318,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12319,
    "Sosis Mentah (Sosis Daging) (08010213)",
    "Timbal (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12320,
    "Sosis Mentah Daging Babi (08010203)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12321,
    "Sosis Mentah Daging Babi (08010203)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12322,
    "Sosis Mentah Daging Babi (08010203)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12323,
    "Sosis Mentah Daging Babi (08010203)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12324,
    "Sosis Mentah Daging Babi (08010203)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12325,
    "Sosis Mentah Daging Babi (08010203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12326,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12327,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12328,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12329,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12330,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12331,
    "Sosis Mentah Tanpa Fermentasi (Loganiza) (08010208)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12332,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12333,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12334,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12335,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12336,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12337,
    "Sosis Sarapan Matang (Sosis Daging Babi Matang) (08030214)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12338,
    "Sosis Segar (08010212)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12339,
    "Sosis Segar (08010212)",
    "Kadmium (Cd) (ppm atau mg/kg)",
  ],
  [
    12340,
    "Sosis Segar (08010212)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12341,
    "Sosis Segar (08010212)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12342,
    "Sosis Segar (08010212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12343,
    "Sosis Segar (08010212)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12344,
    "Sosis Siap Santap (08030220)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12345,
    "Sosis Siap Santap (08030220)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12346,
    "Sosis Siap Santap (08030220)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12347,
    "Sosis Siap Santap (08030220)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12348,
    "Sosis Siap Santap (08030220)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12349,
    "Sosis Siap Santap (08030220)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12350,
    "Sosis Siap Santap (0902040120)",
    "Arsen (As) (ppm atau mg/kg) ",
    "<0.25",
  ],
  [
    12351,
    "Sosis Siap Santap (0902040120)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    12352,
    "Sosis Siap Santap (0902040120)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12353,
    "Sosis Siap Santap (0902040120)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12354,
    "Sosis Siap Santap (0902040120)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12355,
    "Sosis Siap Santap (0902040120)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    12356,
    "Sosis Udang (0902040116)",
    "Angka Lempeng Total (300C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    12357,
    "Sosis Udang (0902040116)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12358,
    "Sosis Udang (0902040116)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [12359, "Sosis Udang (0902040116)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [12360, "Sosis Udang (0902040116)", "Timah (Sn) (mg/kg)", "=40"],
  [
    12361,
    "Sosis Udang (0902040116)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12362,
    "Sosis Udang (0902040208)",
    "Angka Lempeng Total (30 C, 72 jam) (koloni/g)",
    "=500000",
  ],
  [
    12363,
    "Sosis Udang (0902040208)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12364,
    "Sosis Udang (0902040208)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [12365, "Sosis Udang (0902040208)", "Raksa (Hg) (mg/kg)", "=0.5"],
  [12366, "Sosis Udang (0902040208)", "Timah (Sn) (mg/kg)", "=40"],
  [
    12367,
    "Sosis Udang (0902040208)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12368,
    "Sosis Variasi (08030216)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12369,
    "Sosis Variasi (08030216)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12370,
    "Sosis Variasi (08030216)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12371,
    "Sosis Variasi (08030216)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12372,
    "Sosis Variasi (08030216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12373,
    "Sosis Variasi (08030216)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12374,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12375,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12376,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    12377,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12378,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12379,
    "Sosis yang Dikuring dan Dikeringkan (0803010203)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12380,
    "Sotong Dalam Kemasan (090417)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12381,
    "Sotong Dalam Kemasan (090417)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    12382,
    "Sotong Dalam Kemasan (090417)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    12383,
    "Sotong Dalam Kemasan (090417)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    12384,
    "Sotong Dalam Kemasan (090417)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    12385,
    "Sotong Dalam Kemasan (090417)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12386,
    "Sotong Dalam Kemasan (090417)",
    "Bobot Tuntas (%)",
    "",
    "=50",
  ],
  [
    12387,
    "Squash (1401040210)",
    "Kadar gula sebagai sakarosa",
    "=55",
    "=25",
  ],
  [
    12388,
    "Squash (1401040210)",
    "Total padatan terlarut",
    "",
    ">30",
  ],
  [12389, "Squash (1401040210)", "Kandungan buah", "<25", ">10"],
  [
    12390,
    "Squash (1401040210)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    12391,
    "Squash (1401040210)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    12392,
    "Squash (1401040210)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    12393,
    "Squash (1401040210)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    12394,
    "Squash (1401040210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12395,
    "Squash (1401040210)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [12396, "Squash (1401040307)", "Warna, aroma dan rasa"],
  [
    12397,
    "Squash (1401040307)",
    "Kadar gula sebagai sakarosa",
    "=55",
    "=25",
  ],
  [
    12398,
    "Squash (1401040307)",
    "Total padatan terlarut",
    "",
    "=30",
  ],
  [12399, "Squash (1401040307)", "Kandungan sari buah", "", "=10"],
  [
    12400,
    "Squash (1401040307)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    12401,
    "Squash (1401040307)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12402,
    "Squash (1401040307)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12403,
    "Squash (1401040307)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)-siap konsumsi",
    "=100",
  ],
  [
    12404,
    "Squash (1401040307)",
    "Timah (Sn) (ppm atau mg/kg) Pangan olahan yang tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    12405,
    "Squash (1401040307)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    12406,
    "Squash Berperisa (1401040211)",
    "Arsen (As) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    12407,
    "Squash Berperisa (1401040211)",
    "Kadmium (Cd) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    12408,
    "Squash Berperisa (1401040211)",
    "Merkuri (Hg) (ppm atau mg/kg)- siap konsumsi",
    "=0.01",
  ],
  [
    12409,
    "Squash Berperisa (1401040211)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg)- siap konsumsi",
    "=100",
  ],
  [
    12410,
    "Squash Berperisa (1401040211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12411,
    "Squash Berperisa (1401040211)",
    "Timbal (Pb) (ppm atau mg/kg)- siap konsumsi",
    "=0.05",
  ],
  [
    12412,
    "Squash Berperisa (Steril) (1401040241)",
    "Arsen (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    12413,
    "Squash Berperisa (Steril) (1401040241)",
    "Kadmium (ppm atau mg/kg)- Siap konsumsi",
    "=0.01",
  ],
  [
    12414,
    "Squash Berperisa (Steril) (1401040241)",
    "Merkuri (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    12415,
    "Squash Berperisa (Steril) (1401040241)",
    "Timah, minuman dalam kemasan kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12416,
    "Squash Berperisa (Steril) (1401040241)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12417,
    "Squash Berperisa (Steril) (1401040241)",
    "Timbal (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12418,
    "Squash Berperisa (Steril) (1401040315)",
    "Kadar gula sebagai sakarosa (%)",
    "=55",
    "=25",
  ],
  [
    12419,
    "Squash Berperisa (Steril) (1401040315)",
    "Arsen (As) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    12420,
    "Squash Berperisa (Steril) (1401040315)",
    "Kadmium (Cd) (ppm atau mg/kg)- Siap konsumsi",
    "=0.01",
  ],
  [
    12421,
    "Squash Berperisa (Steril) (1401040315)",
    "Merkuri (Hg) (ppm atau mg/kg)- Siap konsumsi",
    "=0.01",
  ],
  [
    12422,
    "Squash Berperisa (Steril) (1401040315)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)- Siap konsumsi",
    "=100",
  ],
  [
    12423,
    "Squash Berperisa (Steril) (1401040315)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12424,
    "Squash Berperisa (Steril) (1401040315)",
    "Timbal (Pb) (ppm atau mg/kg)- Siap konsumsi",
    "=0.05",
  ],
  [
    12425,
    "Squash Berperisa/Rasa (1401040308)",
    "Kadar gula sebagai sakarosa",
    "=55",
    "=25",
  ],
  [
    12426,
    "Squash Berperisa/Rasa (1401040308)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12427,
    "Squash Berperisa/Rasa (1401040308)",
    "Kadmium (Cd) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12428,
    "Squash Berperisa/Rasa (1401040308)",
    "Merkuri (Hg) (ppm atau mg/kg) - Siap konsumsi",
    "=0.01",
  ],
  [
    12429,
    "Squash Berperisa/Rasa (1401040308)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    12430,
    "Squash Berperisa/Rasa (1401040308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12431,
    "Squash Berperisa/Rasa (1401040308)",
    "Timbal (Pb) (ppm atau mg/kg) - Siap konsumsi",
    "=0.05",
  ],
  [
    12432,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12433,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Cd (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    12434,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Hg (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12435,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12436,
    "Stik Ikan (Fish Finger) Berlapis Tepung (09020202)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    12437,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    12438,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Cd (ppm atau mg/kg) ",
    "<0.1",
  ],
  [
    12439,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Hg (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12440,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12441,
    "Stik Ikan, Bagian Ikan dan Filet Ikan Berlapis Tepung (Breaded atau in Batter) yang Dibekukan (09020201)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    12442,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Kandungan Surimi (%)",
    "",
    "=30",
  ],
  [
    12443,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    12444,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    12445,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    12446,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    12447,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    12448,
    "Stik Kepiting Analog atau Imitation Crab Stick (0902040123)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    12449,
    "Still Grape Wine (14020301)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    12450,
    "Still Grape Wine (14020301)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [12451, "Still Grape Wine (14020301)", "Arsen (mg/kg)", "=0.1"],
  [12452, "Still Grape Wine (14020301)", "Kadmium (mg/kg)", "=0.2"],
  [
    12453,
    "Still Grape Wine (14020301)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    12454,
    "Still Grape Wine (14020301)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    12455,
    "Still Grape Wine (14020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12456, "Still Grape Wine (14020301)", "Timbal (mg/kg)", "=0.2"],
  [
    12457,
    "Still Grape Wine (14020301)",
    "Kadar karbondioksida (g/100 ml) pada suhu 20\xB0C",
    "=0.4",
  ],
  [
    12458,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    12459,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    12460,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Arsen (mg/L)",
    "=0.1",
  ],
  [
    12461,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Kadmium (mg/L)",
    "=0.2",
  ],
  [
    12462,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Merkuri (mg/L)",
    "=0.03",
  ],
  [
    12463,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Timah, minuman dalam kemasan kaleng (mg/L)",
    "=100",
  ],
  [
    12464,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    12465,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Timbal (mg/L)",
    "=0.2",
  ],
  [
    12466,
    "Still Grape Wine Merah / Anggur Merah (Red Wine) (1402030101)",
    "Kadar karbondioksida pada suhu 20\xB0C (g/100ml)",
    "=0.4",
  ],
  [
    12467,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Kadar etanol (%)",
    "=24",
    "=7",
  ],
  [
    12468,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Kadar metanol dihitung terhadap volume produk (% v/v) ",
    "=0.01",
  ],
  [
    12469,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Arsen (mg/L)",
    "=0.1",
  ],
  [
    12470,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Kadmium (mg/L)",
    "=0.2",
  ],
  [
    12471,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Merkuri (mg/L)",
    "=0.03",
  ],
  [
    12472,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Timah, minuman dalam kemasan kaleng (mg/L)",
    "=100",
  ],
  [
    12473,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    12474,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Timbal (mg/L)",
    "=0.2",
  ],
  [
    12475,
    "Still Grape Wine Putih / Anggur Putih (White Wine) (1402030102)",
    "Kadar karbondioksida pada suhu 20\xB0C (g/100ml)",
    "=0.4",
  ],
  [
    12476,
    "Stillwine (1402030103)",
    "Kadar metanol dihitung terhadap etanol (%)",
    "=0.1",
  ],
  [
    12477,
    "Stillwine (1402030103)",
    "Kadar karbondioksida pada suhu 20\xB0C (g/ml)",
    "=0.4",
  ],
  [
    12478,
    "Stillwine (1402030103)",
    "Arsen (ppm atau mg/L)",
    "=0.1",
  ],
  [
    12479,
    "Stillwine (1402030103)",
    "Kadmium (ppm atau mg/L)",
    "=0.2",
  ],
  [
    12480,
    "Stillwine (1402030103)",
    "Merkuri (ppm atau mg/L)",
    "=0.03",
  ],
  [
    12481,
    "Stillwine (1402030103)",
    "Timah, minuman dalam kemasan kaleng (ppm atau mg/L)",
    "=100",
  ],
  [
    12482,
    "Stillwine (1402030103)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/L)",
    "=40",
  ],
  [
    12483,
    "Stillwine (1402030103)",
    "Timbal (ppm atau mg/L)",
    "=0.2",
  ],
  [12484, "Stillwine (1402030103)", "Kadar etanol (%)"],
  [12485, "Stroopwafel (07020212)", "Arsen (As) (mg/kg) ", "=0.5"],
  [
    12486,
    "Stroopwafel (07020212)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.2",
  ],
  [
    12487,
    "Stroopwafel (07020212)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.05",
  ],
  [
    12488,
    "Stroopwafel (07020212)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12489,
    "Stroopwafel (07020212)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [12490, "Stroopwafel (07020212)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [
    12491,
    "Suet (02010308)",
    "Berat jenis (40\xB0C/air pada 20\xB0C)",
    "=0.904",
    "=0.893",
  ],
  [
    12492,
    "Suet (02010308)",
    "Indeks bias (pada suhu 40\xB0C)",
    "=1.46",
    "=1.448",
  ],
  [
    12493,
    "Suet (02010308)",
    "Bilangan penyabunan (mg KOH/g)",
    "=200",
    "=190",
  ],
  [12494, "Suet (02010308)", "Bilangan iod (Wijs)", "=47", ">32"],
  [12495, "Suet (02010308)", "Bilangan asam (mg KOH/g)", "=2"],
  [
    12496,
    "Suet (02010308)",
    "Bilangan peroksida (mek O2/kg)",
    "=20",
  ],
  [
    12497,
    "Suet (02010308)",
    "Kadar bahan tak tersabunkan (g/kg)",
    "=10",
  ],
  [12498, "Suet (02010308)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    12499,
    "Suet (02010308)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12500,
    "Suet (02010308)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12501,
    "Suet (02010308)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12502,
    "Suet (02010308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12503,
    "Suet (02010308)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12504,
    "Sumpia Udang (150306)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    12505,
    "Sumpia Udang (150306)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12506,
    "Sumpia Udang (150306)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    12507,
    "Sumpia Udang (150306)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    12508,
    "Sumpia Udang (150306)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [12509, "Sup Instan (12050201)", "Kadar air (%)", "=7"],
  [
    12510,
    "Sup Instan (12050201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    12511,
    "Sup Instan (12050201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12512,
    "Sup Instan (12050201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12513,
    "Sup Instan (12050201)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12514,
    "Sup Instan (12050201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12515,
    "Sup Instan (12050201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12516,
    "Sup Instan (Steril) (12050213)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    12517,
    "Sup Instan (Steril) (12050213)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    12518,
    "Sup Instan (Steril) (12050213)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    12519,
    "Sup Instan (Steril) (12050213)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    12520,
    "Sup Instan (Steril) (12050213)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    12521,
    "Sup Instan (Steril) (12050213)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    12522,
    "Sup Instan Dalam Kaleng (12050214)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    12523,
    "Sup Instan Dalam Kaleng (12050214)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12524,
    "Sup Instan Dalam Kaleng (12050214)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12525,
    "Sup Instan Dalam Kaleng (12050214)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12526,
    "Sup Instan Dalam Kaleng (12050214)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [12527, "Sup Jamur (1659)", "Arsen (As) (mg/kg)", "=0.25"],
  [12528, "Sup Jamur (1659)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [12529, "Sup Jamur (1659)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    12530,
    "Sup Jamur (1659)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12531,
    "Sup Jamur (1659)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12532, "Sup Jamur (1659)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [12533, "Sup Krim Instan (12050203)", "Kadar air (%)", "=8"],
  [
    12534,
    "Sup Krim Instan (12050203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    12535,
    "Sup Krim Instan (12050203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12536,
    "Sup Krim Instan (12050203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12537,
    "Sup Krim Instan (12050203)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12538,
    "Sup Krim Instan (12050203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12539,
    "Sup Krim Instan (12050203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12540,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Kadar air (%)",
    "=12.5",
  ],
  [
    12541,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    12542,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12543,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12544,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12545,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12546,
    "Sup Krim Pasta Instan (Misalnya Sup Krim Makaroni Instan) (12050204)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    12547,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Kadar air (%)",
    "=12.5",
  ],
  [
    12548,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    12549,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    12550,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12551,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12552,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    12553,
    "Sup Pasta Instan (Misalnya Sup Makaroni Instan) (12050202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [12554, "Sup Sayuran (1660)", "Arsen (As) (mg/kg)", "=0.25"],
  [12555, "Sup Sayuran (1660)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [12556, "Sup Sayuran (1660)", "Raksa (Hg) (mg/kg)", "=0.03"],
  [
    12557,
    "Sup Sayuran (1660)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12558,
    "Sup Sayuran (1660)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12559, "Sup Sayuran (1660)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [
    12560,
    "Sup Siap Saji (12050105)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    12561,
    "Sup Siap Saji (12050105)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    12562,
    "Sup Siap Saji (12050105)",
    "Merkuri (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    12563,
    "Sup Siap Saji (12050105)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    12564,
    "Sup Siap Saji (12050105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [12565, "Sup Siap Saji (12050105)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    12566,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12567,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12568,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12569,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    12570,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    12571,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12572,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Kadar lemak susu (%)",
  ],
  [12573, "", "", "=2"],
  [
    12574,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Total padatan susu bukan-lemak (%)",
  ],
  [12575, "", "", "=5.2"],
  [
    12576,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Kadar protein (%)",
  ],
  [12577, "", "", "=2"],
  [
    12578,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Kadar bahan/ekstrak alami (%)",
    "",
    "=0.5",
  ],
  [
    12579,
    "Susu (Rasa) Lemak Penuh (Full Cream Milk) (01010401)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    12580,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Kadar lemak susu (%)",
    "",
    "=2",
  ],
  [
    12581,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=8",
  ],
  [
    12582,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Kadar protein (%) ",
    "",
    "=2",
  ],
  [
    12583,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Kadar bahan/ekstrak alami (%) ",
    "",
    "=0.5",
  ],
  [
    12584,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12585,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12586,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12587,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12588,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12589,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12590,
    "Susu (Rasa) Pasteurisasi (01010212)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12591,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Kadar lemak susu (%) ",
    "",
    "=2",
  ],
  [
    12592,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Total padatan susu bukan lemak (%) ",
    "",
    "=8",
  ],
  [
    12593,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Kadar protein (%) ",
    "",
    "=2",
  ],
  [
    12594,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Kadar bahan/ekstrak alami (%) ",
    "",
    "=0.5",
  ],
  [
    12595,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12596,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12597,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12598,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12599,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12600,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12601,
    "Susu (Rasa) Steril / UHT (01010211)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12602,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12603,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    12604,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12605,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12606,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    12607,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12608,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12609,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12610,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010204)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    12611,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12612,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12613,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12614,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12615,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12616,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12617,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12618,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12619,
    "Susu Asidofilus (Acidophilus Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010104)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12620,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Kadar lemak susu (%)",
    "",
    "=2",
  ],
  [
    12621,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=8",
  ],
  [
    12622,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Kadar protein (%)",
    "",
    "=2",
  ],
  [
    12623,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12624,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12625,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12626,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12627,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12628,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12629,
    "Susu Berperisa / Susu Rasa Pasteurisasi (01010214)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12630,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Kadar lemak susu (%)",
    "",
    "=2",
  ],
  [
    12631,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=8",
  ],
  [
    12632,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Kadar protein (%)",
    "",
    "=2",
  ],
  [
    12633,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12634,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12635,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12636,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12637,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12638,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12639,
    "Susu Berperisa / Susu Rasa Steril atau UHT (01010213)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12640,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12641,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12642,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12643,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    12644,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    12645,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12646,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Kadar lemak susu tidak kurang (%)",
  ],
  [12647, "", "", "=2"],
  [
    12648,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Total padatan susu bukan-lemak (%)",
  ],
  [12649, "", "", "=5.2"],
  [
    12650,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Kadar protein (%)",
  ],
  [12651, "", "", "=2"],
  [
    12652,
    "Susu Berperisa/Susu Rasa (01010402)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    12653,
    "Susu Bubuk (01050106)",
    "Kadar lemak susu (%) ",
    "<26",
    ">1.5",
  ],
  [12654, "Susu Bubuk (01050106)", "Kadar air (%) ", "=5"],
  [
    12655,
    "Susu Bubuk (01050106)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12656,
    "Susu Bubuk (01050106)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12657,
    "Susu Bubuk (01050106)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12658,
    "Susu Bubuk (01050106)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12659,
    "Susu Bubuk (01050106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12660,
    "Susu Bubuk (01050106)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12661,
    "Susu Bubuk (01050106)",
    "Aflatoksin M1 (mcg/kg) ",
    "=0.5",
  ],
  [
    12662,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12663,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12664,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Merkuri (Hg) (mg/Kg)",
    "=0.02",
  ],
  [
    12665,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12666,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/Kg)",
    "=40",
  ],
  [
    12667,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12668,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Kadar Air (%)",
    "=5",
  ],
  [
    12669,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Kadar lemak susu (%)",
    "",
    "= 26",
  ],
  [
    12670,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Kadar protein (%)",
    "",
    "= 11.00",
  ],
  [
    12671,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55.0",
  ],
  [
    12672,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01010408)",
    "Aflatoksin M1 (mcg/Kg)",
    "=0.50",
  ],
  [
    12673,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Kadar bahan/ekstrak alami (%)",
  ],
  [
    12674,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Kadar air (%) ",
    "=5",
  ],
  [
    12675,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Kadar protein (%) ",
    "",
    "=11",
  ],
  [
    12676,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Kadar gula dihitung sebagai sakarosa (%) ",
    "=55",
  ],
  [
    12677,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12678,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12679,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12680,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12681,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12682,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12683,
    "Susu Bubuk (Rasa) (Susu Bubuk Cokelat, Susu Bubuk Stroberi, Susu Bubuk Vanila, Susu Bubuk Madu, dll) (01050205)",
    "Aflatoksin M1 (ppb atau mcg/kg) ",
    "=5",
  ],
  [
    12684,
    "Susu Bubuk Berperisa (01050108)",
    "Kadar lemak susu (%)",
    "=26",
    "=1.5",
  ],
  [12685, "Susu Bubuk Berperisa (01050108)", "Kadar air (%)", "=5"],
  [
    12686,
    "Susu Bubuk Berperisa (01050108)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12687,
    "Susu Bubuk Berperisa (01050108)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12688,
    "Susu Bubuk Berperisa (01050108)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12689,
    "Susu Bubuk Berperisa (01050108)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12690,
    "Susu Bubuk Berperisa (01050108)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12691,
    "Susu Bubuk Berperisa (01050108)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12692,
    "Susu Bubuk Berperisa (01050108)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12693,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12694,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12695,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12696,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12697,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12698,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12699,
    "Susu Bubuk Lemak Nabati/Susu Bubuk Minyak Nabati (01050203)",
    "aflatoksin M1 (mcg/kg)/ ppb",
    "=5",
  ],
  [
    12700,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Kadar lemak susu (%)",
    "",
    "=26",
  ],
  [
    12701,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12702,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12703,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12704,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12705,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12706,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12707,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12708,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12709,
    "Susu Bubuk Lemak Penuh (Full Cream) (Plain) (01050101)",
    "Kadar protein dari padatan susu bukan lemak (%)",
    "",
    "=32",
  ],
  [
    12710,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Kadar lemak susu (%)",
    "",
    "=26",
  ],
  [
    12711,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12712,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Kadar protein dari padatan susu bukan lemak (%)",
    "",
    "=32",
  ],
  [
    12713,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12714,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12715,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12716,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12717,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12718,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Timbal (Pb) (mg/kg) - siap konsumsi ",
    "=0.02",
  ],
  [
    12719,
    "Susu Bubuk Lemak Penuh (Full Cream) Instan (Plain) (01050102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12720,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Kadar air (%) ",
    "=5",
  ],
  [
    12721,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Kadar protein (%) ",
    "",
    "=11",
  ],
  [
    12722,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Kadar gula dihitung sebagai sakarosa (%) ",
    "=55",
  ],
  [
    12723,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12724,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12725,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12726,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12727,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12728,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12729,
    "Susu Bubuk Rasa atau Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01050206)",
    "Aflatoksin M1 (ppb atau mcg/kg) ",
    "=5",
  ],
  [
    12730,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12731,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12732,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12733,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12734,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12735,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12736,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Kadar air (%)",
    "=5.00",
  ],
  [
    12737,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Kadar protein (%)",
  ],
  [12738, "", "", "=11"],
  [
    12739,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55",
  ],
  [
    12740,
    "Susu Bubuk Rasa/Berperisa (Susu Bubuk Rasa Cokelat, Susu Bubuk Rasa Stroberi, Susu Bubuk Rasa Vanila, Susu Bubuk Rasa Madu, dll) (01010411)",
    "Aflatoksin M1 (ppb atau mcg/Kg)",
    "=0.5",
  ],
  [
    12741,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12742,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12743,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12744,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12745,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12746,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12747,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12748,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12749,
    "Susu Bubuk Rendah Lemak dan Susu Bubuk Kurang Lemak (01050103)",
    "Kadar lemak susu (%)",
    "=1.5",
  ],
  [
    12750,
    "Susu Bubuk Skim (01050104)",
    "Kadar lemak susu (%) ",
    "=1.5",
  ],
  [12751, "Susu Bubuk Skim (01050104)", "Kadar air (%) ", "=5"],
  [
    12752,
    "Susu Bubuk Skim (01050104)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12753,
    "Susu Bubuk Skim (01050104)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12754,
    "Susu Bubuk Skim (01050104)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12755,
    "Susu Bubuk Skim (01050104)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12756,
    "Susu Bubuk Skim (01050104)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12757,
    "Susu Bubuk Skim (01050104)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12758,
    "Susu Bubuk Skim (01050104)",
    "Aflatoksin M1 (mcg/kg) ",
    "=0.5",
  ],
  [
    12759,
    "Susu Bubuk Skim (01050104)",
    "Kadar protein dari padatan susu bukan lemak minimal 32 (%)",
  ],
  [
    12760,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Arsen (As) (mg/Kg)",
    "=0.10",
  ],
  [
    12761,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Kadmium (Cd) (mg/Kg)",
    "=0.05",
  ],
  [
    12762,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Merkuri (Hg) (mg/Kg)",
    "=0.02",
  ],
  [
    12763,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/Kg)",
    "=250",
  ],
  [
    12764,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/Kg) ",
    "=40",
  ],
  [
    12765,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Timbal (Pb) (mg/Kg)",
    "=0.02",
  ],
  [
    12766,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Kadar Air (%)",
    "=5.00",
  ],
  [
    12767,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Kadar Lemak Susu (%)",
    "=1.5",
  ],
  [
    12768,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Kadar Protein (%)",
    "",
    "= 11.00",
  ],
  [
    12769,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55.00",
  ],
  [
    12770,
    "Susu Bubuk Skim (Rasa) (Susu Bubuk Skim Cokelat, Susu Skim Bubuk Stroberi, Susu Bubuk Skim Vanila, Susu Bubuk Skim Madu, dll) (01010409)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.50",
  ],
  [
    12771,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12772,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12773,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12774,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12775,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12776,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12777,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Kadar air (%)",
    "=5.0",
  ],
  [
    12778,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Kadar protein (%)",
    "",
    "=11.00",
  ],
  [
    12779,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55.00",
  ],
  [
    12780,
    "Susu Bubuk Skim Rasa/Berperisa (Susu Bubuk Skim Rasa Cokelat, Susu Bubuk Skim Rasa Stroberi, Susu Bubuk Skim Rasa Vanila, Susu Bubuk Skim Rasa Madu, dll) (01010412)",
    "Aflatoksin M1 (ppb atau mcg/Kg)",
    "=0.50",
  ],
  [
    12781,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12782,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12783,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12784,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12785,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12786,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12787,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12788,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Kadar lemak susu (%)",
    "<26",
    ">1.5",
  ],
  [
    12789,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Kadar protein (%) dari padatan susu bukan lemak",
    "",
    "=32",
  ],
  [
    12790,
    "Susu Bubuk Skim Sebagian (01050109)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12791,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12792,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12793,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12794,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Timah (Sn) Pangan Olahan Lain yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12795,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Timah (Sn) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12796,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12797,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12798,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Kadar lemak susu (%)",
    "=26.00",
    "=1.5",
  ],
  [
    12799,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Kadar protein (%)",
    "",
    "=11.0",
  ],
  [
    12800,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55",
  ],
  [
    12801,
    "Susu Bubuk Skim Sebagian (Rasa) (Susu Bubuk Skim Sebagian Cokelat, Susu Skim Sebagian Bubuk Stroberi, Susu Bubuk Skim Sebagian Vanila, Susu Bubuk Skim Sebagian Madu, dll) (01010410)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12802,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12803,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Kadmium (Cd)(mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12804,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12805,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng - siap konsumsi",
    "=250",
  ],
  [
    12806,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng - siap konsumsi",
    "=40",
  ],
  [
    12807,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12808,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Kadar air (%)",
    "=5",
  ],
  [
    12809,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Kadar Protein (%)",
    "",
    "=11",
  ],
  [
    12810,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Kadar gula dihitung sebagai sakarosa (%)",
    "=55",
  ],
  [
    12811,
    "Susu Bubuk Skim Sebagian Rasa/Berperisa (Susu Bubuk Skim Sebagian Rasa Cokelat, Susu Bubuk Skim Sebagian Rasa Stroberi, Susu Bubuk Skim Sebagian Rasa Vanila, Susu Bubuk Skim Sebagian Rasa Madu, dll) (01010413)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12812,
    "Susu Bubuk untuk Kue (01050107)",
    "Kadar lemak susu (%)",
  ],
  [12813, "Susu Bubuk untuk Kue (01050107)", "Kadar air (%)", "=5"],
  [
    12814,
    "Susu Bubuk untuk Kue (01050107)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    12815,
    "Susu Bubuk untuk Kue (01050107)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    12816,
    "Susu Bubuk untuk Kue (01050107)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12817,
    "Susu Bubuk untuk Kue (01050107)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=250",
  ],
  [
    12818,
    "Susu Bubuk untuk Kue (01050107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) - siap konsumsi",
    "=40",
  ],
  [
    12819,
    "Susu Bubuk untuk Kue (01050107)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    12820,
    "Susu Bubuk untuk Kue (01050107)",
    "Aflatoksin M1 (mcg/kg) ",
    "=0.5",
  ],
  [
    12821,
    "Susu Diasamkan (010201A0)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12822,
    "Susu Diasamkan (010201A0)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12823,
    "Susu Diasamkan (010201A0)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12824,
    "Susu Diasamkan (010201A0)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12825,
    "Susu Diasamkan (010201A0)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12826,
    "Susu Diasamkan (010201A0)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12827,
    "Susu Diasamkan (010201A0)",
    "Total padatan susu bukan lemak (%) ",
    "",
    "=7.8",
  ],
  [
    12828,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12829,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    12830,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12831,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12832,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12833,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12834,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12835,
    "Susu Diasamkan (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010203)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12836,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12837,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12838,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12839,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12840,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12841,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12842,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12843,
    "Susu Diasamkan (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010103)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12844,
    "Susu Evaporasi (01030101)",
    "Kadar lemak susu (%)",
    "",
    "=7.5",
  ],
  [
    12845,
    "Susu Evaporasi (01030101)",
    "Total padatan (%)",
    "",
    "=25",
  ],
  [
    12846,
    "Susu Evaporasi (01030101)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12847,
    "Susu Evaporasi (01030101)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12848,
    "Susu Evaporasi (01030101)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12849,
    "Susu Evaporasi (01030101)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12850,
    "Susu Evaporasi (01030101)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12851,
    "Susu Evaporasi (01030101)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12852,
    "Susu Evaporasi (01030101)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12853,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    12854,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Total padatan susu bukan-lemak (%) ",
    "",
    "=7.8",
  ],
  [
    12855,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12856,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12857,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12858,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12859,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12860,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12861,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (010201A3)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12862,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12863,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    12864,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12865,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12866,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    12867,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12868,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12869,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    12870,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12871,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010209)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    12872,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12873,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12874,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12875,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12876,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12877,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12878,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    12879,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    12880,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12881,
    "Susu Fermentasi atau Susu Berkultur (Cultured Milk) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010109)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12882,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12883,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    12884,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12885,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12886,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12887,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12888,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=4.6",
  ],
  [
    12889,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Kadar protein susu (%)",
    "",
    "=1.6",
  ],
  [
    12890,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    12891,
    "Susu Fermentasi atau Susu Berkultur Berperisa/Rasa (010724)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12892,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Kadar lemak susu (%)",
  ],
  [
    12893,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12894,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12895,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12896,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12897,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12898,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12899,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12900,
    "Susu Fermentasi Rendah Lemak atau Susu Berkultur (Cultured Milk) Rendah Lemak (010201A4)",
    "Lemak susu (%)",
    "<3",
    ">1.25",
  ],
  [
    12901,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Kadar lemak susu (%)",
  ],
  [
    12902,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12903,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12904,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12905,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12906,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12907,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12908,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12909,
    "Susu Fermentasi Tanpa Lemak atau Susu Berkultur (Cultured Milk) Tanpa Lemak (010201A5)",
    "kadar lemak susu (%)",
    "<1.25",
  ],
  [
    12910,
    "Susu Kental Manis (01030104)",
    "Kadar lemak susu (%)",
    "",
    "=8",
  ],
  [
    12911,
    "Susu Kental Manis (01030104)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12912,
    "Susu Kental Manis (01030104)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12913,
    "Susu Kental Manis (01030104)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12914,
    "Susu Kental Manis (01030104)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12915,
    "Susu Kental Manis (01030104)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12916,
    "Susu Kental Manis (01030104)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12917,
    "Susu Kental Manis (01030104)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12918,
    "Susu Kental Manis (01030104)",
    "Kadar protein (untuk plain) (%)",
    "",
    "=6.5",
  ],
  [
    12919,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Kadar lemak susu (%)",
    "",
    "=8.8",
  ],
  [
    12920,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12921,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12922,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12923,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12924,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12925,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12926,
    "Susu Kental Manis Diperkaya Lemak Nabati/Susu Kental Manis Diperkaya Minyak Nabati (01030107)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12927,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    12928,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    12929,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12930,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    12931,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    12932,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12933,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Kadar Lemak Total (%)",
    "",
    "=8",
  ],
  [
    12934,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Kadar Protein Total (%)",
    "",
    "=2",
  ],
  [
    12935,
    "Susu Kental Manis Lemak Nabati/ Susu Kental Manis Minyak Nabati (01030203)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [
    12936,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Kadar lemak (%)",
    "",
    "=8",
  ],
  [
    12937,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12938,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12939,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12940,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12941,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12942,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12943,
    "Susu Kental Manis Lemak Nabati/Susu Kental Manis Minyak Nabati (01030105)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12944,
    "Susu Kuda (0101010114)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12945,
    "Susu Kuda (0101010114)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12946,
    "Susu Kuda (0101010114)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12947,
    "Susu Kuda (0101010114)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12948,
    "Susu Kuda (0101010114)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12949,
    "Susu Kuda (0101010114)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12950,
    "Susu Kuda (0101010114)",
    "Aflaktosin M1 (ppb)(mcg/kg)",
    "=0.5",
  ],
  [
    12951,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Kadar lemak (%)",
    "",
    "=6",
  ],
  [
    12952,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Total padatan (%)",
    "",
    "=23.5",
  ],
  [
    12953,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12954,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12955,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12956,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12957,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12958,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12959,
    "Susu Lemak Nabati Evaporasi / Susu Minyak Nabati Evaporasi (Steril) (01030111)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12960,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Arsen (As) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12961,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Kadmium (Cd)(mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12962,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Merkuri (Hg) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12963,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=250",
  ],
  [
    12964,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=40",
  ],
  [
    12965,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Timbal (Pb) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12966,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Total padatan (%)",
    "",
    "=23.5",
  ],
  [
    12967,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Kadar lemak (%)",
    "",
    "=6",
  ],
  [
    12968,
    "Susu Lemak Nabati Evaporasi/ Susu Minyak Nabati Evaporasi (01030202)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    12969,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Kadar lemak (%)",
    "",
    "=6",
  ],
  [
    12970,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Total padatan (%)",
    "",
    "=23.5",
  ],
  [
    12971,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    12972,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12973,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    12974,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    12975,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    12976,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12977,
    "Susu Lemak Nabati Evaporasi/Susu Minyak Nabati Evaporasi (01030103)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    12978,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    12979,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    12980,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    12981,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    12982,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    12983,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    12984,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Kadar lemak total (%)",
    "",
    "=3",
  ],
  [
    12985,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    12986,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    12987,
    "Susu Lemak Nabati Plain (Cair) / Susu Minyak Nabati (Filled Milk) (01010220)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    12988,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    12989,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [
    12990,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    12991,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12992,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    12993,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    12994,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    12995,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    12996,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Kadar Protein (%)",
    "",
    "=2.8",
  ],
  [
    12997,
    "Susu Lemak Nabati/Susu Minyak Nabati (Filled Milk) (0101010110)",
    "Aflaktoksin (ppb)",
    "=0.5",
  ],
  [
    12998,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    12999,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13000,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13001,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13002,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13003,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13004,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13005,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    13006,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13007,
    "Susu Lemak Penuh (Full Cream) Plain (Cair) (010101A0)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13008,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13009,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13010,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13011,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13012,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13013,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13014,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Kadar lemak total (%)",
    "",
    "=3",
  ],
  [
    13015,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    13016,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13017,
    "Susu Lemak Penuh Rekombinasi Plain (Cair) / Recombined Full Cream Milk (01010215)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13018,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13019,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13020,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13021,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13022,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13023,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13024,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13025,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    13026,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13027,
    "Susu Lemak Penuh Rekonstitusi Plain (Cair) / Reconstituted Full Cream Milk (01010216)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13028,
    "Susu Pasteurisasi (0101010103)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13029,
    "Susu Pasteurisasi (0101010103)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [
    13030,
    "Susu Pasteurisasi (0101010103)",
    "Kadar Protein (%)",
    "",
    "=2.8",
  ],
  [
    13031,
    "Susu Pasteurisasi (0101010103)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13032,
    "Susu Pasteurisasi (0101010103)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13033,
    "Susu Pasteurisasi (0101010103)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13034,
    "Susu Pasteurisasi (0101010103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13035,
    "Susu Pasteurisasi (0101010103)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13036,
    "Susu Pasteurisasi (0101010103)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13037,
    "Susu Pasteurisasi (0101010103)",
    "Aflaktosin M1 (ppb)",
    "=0.5",
  ],
  [
    13038,
    "Susu Segar (0101010102)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13039,
    "Susu Segar (0101010102)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13040,
    "Susu Segar (0101010102)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13041,
    "Susu Segar (0101010102)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13042,
    "Susu Segar (0101010102)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13043,
    "Susu Segar (0101010102)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13044,
    "Susu Segar (0101010102)",
    "Aflaktoksin M1 (ppb)",
    "=0.5",
  ],
  [
    13045,
    "Susu Segar (0101010102)",
    "Jika susu sapi segar, kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13046,
    "Susu Segar (0101010102)",
    "Jika susu sapi segar, total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [
    13047,
    "Susu Segar (0101010102)",
    "Jika susu sapi segar, kadar protein (%)",
    "",
    "=2.8",
  ],
  [
    13048,
    "Susu Segar (0101010102)",
    "Jika susu kuda segar, kadar lemak susu (%)",
    "",
    "=1.3",
  ],
  [
    13049,
    "Susu Segar (0101010102)",
    "Jika susu kuda segar, kadar protein (%)",
    "",
    "=2",
  ],
  [
    13050,
    "Susu Skim (0101010106)",
    "Kadar lemak susu (%) ",
    "=0.5",
  ],
  [
    13051,
    "Susu Skim (0101010106)",
    "Kadar protein (%) ",
    "",
    "=2.8",
  ],
  [
    13052,
    "Susu Skim (0101010106)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13053,
    "Susu Skim (0101010106)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13054,
    "Susu Skim (0101010106)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13055,
    "Susu Skim (0101010106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13056,
    "Susu Skim (0101010106)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13057,
    "Susu Skim (0101010106)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [13058, "Susu Skim (0101010106)", "Aflaktosin M1 (ppb)", "=0.5"],
  [
    13059,
    "Susu Skim Evaporasi (01030102)",
    "Kadar lemak susu (%)",
    "=1",
  ],
  [
    13060,
    "Susu Skim Evaporasi (01030102)",
    "Total padatan (%)",
    "",
    "=20",
  ],
  [
    13061,
    "Susu Skim Evaporasi (01030102)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    13062,
    "Susu Skim Evaporasi (01030102)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13063,
    "Susu Skim Evaporasi (01030102)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    13064,
    "Susu Skim Evaporasi (01030102)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13065,
    "Susu Skim Evaporasi (01030102)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    13066,
    "Susu Skim Evaporasi (01030102)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13067,
    "Susu Skim Evaporasi (01030102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13068,
    "Susu Skim Kental Manis (01030106)",
    "Kadar lemak susu (%)",
    "=1",
  ],
  [
    13069,
    "Susu Skim Kental Manis (01030106)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    13070,
    "Susu Skim Kental Manis (01030106)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13071,
    "Susu Skim Kental Manis (01030106)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    13072,
    "Susu Skim Kental Manis (01030106)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13073,
    "Susu Skim Kental Manis (01030106)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=100",
  ],
  [
    13074,
    "Susu Skim Kental Manis (01030106)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13075,
    "Susu Skim Kental Manis (01030106)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    13076,
    "Susu Skim Plain (Cair) (010101A1)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13077,
    "Susu Skim Plain (Cair) (010101A1)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13078,
    "Susu Skim Plain (Cair) (010101A1)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13079,
    "Susu Skim Plain (Cair) (010101A1)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13080,
    "Susu Skim Plain (Cair) (010101A1)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13081,
    "Susu Skim Plain (Cair) (010101A1)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13082,
    "Susu Skim Plain (Cair) (010101A1)",
    "Kadar lemak susu (%)",
    "=0.5",
  ],
  [
    13083,
    "Susu Skim Plain (Cair) (010101A1)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13084,
    "Susu Skim Plain (Cair) (010101A1)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13085,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13086,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13087,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13088,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    13089,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    13090,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13091,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Kadar lemak susu (%)",
    "=0.5",
  ],
  [
    13092,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13093,
    "Susu Skim Rekonstitusi Plain (Cair) (01010217)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13094,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Kadar lemak susu (%) ",
    "<3",
    "=0.5",
  ],
  [
    13095,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Kadar protein (%) ",
    "",
    "=2.8",
  ],
  [
    13096,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13097,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13098,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13099,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13100,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13101,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13102,
    "Susu Skim Sebagian (Pasteurisasi) (0101010107)",
    "Aflatoksin M1 (ppb atau mcg/kg) ",
    "=0.5",
  ],
  [
    13103,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Kadar lemak susu (%) ",
    "<3",
    "=0.5",
  ],
  [
    13104,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Kadar protein (%) ",
    "",
    "=2.8",
  ],
  [
    13105,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13106,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13107,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13108,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13109,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13110,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13111,
    "Susu Skim Sebagian (Steril atau UHT) (0101010115)",
    "Aflatoksin M1 (ppb atau mcg/kg) ",
    "=0.5",
  ],
  [
    13112,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Arsen (As) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    13113,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Kadmium (Cd)(mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    13114,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Merkuri (Hg) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13115,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=250",
  ],
  [
    13116,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    13117,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Timbal (Pb) (mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    13118,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Total padatan susu (%)",
    "",
    "=20",
  ],
  [
    13119,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Kadar protein (%)",
    "=6",
    "=4",
  ],
  [
    13120,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Kadar lemak susu (%)",
    "=7.5",
    "=1",
  ],
  [
    13121,
    "Susu Skim Sebagian Evaporasi (01030112)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    13122,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13123,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13124,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13125,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13126,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13127,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13128,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Kadar lemak susu (%)",
    "<2.9",
    "=0.6",
  ],
  [
    13129,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13130,
    "Susu Skim Sebagian Plain (Cair) (010101A2)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13131,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13132,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13133,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13134,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13135,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13136,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13137,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Kadar lemak susu (%)",
    "<2.9",
    "=0.6",
  ],
  [
    13138,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13139,
    "Susu Skim Sebagian Rekombinasi Plain (Cair) (01010219)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13140,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13141,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13142,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    13143,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13144,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13145,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    13146,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Kadar lemak susu (%)",
    "<2.9",
    "=0.6",
  ],
  [
    13147,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Kadar protein (%)",
    "",
    "=2.7",
  ],
  [
    13148,
    "Susu Skim Sebagian Rekonstitusi Plain (Cair) (01010218)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    13149,
    "Susu Steril (0101010105)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13150,
    "Susu Steril (0101010105)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [
    13151,
    "Susu Steril (0101010105)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13152,
    "Susu Steril (0101010105)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13153,
    "Susu Steril (0101010105)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13154,
    "Susu Steril (0101010105)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13155,
    "Susu Steril (0101010105)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13156,
    "Susu Steril (0101010105)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13157,
    "Susu Steril (0101010105)",
    "Kadar Protein (%)",
    "",
    "=2.8",
  ],
  [
    13158,
    "Susu Steril (0101010105)",
    "Aflaktosin M1 (ppb)",
    "=0.5",
  ],
  [
    13159,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Kadar lemak susu (%)",
    "",
    "=3",
  ],
  [
    13160,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [
    13161,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Kadar protein (%)",
    "",
    "=2.8",
  ],
  [
    13162,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13163,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13164,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13165,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13166,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13167,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13168,
    "Susu UHT (Ultra High Temperature) (0101010104)",
    "Aflaktosin M1 (ppb)",
    "=0.5",
  ],
  [
    13169,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Protein (Nx 6,38)(%)",
    "",
    "=2",
  ],
  [
    13170,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Lemak (%)",
    "",
    "=2",
  ],
  [
    13171,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Total Padatan Tanpa Lemak (%)",
    "",
    "=8",
  ],
  [
    13172,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13173,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13174,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13175,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13176,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13177,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13178,
    "Susu UHT (Ultra High Temperature) Berperisa (0101010113)",
    "Aflaktosin M1 (ppb)",
    "=0.5",
  ],
  [
    13179,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Total padatan susu bukan lemak (%) ",
    "",
    "=7.8",
  ],
  [
    13180,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13181,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13182,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13183,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    13184,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    13185,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    13186,
    "Susu yang Digumpalkan dengan Enzim Renin (Plain) (010202)",
    "Aflatoksin M1 (mcg/kg) ",
    "=0.5",
  ],
  [13187, "Sweet Mayo (12060105)", "Arsen (As) (mg/kg)", "=0.15"],
  [13188, "Sweet Mayo (12060105)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [13189, "Sweet Mayo (12060105)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [13190, "Sweet Mayo (12060105)", "Timah (Sn) (mg/kg)", "=40"],
  [13191, "Sweet Mayo (12060105)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    13192,
    "Sweet Paprika Bubuk (12020187)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13193,
    "Sweet Paprika Bubuk (12020187)",
    "Kadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    13194,
    "Sweet Paprika Bubuk (12020187)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    13195,
    "Sweet Paprika Bubuk (12020187)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13196,
    "Sweet Paprika Bubuk (12020187)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    13197,
    "Sweet Paprika Bubuk (12020187)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    13198,
    "Sweet Paprika Bubuk (12020187)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    13199,
    "Swikiau/Kuotieh Daging (08030313)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13200,
    "Swikiau/Kuotieh Daging (08030313)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13201,
    "Swikiau/Kuotieh Daging (08030313)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13202,
    "Swikiau/Kuotieh Daging (08030313)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13203,
    "Swikiau/Kuotieh Daging (08030313)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13204,
    "Swikiau/Kuotieh Daging (08030313)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    13205,
    "Swikiau/Kuotieh Daging (08030313)",
    "Total Meat Content (%)",
    "",
    "=30",
  ],
  [
    13206,
    "Swikiau/Kuotieh Daging (08030313)",
    "Kadar Daging (%)",
    "",
    ">15",
  ],
  [
    13207,
    "Swikiau/Kuotieh Daging (08030313)",
    "Kadar Ikan (%)",
    "<15",
  ],
  [
    13208,
    "Taburan Berbasis Gula (050410)",
    "Arsen (As) (mg/kg)",
    "=1",
  ],
  [
    13209,
    "Taburan Berbasis Gula (050410)",
    "Cadmium (Cd) (mg/kg)",
    "=0.5",
  ],
  [
    13210,
    "Taburan Berbasis Gula (050410)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    13211,
    "Taburan Berbasis Gula (050410)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13212,
    "Taburan Berbasis Gula (050410)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13213,
    "Taburan Berbasis Gula (050410)",
    "Timbal (Pb) (mg/kg)",
    "=1",
  ],
  [13214, "Tahu (06080301)", "Arsen (As) (ppm atau mg/kg)", "=0.1"],
  [
    13215,
    "Tahu (06080301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13216,
    "Tahu (06080301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13217,
    "Tahu (06080301)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13218,
    "Tahu (06080301)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13219,
    "Tahu (06080301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13220, "Tahu (06080301)", "kadar protein (%)", "", "=9"],
  [
    13221,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13222,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13223,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13224,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13225,
    "Tahu Fermentasi (Contohnya Keju Kedelai) (060807)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13226, "Tahu Kering (060805)", "Kadar Protein ", "", "=9"],
  [
    13227,
    "Tahu Kering (060805)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13228,
    "Tahu Kering (060805)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13229,
    "Tahu Kering (060805)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13230,
    "Tahu Kering (060805)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13231,
    "Tahu Kering (060805)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13232,
    "Tahu Kering (060805)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13233,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Kadar Air (%)",
  ],
  [
    13234,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13235,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13236,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13237,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13238,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13239,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13240,
    "Tahu Semi-Kering Yang Digoreng Dengan Minyak Banyak (Deep Fried) (0608040203)",
    "kadar protein (%)",
    "",
    "=9",
  ],
  [
    13241,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13242,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13243,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13244,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13245,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13246,
    "Tahu Semi-Kering Yang Diolah Dengan Saus Kental (06080401)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13247,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.10",
  ],
  [
    13248,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13249,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13250,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13251,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Timah (Sn) yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13252,
    "Tahu semi-kering, selain dari kategori 06.8.4.1 dan 06.8.4.2 (06080403)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13253,
    "Talam Ebi (060711)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13254,
    "Talam Ebi (060711)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13255,
    "Talam Ebi (060711)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13256,
    "Talam Ebi (060711)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13257,
    "Talam Ebi (060711)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13258,
    "Talam Ebi (060711)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13259,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13260,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13261,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13262,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13263,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13264,
    "Tapioka/Pati Singkong/Pati Ubi Kayu (06020205)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13265,
    "Tauco (06080604)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13266,
    "Tauco (06080604)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13267,
    "Tauco (06080604)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13268,
    "Tauco (06080604)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13269,
    "Tauco (06080604)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13270,
    "Tauco (06080606)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13271,
    "Tauco (06080606)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13272,
    "Tauco (06080606)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13273,
    "Tauco (06080606)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13274,
    "Tauco (06080606)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13275,
    "Tauco (06080606)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13276, "Tauco (12090104)", "Arsen (As) (mg/kg)", "=0.15"],
  [13277, "Tauco (12090104)", "Kadmium (Cd) (mg/kg)", "=0.50"],
  [13278, "Tauco (12090104)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    13279,
    "Tauco (12090104)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13280,
    "Tauco (12090104)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [13281, "Tauco (12090104)", "Timbal (Pb) (mg/kg)", "=1.00"],
  [13282, "Tauco (1209020102)", "Arsen (As) (mg/kg)", "=0.15"],
  [13283, "Tauco (1209020102)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [13284, "Tauco (1209020102)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [13285, "Tauco (1209020102)", "Timah (Sn) (mg/kg)", "=40"],
  [13286, "Tauco (1209020102)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    13287,
    "Tauco Steril (06080605)",
    "Timah (Sn) dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    13288,
    "Tauco Steril (06080605)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13289,
    "Tauco Steril (06080605)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13290,
    "Tauco Steril (06080605)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13291,
    "Tauco Steril (06080605)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13292,
    "Tauco Steril (06080605)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13293,
    "Teh Hijau (14010502)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13294,
    "Teh Hijau (14010502)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13295,
    "Teh Hijau (14010502)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13296,
    "Teh Hijau (14010502)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13297,
    "Teh Hijau (14010502)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13298,
    "Teh Hijau (14010502)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [13299, "Teh Hijau Bubuk (14010507)", "Kadar air (%)", "=8"],
  [
    13300,
    "Teh Hijau Bubuk (14010507)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13301,
    "Teh Hijau Bubuk (14010507)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13302,
    "Teh Hijau Bubuk (14010507)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13303,
    "Teh Hijau Bubuk (14010507)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13304,
    "Teh Hijau Bubuk (14010507)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    13305,
    "Teh Hijau Celup (14010511)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13306,
    "Teh Hijau Celup (14010511)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13307,
    "Teh Hijau Celup (14010511)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13308,
    "Teh Hijau Celup (14010511)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13309,
    "Teh Hijau Celup (14010511)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    13310,
    "Teh Hitam (14010501)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13311,
    "Teh Hitam (14010501)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13312,
    "Teh Hitam (14010501)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13313,
    "Teh Hitam (14010501)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13314,
    "Teh Hitam (14010501)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13315,
    "Teh Hitam (14010501)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [13316, "Teh Hitam Celup (14010509)", "Kadar air (%)", "=10"],
  [
    13317,
    "Teh Hitam Celup (14010509)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13318,
    "Teh Hitam Celup (14010509)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13319,
    "Teh Hitam Celup (14010509)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13320,
    "Teh Hitam Celup (14010509)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13321,
    "Teh Hitam Celup (14010509)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    13322,
    "Teh Instan (14010513)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13323,
    "Teh Instan (14010513)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13324,
    "Teh Instan (14010513)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13325,
    "Teh Instan (14010513)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13326,
    "Teh Instan (14010513)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    13327,
    "Teh Instan Dekafein (14010556)",
    "Kafein anhidrat dihitung terhadap bobot kering (g/kg)",
    "=4",
  ],
  [
    13328,
    "Teh Instan Dekafein (14010556)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13329,
    "Teh Instan Dekafein (14010556)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13330,
    "Teh Instan Dekafein (14010556)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13331,
    "Teh Instan Dekafein (14010556)",
    "Timah dalam kaleng (Sn) (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13332,
    "Teh Instan Dekafein (14010556)",
    "Timah tidak dalam kaleng (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13333,
    "Teh Instan Dekafein (14010556)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [13334, "Teh Kering (14010508)", "Kadar air (%) ", "=8"],
  [
    13335,
    "Teh Kering (14010508)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13336,
    "Teh Kering (14010508)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13337,
    "Teh Kering (14010508)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13338,
    "Teh Kering (14010508)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13339,
    "Teh Kering (14010508)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    13340,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13341,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13342,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13343,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13344,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13345,
    "Teh Olong atau Teh Semi Fermentasi (14010506)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    13346,
    "Teh Putih (14010503)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13347,
    "Teh Putih (14010503)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13348,
    "Teh Putih (14010503)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13349,
    "Teh Putih (14010503)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13350,
    "Teh Putih (14010503)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13351,
    "Teh Putih (14010503)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [13352, "Teh Wangi (14010504)", "Kadar air (%)", "=8"],
  [
    13353,
    "Teh Wangi (14010504)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13354,
    "Teh Wangi (14010504)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13355,
    "Teh Wangi (14010504)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13356,
    "Teh Wangi (14010504)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13357,
    "Teh Wangi (14010504)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13358,
    "Teh Wangi (14010504)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    13359,
    "Teh Wangi Celup (14010510)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13360,
    "Teh Wangi Celup (14010510)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13361,
    "Teh Wangi Celup (14010510)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13362,
    "Teh Wangi Celup (14010510)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13363,
    "Teh Wangi Celup (14010510)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=2",
  ],
  [
    13364,
    "Teh Wangi Tradisional (14010505)",
    "Kadar air (%)",
    "=8",
  ],
  [
    13365,
    "Teh Wangi Tradisional (14010505)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=1",
  ],
  [
    13366,
    "Teh Wangi Tradisional (14010505)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13367,
    "Teh Wangi Tradisional (14010505)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13368,
    "Teh Wangi Tradisional (14010505)",
    "Timah (Sn) minuman dalam kemasan kaleng (ppm atau mg/kg) - siap konsumsi",
    "=100",
  ],
  [
    13369,
    "Teh Wangi Tradisional (14010505)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13370,
    "Teh Wangi Tradisional (14010505)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=2",
  ],
  [
    13371,
    "Tekwan Ikan (0902040127)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13372,
    "Tekwan Ikan (0902040127)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13373,
    "Tekwan Ikan (0902040127)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    13374,
    "Tekwan Ikan (0902040127)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    13375,
    "Tekwan Ikan (0902040127)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    13376,
    "Tekwan Ikan (0902040127)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13377,
    "Tekwan Ikan (0902040127)",
    "Kandungan lumatan daging ikan segar dan/atau surimi (%)",
    "",
    "=30",
  ],
  [13378, "Telur Asin Matang (100302)", "Kadar garam (%)", "", "=2"],
  [
    13379,
    "Telur Asin Matang (100302)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13380,
    "Telur Asin Matang (100302)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13381,
    "Telur Asin Matang (100302)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13382,
    "Telur Asin Matang (100302)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13383,
    "Telur Asin Matang (100302)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [13384, "Telur Asin Mentah (100301)", "Kadar garam (%)", "=2"],
  [
    13385,
    "Telur Asin Mentah (100301)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13386,
    "Telur Asin Mentah (100301)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13387,
    "Telur Asin Mentah (100301)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13388,
    "Telur Asin Mentah (100301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13389,
    "Telur Asin Mentah (100301)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [13390, "Telur Asin Mentah (100301)", "Kadar Garam (%)", "", "=2"],
  [
    13391,
    "Telur Beku Utuh (10020201)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13392,
    "Telur Beku Utuh (10020201)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13393,
    "Telur Beku Utuh (10020201)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13394,
    "Telur Beku Utuh (10020201)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13395,
    "Telur Beku Utuh (10020201)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13396,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13397,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    13398,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13399,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13400,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    13401,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13402,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Kandungan telur (%) (Dihitung Sebagai Telur Cair)",
    "",
    "=50",
  ],
  [
    13403,
    "Telur Cair Campuran /Premiks Telur Cair (10020104)",
    "Kandungan telur (%) (Dihitung Sebagai Tepung Telur)",
    "",
    "=11.5",
  ],
  [
    13404,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Kandungan Telur (%) (Dihitung sebagai telur cair)",
    "",
    "=50",
  ],
  [
    13405,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Kandungan Telur (%) (Dihitung sebagai tepung telur)",
    "",
    "=11.5",
  ],
  [
    13406,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13407,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Kadmium (Cd) (mg/kg)",
    "=0.10",
  ],
  [
    13408,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13409,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13410,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13411,
    "Telur Campuran Beku/Premiks Telur Beku (10020204)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13412,
    "Telur Diawetkan Dengan Cara Lain (100307)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13413,
    "Telur Diawetkan Dengan Cara Lain (100307)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13414,
    "Telur Diawetkan Dengan Cara Lain (100307)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13415,
    "Telur Diawetkan Dengan Cara Lain (100307)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13416,
    "Telur Diawetkan Dengan Cara Lain (100307)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13417,
    "Telur Fermentasi (100308)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13418,
    "Telur Fermentasi (100308)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13419,
    "Telur Fermentasi (100308)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13420,
    "Telur Fermentasi (100308)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13421,
    "Telur Fermentasi (100308)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [13422, "Telur Ikan (09030301)", "Arsen (As) (mg/kg) ", "=0.25"],
  [13423, "Telur Ikan (09030301)", "Kadmium (Cd) (mg/kg) ", "=0.1"],
  [13424, "Telur Ikan (09030301)", "Merkuri (Hg) (mg/kg) ", "=0.5"],
  [13425, "Telur Ikan (09030301)", "Timah (Sn) (mg/kg) ", "=40"],
  [13426, "Telur Ikan (09030301)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    13427,
    "Telur Ikan dalam Kaleng (09030311)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13428,
    "Telur Ikan dalam Kaleng (09030311)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13429,
    "Telur Ikan dalam Kaleng (09030311)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    13430,
    "Telur Ikan dalam Kaleng (09030311)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    13431,
    "Telur Ikan dalam Kaleng (09030311)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13432,
    "Telur Ikan Masak (0902040132)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13433,
    "Telur Ikan Masak (0902040132)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13434,
    "Telur Ikan Masak (0902040132)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    13435,
    "Telur Ikan Masak (0902040132)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13436,
    "Telur Ikan Masak (0902040132)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    13437,
    "Telur Ikan Masak (0902040132)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13438,
    "Telur Matang/Setengah Matang (10020306)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13439,
    "Telur Matang/Setengah Matang (10020306)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13440,
    "Telur Matang/Setengah Matang (10020306)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13441,
    "Telur Matang/Setengah Matang (10020306)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13442,
    "Telur Matang/Setengah Matang (10020306)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13443,
    "Telur Matang/Setengah Matang (10020306)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13444,
    "Telur Olahan Steril (100309)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13445,
    "Telur Olahan Steril (100309)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13446,
    "Telur Olahan Steril (100309)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13447,
    "Telur Olahan Steril (100309)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13448,
    "Telur Olahan Steril (100309)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13449,
    "Telur Olahan Steril (100309)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13450,
    "Telur Pindang (100303)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13451,
    "Telur Pindang (100303)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13452,
    "Telur Pindang (100303)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13453,
    "Telur Pindang (100303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13454,
    "Telur Pindang (100303)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13455,
    "Telur Pindang (100303)",
    "Timah (Sn) yang dikemas dalam kaleng (Sn) (mg/kg)",
    "=250",
  ],
  [
    13456,
    "Tempe (06080603)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13457,
    "Tempe (06080603)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13458,
    "Tempe (06080603)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13459,
    "Tempe (06080603)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13460,
    "Tempe (06080603)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13461,
    "Tempe Selain Kedelai (0402020710)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13462,
    "Tempe Selain Kedelai (0402020710)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13463,
    "Tempe Selain Kedelai (0402020710)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13464,
    "Tempe Selain Kedelai (0402020710)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13465,
    "Tempe Selain Kedelai (0402020710)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13466,
    "Tempoyak / Pakasam (0401021003)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13467,
    "Tempoyak / Pakasam (0401021003)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13468,
    "Tempoyak / Pakasam (0401021003)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13469,
    "Tempoyak / Pakasam (0401021003)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    13470,
    "Tempoyak / Pakasam (0401021003)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13471,
    "Tempoyak / Pakasam (0401021003)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    13472,
    "Tempura Beku (09020206)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13473,
    "Tempura Beku (09020206)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.06",
  ],
  [
    13474,
    "Tempura Beku (09020206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13475,
    "Tempura Beku (09020206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13476,
    "Tempura Beku (09020206)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13477,
    "Tempura Beku (09020206)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13478,
    "Temu Kunci (12020192)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    13479,
    "Temu Kunci (12020192)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    13480,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13481,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13482,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13483,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13484,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13485,
    "Tepung Agar-Agar/Jeli Agar Bubuk/Tepung Gelatin (0401020909)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [13486, "Tepung Almond (06020128)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13487,
    "Tepung Almond (06020128)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13488,
    "Tepung Almond (06020128)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13489,
    "Tepung Almond (06020128)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13490,
    "Tepung Almond (06020128)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13491,
    "Tepung Almond (06020128)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13492,
    "Tepung Almond (06020128)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [13493, "Tepung Aren (06020122)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13494,
    "Tepung Aren (06020122)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13495,
    "Tepung Aren (06020122)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13496,
    "Tepung Aren (06020122)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13497,
    "Tepung Aren (06020122)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [13498, "Tepung Aren (06020122)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [13499, "Tepung Aren (06020122)", "Kadar air (%)", "=13"],
  [
    13500,
    "Tepung Aren (06020122)",
    "Kehalusan lolos ayakan 80 mesh (%)",
    "",
    "=95",
  ],
  [
    13501,
    "Tepung Bakso (060602)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13502,
    "Tepung Bakso (060602)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13503,
    "Tepung Bakso (060602)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13504,
    "Tepung Bakso (060602)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13505,
    "Tepung Bakso (060602)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13506,
    "Tepung Bakso (060602)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13507,
    "Tepung Bakso (060605)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13508,
    "Tepung Bakso (060605)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13509,
    "Tepung Bakso (060605)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13510,
    "Tepung Bakso (060605)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13511,
    "Tepung Bakso (060605)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13512,
    "Tepung Bakso (060605)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13513,
    "Tepung Bakwan (060604)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13514,
    "Tepung Bakwan (060604)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13515,
    "Tepung Bakwan (060604)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13516,
    "Tepung Bakwan (060604)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13517,
    "Tepung Bakwan (060604)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13518,
    "Tepung Bakwan (060604)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13519, "Tepung Beras (06020101)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13520,
    "Tepung Beras (06020101)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13521,
    "Tepung Beras (06020101)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13522,
    "Tepung Beras (06020101)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13523,
    "Tepung Beras (06020101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13524,
    "Tepung Beras (06020101)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13525,
    "Tepung Beras Ketan (06020102)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13526,
    "Tepung Beras Ketan (06020102)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13527,
    "Tepung Beras Ketan (06020102)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13528,
    "Tepung Beras Ketan (06020102)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13529,
    "Tepung Beras Ketan (06020102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13530,
    "Tepung Beras Ketan (06020102)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13531,
    "Tepung Bit (0402020217)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13532,
    "Tepung Bit (0402020217)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13533,
    "Tepung Bit (0402020217)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13534,
    "Tepung Bit (0402020217)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13535,
    "Tepung Bit (0402020217)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13536,
    "Tepung Buah (0401020210)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13537,
    "Tepung Buah (0401020210)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13538,
    "Tepung Buah (0401020210)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13539,
    "Tepung Buah (0401020210)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13540,
    "Tepung Buah (0401020210)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    13541,
    "Tepung Buah (0401020210)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13542,
    "Tepung Buah (0401020816)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13543,
    "Tepung Buah (0401020816)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13544,
    "Tepung Buah (0401020816)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13545,
    "Tepung Buah (0401020816)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    13546,
    "Tepung Buah (0401020816)",
    "Timah (Sn) pangan olahan yang diolah dengan proses panas dan dikemas dalam kaleng (mg/kg) ",
    "=250",
  ],
  [
    13547,
    "Tepung Buah (0401020816)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    13548,
    "Tepung Buckwheat (06020134)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13549,
    "Tepung Buckwheat (06020134)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13550,
    "Tepung Buckwheat (06020134)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13551,
    "Tepung Buckwheat (06020134)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13552,
    "Tepung Buckwheat (06020134)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13553, "Tepung Bumbu (060601)", "Kadar air (%)", "=12"],
  [
    13554,
    "Tepung Bumbu (060601)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13555,
    "Tepung Bumbu (060601)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13556,
    "Tepung Bumbu (060601)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13557,
    "Tepung Bumbu (060601)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13558,
    "Tepung Bumbu (060601)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13559,
    "Tepung Bumbu (060601)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13560, "Tepung Campur (06020133)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13561,
    "Tepung Campur (06020133)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13562,
    "Tepung Campur (06020133)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13563,
    "Tepung Campur (06020133)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13564,
    "Tepung Campur (06020133)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13565, "Tepung Campur (06020133)", "Kadar Air (%)", "=14.5"],
  [
    13566,
    "Tepung Ceshnut (06020127)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13567,
    "Tepung Ceshnut (06020127)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13568,
    "Tepung Ceshnut (06020127)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13569,
    "Tepung Ceshnut (06020127)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13570,
    "Tepung Ceshnut (06020127)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13571,
    "Tepung Ceshnut (06020127)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13572,
    "Tepung Custard (100404)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13573,
    "Tepung Custard (100404)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    13574,
    "Tepung Custard (100404)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13575,
    "Tepung Custard (100404)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13576,
    "Tepung Custard (100404)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13577,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13578,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13579,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13580,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13581,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13582,
    "Tepung Custard Tanpa Telur (Eggless Custard) (060501)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13583,
    "Tepung Daun Kelor (0402020229)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.15",
  ],
  [
    13584,
    "Tepung Daun Kelor (0402020229)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13585,
    "Tepung Daun Kelor (0402020229)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13586,
    "Tepung Daun Kelor (0402020229)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    13587,
    "Tepung Daun Kelor (0402020229)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13588,
    "Tepung Daun Kelor (0402020229)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    13589,
    "Tepung Flaxseed (06020129)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13590,
    "Tepung Flaxseed (06020129)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13591,
    "Tepung Flaxseed (06020129)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13592,
    "Tepung Flaxseed (06020129)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13593,
    "Tepung Flaxseed (06020129)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13594,
    "Tepung Flaxseed (06020129)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13595, "Tepung Gaplek (06020120)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13596,
    "Tepung Gaplek (06020120)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13597,
    "Tepung Gaplek (06020120)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13598,
    "Tepung Gaplek (06020120)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13599,
    "Tepung Gaplek (06020120)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13600,
    "Tepung Gaplek (06020120)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13601,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13602,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13603,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13604,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13605,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    13606,
    "Tepung Gelatin (Bubuk Gelatin) (0401020915)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13607,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Kadar air (%)",
    "=10",
  ],
  [
    13608,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Kadar tepung pati (%) (bk)",
    "=44",
  ],
  [
    13609,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Kadar protein (%) (bk)",
    "",
    "=60",
  ],
  [
    13610,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13611,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13612,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13613,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13614,
    "Tepung Gluten Terigu (Wheat Gluten Powder) (06020115)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13615,
    "Tepung Hazelnut (06020130)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13616,
    "Tepung Hazelnut (06020130)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13617,
    "Tepung Hazelnut (06020130)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13618,
    "Tepung Hazelnut (06020130)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13619,
    "Tepung Hazelnut (06020130)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13620,
    "Tepung Hazelnut (06020130)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13621, "Tepung Ikan (09020522)", "Kadar air (%)", "=4"],
  [13622, "Tepung Ikan (09020522)", "Arsen (mg/kg)", "=0.25"],
  [13623, "Tepung Ikan (09020522)", "Kadmium (mg/kg)", "=0.1"],
  [13624, "Tepung Ikan (09020522)", "Merkuri (mg/kg)", "=0.5"],
  [13625, "Tepung Ikan (09020522)", "Timah (mg/kg)", "=40"],
  [13626, "Tepung Ikan (09020522)", "Timbal (mg/kg)", "=0.2"],
  [
    13627,
    "Tepung Iles-iles (06020126)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13628,
    "Tepung Iles-iles (06020126)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13629,
    "Tepung Iles-iles (06020126)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13630,
    "Tepung Iles-iles (06020126)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13631,
    "Tepung Iles-iles (06020126)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13632,
    "Tepung Iles-iles (06020126)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13633, "Tepung Jagung (06020103)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13634,
    "Tepung Jagung (06020103)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13635,
    "Tepung Jagung (06020103)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13636,
    "Tepung Jagung (06020103)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13637,
    "Tepung Jagung (06020103)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13638,
    "Tepung Jagung (06020103)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13639, "Tepung Jagung (06020103)", "Kadar Air (%)", "=14"],
  [
    13640,
    "Tepung Jagung (06020103)",
    "Kehalusan: Ayakan 60 mesh (%)",
    "",
    "=99",
  ],
  [
    13641,
    "Tepung Jagung (06020103)",
    "Kehalusan: Ayakan 80 mesh (%)",
    "",
    "=70",
  ],
  [
    13642,
    "Tepung Jagung (06020103)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    13643,
    "Tepung Jagung (06020103)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    13644,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Kadar air (%)",
    "=13",
  ],
  [
    13645,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Kehalusan : lolos ayakan 32 mesh (%) (Halus)",
  ],
  [
    13646,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Kehalusan : lolos ayakan 16 mesh (%) (Medium)",
  ],
  [
    13647,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13648,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13649,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13650,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13651,
    "Tepung Jewawut (Pearl Millet Flour) (06020110)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13652,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13653,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13654,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13655,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13656,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13657,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Kadar air (%)",
    "=10",
  ],
  [
    13658,
    "Tepung Kacang Hijau Utuh (06020105)",
    "Kehalusan : lolos ayakan 60 mesh (%) ",
    "",
    "=95",
  ],
  [
    13659,
    "Tepung Kacang Lainnya (06020132)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13660,
    "Tepung Kacang Lainnya (06020132)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13661,
    "Tepung Kacang Lainnya (06020132)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13662,
    "Tepung Kacang Lainnya (06020132)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng",
    "=250",
  ],
  [
    13663,
    "Tepung Kacang Lainnya (06020132)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng",
    "=40",
  ],
  [
    13664,
    "Tepung Kacang Lainnya (06020132)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13665,
    "Tepung Kacang Lainnya (06020132)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    13666,
    "Tepung Kacang Merah (06020106)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=10",
  ],
  [
    13667,
    "Tepung Kacang Merah (06020106)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13668,
    "Tepung Kacang Merah (06020106)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13669,
    "Tepung Kacang Merah (06020106)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13670,
    "Tepung Kacang Merah (06020106)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13671,
    "Tepung Kacang Merah (06020106)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13672,
    "Tepung Kacang Merah (06020106)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13673,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13674,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13675,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13676,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13677,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    13678,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13679,
    "Tepung Karagenan (Bubuk Karagenan) (0401020916)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    13680,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13681,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13682,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13683,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13684,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13685,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13686,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Kadar Air (%)",
    "=10",
  ],
  [
    13687,
    "Tepung Kedelai (Soybean Flour) (06020107)",
    "Kadar Protein (%)",
    "",
    "=50",
  ],
  [
    13688,
    "Tepung Kelapa (0401020818)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13689,
    "Tepung Kelapa (0401020818)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13690,
    "Tepung Kelapa (0401020818)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13691,
    "Tepung Kelapa (0401020818)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13692,
    "Tepung Kelapa (0401020818)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13693,
    "Tepung Kelapa (0401020818)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    13694,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13695,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13696,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13697,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13698,
    "Tepung Kulit Ari (Fine Bran) (06020118)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13699, "Tepung Kuning Telur (10020303)", "Kadar Air (%)", "=5"],
  [
    13700,
    "Tepung Kuning Telur (10020303)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13701,
    "Tepung Kuning Telur (10020303)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13702,
    "Tepung Kuning Telur (10020303)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13703,
    "Tepung Kuning Telur (10020303)",
    "Timah (Sn) yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    13704,
    "Tepung Kuning Telur (10020303)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13705,
    "Tepung Kuning Telur (10020303)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13706,
    "Tepung Melinjo (0402020227)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13707,
    "Tepung Melinjo (0402020227)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13708,
    "Tepung Melinjo (0402020227)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13709,
    "Tepung Melinjo (0402020227)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    13710,
    "Tepung Melinjo (0402020227)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13711,
    "Tepung Melinjo (0402020227)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [13712, "Tepung Mokaf (06020131)", "Kadar Air (%)", "=13"],
  [
    13713,
    "Tepung Mokaf (06020131)",
    "Kehalusan, lolos ayakan 100 mesh (%)",
    "",
    "=90",
  ],
  [
    13714,
    "Tepung Mokaf (06020131)",
    "Kehalusan, lolos ayakan 80 mesh (%)",
    "",
    "=100",
  ],
  [13715, "Tepung Mokaf (06020131)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13716,
    "Tepung Mokaf (06020131)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13717,
    "Tepung Mokaf (06020131)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13718,
    "Tepung Mokaf (06020131)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13719,
    "Tepung Mokaf (06020131)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13720,
    "Tepung Mokaf (06020131)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13721,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Arsen (As) (mg/kg)",
    "=0.10",
  ],
  [
    13722,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13723,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13724,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Timah (Sn) pangan olahan diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13725,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Timah (Sn) pangan olahan yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13726,
    "Tepung Olahan / Pati Olahan / Protein Olahan (Meat Analog / Fish Analog / Seafood Analog) (06040325)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13727, "Tepung Panir (07010402)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    13728,
    "Tepung Panir (07010402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [13729, "Tepung Panir (07010402)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [13730, "Tepung Panir (07010402)", "Timah (Sn) (mg/kg)", "=40"],
  [13731, "Tepung Panir (07010402)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [13732, "Tepung Pelapis (060603)", "Kadar Air (%) ", "=12"],
  [
    13733,
    "Tepung Pelapis (060603)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13734,
    "Tepung Pelapis (060603)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13735,
    "Tepung Pelapis (060603)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13736,
    "Tepung Pelapis (060603)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13737,
    "Tepung Pelapis (060603)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13738,
    "Tepung Roti / Bread Crumb (07010403)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    13739,
    "Tepung Roti / Bread Crumb (07010403)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    13740,
    "Tepung Roti / Bread Crumb (07010403)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    13741,
    "Tepung Roti / Bread Crumb (07010403)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    13742,
    "Tepung Roti / Bread Crumb (07010403)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [13743, "Tepung Singkong (06020119)", "Kadar air (%)", "=12"],
  [
    13744,
    "Tepung Singkong (06020119)",
    "Kehalusan, lolos ayakan 80 mesh) (%)",
    "",
    "=90",
  ],
  [
    13745,
    "Tepung Singkong (06020119)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13746,
    "Tepung Singkong (06020119)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13747,
    "Tepung Singkong (06020119)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13748,
    "Tepung Singkong (06020119)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13749,
    "Tepung Singkong (06020119)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13750, "Tepung Sorgum (06020111)", "Kadar air (%)", "=14.5"],
  [13751, "Tepung Sorgum (06020111)", "Kadar tanin (%) bk", "=0.3"],
  [
    13752,
    "Tepung Sorgum (06020111)",
    "Kehalusan untuk 32 mesh (%)",
    "",
    "=100",
  ],
  [
    13753,
    "Tepung Sorgum (06020111)",
    "Kehalusan untuk 16 mesh (%)",
    "",
    "=100",
  ],
  [13754, "Tepung Sorgum (06020111)", "Arsen (As) (mg/kg)", "=0.1"],
  [
    13755,
    "Tepung Sorgum (06020111)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13756,
    "Tepung Sorgum (06020111)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13757,
    "Tepung Sorgum (06020111)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13758,
    "Tepung Sorgum (06020111)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13759,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13760,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    13761,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13762,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    13763,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    13764,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13765,
    "Tepung Telur Campuran/Premiks Tepung Telur (10020307)",
    "Kandungan telur (%) (Dihitung Sebagai Tepung Telur)",
    "",
    "=11.5",
  ],
  [13766, "Tepung Telur Utuh (10020301)", "Kadar Air (%)", "=5"],
  [
    13767,
    "Tepung Telur Utuh (10020301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13768,
    "Tepung Telur Utuh (10020301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13769,
    "Tepung Telur Utuh (10020301)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13770,
    "Tepung Telur Utuh (10020301)",
    "Timah (Sn) yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    13771,
    "Tepung Telur Utuh (10020301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13772,
    "Tepung Telur Utuh (10020301)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13773, "Tepung Terigu (06020112)", "Bentuk (serbuk)"],
  [
    13774,
    "Tepung Terigu (06020112)",
    "Bau (normal (bebas dari bau asing))",
  ],
  [
    13775,
    "Tepung Terigu (06020112)",
    "Warna (putih, khas terigu)",
  ],
  [13776, "Tepung Terigu (06020112)", "Benda asing (tidak ada)"],
  [
    13777,
    "Tepung Terigu (06020112)",
    "Serangga dalam semua bentuk stadia dan potongan-potongannya yang tampak (tidak ada)",
  ],
  [
    13778,
    "Tepung Terigu (06020112)",
    "Kehalusan, lolos ayakan 212 um (mesh No. 70) (b/b) (%)",
    "",
    "=95",
  ],
  [
    13779,
    "Tepung Terigu (06020112)",
    "Kadar air (b/b) (%)",
    "=14.5",
  ],
  [
    13780,
    "Tepung Terigu (06020112)",
    "Kadar abu (b/b) (%)",
    "=0.7",
  ],
  [
    13781,
    "Tepung Terigu (06020112)",
    "Kadar protein (b/b) (%)",
    "",
    "=7",
  ],
  [
    13782,
    "Tepung Terigu (06020112)",
    "Keasaman (mg KOH / 100 g)",
    "=50",
  ],
  [
    13783,
    "Tepung Terigu (06020112)",
    "Falling number (atas dasar kadar air 14 %) (detik)",
    "",
    "=300",
  ],
  [
    13784,
    "Tepung Terigu (06020112)",
    "Besi (Fe) (mg/kg)",
    "",
    "=50",
  ],
  [
    13785,
    "Tepung Terigu (06020112)",
    "Seng (Zn) (mg/kg)",
    "",
    "=30",
  ],
  [
    13786,
    "Tepung Terigu (06020112)",
    "Vitamin B1 (tiamin) (mg/kg)",
    "",
    "=2.5",
  ],
  [
    13787,
    "Tepung Terigu (06020112)",
    "Vitamin B2 (riboflavin) (mg/kg)",
    "",
    "=4",
  ],
  [
    13788,
    "Tepung Terigu (06020112)",
    "Asam folat (mg/kg)",
    "",
    "=2",
  ],
  [
    13789,
    "Tepung Terigu (06020112)",
    "Cemaran logan timbal (Pb) (mg/kg)",
    "=1",
  ],
  [
    13790,
    "Tepung Terigu (06020112)",
    "Cemaran logan raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    13791,
    "Tepung Terigu (06020112)",
    "Cemaran logan kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13792,
    "Tepung Terigu (06020112)",
    "Cemaran Arsen (mg/kg)",
    "=0.5",
  ],
  [
    13793,
    "Tepung Terigu (06020112)",
    "Cemaran mikroba angka lempeng total (koloni/g)",
    "=1000000",
  ],
  [
    13794,
    "Tepung Terigu (06020112)",
    "Cemaran mikroba APM E. Coli (/g)",
    "=10",
  ],
  [
    13795,
    "Tepung Terigu (06020112)",
    "Cemaran mikroba kapang (koloni/g)",
    "=10000",
  ],
  [
    13796,
    "Tepung Terigu (06020112)",
    "Cemaran mikroba bacillus cereus",
    "=10000",
  ],
  [
    13797,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Kandungan Nitrogen (%(bk))",
    "",
    "=2.7",
  ],
  [
    13798,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13799,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13800,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13801,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13802,
    "Tepung Terigu dengan Penambahan Protein (06020116)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13803,
    "Tepung Terigu Self-Raising (06020113)",
    "Kadar karbondioksida bila dibasahi dan dipanaskan (%)",
    "",
    "=0.64",
  ],
  [
    13804,
    "Tepung Terigu Self-Raising (06020113)",
    "Kadar sulfat (sebagai kalsium sulfat) (%)",
    "=0.6",
  ],
  [
    13805,
    "Tepung Terigu Self-Raising (06020113)",
    "Kandungan bahan pengembang kue (%)",
    "",
    "=0.5",
  ],
  [
    13806,
    "Tepung Terigu Self-Raising (06020113)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13807,
    "Tepung Terigu Self-Raising (06020113)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13808,
    "Tepung Terigu Self-Raising (06020113)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13809,
    "Tepung Terigu Self-Raising (06020113)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13810,
    "Tepung Terigu Self-Raising (06020113)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13811,
    "Tepung Terigu Self-Raising (06020113)",
    "Kadar air (%)",
    "=14.5",
  ],
  [
    13812,
    "Tepung Terigu Self-Raising (06020113)",
    "Kehalusan, lolos ayakan 212 um (mesh No. 70) (b/b) (%)",
    "",
    "=95",
  ],
  [
    13813,
    "Tepung Terigu Self-Raising (06020113)",
    "Besi (Fe) (mg/kg)",
    "",
    "=50",
  ],
  [
    13814,
    "Tepung Terigu Self-Raising (06020113)",
    "Seng (Zn) (mg/kg)",
    "",
    "=30",
  ],
  [
    13815,
    "Tepung Terigu Self-Raising (06020113)",
    "Vitamin B1 (tiamin) (mg/kg)",
    "",
    "=2.5",
  ],
  [
    13816,
    "Tepung Terigu Self-Raising (06020113)",
    "Vitamin B2 (riboflavin) (mg/kg)",
    "",
    "=4",
  ],
  [
    13817,
    "Tepung Terigu Self-Raising (06020113)",
    "Asam folat (mg/kg)",
    "",
    "=2",
  ],
  [
    13818,
    "Tepung Terigu Self-Raising (06020113)",
    "Kadar protein (b/b) (%)",
    "",
    "=7",
  ],
  [
    13819,
    "Tepung Terigu Terklorinasi (06020114)",
    "Jumlah klorin yang ditambahkan (mg/kg)",
    "=1500",
  ],
  [
    13820,
    "Tepung Terigu Terklorinasi (06020114)",
    "Kehalusan, lolos ayakan 70 mesh (b/b) (%)",
    "",
    "=95",
  ],
  [
    13821,
    "Tepung Terigu Terklorinasi (06020114)",
    "Kadar air (b/b) (%)",
    "=14.5",
  ],
  [
    13822,
    "Tepung Terigu Terklorinasi (06020114)",
    "Kadar protein (b/b) (%)",
    "",
    "=7",
  ],
  [
    13823,
    "Tepung Terigu Terklorinasi (06020114)",
    "Besi (Fe) (mg/kg)",
    "",
    "=50",
  ],
  [
    13824,
    "Tepung Terigu Terklorinasi (06020114)",
    "Vitamin B1 (tiamin) (mg/kg)",
    "",
    "=2.5",
  ],
  [
    13825,
    "Tepung Terigu Terklorinasi (06020114)",
    "Vitamin B2 (riboflavin) (mg/kg)",
    "",
    "=4",
  ],
  [
    13826,
    "Tepung Terigu Terklorinasi (06020114)",
    "Asam folat (mg/kg)",
    "",
    "=2",
  ],
  [
    13827,
    "Tepung Terigu Terklorinasi (06020114)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13828,
    "Tepung Terigu Terklorinasi (06020114)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13829,
    "Tepung Terigu Terklorinasi (06020114)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13830,
    "Tepung Terigu Terklorinasi (06020114)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13831,
    "Tepung Terigu Terklorinasi (06020114)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13832,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Kadar air (%)",
    "=14.5",
  ],
  [
    13833,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Kadar serat kasar (%) (bk)",
    "",
    "=2",
  ],
  [
    13834,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13835,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13836,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13837,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    13838,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [
    13839,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Kehalusan, lolos ayakan 70 mesh (b/b) (%)",
    "",
    "=95",
  ],
  [
    13840,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Kadar protein (b/b) (%)",
    "",
    "=7",
  ],
  [
    13841,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Besi (Fe) (mg/kg)",
    "",
    "=50",
  ],
  [
    13842,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Seng (Zn) (mg/kg)",
    "",
    "=30",
  ],
  [
    13843,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Vitamin B1 (tiamin) (mg/kg)",
    "",
    "=2.5",
  ],
  [
    13844,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Vitamin B2 (riboflavin) (mg/kg)",
    "",
    "=4",
  ],
  [
    13845,
    "Tepung Terigu Utuh (Wholemeal Wheat Flour) (06020117)",
    "Vitamin B2 (riboflavin) (mg/kg)",
    "",
    "=2",
  ],
  [
    13846,
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering (0402020216)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13847,
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering (0402020216)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13848,
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering (0402020216)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13849,
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering (0402020216)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13850,
    "Tepung Tomat/Bubur Tomat Kering/ Pasta Tomat Kering (0402020216)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13851,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    13852,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13853,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13854,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13855,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13856,
    "Tepung Umbi Lainnya (Tepung Kentang, Tepung Ubi Jalar, Tepung Garut, Tepung Ganyong dan lain-lain.) (06020121)",
    "Timbal (Pb) (mg/kg)",
    "=0.25",
  ],
  [13857, "Tequila (14020609)", "Kadar etanol (%)", "=55", "=35"],
  [
    13858,
    "Tequila (14020609)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [13859, "Tequila (14020609)", "Arsen (mg/kg)", "=0.1"],
  [13860, "Tequila (14020609)", "Kadmium (mg/kg)", "=0.2"],
  [13861, "Tequila (14020609)", "Merkuri (mg/kg)", "=0.03"],
  [
    13862,
    "Tequila (14020609)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    13863,
    "Tequila (14020609)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [13864, "Tequila (14020609)", "Timbal (mg/kg)", "=0.2"],
  [
    13865,
    "Tequila (14020613)",
    "Dapat ditambahkan gula dari sumber lain, kadar gula pereduksi sebelum fermentasi (%)",
    "=49",
  ],
  [13866, "Tequila (14020613)", "Kadar Etanol (%)", "=55", "=35"],
  [13867, "Tequila (14020613)", "Arsen (mg/kg)", "=0.1"],
  [13868, "Tequila (14020613)", "Kadmium (mg/kg)", "=0.2"],
  [13869, "Tequila (14020613)", "Merkuri (mg/kg)", "=0.03"],
  [
    13870,
    "Tequila (14020613)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    13871,
    "Tequila (14020613)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [13872, "Tequila (14020613)", "Timbal (mg/kg)", "=0.2"],
  [
    13873,
    "Tequila (14020613)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    13874,
    "Tequila 100% Agave (14020614)",
    "Kadar etanol (%)",
    "=55",
    "=35",
  ],
  [13875, "Tequila 100% Agave (14020614)", "Arsen (mg/kg)", "=0.1"],
  [
    13876,
    "Tequila 100% Agave (14020614)",
    "Kadmium (mg/kg)",
    "=0.2",
  ],
  [
    13877,
    "Tequila 100% Agave (14020614)",
    "Merkuri (mg/kg)",
    "=0.03",
  ],
  [
    13878,
    "Tequila 100% Agave (14020614)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13879,
    "Tequila 100% Agave (14020614)",
    "Timbal (mg/kg)",
    "=0.2",
  ],
  [
    13880,
    "Tequila 100% Agave (14020614)",
    "Penambahan gula dari sumber lain",
  ],
  [
    13881,
    "Tequila 100% Agave (14020614)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [
    13882,
    "Terasi Udang (09020517)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13883,
    "Terasi Udang (09020517)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13884,
    "Terasi Udang (09020517)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    13885,
    "Terasi Udang (09020517)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13886,
    "Terasi Udang (09020517)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13887,
    "Terasi Udang (09020517)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13888,
    "Terong Beku (0402020112)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13889,
    "Terong Beku (0402020112)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13890,
    "Terong Beku (0402020112)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13891,
    "Terong Beku (0402020112)",
    "Timah (Sn) untuk produk yang diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13892,
    "Terong Beku (0402020112)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13893,
    "Terong Beku (0402020112)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    13894,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13895,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    13896,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13897,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    13898,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13899,
    "Terrines (Campuran Cacahan Daging Matang) (08030218)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    13900,
    "Tetes Tebu atau Molases (110302)",
    "Arsen (As) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13901,
    "Tetes Tebu atau Molases (110302)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13902,
    "Tetes Tebu atau Molases (110302)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13903,
    "Tetes Tebu atau Molases (110302)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13904,
    "Tetes Tebu atau Molases (110302)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    13905,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    13906,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13907,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13908,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Timah (Sn) (ppm atau mg/kg) dikemas dalam kaleng",
    "=250",
  ],
  [
    13909,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Timah (Sn) (ppm atau mg/kg) tidak dikemas dalam kaleng",
    "=40",
  ],
  [
    13910,
    "Texturized Vegetable Protein (TVP) (06080802)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13911, "Thymi/Thyme (12020194)", "Kadar air (%)", "=9"],
  [
    13912,
    "Thymi/Thyme (12020194)",
    "Minyak atsiri (%v/b)",
    "",
    "=0.9",
  ],
  [
    13913,
    "Thymi/Thyme (12020194)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13914,
    "Thymi/Thyme (12020194)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    13915,
    "Thymi/Thyme (12020194)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13916,
    "Thymi/Thyme (12020194)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    13917,
    "Thymi/Thyme (12020194)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=1",
  ],
  [
    13918,
    "Thymi/Thyme (12020194)",
    "Aflatoxin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    13919,
    "Thymi/Thyme (12020194)",
    "Aflatoxin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    13920,
    "Titiles (0803010107)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    13921,
    "Titiles (0803010107)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    13922,
    "Titiles (0803010107)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    13923,
    "Titiles (0803010107)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    13924,
    "Titiles (0803010107)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13925,
    "Titiles (0803010107)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [13926, "Tiwul (060310)", "Arsen (As) (mg/kg)", "=0.1"],
  [13927, "Tiwul (060310)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [13928, "Tiwul (060310)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    13929,
    "Tiwul (060310)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13930,
    "Tiwul (060310)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [13931, "Tiwul (060310)", "Timbal (Pb) (mg/kg)", "=0.25"],
  [13932, "Toffee (05020206)", "Arsen (As) (mg/kg)", "=1"],
  [13933, "Toffee (05020206)", "Cadmium (Cd) (mg/kg)", "=0.5"],
  [13934, "Toffee (05020206)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [
    13935,
    "Toffee (05020206)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13936,
    "Toffee (05020206)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [13937, "Toffee (05020206)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    13938,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13939,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13940,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13941,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Timah (Sn) pangan olahan lain yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250.00",
  ],
  [
    13942,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    13943,
    "Toffee Asam Jawa/Tamarin (0401020814)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    13944,
    "Tomat Dalam Kemasan (0402020402)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    13945,
    "Tomat Dalam Kemasan (0402020402)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    13946,
    "Tomat Dalam Kemasan (0402020402)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    13947,
    "Tomat Dalam Kemasan (0402020402)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [13948, "Tomat Dalam Kemasan (0402020402)", "Bobot Tuntas (%)"],
  [
    13949,
    "Tomat Dalam Kemasan (0402020402)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    13950,
    "Tomat Dalam Kemasan (0402020402)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    13951,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Arsen (As) (mg/kg)",
    "=0.15",
  ],
  [
    13952,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    13953,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    13954,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13955,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13956,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    13957,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=20",
  ],
  [
    13958,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Aflatoksin B1 (hanya berlaku jika bahan baku dari kacang tanah) (ppb atau mcg/kg)",
    "=15",
  ],
  [
    13959,
    "Topping Berbasis Sayur dan Kacang (0402020611)",
    "Aflatoksin Total (hanya berlaku jika bahan baku dari kacang-kacangan selain kacang tanah) (ppb atau mcg/kg)",
    "=10",
  ],
  [
    13960,
    "Topping Berbasis Susu (010713)",
    "Arsen (As) (mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    13961,
    "Topping Berbasis Susu (010713)",
    "Kadmium (Cd) (mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    13962,
    "Topping Berbasis Susu (010713)",
    "Merkuri (Hg) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    13963,
    "Topping Berbasis Susu (010713)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    13964,
    "Topping Berbasis Susu (010713)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    13965,
    "Topping Berbasis Susu (010713)",
    "Timbal (Pb) (mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    13966,
    "Topping Buah (0401020806)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13967,
    "Topping Buah (0401020806)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13968,
    "Topping Buah (0401020806)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13969,
    "Topping Buah (0401020806)",
    "Timah (Sn) pangan olahan lain yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40.00",
  ],
  [
    13970,
    "Topping Buah (0401020806)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.20",
  ],
  [
    13971,
    "Tororo-Kombu (0402020220)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    13972,
    "Tororo-Kombu (0402020220)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    13973,
    "Tororo-Kombu (0402020220)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    13974,
    "Tororo-Kombu (0402020220)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    13975,
    "Tororo-Kombu (0402020220)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    13976,
    "Tortila Ikan (0902040317)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    13977,
    "Tortila Ikan (0902040317)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    13978,
    "Tortila Ikan (0902040317)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    13979,
    "Tortila Ikan (0902040317)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13980,
    "Tortila Ikan (0902040317)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    13981,
    "Tortila Ikan (0902040317)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [13982, "Tortilla (06040103)", "Arsen (As) ", "=0.1"],
  [13983, "Tortilla (06040103)", "Kadmium (Cd) ", "=0.05"],
  [13984, "Tortilla (06040103)", "Merkuri (Hg) ", "=0.03"],
  [
    13985,
    "Tortilla (06040103)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    13986,
    "Tortilla (06040103)",
    "Timah (Sn) tidak dikemas dalam kaleng ",
    "=40",
  ],
  [
    13987,
    "Tortilla (06040103)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.25",
  ],
  [13988, "Tortilla (07010308)", "Arsen (As) (mg/kg)", "=0.5"],
  [13989, "Tortilla (07010308)", "Kadmium (Cd)(mg/kg)", "=0.2"],
  [13990, "Tortilla (07010308)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    13991,
    "Tortilla (07010308)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    13992,
    "Tortilla (07010308)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [13993, "Tortilla (07010308)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [13994, "Truffles (05010404)", "Arsen (As) (mg/kg)", "=1"],
  [13995, "Truffles (05010404)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [13996, "Truffles (05010404)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    13997,
    "Truffles (05010404)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg) ",
    "=40",
  ],
  [
    13998,
    "Truffles (05010404)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [13999, "Truffles (05010404)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    14000,
    "Tsukemono (0402020312)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14001,
    "Tsukemono (0402020312)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14002,
    "Tsukemono (0402020312)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14003,
    "Tsukemono (0402020312)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14004,
    "Tsukemono (0402020312)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14005,
    "Tsukemono (0402020312)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [14006, "Tsukudani (0902040131)", "Arsen (As) (mg/kg)", "=0.25"],
  [14007, "Tsukudani (0902040131)", "Kadmium (Cd) (mg/kg)", "=0.1"],
  [
    14008,
    "Tsukudani (0902040131)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14009,
    "Tsukudani (0902040131)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [14010, "Tsukudani (0902040131)", "Timbal (Pb) (mg/kg)", "=0.2"],
  [14011, "Tuak (14020406)", "Kadar etanol (%)", "=24", "=7"],
  [
    14012,
    "Tuak (14020406)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [14013, "Tuak (14020406)", "Arsen (mg/kg)", "=0.1"],
  [14014, "Tuak (14020406)", "Kadmium (mg/kg)", "=0.2"],
  [14015, "Tuak (14020406)", "Merkuri (mg/kg)", "=0.03"],
  [
    14016,
    "Tuak (14020406)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    14017,
    "Tuak (14020406)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14018, "Tuak (14020406)", "Timbal (mg/kg)", "=0.2"],
  [14019, "Tuna Dalam Kemasan (090402)", "Sensori", "", "=7"],
  [
    14020,
    "Tuna Dalam Kemasan (090402)",
    "Histamin (mg/kg) ",
    "=100",
  ],
  [
    14021,
    "Tuna Dalam Kemasan (090402)",
    "Kadmium (Cd) (mg/kg)",
    "=0.3",
  ],
  [
    14022,
    "Tuna Dalam Kemasan (090402)",
    "Merkuri (Hg) (mg/kg)",
    "=1",
  ],
  [
    14023,
    "Tuna Dalam Kemasan (090402)",
    "Timah putih (Sn) (mg/kg) ",
    "=250",
  ],
  [
    14024,
    "Tuna Dalam Kemasan (090402)",
    "Timbal (Pb) (mg/kg)",
    "=0.4",
  ],
  [
    14025,
    "Tuna Dalam Kemasan (090402)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    14026,
    "Tuna Dalam Kemasan (090402)",
    "Bobot Tuntas (%) ",
    "",
    "=60",
  ],
  [14027, "Tuna Dalam Kemasan (090402)", "Filth"],
  [14028, "Ubi Beku (0402020113)", "Arsen (As) (mg/kg) ", "=0.15"],
  [
    14029,
    "Ubi Beku (0402020113)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14030,
    "Ubi Beku (0402020113)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    14031,
    "Ubi Beku (0402020113)",
    "Timah (Sn) untuk produk yang diolah dengan proses panas dan dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14032,
    "Ubi Beku (0402020113)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14033, "Ubi Beku (0402020113)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [14034, "Udang Beku (09020116)", "Arsen (As) (mg/kg) ", "=0.25"],
  [14035, "Udang Beku (09020116)", "Kadmium (Cd) (mg/kg) ", "=0.1"],
  [14036, "Udang Beku (09020116)", "Merkuri (Hg) (mg/kg) ", "=0.5"],
  [
    14037,
    "Udang Beku (09020116)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [14038, "Udang Beku (09020116)", "Timbal (Pb) (mg/kg) ", "=0.2"],
  [
    14039,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    14040,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    14041,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    14042,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14043,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (0902040209)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    14044,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    14045,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    14046,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    14047,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14048,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14049,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) (Steril) (0902040210)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    14050,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng (0902040211)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    14051,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng (0902040211)",
    "Kadmium (Cd) (mg/kg)",
    "=0.1",
  ],
  [
    14052,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng (0902040211)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    14053,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng (0902040211)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14054,
    "Udang dalam Saus (Tomat, Kari, Pedas, ...) dikemas Kaleng (0902040211)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    14055,
    "Udang Kering (09020508)",
    "Cd (ppm atau mg/kg) ",
    "=0.1",
  ],
  [
    14056,
    "Udang Kering (09020508)",
    "Hg (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    14057,
    "Udang Kering (09020508)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14058,
    "Udang Kering (09020508)",
    "Sn (dalam kaleng) (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14059,
    "Udang Kering (09020508)",
    "Pb (ppm atau mg/kg) ",
    "=0.2",
  ],
  [
    14060,
    "Udang Kering (09020508)",
    "As (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    14061,
    "Udang Kupas Mentah Beku (09020117)",
    "Arsen (As) (mg/kg) ",
    "=0.25",
  ],
  [
    14062,
    "Udang Kupas Mentah Beku (09020117)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.1",
  ],
  [
    14063,
    "Udang Kupas Mentah Beku (09020117)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.5",
  ],
  [
    14064,
    "Udang Kupas Mentah Beku (09020117)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14065,
    "Udang Kupas Mentah Beku (09020117)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    14066,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    14067,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14068,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    14069,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14070,
    "Udang Kupas Rebus Beku untuk Sushi Ebi (0902040204)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14071,
    "Udang Lapis Tepung Beku (09020203)",
    "As (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    14072,
    "Udang Lapis Tepung Beku (09020203)",
    "Cd (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14073,
    "Udang Lapis Tepung Beku (09020203)",
    "Hg (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    14074,
    "Udang Lapis Tepung Beku (09020203)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14075,
    "Udang Lapis Tepung Beku (09020203)",
    "Pb (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14076,
    "Udang Popcorn (0902040309)",
    "Arsen (As) (mg/kg)",
    "=0.25",
  ],
  [
    14077,
    "Udang Popcorn (0902040309)",
    "Kadmium (Cd)(mg/kg)",
    "=0.1",
  ],
  [
    14078,
    "Udang Popcorn (0902040309)",
    "Merkuri (Hg) (mg/kg)",
    "=0.5",
  ],
  [
    14079,
    "Udang Popcorn (0902040309)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14080,
    "Udang Popcorn (0902040309)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    14081,
    "Udang Popcorn (0902040309)",
    "Timbal (Pb) (mg/kg)",
    "=0.2",
  ],
  [
    14082,
    "Urutan (0803010115)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.25",
  ],
  [
    14083,
    "Urutan (0803010115)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14084,
    "Urutan (0803010115)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    14085,
    "Urutan (0803010115)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14086,
    "Urutan (0803010115)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14087,
    "Urutan (0803010115)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.5",
  ],
  [
    14088,
    "Urutan (0803010301)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    14089,
    "Urutan (0803010301)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    14090,
    "Urutan (0803010301)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    14091,
    "Urutan (0803010301)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14092,
    "Urutan (0803010301)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14093,
    "Urutan (0803010301)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    14094,
    "Usus Ayam Goreng (08020224)",
    "Arsen (As) (ppm atau mg/kg) ",
    "=0.25",
  ],
  [
    14095,
    "Usus Ayam Goreng (08020224)",
    "Kadmium (Cd) (ppm atau mg/kg) ",
    "=0.05",
  ],
  [
    14096,
    "Usus Ayam Goreng (08020224)",
    "Merkuri (Hg) (ppm atau mg/kg) ",
    "=0.03",
  ],
  [
    14097,
    "Usus Ayam Goreng (08020224)",
    "Timah (Sn) dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14098,
    "Usus Ayam Goreng (08020224)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14099,
    "Usus Ayam Goreng (08020224)",
    "Timbal (Pb) (ppm atau mg/kg) ",
    "=0.5",
  ],
  [
    14100,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Kadar lemak nabati (%)",
    "",
    "=97",
  ],
  [
    14101,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Titik leleh/lebur (\xB0C)",
    "=48",
    "=30",
  ],
  [
    14102,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Kadar air (%)",
    "=0.25",
  ],
  [
    14103,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Kadar bahan tak tersabunkan (g/kg)",
    "=12.5",
  ],
  [
    14104,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Kadar asam lemak bebas (sebagai asam oleat) (%)",
    "=0.5",
  ],
  [
    14105,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14106,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14107,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14108,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14109,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14110,
    "Vanaspati atau Minyak Samin (Vegetable Ghee) (02010208)",
    "Timbal (Pb) (mg/kg)",
    "=0.1",
  ],
  [
    14111,
    "Vegetable Kasu-zuke (0402020314)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14112,
    "Vegetable Kasu-zuke (0402020314)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14113,
    "Vegetable Kasu-zuke (0402020314)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14114,
    "Vegetable Kasu-zuke (0402020314)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14115,
    "Vegetable Kasu-zuke (0402020314)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14116,
    "Vegetable Kasu-zuke (0402020314)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14117,
    "Vegetable Koji-zuke (0402020313)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14118,
    "Vegetable Koji-zuke (0402020313)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14119,
    "Vegetable Koji-zuke (0402020313)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14120,
    "Vegetable Koji-zuke (0402020313)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14121,
    "Vegetable Koji-zuke (0402020313)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14122,
    "Vegetable Koji-zuke (0402020313)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14123,
    "Vegetable Miso-zuke (0402020315)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14124,
    "Vegetable Miso-zuke (0402020315)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14125,
    "Vegetable Miso-zuke (0402020315)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14126,
    "Vegetable Miso-zuke (0402020315)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14127,
    "Vegetable Miso-zuke (0402020315)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14128,
    "Vegetable Miso-zuke (0402020315)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14129,
    "Vegetable Shio-zuke (0402020318)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14130,
    "Vegetable Shio-zuke (0402020318)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14131,
    "Vegetable Shio-zuke (0402020318)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14132,
    "Vegetable Shio-zuke (0402020318)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14133,
    "Vegetable Shio-zuke (0402020318)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14134,
    "Vegetable Shio-zuke (0402020318)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14135,
    "Vegetable Shoyu-zuke (0402020316)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14136,
    "Vegetable Shoyu-zuke (0402020316)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14137,
    "Vegetable Shoyu-zuke (0402020316)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14138,
    "Vegetable Shoyu-zuke (0402020316)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14139,
    "Vegetable Shoyu-zuke (0402020316)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14140,
    "Vegetable Shoyu-zuke (0402020316)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14141,
    "Vegetable Su-zuke (0402020317)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14142,
    "Vegetable Su-zuke (0402020317)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14143,
    "Vegetable Su-zuke (0402020317)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14144,
    "Vegetable Su-zuke (0402020317)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14145,
    "Vegetable Su-zuke (0402020317)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14146,
    "Vegetable Su-zuke (0402020317)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14147,
    "Vegetable Tsukudani (0402020807)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14148,
    "Vegetable Tsukudani (0402020807)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14149,
    "Vegetable Tsukudani (0402020807)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14150,
    "Vegetable Tsukudani (0402020807)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14151,
    "Vegetable Tsukudani (0402020807)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14152,
    "Virgin Oil (02010202)",
    "Bilangan peroksida (mek O2/kg)",
    "=10",
  ],
  [
    14153,
    "Virgin Oil (02010202)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14154,
    "Virgin Oil (02010202)",
    "Cadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14155,
    "Virgin Oil (02010202)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14156,
    "Virgin Oil (02010202)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14157,
    "Virgin Oil (02010202)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14158, "Virgin Oil (02010202)", "Timbal (Pb) (mg/kg)", "=0.1"],
  [
    14159,
    "Virgin olive oil (02010239)",
    "Kadar asam lemak bebas sebagai asam oleat (gram per 100 gram)",
    "=2",
  ],
  [
    14160,
    "Virgin olive oil (02010239)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14161,
    "Virgin olive oil (02010239)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14162,
    "Virgin olive oil (02010239)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14163,
    "Virgin olive oil (02010239)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14164,
    "Virgin olive oil (02010239)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14165,
    "Virgin olive oil (02010239)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.1",
  ],
  [14166, "Vodka (14020608)", "Kadar etanol (%)", "", "=37.5"],
  [
    14167,
    "Vodka (14020608)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [14168, "Vodka (14020608)", "Arsen (mg/kg)", "=0.1"],
  [14169, "Vodka (14020608)", "Kadmium (mg/kg)", "=0.2"],
  [14170, "Vodka (14020608)", "Merkuri (mg/kg)", "=0.03"],
  [
    14171,
    "Vodka (14020608)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    14172,
    "Vodka (14020608)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14173, "Vodka (14020608)", "Timbal (mg/kg)", "=0.2"],
  [14174, "Wafel (07020211)", "Arsen (As) (mg/kg) ", "=0.5"],
  [14175, "Wafel (07020211)", "Kadmium (Cd) (mg/kg) ", "=0.2"],
  [14176, "Wafel (07020211)", "Merkuri (Hg) (mg/kg) ", "=0.05"],
  [
    14177,
    "Wafel (07020211)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [14178, "Wafel (07020211)", "Timbal (Pb) (mg/kg) ", "=0.5"],
  [14179, "Wafer (07020112)", "Kadar Air (%)", "=5"],
  [14180, "Wafer (07020112)", "Arsen (As) (mg/kg)", "=0.5"],
  [14181, "Wafer (07020112)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [14182, "Wafer (07020112)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [14183, "Wafer (07020112)", "Timah (Sn) (mg/kg)", "=40"],
  [14184, "Wafer (07020112)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    14185,
    "Wafer Roll / Wafer Stick (07020113)",
    "Arsen (As) (mg/kg)",
    "=0.5",
  ],
  [
    14186,
    "Wafer Roll / Wafer Stick (07020113)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    14187,
    "Wafer Roll / Wafer Stick (07020113)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [
    14188,
    "Wafer Roll / Wafer Stick (07020113)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    14189,
    "Wafer Roll / Wafer Stick (07020113)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [14190, "Wafer Salut (07020114)", "Arsen (As) (mg/kg)", "=0.5"],
  [14191, "Wafer Salut (07020114)", "Kadmium (Cd) (mg/kg)", "=0.2"],
  [14192, "Wafer Salut (07020114)", "Raksa (Hg) (mg/kg)", "=0.05"],
  [14193, "Wafer Salut (07020114)", "Timah (Sn) (mg/kg)", "=40"],
  [14194, "Wafer Salut (07020114)", "Timbal (Pb) (mg/kg)", "=0.5"],
  [
    14195,
    "Wajit Buah (0401021209)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    14196,
    "Wajit Buah (0401021209)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14197,
    "Wajit Buah (0401021209)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    14198,
    "Wajit Buah (0401021209)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14199,
    "Wajit Buah (0401021209)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14200,
    "Wajit Buah (0401021209)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    14201,
    "Wakame (0402020222)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.15",
  ],
  [
    14202,
    "Wakame (0402020222)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [14203, "Wakame (0402020222)", "Merkuri (Hg) (mg/kg)", "=0.03"],
  [
    14204,
    "Wakame (0402020222)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14205,
    "Wakame (0402020222)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.2",
  ],
  [14206, "Wasabi (120201A8)", "Arsen (As) (mg/kg)", "=0.15"],
  [14207, "Wasabi (120201A8)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [14208, "Wasabi (120201A8)", "Merkuri (Hg) (mg/kg)", "=0.05"],
  [
    14209,
    "Wasabi (120201A8)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14210,
    "Wasabi (120201A8)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14211,
    "Wasabi (120201A8)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    14212,
    "Wasabi (120201A8)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [14213, "Water Biscuit (07010205)", "Arsen (As) (mg/kg)", "=0.5"],
  [
    14214,
    "Water Biscuit (07010205)",
    "Kadmium (Cd) (mg/kg)",
    "=0.2",
  ],
  [
    14215,
    "Water Biscuit (07010205)",
    "Raksa (Hg) (mg/kg)",
    "=0.05",
  ],
  [14216, "Water Biscuit (07010205)", "Timah (Sn) (mg/kg)", "=40"],
  [
    14217,
    "Water Biscuit (07010205)",
    "Timbal (Pb) (mg/kg)",
    "=0.5",
  ],
  [
    14218,
    "Water Ices (0301)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.2",
  ],
  [
    14219,
    "Water Ices (0301)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.01",
  ],
  [
    14220,
    "Water Ices (0301)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.03",
  ],
  [
    14221,
    "Water Ices (0301)",
    "Timah (Sn) (ppm atau mg/kg)",
    "=40",
  ],
  [
    14222,
    "Water Ices (0301)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.15",
  ],
  [14223, "Whey (01080101)", "Arsen (As) (mg/kg) ", "=0.1"],
  [14224, "Whey (01080101)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [14225, "Whey (01080101)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    14226,
    "Whey (01080101)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14227,
    "Whey (01080101)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14228,
    "Whey (01080101)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    14229,
    "Whey (01080101)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [14230, "Whey Asam (01080102)", "Arsen (As) (mg/kg) ", "=0.1"],
  [14231, "Whey Asam (01080102)", "Kadmium (Cd) (mg/kg)", "=0.05"],
  [14232, "Whey Asam (01080102)", "Merkuri (Hg) (mg/kg) ", "=0.02"],
  [
    14233,
    "Whey Asam (01080102)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14234,
    "Whey Asam (01080102)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [14235, "Whey Asam (01080102)", "Timbal (Pb) (mg/kg)", "=0.02"],
  [
    14236,
    "Whey Asam (01080102)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    14237,
    "Whipped Cream (01040201)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    14238,
    "Whipped Cream (01040201)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14239,
    "Whipped Cream (01040201)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    14240,
    "Whipped Cream (01040201)",
    "Timah (Sn) pangan olahan dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14241,
    "Whipped Cream (01040201)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg) ",
    "=40",
  ],
  [
    14242,
    "Whipped Cream (01040201)",
    "Timbal (Pb) (mg/kg) ",
    "=0.02",
  ],
  [
    14243,
    "Whipped Cream (01040201)",
    "Kadar Lemak Susu (%)",
    "",
    "=10",
  ],
  [
    14244,
    "Whipped Cream (01040201)",
    "Aflatoksin M1 (ppb atau mcg/kg)",
    "=0.5",
  ],
  [
    14245,
    "Whipping Cream (01040205)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14246,
    "Whipping Cream (01040205)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    14247,
    "Whipping Cream (01040205)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14248,
    "Whipping Cream (01040205)",
    "Timah (Sn) Pangan Olahan yang Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14249,
    "Whipping Cream (01040205)",
    "Timah (Sn) Pangan Olahan yang Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    14250,
    "Whipping Cream (01040205)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14251,
    "Whipping Cream (01040205)",
    "Kadar Lemak Susu (%)",
    "",
    "=10",
  ],
  [
    14252,
    "Whipping Cream (01040205)",
    "Aflatoksin M1 (ppb atau \x{3BC}g/kg)",
    "=0.5",
  ],
  [14253, "Whisky (14020606)", "Kadar etanol (% v/v)", "", "=40"],
  [
    14254,
    "Whisky (14020606)",
    "Kadar metanol dihitung terhadap volume produk (% v/v)",
    "=0.01",
  ],
  [14255, "Whisky (14020606)", "Arsen (mg/kg)", "=0.1"],
  [14256, "Whisky (14020606)", "Kadmium (mg/kg)", "=0.2"],
  [14257, "Whisky (14020606)", "Merkuri (mg/kg)", "=0.03"],
  [
    14258,
    "Whisky (14020606)",
    "Timah, minuman dalam kemasan kaleng (mg/kg)",
    "=100",
  ],
  [
    14259,
    "Whisky (14020606)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14260, "Whisky (14020606)", "Timbal (mg/kg)", "=0.2"],
  [
    14261,
    "Whisky (14020606)",
    "Lama proses pematangan dalam tong kayu (tahun)",
    "",
    "=2",
  ],
  [
    14262,
    "Whole Maize (Corn) Meal (060306)",
    "Kadar Air (%)",
    "=15",
  ],
  [
    14263,
    "Whole Maize (Corn) Meal (060306)",
    "Kehalusan - lolos ayakan 10 mesh (%)",
    "",
    "=95",
  ],
  [
    14264,
    "Whole Maize (Corn) Meal (060306)",
    "Kehalusan - lolos ayakan 24 mesh (%)",
    "",
    "=45",
  ],
  [
    14265,
    "Whole Maize (Corn) Meal (060306)",
    "Kehalusan - lolos ayakan 65 mesh (%)",
    "",
    "=35",
  ],
  [
    14266,
    "Whole Maize (Corn) Meal (060306)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    14267,
    "Whole Maize (Corn) Meal (060306)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14268,
    "Whole Maize (Corn) Meal (060306)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    14269,
    "Whole Maize (Corn) Meal (060306)",
    "Timah (Sn) (mg/kg)",
    "=40",
  ],
  [
    14270,
    "Whole Maize (Corn) Meal (060306)",
    "Timbal (Pb) (mg/kg) ",
    "=0.25",
  ],
  [
    14271,
    "Whole Maize (Corn) Meal (060306)",
    "Aflatoksin B1 (mcg/kg)",
    "=15",
  ],
  [
    14272,
    "Whole Maize (Corn) Meal (060306)",
    "Aflatoksin Total (mcg/kg)",
    "=20",
  ],
  [14273, "Wijen (120201A9)", "Arsen (As) (mg/kg)", "=0.15"],
  [14274, "Wijen (120201A9)", "Kadmium (Cd) (mg/kg)", "=0.5"],
  [14275, "Wijen (120201A9)", "Merkuri (Hg) (mg/kg", "=0.05"],
  [
    14276,
    "Wijen (120201A9)",
    "Timah (Sn) pangan olahan yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14277,
    "Wijen (120201A9)",
    "Timah (Sn) yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [14278, "Wijen (120201A9)", "Timbal (Pb) (mg/kg)", "=1"],
  [
    14279,
    "Wijen (120201A9)",
    "Aflatoksin B1 (ppb atau mcg/kg)",
    "=15",
  ],
  [
    14280,
    "Wijen (120201A9)",
    "Aflatoksin Total (ppb atau mcg/kg)",
    "=20",
  ],
  [
    14281,
    "Wortel Beku (0402020107)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    14282,
    "Wortel Beku (0402020107)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14283,
    "Wortel Beku (0402020107)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.03",
  ],
  [
    14284,
    "Wortel Beku (0402020107)",
    "Timah (Sn) dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14285,
    "Wortel Beku (0402020107)",
    "Timah (Sn) tidak dikemas dalam kaleng (mg/kg)",
    "=40",
  ],
  [
    14286,
    "Wortel Beku (0402020107)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    14287,
    "Wortel Dalam Kemasan (0402020406)",
    "Arsen (As) (mg/kg) ",
    "=0.15",
  ],
  [
    14288,
    "Wortel Dalam Kemasan (0402020406)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14289,
    "Wortel Dalam Kemasan (0402020406)",
    "Merkuri (Hg) (mg/kg)",
    "=0.03",
  ],
  [
    14290,
    "Wortel Dalam Kemasan (0402020406)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (mg/kg)",
    "=250",
  ],
  [
    14291,
    "Wortel Dalam Kemasan (0402020406)",
    "Timbal (Pb) (mg/kg) ",
    "=0.2",
  ],
  [
    14292,
    "Yogurt (010201A6)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=7.8",
  ],
  [14293, "Yogurt (010201A6)", "Kadar asam laktat (%)", "", "=0.5"],
  [
    14294,
    "Yogurt (010201A6)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14295,
    "Yogurt (010201A6)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    14296,
    "Yogurt (010201A6)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14297,
    "Yogurt (010201A6)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    14298,
    "Yogurt (010201A6)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    14299,
    "Yogurt (010201A6)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [14300, "Yogurt (010201A6)", "Aflatoksin M1 (ppb)", "=0.5"],
  [
    14301,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14302,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    14303,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14304,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14305,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    14306,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14307,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    14308,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    14309,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14310,
    "Yogurt (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010205)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    14311,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14312,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    14313,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14314,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14315,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    14316,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14317,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    14318,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    14319,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14320,
    "Yogurt (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010105)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    14321,
    "Yogurt Berperisa/Rasa (010702)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=4.6",
  ],
  [
    14322,
    "Yogurt Berperisa/Rasa (010702)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14323,
    "Yogurt Berperisa/Rasa (010702)",
    "Arsen (As) (mg/kg) ",
    "=0.1",
  ],
  [
    14324,
    "Yogurt Berperisa/Rasa (010702)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14325,
    "Yogurt Berperisa/Rasa (010702)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Tidak Dikemas dalam Kaleng ",
    "=40",
  ],
  [
    14326,
    "Yogurt Berperisa/Rasa (010702)",
    "Timah (Sn) (mg/kg) Pangan Olahan Lain yang Dikemas dalam Kaleng ",
    "=250",
  ],
  [
    14327,
    "Yogurt Berperisa/Rasa (010702)",
    "Merkuri (Hg) (mg/kg) ",
    "=0.02",
  ],
  [
    14328,
    "Yogurt Berperisa/Rasa (010702)",
    "Kadmium (Cd) (mg/kg) ",
    "=0.05",
  ],
  [
    14329,
    "Yogurt Berperisa/Rasa (010702)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    14330,
    "Yogurt Berperisa/Rasa (010702)",
    "Kadar protein susu (%)",
    "",
    "=1.6",
  ],
  [
    14331,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Total padatan bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    14332,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14333,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Arsen (As) (ppm atau mg/kg) - siap konsumsi",
    "=0.1",
  ],
  [
    14334,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Kadmium (Cd) (ppm atau mg/kg) - siap konsumsi",
    "=0.05",
  ],
  [
    14335,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Merkuri (Hg) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    14336,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Timah (Sn) untuk produk yang dikemas dalam kaleng (ppm atau mg/kg)",
    "=250",
  ],
  [
    14337,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Timah (Sn) untuk produk yang tidak dikemas dalam kaleng (ppm atau mg/kg)",
    "=40",
  ],
  [
    14338,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Timbal (Pb) (ppm atau mg/kg) - siap konsumsi",
    "=0.02",
  ],
  [
    14339,
    "Yogurt Berperisa/Rasa Bubuk (010716)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    14340,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    14341,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14342,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Arsen (As) (ppm atau mg/kg)",
    "=0.1",
  ],
  [
    14343,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Merkuri (Hg) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    14344,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Kadmium (Cd) (ppm atau mg/kg)",
    "=0.05",
  ],
  [
    14345,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Timbal (Pb) (ppm atau mg/kg)",
    "=0.02",
  ],
  [
    14346,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg)",
    "=100",
  ],
  [
    14347,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    14348,
    "Yogurt kultur lain (alternate culture yoghurt) (010201B3)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    14349,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14350,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    14351,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14352,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14353,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    14354,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14355,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    14356,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    14357,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14358,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Dengan Pemanasan Setelah Difermentasi) (0102010206)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
  [
    14359,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14360,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Kadmium (Cd)(mg/kg)",
    "=0.05",
  ],
  [
    14361,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14362,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14363,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg) ",
    "=40",
  ],
  [
    14364,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14365,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Total padatan susu bukan lemak (%)",
    "",
    "=6.6",
  ],
  [
    14366,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Kadar protein susu (%)",
    "",
    "=2.3",
  ],
  [
    14367,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14368,
    "Yogurt Kultur Lain (Alternate Culture Yogurt) (Plain) (Tanpa Pemanasan Setelah Difermentasi) (0102010106)",
    "Aflatoksin M1 (mcg/kg)",
    "=0.5",
  ],
  [
    14369,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Arsen (As) (mg/kg)",
    "=0.1",
  ],
  [
    14370,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Kadmium (Cd) (mg/kg)",
    "=0.05",
  ],
  [
    14371,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Merkuri (Hg) (mg/kg)",
    "=0.02",
  ],
  [
    14372,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Timah (Sn) Dikemas dalam Kaleng (mg/kg)",
    "=250",
  ],
  [
    14373,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Timah (Sn) Tidak Dikemas dalam Kaleng (mg/kg)",
    "=40",
  ],
  [
    14374,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Timbal (Pb) (mg/kg)",
    "=0.02",
  ],
  [
    14375,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=4.6",
  ],
  [
    14376,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Kadar Protein Susu (%)",
    "",
    "= 1.6",
  ],
  [
    14377,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Kadar Asam Laktat (%)",
    "",
    "=0.5",
  ],
  [
    14378,
    "Yogurt Kultur Lain Berperisa/Rasa (alternate culture yogurt) (010723)",
    "Aflatoksin M1 (ppb atau \xB5g/kg)",
    "=0.5",
  ],
  [
    14379,
    "Yogurt Plain Bubuk (010201B1)",
    "Total padatan susu bukan-lemak (%)",
    "",
    "=7.8",
  ],
  [
    14380,
    "Yogurt Plain Bubuk (010201B1)",
    "Kadar asam laktat (%)",
    "",
    "=0.5",
  ],
  [
    14381,
    "Yogurt Plain Bubuk (010201B1)",
    "Arsen (As) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.1",
  ],
  [
    14382,
    "Yogurt Plain Bubuk (010201B1)",
    "Merkuri (Hg) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    14383,
    "Yogurt Plain Bubuk (010201B1)",
    "Kadmium (Cd) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.05",
  ],
  [
    14384,
    "Yogurt Plain Bubuk (010201B1)",
    "Timbal (Pb) (ppm atau mg/kg) - dihitung terhadap produk siap konsumsi",
    "=0.02",
  ],
  [
    14385,
    "Yogurt Plain Bubuk (010201B1)",
    "Timah (Sn) dikemas dalam kaleng (ppm atau mg/kg) ",
    "=250",
  ],
  [
    14386,
    "Yogurt Plain Bubuk (010201B1)",
    "Timah (Sn) tidak dikemas dalam kaleng (ppm mg/kg) ",
    "=40",
  ],
  [
    14387,
    "Yogurt Plain Bubuk (010201B1)",
    "Aflatoksin M1 (ppb)",
    "=0.5",
  ],
];
# END FRAGMENT id=data-idn_bpom_karakteristik_dasar_dan_cemaran_logam_pangan

1;
# ABSTRACT: Table data for App-BPOMUtils

__END__

=pod

=encoding UTF-8

=head1 NAME

App::BPOMUtils::Table - Table data for App-BPOMUtils

=head1 VERSION

This document describes version 0.014 of App::BPOMUtils::Table (from Perl distribution App-BPOMUtils), released on 2022-11-10.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-BPOMUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-BPOMUtils>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-BPOMUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
